@@ -1,10 +1,11 @@
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2004, 2005 Ulf Lorenz
 // Copyright (C) 2006 Andrea Paternesi
+// Copyright (C) 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,6 +21,7 @@
 #ifndef AI_ANALYSIS_H
 #define AI_ANALYSIS_H
 
+#include <gtkmm.h>
 #include <string>
 #include <map>
 #include "vector.h"
@@ -62,6 +64,8 @@ class AI_Analysis
           */
         static void deleteStack(Stack* s);
 
+	static void deleteStack(guint32 id);
+
         // guess the strength of the given stack. Note: next to useless outside
         // of computer turn.
         static float assessStackStrength(const Stack *stack);
