@@ -7,7 +7,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -31,6 +31,7 @@
 #include "string_tokenizer.h"
 #include "xmlhelper.h"
 #include "defs.h"
+#include "File.h"
 
 using namespace std;
 
@@ -53,15 +54,13 @@ string Configuration::s_lang = "";
 int Configuration::s_displaySpeedDelay = 0;
 int Configuration::s_displayFightRoundDelayFast = 250;
 int Configuration::s_displayFightRoundDelaySlow = 500;
-Uint32 Configuration::s_surfaceFlags = SDL_SWSURFACE;
-Uint32 Configuration::s_cacheSize = 1000000;
+guint32 Configuration::s_cacheSize = 1000000;
 bool Configuration::s_zipfiles = false;
 int Configuration::s_autosave_policy = 1;
-bool Configuration::s_hardware = false;
 bool Configuration::s_ggz = false;
 bool Configuration::s_musicenable = true;
-Uint32 Configuration::s_musicvolume = 64;
-Uint32 Configuration::s_musiccache = 10000000;
+guint32 Configuration::s_musicvolume = 64;
+guint32 Configuration::s_musiccache = 10000000;
 string Configuration::s_filename = "";
 bool Configuration::s_see_opponents_stacks = false;
 bool Configuration::s_see_opponents_production = false;
@@ -77,6 +76,7 @@ bool Configuration::s_quick_start = false;
 bool Configuration::s_cusp_of_war = false;
 bool Configuration::s_decorated = true;
 bool Configuration::s_remember_recent_games = true;
+guint32 Configuration::s_double_click_threshold = 400; //milliseconds
 
 Configuration::Configuration()
 {
@@ -127,9 +127,9 @@ bool Configuration::saveConfigurationFile(string filename)
     retval &= helper.saveData("savepath", s_savePath);
     retval &= helper.saveData("lang", s_lang);
     retval &= helper.saveData("cachesize", s_cacheSize);
-    retval &= helper.saveData("hardware", s_hardware);
     retval &= helper.saveData("zipfiles", s_zipfiles);
-    retval &= helper.saveData("autosave_policy", s_autosave_policy);
+    std::string autosave_policy_str = savingPolicyToString(SavingPolicy(s_autosave_policy));
+    retval &= helper.saveData("autosave_policy", autosave_policy_str);
     retval &= helper.saveData("speeddelay", s_displaySpeedDelay);
     retval &= helper.saveData("fightrounddelayfast", s_displayFightRoundDelayFast);
     retval &= helper.saveData("fightrounddelayslow", s_displayFightRoundDelaySlow);
@@ -153,6 +153,8 @@ bool Configuration::saveConfigurationFile(string filename)
     retval &= helper.saveData("cusp_of_war", s_cusp_of_war);
     retval &= helper.saveData("decorated", s_decorated);
     retval &= helper.saveData("remember_recent_games", s_remember_recent_games);
+    retval &= helper.saveData("double_click_threshold", 
+			      s_double_click_threshold);
     retval &= helper.closeTag();
     
     if (!retval)
@@ -175,7 +177,6 @@ bool Configuration::parseConfiguration(string tag, XML_Helper* helper)
     
     string temp;
     bool retval,zipping;
-    int autosave_policy;
     
     if (helper->getVersion() != LORDSAWAR_CONFIG_VERSION)
     {
@@ -230,31 +231,15 @@ bool Configuration::parseConfiguration(string tag, XML_Helper* helper)
     if (retval)
         s_cacheSize = atoi(temp.c_str());
 
-    //parse surface flags
-    retval = helper->getData(s_hardware, "hardware");
-    if (retval)
-    {
-        if (s_hardware)
-        {
-            s_surfaceFlags &= ~(SDL_SWSURFACE);
-            s_surfaceFlags |= SDL_HWSURFACE;
-        }
-        else
-        {
-            s_surfaceFlags &= ~(SDL_HWSURFACE);
-            s_surfaceFlags |= SDL_SWSURFACE;
-        }
-    }
-
     //parse if savefiles should be zipped
     retval = helper->getData(zipping, "zipfiles");
     if (retval)
         s_zipfiles = zipping;
 
     //parse when and how to save autosave files
-    retval = helper->getData(autosave_policy, "autosave_policy");
-    if (retval)
-        s_autosave_policy = autosave_policy;
+    std::string autosave_policy_str;
+    helper->getData(autosave_policy_str, "autosave_policy");
+    s_autosave_policy = savingPolicyFromString(autosave_policy_str);
 
     //parse the speed delays
     helper->getData(s_displaySpeedDelay, "speeddelay");
@@ -287,6 +272,7 @@ bool Configuration::parseConfiguration(string tag, XML_Helper* helper)
     helper->getData(s_cusp_of_war, "cusp_of_war");
     helper->getData(s_decorated, "decorated");
     helper->getData(s_remember_recent_games, "remember_recent_games");
+    helper->getData(s_double_click_threshold, "double_click_threshold");
     return true;
 }
 
@@ -308,23 +294,58 @@ void initialize_configuration()
 	    std::cerr << "Created the standard configuration file " << Configuration::configuration_file_path << std::endl;
     }
     
-#ifndef __WIN32__
     //Check if the save game directory exists. If not, try to create it.
-    struct stat testdir;
 
-    if (stat(Configuration::s_savePath.c_str(), &testdir)
-        || !S_ISDIR(testdir.st_mode))
+    if (File::create_dir(Configuration::s_savePath) == false)
     {
-        Uint32 mask = 0755; //make directory only readable for user and group
-        if (mkdir(Configuration::s_savePath.c_str(), mask))
-        {
-            std::cerr << "Couldn't create save game directory ";
-            std::cerr << Configuration::s_savePath <<".\n";
-            std::cerr << "Check permissions and the entries in your lordsawarrc file!" << std::endl;
-            exit(-1);
-        }
+        std::cerr << "Couldn't create save game directory ";
+        std::cerr << Configuration::s_savePath <<".\n";
+        std::cerr << "Check permissions and the entries in your lordsawarrc file!" << std::endl;
+        exit(-1);
+    }
+    //Check if the personal armyset directory exists. If not, try to create it.
+    if (File::create_dir(File::getUserArmysetDir()) == false)
+    {
+        std::cerr << "Couldn't create personal armyset directory ";
+        std::cerr << File::getUserArmysetDir() <<".\n";
+        std::cerr << "Check permissions and the entries in your lordsawarrc file!" << std::endl;
+        exit(-1);
+    }
+    //Check if the personal tileset directory exists. If not, try to create it.
+    if (File::create_dir(File::getUserTilesetDir()) == false)
+    {
+        std::cerr << "Couldn't create personal tileset directory ";
+        std::cerr << File::getUserTilesetDir() <<".\n";
+        std::cerr << "Check permissions and the entries in your lordsawarrc file!" << std::endl;
+        exit(-1);
+    }
+
+    //Check if the personal maps directory exists. If not, try to create it.
+    if (File::create_dir(File::getUserMapDir()) == false)
+    {
+        std::cerr << "Couldn't create personal map directory ";
+        std::cerr << File::getUserMapDir() <<".\n";
+        std::cerr << "Check permissions and the entries in your lordsawarrc file!" << std::endl;
+        exit(-1);
+    }
+
+    //Check if the personal shieldset directory exists. If not, try to make it.
+    if (File::create_dir(File::getUserShieldsetDir()) == false)
+    {
+        std::cerr << "Couldn't create personal shieldset directory ";
+        std::cerr << File::getUserShieldsetDir() <<".\n";
+        std::cerr << "Check permissions and the entries in your lordsawarrc file!" << std::endl;
+        exit(-1);
+    }
+
+    //Check if the personal cityset directory exists. If not, try to make it.
+    if (File::create_dir(File::getUserCitysetDir()) == false)
+    {
+        std::cerr << "Couldn't create personal cityset directory ";
+        std::cerr << File::getUserCitysetDir() <<".\n";
+        std::cerr << "Check permissions and the entries in your lordsawarrc file!" << std::endl;
+        exit(-1);
     }
-#endif
 }
 
 std::string Configuration::neutralCitiesToString(const GameParameters::NeutralCities neutrals)
@@ -340,6 +361,9 @@ std::string Configuration::neutralCitiesToString(const GameParameters::NeutralCi
       case GameParameters::ACTIVE:
 	return "GameParameters::ACTIVE";
 	break;
+      case GameParameters::DEFENSIVE:
+	return "GameParameters::DEFENSIVE";
+	break;
     }
   return "GameParameters::AVERAGE";
 }
@@ -354,6 +378,8 @@ GameParameters::NeutralCities Configuration::neutralCitiesFromString(std::string
     return GameParameters::STRONG;
   else if (str == "GameParameters::ACTIVE")
     return GameParameters::ACTIVE;
+  else if (str == "GameParameters::DEFENSIVE")
+    return GameParameters::DEFENSIVE;
     
   return GameParameters::AVERAGE;
 }
@@ -388,3 +414,34 @@ GameParameters::RazingCities Configuration::razingCitiesFromString(std::string s
     
   return GameParameters::ALWAYS;
 }
+
+std::string Configuration::savingPolicyToString(const Configuration::SavingPolicy policy)
+{
+  switch (policy)
+    {
+    case Configuration::NO_SAVING:
+      return "Configuration::NO_SAVING";
+      break;
+    case Configuration::WRITE_UNNUMBERED_AUTOSAVE_FILE:
+      return "Configuration::WRITE_UNNUMBERED_AUTOSAVE_FILE";
+      break;
+    case Configuration::WRITE_NUMBERED_AUTOSAVE_FILE:
+      return "Configuration::WRITE_NUMBERED_AUTOSAVE_FILE";
+      break;
+    }
+  return "Configuration::NO_SAVING";
+}
+
+Configuration::SavingPolicy Configuration::savingPolicyFromString(std::string str)
+{
+  if (str.size() > 0 && isdigit(str.c_str()[0]))
+    return Configuration::SavingPolicy(atoi(str.c_str()));
+  if (str == "Configuration::NO_SAVING")
+    return Configuration::NO_SAVING;
+  else if (str == "Configuration::WRITE_UNNUMBERED_AUTOSAVE_FILE")
+    return Configuration::WRITE_UNNUMBERED_AUTOSAVE_FILE;
+  else if (str == "Configuration::WRITE_NUMBERED_AUTOSAVE_FILE")
+    return Configuration::WRITE_NUMBERED_AUTOSAVE_FILE;
+    
+  return Configuration::WRITE_NUMBERED_AUTOSAVE_FILE;
+}
