@@ -7,7 +7,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -23,8 +23,8 @@
 #ifndef CONFIGURATION_H
 #define CONFIGURATION_H
 
+#include <gtkmm.h>
 #include <string>
-#include <SDL_types.h>
 #include <sigc++/trackable.h>
 
 class XML_Helper;
@@ -81,12 +81,8 @@ class Configuration : public sigc::trackable
         // Language setting
         static std::string s_lang;
 
-        // if using hardware surfaces for pixmaps or not
-        static Uint32 s_surfaceFlags;
-        static bool s_hardware;
-
         //the maximum size of the graphics cache
-        static Uint32 s_cacheSize;
+        static guint32 s_cacheSize;
 
         //zip and obfuscate save files
         static bool s_zipfiles;
@@ -101,8 +97,8 @@ class Configuration : public sigc::trackable
 
         // music settings; the cache size is given in pieces instead of memory
         static bool s_musicenable;
-        static Uint32 s_musicvolume;
-        static Uint32 s_musiccache;
+        static guint32 s_musicvolume;
+        static guint32 s_musiccache;
 
 	// various default game settings
         static bool s_see_opponents_stacks;
@@ -119,12 +115,19 @@ class Configuration : public sigc::trackable
         static bool s_cusp_of_war;
         static bool s_decorated;
         static bool s_remember_recent_games;
+	static guint32 s_double_click_threshold;
 
 	static GameParameters::NeutralCities neutralCitiesFromString(const std::string str);
 	static std::string neutralCitiesToString(const GameParameters::NeutralCities neutrals);
 	static GameParameters::RazingCities razingCitiesFromString(const std::string str);
 	static std::string razingCitiesToString(const GameParameters::RazingCities razing);
-	//autos
+        enum SavingPolicy {
+	  NO_SAVING = 0,
+	  WRITE_UNNUMBERED_AUTOSAVE_FILE = 1,
+	  WRITE_NUMBERED_AUTOSAVE_FILE = 2,
+	};
+	static Configuration::SavingPolicy savingPolicyFromString(const std::string str);
+	static std::string savingPolicyToString(const Configuration::SavingPolicy policy);
     private:
         /** \brief The callback for the XML_Helper
           * 
