@@ -2,12 +2,12 @@
 // Copyright (C) 2003 Michael Bartl
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2004, 2005, 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -32,14 +32,21 @@
 #include "playerlist.h"
 #include "stacklist.h"
 #include "citylist.h"
+#include "city.h"
 #include "ruinlist.h"
+#include "ruin.h"
 #include "rewardlist.h"
 #include "Itemlist.h"
 #include "templelist.h"
+#include "temple.h"
 #include "signpostlist.h"
+#include "signpost.h"
 #include "portlist.h"
+#include "port.h"
 #include "bridgelist.h"
+#include "bridge.h"
 #include "roadlist.h"
+#include "road.h"
 #include "armysetlist.h"
 
 #include "real_player.h"
@@ -229,8 +236,8 @@ void CreateScenario::setHeight(int height)
     GameMap::setHeight(height);
 }
 
-Player* CreateScenario::addPlayer(std::string name, Uint32 armyset,
-                                SDL_Color color, int type)
+Player* CreateScenario::addPlayer(std::string name, guint32 armyset,
+                                Gdk::Color color, int type)
 {
     debug("CreateScenario::addPlayer")
 
@@ -241,8 +248,8 @@ Player* CreateScenario::addPlayer(std::string name, Uint32 armyset,
     return p;
 }
 
-bool CreateScenario::addNeutral(std::string name, Uint32 armyset,
-                                SDL_Color color, int type)
+bool CreateScenario::addNeutral(std::string name, guint32 armyset,
+                                Gdk::Color color, int type)
 {
     // for consistency, we only allow exactly one neutral player
     if (Playerlist::getInstance()->getNeutral() != 0)
@@ -351,9 +358,6 @@ bool CreateScenario::create(const GameParameters &g)
     if (!setupItems())
         return false;
 
-    if (!setupRewards())
-        return false;
-
     if (!setupRoads())
         return false;
     
@@ -410,27 +414,27 @@ bool CreateScenario::createMap()
             switch (map[y*d_width + x])
             {
                 case Maptile::SIGNPOST:
-                    Signpostlist::getInstance()->push_back(new Signpost(Vector<int>(x,y)));
+                    Signpostlist::getInstance()->add(new Signpost(Vector<int>(x,y)));
                     break;
                 case Maptile::TEMPLE:
-                    Templelist::getInstance()->push_back
+                    Templelist::getInstance()->add
 		      (new Temple(Vector<int>(x,y), popRandomTempleName()));
                     break;
                 case Maptile::RUIN:
-		    Ruinlist::getInstance()->push_back
+		    Ruinlist::getInstance()->add
 		      (new Ruin(Vector<int>(x,y), popRandomRuinName()));
 		    break;
                 case Maptile::CITY:
-                    Citylist::getInstance()->push_back(new City(Vector<int>(x,y)));
+                    Citylist::getInstance()->add(new City(Vector<int>(x,y)));
                     break;
                 case Maptile::ROAD:
-                    Roadlist::getInstance()->push_back(new Road(Vector<int>(x,y)));
+                    Roadlist::getInstance()->add(new Road(Vector<int>(x,y)));
                     break;
                 case Maptile::PORT:
-                    Portlist::getInstance()->push_back(new Port(Vector<int>(x,y)));
+                    Portlist::getInstance()->add(new Port(Vector<int>(x,y)));
                     break;
                 case Maptile::BRIDGE:
-                    Bridgelist::getInstance()->push_back(new Bridge(Vector<int>(x,y)));
+                    Bridgelist::getInstance()->add(new Bridge(Vector<int>(x,y)));
                     break;
                 case Maptile::NONE:
 		    break;
@@ -453,13 +457,13 @@ void CreateScenario::createCapitalCity(Player *player, City *city)
   player->addHistory(item);
 }
 
-bool CreateScenario::tooNearToOtherCapitalCities(City *c, std::list<City*> capitals, Uint32 distance)
+bool CreateScenario::tooNearToOtherCapitalCities(City *c, std::list<City*> capitals, guint32 distance)
 {
   for (std::list<City*>::iterator it = capitals.begin(); it != capitals.end(); 
        it++)
     {
       int d = dist(c->getPos(), (*it)->getPos());
-      if ((Uint32) d < distance)
+      if ((guint32) d < distance)
 	return true;
     }
   return false;
@@ -671,98 +675,12 @@ bool CreateScenario::setupPlayers(bool random_turns,
     return true;
 }
 
-bool CreateScenario::setupRewards()
-{
-  debug("CreateScenario::setupRewards")
-  setupItemRewards();
-  setupRuinRewards();
-  setupMapRewards();
-  return true;
-}
-
-bool CreateScenario::setupMapRewards()
-{
-  debug("CreateScenario::setupMapRewards")
-  if (GameScenario::s_hidden_map == false)
-    return true;
-  //okay, let's make some maps
-  //split the terrain into a 3x3 grid
-  Vector<int> step = Vector<int>(GameMap::getWidth() / 3, 
-				 GameMap::getHeight() / 3);
-  Reward_Map *reward = new Reward_Map(Vector<int>(step.x * 0, 0), 
-				      _("Northwestern map"), step.x, step.y);
-  Rewardlist::getInstance()->push_back(reward);
-  reward = new Reward_Map(Vector<int>(step.x * 1, 0), 
-			  _("Northern map"), step.x, step.y);
-  Rewardlist::getInstance()->push_back(reward);
-  reward = new Reward_Map(Vector<int>(step.x * 2, 0), 
-			  _("Northeastern map"), step.x, step.y);
-  Rewardlist::getInstance()->push_back(reward);
-  reward = new Reward_Map(Vector<int>(step.x * 0, step.y * 1), 
-			  _("Western map"), step.x, step.y);
-  Rewardlist::getInstance()->push_back(reward);
-  reward = new Reward_Map(Vector<int>(step.x * 1, step.y * 1), 
-			  _("Central map"), step.x, step.y);
-  Rewardlist::getInstance()->push_back(reward);
-  reward = new Reward_Map(Vector<int>(step.x * 2, step.y * 1), 
-			  _("Eastern map"), step.x, step.y);
-  Rewardlist::getInstance()->push_back(reward);
-  reward = new Reward_Map(Vector<int>(step.x * 0, step.y * 2), 
-			  _("Southwestern map"), step.x, step.y);
-  Rewardlist::getInstance()->push_back(reward);
-  reward = new Reward_Map(Vector<int>(step.x * 1, step.y * 2), 
-			  _("Southern map"), step.x, step.y);
-  Rewardlist::getInstance()->push_back(reward);
-  reward = new Reward_Map(Vector<int>(step.x * 2, step.y * 2), 
-			  _("Southeastern map"), step.x, step.y);
-  Rewardlist::getInstance()->push_back(reward);
-  return true;
-}
-bool CreateScenario::setupRuinRewards()
-{
-  debug("CreateScenario::setupRuinRewards")
-    for (Ruinlist::iterator it = Ruinlist::getInstance()->begin();
-	 it != Ruinlist::getInstance()->end(); it++)
-      {
-	if ((*it)->isHidden() == true)
-	  {
-	    //add it to the reward list
-	    Reward_Ruin *newReward = new Reward_Ruin((*it)); //make a reward
-	    newReward->setName(newReward->getDescription());
-	    Rewardlist::getInstance()->push_back(newReward); //add it
-	  }
-	else
-	  {
-	    if ((*it)->hasSage() == false && (*it)->getReward() == NULL)
-	      (*it)->populateWithRandomReward();
-	  }
-      }
-  return true;
-}
-
 bool CreateScenario::setupItems()
 {
   Itemlist::createStandardInstance();
   return true;
 }
 
-bool CreateScenario::setupItemRewards()
-{
-  debug("CreateScenario::setupItemRewards")
-  Itemlist *il = Itemlist::getInstance();
-  Itemlist::iterator iter;
-  for (iter = il->begin(); iter != il->end(); iter++)
-    {
-      Item templateItem = *iter->second;
-      Item *newItem = new Item(templateItem); //instantiate it
-      Reward_Item *newReward = new Reward_Item(newItem); //make a reward
-      newReward->setName(newReward->getDescription());
-      Rewardlist::getInstance()->push_back(newReward); //add it
-    }
-
-  return true;
-}
-
 void CreateScenario::getRuinDifficulty (int difficulty, int *sage_factor, 
 					int *no_guardian_factor, 
 					int *stronghold_factor)
