@@ -1,11 +1,11 @@
 // Copyright (C) 2003, 2004, 2005 Ulf Lorenz
 // Copyright (C) 2003 Michael Bartl
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -24,7 +24,7 @@
 #include <string>
 #include <vector>
 #include <list>
-#include <SDL.h>
+#include <gtkmm.h>
 #include <sigc++/signal.h>
 #include "CreateScenarioRandomize.h"
 #include "game-parameters.h"
@@ -113,7 +113,7 @@ class CreateScenario : public CreateScenarioRandomize
           * @param type     the type of the player (see class player for more info)
           * @return a pointer to the created player
           */
-        Player* addPlayer(std::string name, Uint32 armyset, SDL_Color color,
+        Player* addPlayer(std::string name, guint32 armyset, Gdk::Color color,
 			  int type);
 
         /** Almost the same as addPlayer, but performs some additional checks
@@ -124,7 +124,7 @@ class CreateScenario : public CreateScenarioRandomize
           * @param type     the type of the player (see class player for more info)
           * @return false if a neutral player already exists, true otherwise
           */
-        bool addNeutral(std::string name, Uint32 armyset, SDL_Color color,
+        bool addNeutral(std::string name, guint32 armyset, Gdk::Color color,
                         int type);
 
         
@@ -182,7 +182,7 @@ class CreateScenario : public CreateScenarioRandomize
         bool createMap();
 
 	void createCapitalCity(Player *player, City *city);
-	bool tooNearToOtherCapitalCities(City *c, std::list<City*> capitals, Uint32 distance);
+	bool tooNearToOtherCapitalCities(City *c, std::list<City*> capitals, guint32 distance);
 
         //! Distributes the players over the map
         bool distributePlayers();
@@ -217,11 +217,6 @@ class CreateScenario : public CreateScenarioRandomize
 	bool setupRoads();
 	bool setupBridges();
 
-        //! Set up rewards to be given out for quests, ruins and sages
-        bool setupRewards();
-        bool setupItemRewards();
-        bool setupRuinRewards();
-	bool setupMapRewards();
 	void quickStart();
 
 	//! Given the difficulty, get some characteristics of ruins
