@@ -1,8 +1,8 @@
-//  Copyright (C) 2008, Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,11 +18,15 @@
 #include <sstream>
 #include <iostream>
 #include <fstream>
+#include "ucompose.hpp"
 
 #include "CreateScenarioRandomize.h"
 
 #include "File.h"
 #include "citylist.h"
+#include "city.h"
+#include "ruin.h"
+#include "temple.h"
 #include "signpost.h"
 #include "armysetlist.h"
 #include "playerlist.h"
@@ -38,28 +42,16 @@ CreateScenarioRandomize::CreateScenarioRandomize()
     // Fill the namelists 
     bool success = true;
     
-    std::ifstream file(File::getMiscFile("citynames").c_str());
-    success &= loadNames(d_citynames, file);
-    file.close();
-
-    file.open(File::getMiscFile("templenames").c_str());
-    success &= loadNames(d_templenames, file);
-    file.close();
-
-    file.open(File::getMiscFile("ruinnames").c_str());
-    success &= loadNames(d_ruinnames, file);
-    file.close();
-
-    file.open(File::getMiscFile("signposts").c_str());
-    success &= loadNames(d_signposts, file);
-    file.close();
+    d_citynames = new NameList("citynames.xml", "city");
+    d_templenames = new NameList("templenames.xml", "temple");
+    d_ruinnames = new NameList("ruinnames.xml", "ruin");
+    d_signposts = new NameList("signposts.xml", "signpost");
 
     if (!success)
     {
         std::cerr <<"CreateScenarioRandomize: Didn't succeed in reading object names. Aborting!\n";
         exit(-1);
     }
-
 }
 
 CreateScenarioRandomize::~CreateScenarioRandomize()
@@ -67,88 +59,56 @@ CreateScenarioRandomize::~CreateScenarioRandomize()
     debug("CreateScenarioRandomize::~CreateScenarioRandomize")
 }
 
-
-bool CreateScenarioRandomize::loadNames(std::vector<std::string>& list, std::ifstream& namefile)
-{
-    debug("CreateScenarioRandomize::loadNames")
-
-    int counter;
-    char buffer[101];
-    buffer[100] = '\0';
-    
-    if (!namefile)
-    {
-        std::cerr << "Critical Error: Couldn't open names data file\n";
-        return false;
-    }
-
-    namefile >> counter;
-    list.resize(counter);
-
-    //with getline, the first call will get the first line to the end, i.e.
-    //a newline character. Thus, we throw away the result of the first call.
-    namefile.getline(buffer, 100);
-
-    for (counter--; counter >= 0; counter--)
-    {
-        namefile.getline(buffer, 100);
-        list[counter] = std::string(buffer);
-    }
-
-    return true;
-}
-
-std::string CreateScenarioRandomize::popRandomListName(std::vector<std::string> &list)
-{
-  std::string name;
-  if (list.empty())
-    return "";
-  int randno = rand() % list.size();
-  name = list[randno];
-  return name;
-}
-
 std::string CreateScenarioRandomize::popRandomCityName()
 {
-  return popRandomListName(d_citynames);
+  std::string name = d_citynames->popRandomName().c_str();
+  if (name == "")
+    return City::getDefaultName();
+  return name;
 }
 
 void CreateScenarioRandomize::pushRandomCityName(std::string name)
 {
-  d_citynames.push_back(name);
+  d_citynames->push_back(name);
 }
 
 std::string CreateScenarioRandomize::popRandomRuinName()
 {
-  return popRandomListName(d_ruinnames);
+  std::string name = d_ruinnames->popRandomName().c_str();
+  if (name == "")
+    return Ruin::getDefaultName();
+  return name;
 }
 
 void CreateScenarioRandomize::pushRandomRuinName(std::string name)
 {
-  d_ruinnames.push_back(name);
+  d_ruinnames->push_back(name);
 }
 
 std::string CreateScenarioRandomize::popRandomTempleName()
 {
-  return popRandomListName(d_templenames);
+  std::string name = d_templenames->popRandomName().c_str();
+  if (name == "")
+    return Temple::getDefaultName();
+  return name;
 }
 
 void CreateScenarioRandomize::pushRandomTempleName(std::string name)
 {
-  d_templenames.push_back(name);
+  d_templenames->push_back(name);
 }
 
 std::string CreateScenarioRandomize::popRandomSignpost()
 {
-  return popRandomListName(d_signposts);
+  return d_signposts->popRandomName().c_str();
 }
 
 void CreateScenarioRandomize::pushRandomSignpost(std::string name)
 {
-  d_signposts.push_back(name);
+  d_signposts->push_back(name);
 }
 
-Uint32 CreateScenarioRandomize::getRandomCityIncome(bool capital)
+guint32 CreateScenarioRandomize::getRandomCityIncome(bool capital)
 {
   if (capital)
     return 33 + (rand() % 8);
@@ -180,7 +140,6 @@ std::string CreateScenarioRandomize::getDynamicSignpost(Signpost *signpost)
 {
   char *dir = NULL;
   int xdir, ydir;
-  char buf[101]; buf[100] = '\0';
   Vector<int> signpostPos = signpost->getPos();
   City *nearCity = Citylist::getInstance()->getNearestCity(signpostPos);
   if (nearCity == NULL)
@@ -205,9 +164,7 @@ std::string CreateScenarioRandomize::getDynamicSignpost(Signpost *signpost)
     dir = _("west");
   else if (xdir <= -1 && ydir <= -1)
     dir = _("northwest");
-  snprintf(buf,100,_("%s lies to the %s"), 
-	   nearCity->getName().c_str(), dir);
-  return buf;
+  return String::ucompose("%1 lies to the %2", nearCity->getName(), dir);
 }
   
 Reward *CreateScenarioRandomize::getNewRandomReward(bool hidden_ruins)
