@@ -1,8 +1,8 @@
-//  Copyright (C) 2008, Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,8 +21,9 @@
 #include <fstream>
 #include <string>
 #include <vector>
-#include <SDL.h>
+#include <gtkmm.h>
 #include "game-parameters.h"
+#include "namelist.h"
 
 class Signpost;
 class Army;
@@ -48,10 +49,10 @@ class CreateScenarioRandomize
 	void pushRandomTempleName(std::string name);
 	std::string popRandomSignpost();
 	void pushRandomSignpost(std::string name);
-	Uint32 getRandomCityIncome(bool capital = false);
-	bool randomSignpostsEmpty() {return d_signposts.empty();}
+	guint32 getRandomCityIncome(bool capital = false);
+	bool randomSignpostsEmpty() {return d_signposts->empty();}
 	std::string getDynamicSignpost(Signpost *signpost);
-	int getNumSignposts() {return d_signposts.size();}
+	int getNumSignposts() {return d_signposts->size();}
 	Army * getRandomRuinKeeper(Player *p);
 	Reward *getNewRandomReward(bool hidden_ruins);
 
@@ -62,8 +63,10 @@ class CreateScenarioRandomize
 	bool loadNames(std::vector<std::string>& list, std::ifstream& file);
 
         //the namelists
-        std::vector<std::string> d_citynames, d_signposts;
-        std::vector<std::string> d_templenames, d_ruinnames;
+	NameList *d_citynames;
+	NameList *d_signposts;
+	NameList *d_templenames;
+	NameList *d_ruinnames;
 };
 
 #endif  //CREATE_SCENARIO_RANDOMIZE_H
