@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,6 +18,7 @@
 #ifndef FOGMAP_H
 #define FOGMAP_H
 
+#include <list>
 #include "vector.h"
 
 class XML_Helper;
@@ -42,6 +43,24 @@ class FogMap
 	  //! Closed to view can be partially obscured.
 	  CLOSED = 1
 	};
+	enum ShadeType {
+	  NONE = 0,
+	  LIGHTLY_TO_SOUTH_AND_EAST = 1,
+	  LIGHTLY_TO_SOUTH_AND_WEST = 2,
+	  LIGHTLY_TO_NORTH_AND_WEST = 3,
+	  LIGHTLY_TO_NORTH_AND_EAST = 4,
+	  DARKLY_TO_NORTH_AND_WEST_LIGHTLY_TO_SOUTH_AND_EAST = 5,
+	  DARKLY_TO_NORTH_AND_EAST_LIGHTLY_TO_SOUTH_AND_WEST = 6,
+	  DARKLY_TO_SOUTH_AND_EAST_LIGHTLY_TO_NORTH_AND_WEST = 7,
+	  DARKLY_TO_SOUTH_AND_WEST_LIGHTLY_TO_NORTH_AND_EAST = 8,
+	  DARKLY_TO_SOUTH_LIGHTLY_TO_EAST_AND_WEST = 9,
+	  DARKLY_TO_NORTH_LIGHTLY_TO_EAST_AND_WEST = 10,
+	  DARKLY_TO_WEST_LIGHTLY_TO_NORTH_AND_SOUTH = 11,
+	  DARKLY_TO_EAST_LIGHTLY_TO_NORTH_AND_SOUTH = 12,
+	  ALL = 13,
+	  DARKLY_TO_SOUTH_AND_WEST_DARKLY_TO_NORTH_AND_EAST = 14,
+	  DARKLY_TO_NORTH_AND_WEST_DARKLY_TO_SOUTH_AND_EAST = 15,
+	};
         
         //! Standard constructor: create a given map
 	/**
@@ -82,6 +101,7 @@ class FogMap
 
         //! Get the foggedness of a given position.
         FogType getFogTile(Vector<int> pos) const;
+	ShadeType getShadeTile(Vector<int> pos) const;
 
 	//! Alter the fog around a given position in the fog map.
 	/** 
@@ -139,9 +159,16 @@ class FogMap
 	 * @return True if the position is obscured due to fog, false if not.
 	 */
 	static bool isFogged(Vector <int> pos, Player *player);
+	bool isFogged(Vector <int> pos);
+	static bool isClear(Vector <int> pos, Player *player) ;
+
+	bool isCompletelyObscuredFogTile(Vector<int> pos) const;
+
+	ShadeType calculateShade(Vector<int> tile);
 
-	bool isCompletelyObscuredFogTile(Vector<int> pos);
     private:
+
+	void calculateShadeMap();
         // Data
 	//! The width of the fog map.
         int d_width;
@@ -151,6 +178,10 @@ class FogMap
 
 	//! An array of tiles that describe how a tile is fogged.
         FogType * d_fogmap;
+	ShadeType *shademap;
+
+	//! A list of tiles that are completely obscured.
+	std::list<Vector<int> > completely_obscured;
 };
 
 #endif
