@@ -1,13 +1,13 @@
 // Copyright (C) 2003 Michael Bartl
 // Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2003, 2005, 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 // Copyright (C) 2008 Janek Kozicki
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,14 +21,21 @@
 //  02110-1301, USA.
 
 #include <sstream>
+#include <iostream>
+#include <iomanip>
 #include <assert.h>
 #include <sigc++/functors/mem_fun.h>
+#include <string.h>
 
+#include "ucompose.hpp"
 #include "GameMap.h"
 #include "citylist.h"
 #include "bridgelist.h"
+#include "bridge.h"
 #include "portlist.h"
+#include "port.h"
 #include "roadlist.h"
+#include "road.h"
 #include "city.h"
 #include "ruin.h"
 #include "temple.h"
@@ -36,6 +43,7 @@
 #include "stacklist.h"
 #include "ruinlist.h"
 #include "templelist.h"
+#include "signpostlist.h"
 #include "xmlhelper.h"
 #include "MapGenerator.h"
 #include "tilesetlist.h"
@@ -48,7 +56,6 @@ std::string GameMap::d_tag = "map";
 std::string GameMap::d_itemstack_tag = "itemstack";
 using namespace std;
 
-//#include <iostream>
 //#define debug(x) {std::cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<std::endl<<flush;}
 #define debug(x)
 
@@ -101,6 +108,7 @@ GameMap::GameMap(std::string TilesetName, std::string ShieldsetName,
     d_shieldSet = Shieldsetlist::getInstance()->getShieldset(ShieldsetName);
     d_citySet = Citysetlist::getInstance()->getCityset(CitysetName);
 
+    Vector<int>::setMaximumWidth(s_width);
     d_map = new Maptile*[s_width*s_height];
     for (int j = 0; j < s_height; j++)
         for (int i = 0; i < s_width; i++)
@@ -135,7 +143,7 @@ void GameMap::processStyles(std::string styles, int chars_per_style)
 	    unsigned long int val = 0;
 	    char *end = NULL;
 	    val = strtoul (hexstr, &end, 16);
-	    Uint32 id = (Uint32) val;
+	    guint32 id = (guint32) val;
 	    TileStyle *style = d_tileSet->getTileStyle(id);
 	    if (!style)
 	      style = d_tileSet->getTileStyle(0);
@@ -169,6 +177,7 @@ GameMap::GameMap(XML_Helper* helper)
     d_shieldSet = Shieldsetlist::getInstance()->getShieldset(s_dir);
     d_citySet = Citysetlist::getInstance()->getCityset(c_dir);
 
+    Vector<int>::setMaximumWidth(s_width);
     //create the map
     d_map = new Maptile*[s_width*s_height];
 
@@ -244,7 +253,7 @@ bool GameMap::fill(MapGenerator* generator)
     for (int j = 0; j < height; j++)
         for (int i = 0; i < width; i++)
         {
-            Uint32 index = d_tileSet->getIndex(terrain[j*width + i]);
+            guint32 index = d_tileSet->getIndex(terrain[j*width + i]);
             d_map[j*s_width + i] = new Maptile(d_tileSet, i, j, index, NULL);
         }
 
@@ -252,7 +261,7 @@ bool GameMap::fill(MapGenerator* generator)
     return true;
 }
 
-bool GameMap::fill(Uint32 type)
+bool GameMap::fill(guint32 type)
 {
     for (int i = 0; i < s_width; i++)
         for (int j = 0; j < s_height; j++)
@@ -286,20 +295,16 @@ bool GameMap::save(XML_Helper* helper) const
     {
         for (int j = 0; j < s_width; j++)
 	  {
-	    char *hexstr = NULL;
-	    int byteswritten = -1;
+	    Glib::ustring hexstr;
 	    TileStyle *style = getTile(j, i)->getTileStyle();
 	    if (largest_style_id < 256)
-	      byteswritten = asprintf (&hexstr, "%02x", style->getId());
+	      hexstr = String::ucompose ("%1", Glib::ustring::format(std::hex, std::setfill(L'0'), std::setw(2), style->getId()));
 	    else if (largest_style_id < 4096)
-	      byteswritten = asprintf (&hexstr, "%03x", style->getId());
+	      hexstr = String::ucompose ("%1", Glib::ustring::format(std::hex, std::setfill(L'0'), std::setw(3), style->getId()));
 	    else if (largest_style_id < 65536)
-	      byteswritten = asprintf (&hexstr, "%04x", style->getId());
-	    if (hexstr && byteswritten > -1)
-	      {
-		styles << hexstr;
-		free (hexstr);
-	      }
+	      hexstr = String::ucompose ("%1", Glib::ustring::format(std::hex, std::setfill(L'0'), std::setw(4), style->getId()));
+
+	    styles << hexstr;
 	  }
         styles <<endl;
     }
@@ -360,7 +365,7 @@ Maptile* GameMap::getTile(int x, int y) const
 
 Stack* GameMap::addArmy(Vector<int> pos, Army *a)
 {
-  City *c = Citylist::getInstance()->getObjectAt(pos);
+  City *c = getCity(pos);
   if (c)
     {
       if (c->isBurnt())
@@ -368,10 +373,10 @@ Stack* GameMap::addArmy(Vector<int> pos, Army *a)
       else
         return addArmy(c, a);
     }
-  Temple *t = Templelist::getInstance()->getObjectAt(pos);
+  Temple *t = getTemple(pos);
   if (t)
     return addArmy(t, a);
-  Ruin *r = Ruinlist::getInstance()->getObjectAt(pos);
+  Ruin *r = getRuin(pos);
   if (r)
     return addArmy(r, a);
   return addArmyAtPos(pos, a);
@@ -381,9 +386,9 @@ Stack* GameMap::addArmyAtPos(Vector<int> pos, Army *a)
 {
   Stack *s = NULL;
   bool added_army = false;
-  Uint32 i, j;
-  Uint32 d;
-  Uint32 max;
+  guint32 i, j;
+  guint32 d;
+  guint32 max;
   int x, y;
   if (s_height > s_width)
     max = s_height;
@@ -421,7 +426,7 @@ Stack* GameMap::addArmyAtPos(Vector<int> pos, Army *a)
                   if (x >= s_width || y >= s_height)
                     continue;
                   //is there somebody else's city here?
-                  City *c = Citylist::getInstance()->getObjectAt(x, y);
+                  City *c = getCity(Vector<int>(x, y));
                   if (c && c->getOwner() != a->getOwner())
                     {
                       if (c->isBurnt() == false)
@@ -487,13 +492,13 @@ Stack* GameMap::addArmy(Location *l, Army *a)
   return addArmyAtPos(l->getPos(), a);
 }
 
-bool GameMap::isDock(int x, int y)
+bool GameMap::isDock(Vector<int> pos)
 {
-  if (Citylist::getInstance()->getObjectAt(x,y))
+  if (getTile(pos)->getBuilding() == Maptile::CITY)
     return true;
-  if (Portlist::getInstance()->getObjectAt(x,y))
+  if (getTile(pos)->getBuilding() == Maptile::PORT)
     return true;
-  if (Bridgelist::getInstance()->getObjectAt(x,y))
+  if (getTile(pos)->getBuilding() == Maptile::BRIDGE)
     return true;
   return false;
 }
@@ -511,8 +516,8 @@ bool GameMap::isBlockedAvenue(int x, int y, int destx, int desty)
   if (diffx >= -1 && diffx <= 1 && diffy >= -1 && diffy <= 1)
     {
       assert (Citylist::getInstance()->size());
-      bool from_dock = isDock(x,y);
-      bool to_dock = isDock(destx,desty);
+      bool from_dock = isDock(Vector<int>(x,y));
+      bool to_dock = isDock(Vector<int>(destx,desty));
       Maptile *from = getTile(x, y);
       Maptile *to = getTile(destx, desty);
       if (from == to)
@@ -544,12 +549,12 @@ bool GameMap::isBlockedAvenue(int x, int y, int destx, int desty)
 
       //is the tile i'm going to a mountain that doesn't have a road?
       if (to->getMaptileType() == Tile::MOUNTAIN &&
-	  Roadlist::getInstance()->getObjectAt(destx, desty) == NULL)
+	  getRoad(Vector<int>(destx, desty)) == NULL)
         return true;
 
       //am i on a mountain without a road?
       if (from->getMaptileType() == Tile::MOUNTAIN &&
-	  Roadlist::getInstance()->getObjectAt(x, y) == NULL)
+	  getRoad(Vector<int>(x, y)) == NULL)
         return true;
 
       if (from->getMaptileType() == Tile::VOID)
@@ -1006,3 +1011,35 @@ Vector<int> GameMap::findNearestObjectToTheWest(Vector<int> pos)
   Vector<int> dir = Vector<int>(-1, 0);
   return findNearestObjectInDir(pos, dir);
 }
+City* GameMap::getCity(Vector<int> pos)
+{
+  return Citylist::getInstance()->getObjectAt(pos);
+}
+Ruin* GameMap::getRuin(Vector<int> pos)
+{
+  return Ruinlist::getInstance()->getObjectAt(pos);
+}
+Temple* GameMap::getTemple(Vector<int> pos)
+{
+  return Templelist::getInstance()->getObjectAt(pos);
+}
+Port* GameMap::getPort(Vector<int> pos)
+{
+  return Portlist::getInstance()->getObjectAt(pos);
+}
+Road* GameMap::getRoad(Vector<int> pos)
+{
+  return Roadlist::getInstance()->getObjectAt(pos);
+}
+Bridge* GameMap::getBridge(Vector<int> pos)
+{
+  return Bridgelist::getInstance()->getObjectAt(pos);
+}
+Signpost* GameMap::getSignpost(Vector<int> pos)
+{
+  return Signpostlist::getInstance()->getObjectAt(pos);
+}
+Stack* GameMap::getStack(Vector<int> pos)
+{
+  return Stacklist::getObjectAt(pos);
+}
