@@ -1,12 +1,12 @@
 // Copyright (C) 2003 Michael Bartl
 // Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2003, 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2008 Janek Kozicki
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -26,6 +26,7 @@
 
 #include <vector>
 
+#include <gtkmm.h>
 #include "vector.h"
 #include "rectangle.h"
 #include "maptile.h"
@@ -36,6 +37,12 @@
 
 class MapGenerator;
 class XML_Helper;
+class Port;
+class Road;
+class City;
+class Temple;
+class Bridge;
+class Ruin;
 
 /** Class representing the map in the game
   * 
@@ -116,6 +123,15 @@ class GameMap: public sigc::trackable
         //! Alternative setting
         void setTile(Vector<int> p, Maptile *t) {return setTile(p.x, p.y, t);}
 
+	static City* getCity(Vector<int> pos);
+	static Ruin* getRuin(Vector<int> pos);
+	static Temple* getTemple(Vector<int> pos);
+	static Port* getPort(Vector<int> pos);
+	static Road* getRoad(Vector<int> pos);
+	static Bridge* getBridge(Vector<int> pos);
+	static Signpost* getSignpost(Vector<int> pos);
+	static Stack* getStack(Vector<int> pos);
+
         //! Get the tile object at position (x,y)
         Maptile* getTile(int x, int y) const;
 
@@ -141,7 +157,7 @@ class GameMap: public sigc::trackable
           * @param type             the type of the terrain(index in the tileset)
           * @return true on success, false on error
           */
-        bool fill(Uint32 type);
+        bool fill(guint32 type);
 
         /** Save the contents of the map
           * 
@@ -187,7 +203,7 @@ class GameMap: public sigc::trackable
         bool loadItems(std::string tag, XML_Helper* helper);
         Stack* addArmyAtPos(Vector<int> pos, Army *a);
         bool isBlockedAvenue(int x, int y, int destx, int desty);
-        bool isDock(int x, int y);
+        bool isDock(Vector<int> pos);
 	void close_circles (int minx, int miny, int maxx, int maxy);
 	void processStyles(std::string styles, int chars_per_style);
 	int determineCharsPerStyle(std::string styles);
