@@ -6,7 +6,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,15 +20,15 @@
 //  02110-1301, USA.
 
 #include <iostream>
+#include <iomanip>
 #include <fstream>
 #include <stdlib.h>
 #include <errno.h>
 #include <sigc++/functors/mem_fun.h>
-#include <uuid/uuid.h>
+#include <string.h>
 
 #include "ucompose.hpp"
 #include "GameScenario.h"
-#include "Campaign.h"
 #include "MapGenerator.h"
 #include "playerlist.h"
 #include "FogMap.h"
@@ -73,7 +73,7 @@ using namespace std;
 GameScenario::GameScenario(std::string name,std::string comment, bool turnmode,
 			   GameScenario::PlayMode playmode)
     :d_name(name),d_comment(comment), d_turnmode(turnmode), 
-    d_playmode(playmode), recording_file("")
+    d_playmode(playmode), recording_file(""), inhibit_autosave_removal(false)
 {
     Armysetlist::getInstance();
     Tilesetlist::getInstance();
@@ -88,7 +88,8 @@ GameScenario::GameScenario(std::string name,std::string comment, bool turnmode,
 // savegame is a filename with absolute path!
 
 GameScenario::GameScenario(string savegame, bool& broken)
-  :d_turnmode(true), d_playmode(GameScenario::HOTSEAT), recording_file("")
+  :d_turnmode(true), d_playmode(GameScenario::HOTSEAT), recording_file(""), 
+    inhibit_autosave_removal(false)
 {
   XML_Helper helper(savegame, ios::in, Configuration::s_zipfiles);
   broken = loadWithHelper(helper);
@@ -96,7 +97,8 @@ GameScenario::GameScenario(string savegame, bool& broken)
 }
 
 GameScenario::GameScenario(XML_Helper &helper, bool& broken)
-  : d_turnmode(true), d_playmode(GameScenario::HOTSEAT), recording_file("")
+  : d_turnmode(true), d_playmode(GameScenario::HOTSEAT), recording_file(""),
+    inhibit_autosave_removal(false)
 {
   broken = loadWithHelper(helper);
 }
@@ -175,6 +177,93 @@ bool GameScenario::setupStacks(bool hidden_map)
   return true;
 }
 
+bool GameScenario::setupMapRewards()
+{
+  debug("GameScenario::setupMapRewards")
+  //okay, let's make some maps
+  //split the terrain into a 3x3 grid
+  Vector<int> step = Vector<int>(GameMap::getWidth() / 3, 
+				 GameMap::getHeight() / 3);
+  Reward_Map *reward = new Reward_Map(Vector<int>(step.x * 0, 0), 
+				      _("Northwestern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 1, 0), 
+			  _("Northern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 2, 0), 
+			  _("Northeastern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 0, step.y * 1), 
+			  _("Western map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 1, step.y * 1), 
+			  _("Central map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 2, step.y * 1), 
+			  _("Eastern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 0, step.y * 2), 
+			  _("Southwestern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 1, step.y * 2), 
+			  _("Southern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  reward = new Reward_Map(Vector<int>(step.x * 2, step.y * 2), 
+			  _("Southeastern map"), step.x, step.y);
+  Rewardlist::getInstance()->push_back(reward);
+  return true;
+}
+
+bool GameScenario::setupRuinRewards()
+{
+  debug("GameScenario::setupRuinRewards")
+    for (Ruinlist::iterator it = Ruinlist::getInstance()->begin();
+	 it != Ruinlist::getInstance()->end(); it++)
+      {
+	if ((*it)->isHidden() == true)
+	  {
+	    //add it to the reward list
+	    Reward_Ruin *newReward = new Reward_Ruin((*it)); //make a reward
+	    newReward->setName(newReward->getDescription());
+	    Rewardlist::getInstance()->push_back(newReward); //add it
+	  }
+	else
+	  {
+	    if ((*it)->hasSage() == false && (*it)->getReward() == NULL)
+	      (*it)->populateWithRandomReward();
+	  }
+      }
+  return true;
+}
+
+bool GameScenario::setupItemRewards()
+{
+  debug("GameScenario::setupItemRewards")
+  Itemlist *il = Itemlist::getInstance();
+  Itemlist::iterator iter;
+  for (iter = il->begin(); iter != il->end(); iter++)
+    {
+      Item templateItem = *iter->second;
+      Item *newItem = new Item(templateItem); //instantiate it
+      Reward_Item *newReward = new Reward_Item(newItem); //make a reward
+      newReward->setName(newReward->getDescription());
+      Rewardlist::getInstance()->push_back(newReward); //add it
+    }
+
+  return true;
+}
+
+bool GameScenario::setupRewards(bool hidden_map)
+{
+  if (Rewardlist::getInstance()->size() != 0)
+    return true;
+  setupItemRewards();
+  setupRuinRewards();
+  if (hidden_map)
+    setupMapRewards();
+  return true;
+}
+
 bool GameScenario::setupCities(bool quick_start)
 {
   debug("GameScenario::setupCities")
@@ -216,6 +305,10 @@ bool GameScenario::setupCities(bool quick_start)
 	      else
 		(*it)->produceWeakestProductionBase();
 	      break;
+	    case GameParameters::DEFENSIVE:
+	      (*it)->produceScout();
+	      (*it)->produceScout();
+	      break;
 	    }
 	  (*it)->setActiveProductionSlot(-1);
 	}
@@ -272,7 +365,6 @@ bool GameScenario::loadWithHelper(XML_Helper& helper)
   bool broken = false;
 
   helper.registerTag(d_tag, sigc::mem_fun(this, &GameScenario::load));
-  helper.registerTag(Campaign::d_tag, sigc::mem_fun(this, &GameScenario::load));
   helper.registerTag(Itemlist::d_tag, sigc::mem_fun(this, &GameScenario::load));
   helper.registerTag(Playerlist::d_tag, sigc::mem_fun(this, &GameScenario::load));
   helper.registerTag(GameMap::d_tag, sigc::mem_fun(this, &GameScenario::load));
@@ -313,14 +405,14 @@ GameScenario::~GameScenario()
   Roadlist::deleteInstance();
   QuestsManager::deleteInstance();
   VectoredUnitlist::deleteInstance();
-  Campaign::deleteInstance();
 
   if (fl_counter)
     {
       delete fl_counter;
       fl_counter = 0;
     }
-  if (Configuration::s_autosave_policy == 1)
+  if (Configuration::s_autosave_policy == 1 && 
+      inhibit_autosave_removal == false)
     {
       std::string filename = File::getSavePath() + "autosave.sav";
       remove(filename.c_str());
@@ -399,7 +491,6 @@ bool GameScenario::saveWithHelper(XML_Helper &helper) const
   retval &= Bridgelist::getInstance()->save(&helper);
   retval &= QuestsManager::getInstance()->save(&helper);
   retval &= VectoredUnitlist::getInstance()->save(&helper);
-  retval &= Campaign::getInstance()->save(&helper);
 
   //save the private GameScenario data last due to dependencies
   retval &= helper.openTag(GameScenario::d_tag);
@@ -476,13 +567,6 @@ bool GameScenario::load(std::string tag, XML_Helper* helper)
       return true;
     }
   
-  if (tag == Campaign::d_tag)
-    {
-      debug("loading campaign")
-      Campaign::getInstance(helper);
-      return true;
-    }
-
   if (tag == FL_Counter::d_tag)
     {
       debug("loading counter")
@@ -585,6 +669,36 @@ bool GameScenario::load(std::string tag, XML_Helper* helper)
   return false;
 }
 
+bool GameScenario::autoSave()
+{
+  Glib::ustring filename = "";
+  if (Configuration::s_autosave_policy == 2)
+    filename = String::ucompose("autosave-%1.sav", Glib::ustring::format(std::setfill(L'0'), std::setw(3), s_round - 1));
+  else if (Configuration::s_autosave_policy == 1)
+    filename = "autosave.sav";
+  else
+    return true;
+  // autosave to the file "autosave.sav". This is crude, but should work
+  //
+  // As a more enhanced version: autosave to a temporary file, then rename
+  // the file. Avoids screwing up the autosave if something goes wrong
+  // (and we have a savefile for debugging)
+  if (!saveGame(File::getSavePath() + "tmp.sav"))
+    {
+      std::cerr<< "Autosave failed.\n";
+      return false;
+    }
+  if (rename(std::string(File::getSavePath() + "tmp.sav").c_str(),
+	     std::string(File::getSavePath() + filename).c_str()))
+    {
+      char* err = strerror(errno);
+      std::cerr << "Error while trying to rename the temporary file to autosave.sav\n";
+      std::cerr << "Error: " <<err <<std::endl;
+      return false;
+    }
+  return true;
+}
+
 void GameScenario::nextRound()
 {
   s_round++;
@@ -603,31 +717,8 @@ void GameScenario::nextRound()
 	}
       helper.close();
     }
+  autoSave();
 
-  char filename[1024];
-  if (Configuration::s_autosave_policy == 2)
-    snprintf(filename,sizeof(filename), "autosave-%03d.sav", s_round - 1);
-  else if (Configuration::s_autosave_policy == 1)
-    snprintf(filename,sizeof(filename), "autosave.sav");
-  else
-    return;
-  // autosave to the file "autosave.sav". This is crude, but should work
-  //
-  // As a more enhanced version: autosave to a temporary file, then rename
-  // the file. Avoids screwing up the autosave if something goes wrong
-  // (and we have a savefile for debugging)
-  if (!saveGame(File::getSavePath() + "tmp.sav"))
-    {
-      std::cerr<< "Autosave failed.\n";
-      return;
-    }
-  if (rename(std::string(File::getSavePath() + "tmp.sav").c_str(),
-	     std::string(File::getSavePath() + filename).c_str()))
-    {
-      char* err = strerror(errno);
-      std::cerr << "Error while trying to rename the temporary file to autosave.sav\n";
-      std::cerr << "Error: " <<err <<std::endl;
-    }
 }
 
 std::string GameScenario::playModeToString(const GameScenario::PlayMode mode)
@@ -643,9 +734,6 @@ std::string GameScenario::playModeToString(const GameScenario::PlayMode mode)
       case GameScenario::PLAY_BY_MAIL:
 	return "GameScenario::PLAY_BY_MAIL";
 	break;
-      case GameScenario::CAMPAIGN:
-	return "GameScenario::CAMPAIGN";
-	break;
     }
   return "GameScenario::HOTSEAT";
 }
@@ -660,24 +748,19 @@ GameScenario::PlayMode GameScenario::playModeFromString(const std::string str)
     return GameScenario::NETWORKED;
   else if (str == "GameScenario::PLAY_BY_MAIL")
     return GameScenario::PLAY_BY_MAIL;
-  else if (str == "GameScenario::CAMPAIGN")
-    return GameScenario::CAMPAIGN;
   return GameScenario::HOTSEAT;
 }
 	
 void GameScenario::setNewRandomId()
 {
-  char buf[40];
-  uuid_t uu;
-  uuid_generate_time(uu);
-  uuid_unparse(uu, buf);
-  d_id = buf;
+  d_id = String::ucompose("%1%2%3", time(NULL), getpid(), rand());
 }
 	
 bool GameScenario::validate(std::list<std::string> &errors, std::list<std::string> &warnings)
 {
+  std::string s;
   Playerlist *pl = Playerlist::getInstance();
-  Uint32 num = pl->countPlayersAlive();
+  guint32 num = pl->countPlayersAlive();
   if (num < 2)
     errors.push_back(_("There must be at least 2 players in the scenario."));
 
@@ -693,12 +776,15 @@ bool GameScenario::validate(std::list<std::string> &errors, std::list<std::strin
 	continue;
       if (Citylist::getInstance()->getFirstCity(*it) == NULL)
 	{
-	  errors.push_back(_("Every player must have at least one city in the scenario."));
+	  s = String::ucompose
+	    (_("The player called `%1' lacks a starting city."), 
+	     (*it)->getName().c_str());
+	  errors.push_back(s);
 	  break;
 	}
     }
 
-  Uint32 count = 0;
+  guint32 count = 0;
   Citylist *cl = Citylist::getInstance();
   for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
     {
@@ -707,7 +793,6 @@ bool GameScenario::validate(std::list<std::string> &errors, std::list<std::strin
     }
   if (count > 0)
     {
-      std::string s;
       s = String::ucompose(ngettext("There is %1 unnamed city", "There are %1 unnamed cities", count), count);
       warnings.push_back(s);
     }
@@ -764,12 +849,15 @@ void GameScenario::initialize(GameParameters g)
   setupFog(g.hidden_map);
   setupCities(g.quick_start);
   setupStacks(g.hidden_map);
+  setupRewards(g.hidden_map);
   setupDiplomacy(g.diplomacy);
   if (s_random_turns)
     Playerlist::getInstance()->randomizeOrder();
   nextRound();
   if (d_playmode == GameScenario::NETWORKED)
     Playerlist::getInstance()->turnHumansIntoNetworkPlayers();
+  else
+    autoSave();
 }
 
 class ParamLoader
@@ -777,6 +865,11 @@ class ParamLoader
 public:
     bool loadParam(std::string tag, XML_Helper* helper)
       {
+	if (tag == Playerlist::d_tag)
+	  {
+	    helper->getData(d_neutral, "neutral");
+	    return true;
+	  }
 	if (tag == Player::d_tag)
 	  {
 	    int type;
@@ -806,7 +899,7 @@ public:
 	      }
 	    helper->getData(name, "name");
 	    p.name = name;
-	    if (p.id != 8) //is not neutral
+	    if (p.id != d_neutral) //is not neutral
 	      game_params.players.push_back(p);
 	    else
 	      {
@@ -854,6 +947,7 @@ public:
 	return false;
       };
     GameParameters game_params;
+    int d_neutral;
 };
 GameParameters GameScenario::loadGameParameters(std::string filename, bool &broken)
 {
@@ -864,6 +958,8 @@ GameParameters GameScenario::loadGameParameters(std::string filename, bool &brok
 		     sigc::mem_fun(loader, &ParamLoader::loadParam));
   helper.registerTag(GameScenario::d_tag, 
 		     sigc::mem_fun(loader, &ParamLoader::loadParam));
+  helper.registerTag(Playerlist::d_tag, 
+		     sigc::mem_fun(loader, &ParamLoader::loadParam));
   helper.registerTag(Player::d_tag, 
 		     sigc::mem_fun(loader, &ParamLoader::loadParam));
   bool retval = helper.parse();
@@ -872,6 +968,36 @@ GameParameters GameScenario::loadGameParameters(std::string filename, bool &brok
   helper.close();
   return loader.game_params;
 }
+class PlayModeLoader
+{
+public:
+    bool loadParam(std::string tag, XML_Helper* helper)
+      {
+	if (tag == GameScenario::d_tag)
+	  {
+	    std::string playmode_str;
+	    helper->getData(playmode_str, "playmode");
+	    play_mode = GameScenario::playModeFromString(playmode_str);
+	    return true;
+	  }
+	return false;
+      };
+    GameScenario::PlayMode play_mode;
+};
+
+GameScenario::PlayMode GameScenario::loadPlayMode(std::string filename, bool &broken)
+{
+  PlayModeLoader loader;
+  
+  XML_Helper helper(filename, std::ios::in, Configuration::s_zipfiles);
+  helper.registerTag(GameScenario::d_tag, 
+		     sigc::mem_fun(loader, &PlayModeLoader::loadParam));
+  bool retval = helper.parse();
+
+  broken = !retval;
+  helper.close();
+  return loader.play_mode;
+}
 
 void GameScenario::startRecordingEventsToFile(std::string filename)
 {
