@@ -6,7 +6,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -60,7 +60,6 @@ class GameScenario: public GameScenarioOptions
 	    HOTSEAT = 0, 
 	    NETWORKED = 1,
 	    PLAY_BY_MAIL = 2,
-	    CAMPAIGN = 3
 	  };
 
 	static std::string playModeToString(const GameScenario::PlayMode mode);
@@ -118,12 +117,11 @@ class GameScenario: public GameScenarioOptions
           * @return true if all went well, false otherwise
           */
         bool saveGame(std::string filename, std::string extension = "sav") const;
-
         bool loadWithHelper(XML_Helper &helper);
         bool saveWithHelper(XML_Helper &helper) const;
 
         
-	Uint32 getPlayMode() const {return d_playmode;};
+	guint32 getPlayMode() const {return d_playmode;};
 	void setPlayMode(GameScenario::PlayMode mode) {d_playmode = mode;};
 
 	bool validate(std::list<std::string> &errors, std::list<std::string> &warnings);
@@ -132,9 +130,12 @@ class GameScenario: public GameScenarioOptions
 
 	static GameParameters loadGameParameters(std::string filename, bool &broken);
 
+	static PlayMode loadPlayMode(std::string filename, bool &broken);
+
 	void startRecordingEventsToFile(std::string filename);
 	void stopRecordingEventsToFile();
 
+	void inhibitAutosaveRemoval(bool i) {inhibit_autosave_removal = i;}
     private:
 	  /** Callback function for loading a game. See XML_Helper for details.
 	   *
@@ -146,16 +147,22 @@ class GameScenario: public GameScenarioOptions
 	  void quickStart();
 	  bool setupFog(bool hidden_map);
 	  bool setupCities(bool quick_start);
+	  bool setupRewards(bool hidden_map);
+	  bool setupMapRewards();
+	  bool setupRuinRewards();
+	  bool setupItemRewards();
 	  bool setupStacks(bool hidden_map);
 	  void setupDiplomacy(bool diplomacy);
+	  bool autoSave();
 
 	  // DATA
 	  std::string d_name;
 	  std::string d_comment;
 	  bool d_turnmode; //see NextTurn for a description of this option
-	  Uint32 d_playmode;
+	  guint32 d_playmode;
 	  std::string d_id; //globally unique id identifying the scenario
 	  std::string recording_file;
+	  bool inhibit_autosave_removal;
 };
 
 #endif // GAME_SCENARIO_H
