@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -98,6 +98,8 @@ int GameScenarioOptions::calculate_difficulty_rating(GameParameters g)
   if (g.neutral_cities == GameParameters::STRONG)
     total_difficulty += (float) 3.0;
   else if (g.neutral_cities == GameParameters::ACTIVE)
+    total_difficulty += (float) 5.0;
+  else if (g.neutral_cities == GameParameters::DEFENSIVE)
     total_difficulty += (float) 6.0;
   if (g.razing_cities == GameParameters::ON_CAPTURE)
     total_difficulty += (float) 3.0;
