@@ -1,10 +1,10 @@
 // Copyright (C) 2003, 2004, 2005, 2006, 2007 Ulf Lorenz
 // Copyright (C) 2004, 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,10 +22,17 @@
 
 #include <string>
 #include <list>
+#include <map>
 #include <vector>
+#include <string.h>
 
 #include "player.h"
 #include "defs.h"
+#include "rgb_shift.h"
+#include "PixMask.h"
+#include "maptile.h"
+
+class Tileset;
 
 struct ArmyCacheItem;
 struct ShipCacheItem;
@@ -45,6 +52,8 @@ struct ProdShieldCacheItem;
 struct MoveBonusCacheItem;
 struct FogCacheItem;
 struct PlantedStandardCacheItem;
+struct NewLevelCacheItem;
+struct TileCacheItem;
 class City;
 
 /** Soliton class for caching army and map images
@@ -103,7 +112,7 @@ class GraphicsCache
         void clear();
 
         //! Get the current cache size, the maximum is in Configuration::s_cacheSize
-        Uint32 getCacheSize() const {return d_cachesize;}
+        guint32 getCacheSize() const {return d_cachesize;}
 
         /** Function for getting the army picture from the cache
           * 
@@ -118,11 +127,15 @@ class GraphicsCache
           * @param armyset      the armyset to be used
           * @param army         the index of the army to be used
           * @param player       the player owning the army
+	  * @param greyed       the image is greyed out; deselected/inactive.
           * @return the image of the unit
           */
-        SDL_Surface* getArmyPic(Uint32 armyset, Uint32 army, const Player* p,
-                                const bool* medals);
-	SDL_Surface* getArmyPic(Army *a);
+        PixMask* getArmyPic(guint32 armyset, guint32 army, const Player* p,
+                                const bool* medals, bool greyed = false);
+	PixMask* getArmyPic(Army *a, bool greyed = false);
+
+	PixMask* getTilePic(int tile_style_id, int fog_type_id, bool has_bag, bool has_standard, int standard_player_id, int stack_size, int stack_player_id, int army_type_id, bool has_tower, bool has_ship, Maptile::Building building_type, int building_subtype, Vector<int> building_tile, int building_player_id, guint32 tilesize, bool has_grid, guint32 tileset, guint32 cityset);
+	PixMask* getTilePic(int tile_style_id, int fog_type_id, bool has_bag, bool has_standard, int standard_player_id, int stack_size, int stack_player_id, int army_type_id, bool has_tower, bool has_ship, Maptile::Building building_type, int building_subtype, Vector<int> building_tile, int building_player_id, guint32 tilesize, bool has_grid);
 
         /** Function for getting the shield picture from the cache
           * 
@@ -134,20 +147,21 @@ class GraphicsCache
           * The returned surface contains the correct player colors and some
           * icons displaying the level of the unit.
           *
-          * @param shieldset    the shieldset to be used
+          * @param shieldset    the id of the shieldset to be used
 	  * @param type         the size of the shield: 0=sm, 1=med, 2=lg
           * @param colour       which player the shield is for
           * @return the image of the shield
           */
-        SDL_Surface* getShieldPic(std::string shieldset, Uint32 type, Uint32 colour);
-        SDL_Surface* getShieldPic(Uint32 type, Player *p);
+        PixMask* getShieldPic(guint32 shieldset, guint32 type, guint32 colour);
+        PixMask* getShieldPic(guint32 type, Player *p);
 
         /** Function for getting a ruin picture
           *
           * @param type         the type of the ruin
           * @return image of the ruin 
           */
-        SDL_Surface* getRuinPic(int type);
+        PixMask* getRuinPic(int type);
+        PixMask* getRuinPic(int type, guint32 cityset);
 
         /** Function for getting a diplomacy icon
           *
@@ -155,42 +169,46 @@ class GraphicsCache
           * @param state        the diplomatic state.  e.g. peace, war, etc
           * @return image of the icon
           */
-        SDL_Surface* getDiplomacyPic(int type, Player::DiplomaticState state);
+        PixMask* getDiplomacyPic(int type, Player::DiplomaticState state);
 
         /** Function for getting a temple picture
           *
           * @param type         the type of the temple
           * @return image of the temple
           */
-        SDL_Surface* getTemplePic(int type);
+        PixMask* getTemplePic(int type);
+        PixMask* getTemplePic(int type, guint32 cityset);
 
         /** Function for getting a road picture
           *
           * @param type         the type of the road
           * @return image of the road
           */
-        SDL_Surface* getRoadPic(int type);
+        PixMask* getRoadPic(int type, guint32 tileset);
+        PixMask* getRoadPic(int type);
 
         /** Function for getting a fog picture
           *
           * @param type         the type of the fog
           * @return image of the fog
           */
-        SDL_Surface* getFogPic(int type);
+        PixMask* getFogPic(int type, guint32 tileset);
+        PixMask* getFogPic(int type);
 
         /** Function for getting a bridge picture
           *
           * @param type         the type of the bridge 0=e/w 1=n/s
           * @return image of the bridge
           */
-        SDL_Surface* getBridgePic(int type);
+        PixMask* getBridgePic(int type, guint32 tileset);
+        PixMask* getBridgePic(int type);
 
         /** Function for getting a cursor picture
           *
           * @param type         the type of the cursor 
           * @return image of the cursor
           */
-        SDL_Surface* getCursorPic(int type);
+        PixMask* getCursorPic(int type);
 
         /** Function for getting a ship picture.  This is the picture
 	  * that appears when the stack goes into the water.
@@ -198,7 +216,7 @@ class GraphicsCache
           * @param p            the player to colour the ship as
           * @return image of the ship
           */
-        SDL_Surface* getShipPic(const Player* p);
+        PixMask* getShipPic(const Player* p);
 
         /** Function for getting a standard picture.  This is the picture
 	  * that appears when the hero plants a flag..
@@ -206,7 +224,16 @@ class GraphicsCache
           * @param p            the player to colour the flag as
           * @return image of the standard
           */
-        SDL_Surface* getPlantedStandardPic(const Player* p);
+        PixMask* getPlantedStandardPic(const Player* p);
+
+	/** Function for getting a new-level picture.  This is the picture
+	 * that appears when a hero gains a new level, and subsequently gets
+	 * to increase a stat.
+	 *
+	 * @param p the player to colour the image as.
+	 * @return new-level image.
+	 */
+        PixMask* getNewLevelPic(const Player* p);
 
         /** Function for getting a city picture
           * 
@@ -218,9 +245,10 @@ class GraphicsCache
           * @param type         the level of the city; -1 returns the pic for
           *                     the razed city
           * @param player       the player owning the city
+	  * @param cityset      the cityset that has the city image
           * @return image of the described city
           */
-        SDL_Surface* getCityPic(int type, const Player* p);
+        PixMask* getCityPic(int type, const Player* p, guint32 cityset);
         /** Another function for getting a city picture
           *
           * Most often, we don't need such a sophisticated function. So just
@@ -229,7 +257,8 @@ class GraphicsCache
           * @param city     the city whose picture we want to get
           * @return image of the city
           */
-        SDL_Surface* getCityPic(const City* city);
+        PixMask* getCityPic(const City* city);
+        PixMask* getCityPic(const City* city, guint32 cityset);
 
         /** Function for getting tower pictures.
           *
@@ -239,7 +268,8 @@ class GraphicsCache
           * @param p the player for which we want to get the tower
           * @return image for the tower
           */
-        SDL_Surface* getTowerPic(const Player *p);
+        PixMask* getTowerPic(const Player *p);
+	PixMask* getTowerPic(const Player* p, guint32 cityset);
 
         /** Function for getting flag pictures.
           *
@@ -249,7 +279,10 @@ class GraphicsCache
           * @param stack    the stack for which we want to get the flag
           * @return image for the flag
           */
-        SDL_Surface* getFlagPic(const Stack* s);
+        PixMask* getFlagPic(const Stack* s);
+        PixMask* getFlagPic(const Stack* s, guint32 tileset);
+	PixMask* getFlagPic(guint32 stack_size, const Player *p);
+        PixMask* getFlagPic(guint32 stack_size, const Player *p, guint32 tileset);
 
         /** Function for getting selector pictures.
           *
@@ -260,7 +293,9 @@ class GraphicsCache
           * @param p the player to draw it for
           * @return image for the flag
           */
-        SDL_Surface* getSelectorPic(Uint32 type, Uint32 frame, const Player* p);
+        PixMask* getSelectorPic(guint32 type, guint32 frame, const Player* p, guint32 tileset);
+
+	PixMask* getSelectorPic(guint32 type, guint32 frame, const Player *p);
 
         /** Function for getting shield pictures.
           *
@@ -271,32 +306,39 @@ class GraphicsCache
           * @param p the player to draw it for
           * @return image for the shield
           */
-        SDL_Surface* getShieldPic(Uint32 type, const Player* p);
+        PixMask* getShieldPic(guint32 type, const Player* p);
 
 
-        SDL_Surface* getSmallRuinedCityPic();
-        SDL_Surface* getSmallHeroPic();
-        SDL_Surface* getPortPic();
-        SDL_Surface* getExplosionPic();
-        SDL_Surface* getSignpostPic();
-        SDL_Surface* getMoveBonusPic(Uint32 bonus, bool has_ship);
-        SDL_Surface *getSmallTemplePic();
-        SDL_Surface *getSmallRuinExploredPic();
-        SDL_Surface* getSmallRuinUnexploredPic();
-        SDL_Surface* getSmallStrongholdUnexploredPic();
+        PixMask* getSmallRuinedCityPic();
+	//! Return a small hero picture, either white (active==true) or black.
+        PixMask* getSmallHeroPic(bool active);
+        PixMask* getBagPic();
+        PixMask* getPortPic();
+        PixMask* getExplosionPic();
+        PixMask* getSignpostPic();
+        PixMask* getMoveBonusPic(guint32 bonus, bool has_ship);
+        PixMask*getSmallTemplePic();
+        PixMask*getSmallRuinExploredPic();
+        PixMask* getSmallRuinUnexploredPic();
+        PixMask* getSmallStrongholdUnexploredPic();
 
         /** Function for getting production shield pictures.
           *
           * As with the other functions, use solely this function to get the 
           * shield images. And DON'T modify the images!
           *
-          * @param type home/away/destination/source.  one sees home/away
+          * @param type home/away/destination/source/invalid.  
+	  * one sees home/away
 	  * normally, but when "see all" is turned on, one sees source/dest.
           * @param prod city production is going on, true or false
           * @return image for the shield
 	  * note that type=source, production=false is impossible
+	  * note that type=invalid,production=true is used to show the symbol
+	  * that means no more units can be vectored to this city.
           */
-        SDL_Surface* getProdShieldPic(Uint32 type, bool prod);
+        PixMask* getProdShieldPic(guint32 type, bool prod);
+
+        PixMask* getMedalPic(bool large, int type);
 
 
         /** Modify an image with player colors.
@@ -310,51 +352,58 @@ class GraphicsCache
           * @param mask     the mask; is only opaque where player colors are wanted
           * @return a surface with player colors applied.
           */
-        SDL_Surface* applyMask(SDL_Surface* image, SDL_Surface* mask, const Player* p);
-	static SDL_Surface* applyMask(SDL_Surface* image, SDL_Surface* mask, SDL_Color mask_color, bool isNeutral);
-        
-	static bool loadSelectorImages(std::string tileset, std::string filename, Uint32 tilesize, std::vector<SDL_Surface*> &images, std::vector<SDL_Surface *> &masks);
 
-	Uint32 getNumberOfLargeSelectorFrames() {return d_selector.size();};
-	Uint32 getNumberOfSmallSelectorFrames() {return d_smallselector.size();}
+	PixMask* applyMask(PixMask* image, PixMask* mask, const Player* p);
+
+
+	static PixMask* applyMask(PixMask* image, PixMask* mask, struct rgb_shift shifts, bool isNeutral);
+        
+	static PixMask* greyOut(PixMask* image);
+
+	static bool loadSelectorImages(std::string filename, guint32 tilesize, std::vector<PixMask* > &images, std::vector<PixMask* > &masks);
+
+	static bool loadFlagImages(std::string filename, guint32 size, std::vector<PixMask* > &images, std::vector<PixMask* > &masks);
+
 
     private:
         GraphicsCache();
         ~GraphicsCache();
 
         //! Creates a new temple picture with the given parameters.
-        TempleCacheItem* addTemplePic(int type);
+        TempleCacheItem* addTemplePic(int type, guint32 cityset);
 
         //! Creates a new ruin picture with the given parameters.
-        RuinCacheItem* addRuinPic(int type);
+        RuinCacheItem* addRuinPic(int type, guint32 cityset);
 
         //! Creates a new diplomacy icon with the given parameters.
         DiplomacyCacheItem* addDiplomacyPic(int type, Player::DiplomaticState state);
 
         //! Creates a new road picture with the given parameters.
-        RoadCacheItem* addRoadPic(int type);
+        RoadCacheItem* addRoadPic(int type, guint32 tileset);
 
         //! Creates a new fog picture with the given parameters.
-        FogCacheItem* addFogPic(int type);
+        FogCacheItem* addFogPic(FogCacheItem *item);
 
         //! Creates a new bridge picture with the given parameters.
-        BridgeCacheItem* addBridgePic(int type);
+        BridgeCacheItem* addBridgePic(int type, guint32 tileset);
 
         //! Creates a new cursor picture with the given parameters.
         CursorCacheItem* addCursorPic(int type);
 
         //! Creates a new army picture with the given parameters.
-        ArmyCacheItem* addArmyPic(Uint32 armyset, Uint32 army, const Player* p,
-                                  const bool* medalsbonus);
+        ArmyCacheItem* addArmyPic(ArmyCacheItem*item);
+
+	//! Creates a new drawn tile with the given parameters.
+	TileCacheItem* addTilePic(TileCacheItem*item);
 
         //! Creates a new shield picture with the given parameters.
-        ShieldCacheItem* addShieldPic(std::string shieldset, Uint32 type, Uint32 colour);
+        ShieldCacheItem* addShieldPic(guint32 shieldset, guint32 type, guint32 colour);
 
         //! Creates a new city picture with the given parameters.
-        CityCacheItem* addCityPic(int type, const Player* p);
+        CityCacheItem* addCityPic(int type, const Player* p, guint32 cityset);
 
         //! Creates a new tower picture with the given parameters.
-        TowerCacheItem* addTowerPic(const Player* p);
+	TowerCacheItem* addTowerPic(const Player* p, guint32 cityset);
 
         //! Creates a new ship picture with the given parameters.
         ShipCacheItem* addShipPic(const Player* p);
@@ -362,18 +411,22 @@ class GraphicsCache
         //! Creates a new planted standard picture with the given parameters.
         PlantedStandardCacheItem* addPlantedStandardPic(const Player* p);
 
+	//! Creates a new new-level picture in the player's colour.
+        NewLevelCacheItem* addNewLevelPic(const Player* p);
+
         //! Creates a new flag picture with the given parameters.
-        FlagCacheItem* addFlagPic(int size, const Player* p);
+        FlagCacheItem* addFlagPic(int size, const Player *p, guint32 tileset);
 
         //! Creates a new selector picture with the given parameters.
-        SelectorCacheItem* addSelectorPic(Uint32 type, Uint32 frame, 
-					  const Player* p);
+        SelectorCacheItem* addSelectorPic(guint32 type, guint32 frame, 
+					  const Player* p, guint32 tileset);
 
         //! Creates a new production shield picture with the given parameters.
-        ProdShieldCacheItem* addProdShieldPic(Uint32 type, bool prod);
+        ProdShieldCacheItem* addProdShieldPic(guint32 type, bool prod);
 
         //! Creates a new movement bonus picture with the given parameters.
-        MoveBonusCacheItem* addMoveBonusPic(Uint32 type);
+        MoveBonusCacheItem* addMoveBonusPic(guint32 type);
+
 
         //! Checks if the cache has exceeded the maximum size and reduce it.
         void checkPictures();
@@ -381,6 +434,9 @@ class GraphicsCache
         //! Erases the oldest (least recently requested) army cache item.
         void eraseLastArmyItem();
 
+        //! Erases the oldest (least recently requested) army cache item.
+        void eraseLastTileItem();
+
         //! Erases the oldest (least recently requested) temple cache item.
         void eraseLastTempleItem();
 
@@ -413,6 +469,7 @@ class GraphicsCache
 
         //! Erases the oldest planted standard cache item.
         void eraseLastPlantedStandardItem();
+        void eraseLastNewLevelItem();
 
         //! Erases the oldest flag cache item
         void eraseLastFlagItem();
@@ -444,42 +501,34 @@ class GraphicsCache
         //! Loads the images for the diplomacy pictures.
         void loadDiplomacyPics();
 
-        //! Loads the images for the road pictures.
-        void loadRoadPics();
-
-        //! Loads the images for the fog pictures.
-        void loadFogPics();
-
-        //! Loads the images for the bridge pictures.
-        void loadBridgePics();
-
         //! Loads the images for the cursor pictures.
         void loadCursorPics();
 
-        //! Loads the images for the flags
-        void loadFlags();
-
-        //! Loads the images for the two selectors
-        void loadSelectors();
-
+        //! Loads the images for the medals.
+        void loadMedalPics();
         
         //! Loads the images for the production shields
         void loadProdShields();
         
+	//! Loads the images associated with heroes gaining a new level.
+        void loadNewLevelPics();
+
         //! Loads the images for the movement bonuses
         void loadMoveBonusPics();
-        /** Get a cityset picture
-          * @param citysetname       the name of the cityset
-          * @param picname          the name of the picture
-          * @return the surface which contains the picture
-          */
-        static SDL_Surface* getCitysetPicture(std::string citysetname, std::string picname);
+
+	void drawTilePic(PixMask *surface, int fog_type_id, bool has_bag, bool has_standard, int standard_player_id, int stack_size, int stack_player_id, int army_type_id, bool has_tower, bool has_ship, Maptile::Building building_type, int building_subtype, Vector<int> building_tile, int building_player_id, guint32 ts, bool has_grid, guint32 tileset, guint32 cityset);
 
         //the data
         static GraphicsCache* s_instance;
 
-        Uint32 d_cachesize;
+        guint32 d_cachesize;
         std::list<ArmyCacheItem*> d_armylist;
+	typedef std::map<ArmyCacheItem, std::list<ArmyCacheItem*>::iterator > ArmyMap;
+
+	ArmyMap	d_armymap;
+        std::list<TileCacheItem*> d_tilelist;
+	typedef std::map<TileCacheItem, std::list<TileCacheItem*>::iterator > TileMap;
+	TileMap	d_tilemap;
         std::list<CityCacheItem*> d_citylist;
         std::list<TowerCacheItem*> d_towerlist;
         std::list<FlagCacheItem*> d_flaglist;
@@ -488,6 +537,9 @@ class GraphicsCache
         std::list<DiplomacyCacheItem*> d_diplomacylist;
         std::list<RoadCacheItem*> d_roadlist;
         std::list<FogCacheItem*> d_foglist;
+	typedef std::map<FogCacheItem, std::list<FogCacheItem*>::iterator > FogCacheMap;
+
+	FogCacheMap d_fogmap;
         std::list<BridgeCacheItem*> d_bridgelist;
         std::list<CursorCacheItem*> d_cursorlist;
         std::list<SelectorCacheItem*> d_selectorlist;
@@ -496,40 +548,28 @@ class GraphicsCache
         std::list<MoveBonusCacheItem*> d_movebonuslist;
         std::list<ShipCacheItem*> d_shiplist;
         std::list<PlantedStandardCacheItem*> d_plantedstandardlist;
+        std::list<NewLevelCacheItem*> d_newlevellist;
 
         //some private surfaces
-        SDL_Surface* d_medalsmask;
-        SDL_Surface* d_citypic[MAX_PLAYERS + 1]; //+1 for neutral
-        SDL_Surface* d_towerpic[MAX_PLAYERS];
-        SDL_Surface* d_templepic[TEMPLE_TYPES];
-        SDL_Surface* d_ruinpic[RUIN_TYPES];
-        SDL_Surface* d_diplomacypic[2][DIPLOMACY_TYPES];
-        SDL_Surface* d_roadpic[ROAD_TYPES];
-        SDL_Surface* d_bridgepic[BRIDGE_TYPES];
-        SDL_Surface* d_cursorpic[CURSOR_TYPES];
-        SDL_Surface* d_razedpic[MAX_PLAYERS + 1]; //+1 for neutral
-        SDL_Surface* d_flagpic[MAX_STACK_SIZE];
-        SDL_Surface* d_flagmask[MAX_STACK_SIZE];
-	//SDL_Surface* d_selector[SELECTOR_FRAMES];
-	//SDL_Surface* d_selectormask[SELECTOR_FRAMES];
-	std::vector<SDL_Surface*> d_selector;
-	std::vector<SDL_Surface*> d_selectormask;
-	std::vector<SDL_Surface*> d_smallselector;
-	std::vector<SDL_Surface*> d_smallselectormask;
-	//SDL_Surface* d_smallselector[SMALL_SELECTOR_FRAMES];
-	//SDL_Surface* d_smallselectormask[SMALL_SELECTOR_FRAMES];
-        SDL_Surface* d_prodshieldpic[PRODUCTION_SHIELD_TYPES];
-	SDL_Surface* d_smallruinedcity;
-	SDL_Surface* d_smallhero;
-        SDL_Surface* d_movebonuspic[MOVE_BONUS_TYPES];
-	SDL_Surface* d_port;
-	SDL_Surface* d_explosion;
-	SDL_Surface* d_signpost;
-	SDL_Surface* d_small_ruin_unexplored;
-	SDL_Surface* d_small_stronghold_unexplored;
-	SDL_Surface* d_small_ruin_explored;
-	SDL_Surface* d_small_temple;
-	SDL_Surface *d_fogpic[FOG_TYPES];
+        PixMask* d_diplomacypic[2][DIPLOMACY_TYPES];
+
+        PixMask* d_cursorpic[CURSOR_TYPES];
+        PixMask* d_prodshieldpic[PRODUCTION_SHIELD_TYPES];
+	PixMask* d_smallruinedcity;
+	PixMask* d_smallhero;
+	PixMask* d_smallinactivehero;
+        PixMask* d_movebonuspic[MOVE_BONUS_TYPES];
+        PixMask* d_medalpic[2][MEDAL_TYPES];
+	PixMask* d_bag;
+	PixMask* d_small_ruin_unexplored;
+	PixMask* d_small_stronghold_unexplored;
+	PixMask* d_small_ruin_explored;
+	PixMask* d_small_temple;
+	PixMask *d_newlevel;
+	PixMask *d_newlevelmask;
 };
 
+bool operator <(ArmyCacheItem lhs, ArmyCacheItem rhs);
+bool operator <(TileCacheItem lhs, TileCacheItem rhs);
+bool operator <(FogCacheItem lhs, FogCacheItem rhs);
 #endif
