@@ -1,11 +1,11 @@
 // Copyright (C) 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -63,7 +63,7 @@ Item::Item(std::string name, bool plantable, Player *plantable_owner)
   //std::cerr << "item created with id " << d_id << std::endl;
 }
 
-Item::Item(std::string name, bool plantable, Player *plantable_owner, Uint32 id)
+Item::Item(std::string name, bool plantable, Player *plantable_owner, guint32 id)
 	: ItemProto(name, 0), UniquelyIdentified(id)
 {
   d_type = 0;
@@ -106,7 +106,7 @@ bool Item::save(XML_Helper* helper) const
 
   // A template is never saved, so we assume this class is a real-life item
   retval &= helper->openTag(Item::d_tag);
-  retval &= helper->saveData("name", getName());
+  retval &= helper->saveData("name", getName(false));
   retval &= helper->saveData("plantable", d_plantable);
   if (d_plantable)
     {
