@@ -3,7 +3,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -35,7 +35,7 @@
  * you can get the item belonging to the index by the []-operator using the
  * item index as index.
  */
-class Itemlist : public std::map<Uint32, ItemProto*>, public sigc::trackable
+class Itemlist : public std::map<guint32, ItemProto*>, public sigc::trackable
 {
     public:
 
