@@ -5,7 +5,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -27,7 +27,7 @@
 
 #include "xmlhelper.h"
 
-Location::Location(Vector<int> pos, Uint32 size)
+Location::Location(Vector<int> pos, guint32 size)
     :UniquelyIdentified(), LocationBox(pos, size)
 {
 }
@@ -37,7 +37,7 @@ Location::Location(const Location& loc)
 {
 }
 
-Location::Location(XML_Helper* helper, Uint32 size)
+Location::Location(XML_Helper* helper, guint32 size)
     :UniquelyIdentified(helper), LocationBox(helper)
 {
     d_size = size;
