@@ -2,7 +2,21 @@
 // Copyright (C) 2000, 2001, 2002, 2004, 2005 Ulf Lorenz
 // Copyright (C) 2006 Andrea Paternesi
 // Copyright (C) 2006, 2007, 2008 Ben Asselstine
-
+//
+//  This program is free software; you can redistribute it and/or modify
+//  it under the terms of the GNU General Public License as published by
+//  the Free Software Foundation; either version 3 of the License, or
+//  (at your option) any later version.
+//
+//  This program is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU Library General Public License for more details.
+//
+//  You should have received a copy of the GNU General Public License
+//  along with this program; if not, write to the Free Software
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 #ifndef LOCATION_H
 #define LOCATION_H
 
@@ -31,7 +45,7 @@ class Location : public UniquelyIdentified, public LocationBox
       *                position on the game map.
       * @param size    The number of tiles wide and high the feature is.
       */
-     Location(Vector<int> pos, Uint32 size = 1);
+     Location(Vector<int> pos, guint32 size = 1);
      //! Copy constructor.
      Location(const Location&);
      //! Loading constructor.
@@ -42,7 +56,7 @@ class Location : public UniquelyIdentified, public LocationBox
       * @param size    The size of the feature.  This value is not read in
       *                from the saved-game file.
       */
-     Location(XML_Helper* helper, Uint32 size = 1);
+     Location(XML_Helper* helper, guint32 size = 1);
      //! Destructor.
     ~Location();
 };
