@@ -1,11 +1,11 @@
 // Copyright (C) 2000, 2001, 2003 Michael Bartl
 // Copyright (C) 2000, 2001, 2002, 2004, 2005 Ulf Lorenz
 // Copyright (C) 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -28,7 +28,7 @@
 
 #include "xmlhelper.h"
 
-LocationBox::LocationBox(Vector<int> pos, Uint32 size)
+LocationBox::LocationBox(Vector<int> pos, guint32 size)
     :Immovable(pos), d_size(size)
 {
 }
@@ -55,7 +55,7 @@ LocationBox::LocationBox(const LocationBox& loc)
 {
 }
 
-LocationBox::LocationBox(XML_Helper* helper, Uint32 size)
+LocationBox::LocationBox(XML_Helper* helper, guint32 size)
     :Immovable(helper)
 {
     d_size = size;
@@ -106,7 +106,7 @@ Stack* LocationBox::getFreeStack(Player *p) const
     return NULL;
 }
 
-bool LocationBox::isFogged(Player *player)
+bool LocationBox::isVisible(Player *player) const
 {
   for (unsigned int i = 0; i < d_size; i++)
     for (unsigned int j = 0; j < d_size; j++)
@@ -114,12 +114,11 @@ bool LocationBox::isFogged(Player *player)
         Vector<int> pos;
         pos.x = getPos().x + i;
         pos.y = getPos().y + j;
-	if (FogMap::isFogged(pos, player))
-          return true;
+	if (FogMap::isClear(pos, player))
+	  return true;
       }
   return false;
 }
-
 void LocationBox::deFog()
 {
   Player *p = Playerlist::getActiveplayer();
@@ -145,3 +144,15 @@ bool LocationBox::contains(Vector<int> pos) const
       && (pos.y >= getPos().y) && (pos.y < getPos().y + (int) d_size);
 }
 
+    
+bool LocationBox::isCompletelyObscuredByFog(Player *p) const
+{
+  for (unsigned int i = 0; i < d_size; i++)
+    for (unsigned int j = 0; j < d_size; j++)
+      {
+	Vector<int> pos = Vector<int>(i,j);
+	if (p->getFogMap()->isCompletelyObscuredFogTile(pos) == false)
+	  return false;
+      }
+  return true;
+}
