@@ -1,12 +1,26 @@
 // Copyright (C) 2000, 2001, 2003 Michael Bartl
 // Copyright (C) 2000, 2001, 2002, 2004, 2005 Ulf Lorenz
 // Copyright (C) 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
-
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
+//
+//  This program is free software; you can redistribute it and/or modify
+//  it under the terms of the GNU General Public License as published by
+//  the Free Software Foundation; either version 3 of the License, or
+//  (at your option) any later version.
+//
+//  This program is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU Library General Public License for more details.
+//
+//  You should have received a copy of the GNU General Public License
+//  along with this program; if not, write to the Free Software
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 #ifndef LOCATION_BOX_H
 #define LOCATION_BOX_H
 
-#include <SDL.h>
+#include <gtkmm.h>
 #include <string>
 #include "vector.h"
 #include "Immovable.h"
@@ -30,7 +44,7 @@ class LocationBox : public Immovable
       *                position on the game map.
       * @param size    The number of tiles wide and high the feature is.
       */
-     LocationBox(Vector<int> pos, Uint32 size = 1);
+     LocationBox(Vector<int> pos, guint32 size = 1);
 
      //! Non-Standard constructor.
      /**
@@ -48,7 +62,7 @@ class LocationBox : public Immovable
       * @param size    The size of the place.  This value is not read in
       *                from the saved-game file.
       */
-     LocationBox(XML_Helper* helper, Uint32 size = 1);
+     LocationBox(XML_Helper* helper, guint32 size = 1);
      //! Destructor.
     ~LocationBox();
     
@@ -61,11 +75,18 @@ class LocationBox : public Immovable
      */
     Stack *addArmy(Army *army) const;
 
-    //! Returns whether or not this location obscured from view on a hidden map.
+    //! Returns whether this location is at least partially viewable.
     /**
+     * This method returns true if the location has parts that are completely
+     * defogged.
+     * If the location is completely fogged or partially fogged then this 
+     * method returns false.
+     *
      * @param player The player whose map to query.
      */
-    bool isFogged(Player *player);
+    bool isVisible(Player *player) const;
+
+    bool isCompletelyObscuredByFog(Player *player) const;
 
     //! Unobscures the view of this location in the active player's FogMap.
     void deFog();
@@ -74,7 +95,7 @@ class LocationBox : public Immovable
     void deFog(Player *p);
 
     //! Return the size of the location.
-    Uint32 getSize() const {return d_size;}
+    guint32 getSize() const {return d_size;}
 
     //! Returns whether or not the Location contains the given point?
     bool contains(Vector<int> pos) const;
@@ -105,7 +126,7 @@ class LocationBox : public Immovable
      * This size is the number tiles high and wide the location is.
      * This value is always 1, except for City objects which are always 2.
      */
-    Uint32 d_size;
+    guint32 d_size;
 };
 
 #endif
