@@ -1,8 +1,8 @@
-//  Copyright (C) 2008, Ben Asselstine
+//  Copyright (C) 2008 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -45,7 +45,7 @@ class Movable: private Positioned
     Vector<int> getPos() const {return d_pos;}
 
     //! Set the position of the object on the game map.
-    void setPos(Vector<int> pos) {d_pos = pos;}
+    void setPos(Vector<int> pos) {d_pos = pos;};
 
 };
 
