@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -19,7 +19,7 @@
 
 #include "xmlhelper.h"
 
-NamedLocation::NamedLocation(Vector<int> pos, Uint32 size, std::string name,
+NamedLocation::NamedLocation(Vector<int> pos, guint32 size, std::string name,
 			     std::string desc)
   :Location(pos, size), Namable(name), d_description(desc)
 {
@@ -30,7 +30,7 @@ NamedLocation::NamedLocation(const NamedLocation& object)
 {
 }
 
-NamedLocation::NamedLocation(XML_Helper* helper, Uint32 size)
+NamedLocation::NamedLocation(XML_Helper* helper, guint32 size)
   :Location(helper, size), Namable(helper)
 {
   helper->getData(d_description, "description");
