@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -19,6 +19,7 @@
 #include <sstream>
 #include <assert.h>
 #include <sigc++/functors/mem_fun.h>
+#include "ucompose.hpp"
 
 #include "QCityRaze.h"
 #include "QuestsManager.h"
@@ -33,7 +34,7 @@ using namespace std;
 #define debug(x)
 
 //=======================================================================
-QuestCityRaze::QuestCityRaze (QuestsManager& mgr, Uint32 hero) 
+QuestCityRaze::QuestCityRaze (QuestsManager& mgr, guint32 hero) 
     : Quest(mgr, hero, Quest::CITYRAZE)
 {
     // find us a victim
@@ -54,7 +55,7 @@ QuestCityRaze::QuestCityRaze (QuestsManager& q_mgr, XML_Helper* helper)
     initDescription();
 }
 //=======================================================================
-QuestCityRaze::QuestCityRaze (QuestsManager& mgr, Uint32 hero, Uint32 target) 
+QuestCityRaze::QuestCityRaze (QuestsManager& mgr, guint32 hero, guint32 target) 
     : Quest(mgr, hero, Quest::CITYRAZE)
 {
     d_city = target;
@@ -62,7 +63,7 @@ QuestCityRaze::QuestCityRaze (QuestsManager& mgr, Uint32 hero, Uint32 target)
     initDescription();
 }
 //=======================================================================
-bool QuestCityRaze::isFeasible(Uint32 heroId)
+bool QuestCityRaze::isFeasible(guint32 heroId)
 {
   if (QuestCityRaze::chooseToRaze(getHeroById(heroId)->getOwner()))
     return true;
@@ -94,12 +95,10 @@ void QuestCityRaze::getSuccessMsg(std::queue<std::string>& msgs) const
 //=======================================================================
 void QuestCityRaze::getExpiredMsg(std::queue<std::string>& msgs) const
 {
-    char buf[101]; buf[100] = '\0';
     const City* c = getCity();
-
-    snprintf(buf, 100, _("The razing of city \"%s\" could not be "
-			 "accomplished."), c->getName().c_str());
-    msgs.push(buf);
+    msgs.push(String::ucompose
+	      (_("The razing of city \"%1\" could not be accomplished."), 
+	       c->getName()));
 }
 //=======================================================================
 City* QuestCityRaze::getCity() const
@@ -115,13 +114,10 @@ City* QuestCityRaze::getCity() const
 void QuestCityRaze::initDescription()
 {
     const City* c = getCity();
-    char buffer[121]; buffer[120]='\0';
-    
-    snprintf(buffer, 100, 
-	     _("You must conquer the city \"%s\" and burn it to the ground."),
-            c->getName().c_str());
 
-    d_description = std::string(buffer);
+    d_description = String::ucompose 
+      ( _("You must conquer the city \"%1\" and burn it to the ground."),
+	c->getName());
 }
 //=======================================================================
 City* QuestCityRaze::chooseToRaze(Player *p)
