@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -19,6 +19,7 @@
 #include <sstream>
 #include <assert.h>
 #include <sigc++/functors/mem_fun.h>
+#include "ucompose.hpp"
 
 #include "QCitySack.h"
 #include "QuestsManager.h"
@@ -33,7 +34,7 @@ using namespace std;
 #define debug(x)
 
 //=======================================================================
-QuestCitySack::QuestCitySack (QuestsManager& mgr, Uint32 hero) 
+QuestCitySack::QuestCitySack (QuestsManager& mgr, guint32 hero) 
     : Quest(mgr, hero, Quest::CITYSACK)
 {
     // find us a victim
@@ -55,7 +56,7 @@ QuestCitySack::QuestCitySack (QuestsManager& q_mgr, XML_Helper* helper)
     initDescription();
 }
 //=======================================================================
-QuestCitySack::QuestCitySack (QuestsManager& mgr, Uint32 hero, Uint32 target) 
+QuestCitySack::QuestCitySack (QuestsManager& mgr, guint32 hero, guint32 target) 
     : Quest(mgr, hero, Quest::CITYSACK)
 {
     d_city = target;
@@ -63,7 +64,7 @@ QuestCitySack::QuestCitySack (QuestsManager& mgr, Uint32 hero, Uint32 target)
     initDescription();
 }
 //=======================================================================
-bool QuestCitySack::isFeasible(Uint32 heroId)
+bool QuestCitySack::isFeasible(guint32 heroId)
 {
   if (QuestCitySack::chooseToSack(getHeroById(heroId)->getOwner()))
     return true;
@@ -94,12 +95,9 @@ void QuestCitySack::getSuccessMsg(std::queue<std::string>& msgs) const
 //=======================================================================
 void QuestCitySack::getExpiredMsg(std::queue<std::string>& msgs) const
 {
-    char buf[101]; buf[100] = '\0';
     const City* c = getCity();
-
-    snprintf(buf, 100, _("The sacking of \"%s\" could not be accomplished."), 
-	     c->getName().c_str());
-    msgs.push(buf);
+    msgs.push(String::ucompose(_("The sacking of \"%1\" could not be accomplished."), 
+			       c->getName()));
 }
 //=======================================================================
 City* QuestCitySack::getCity() const
@@ -115,12 +113,7 @@ City* QuestCitySack::getCity() const
 void QuestCitySack::initDescription()
 {
     const City* c = getCity();
-    char buffer[121]; buffer[120]='\0';
-    
-    snprintf(buffer, 100, _("You must take over and sack the city of \"%s\"."),
-            c->getName().c_str());
-
-    d_description = std::string(buffer);
+    d_description = String::ucompose (_("You must take over and sack the city of \"%1\"."), c->getName());
 }
 //=======================================================================
 City * QuestCitySack::chooseToSack(Player *p)
