@@ -1,11 +1,11 @@
 // Copyright (C) 2003, 2004, 2005 Ulf Lorenz
 // Copyright (C) 2004 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,12 +20,13 @@
 
 #include <sstream>
 #include <sigc++/functors/mem_fun.h>
+#include "ucompose.hpp"
 
 #include "QEnemyArmies.h"
 #include "QuestsManager.h"
 #include "playerlist.h"
 #include "stacklist.h"
-#include "citylist.h"
+#include "GameMap.h"
 
 using namespace std;
 
@@ -50,12 +51,11 @@ void QuestEnemyArmies::update_targets()
 {
   Stacklist::const_iterator sit ;
   Stacklist *sl = d_victim_player->getStacklist();
-  Citylist *cl = Citylist::getInstance();
   d_targets.clear();
   for (sit = sl->begin(); sit != sl->end(); sit++)
     {
       //is this not a city location?  no?  then it's a target.
-      if (cl->getObjectAt((*sit)->getPos()) == NULL)
+      if (GameMap::getCity((*sit)->getPos()) == NULL)
         d_targets.push_back((*sit)->getPos());
     }
 }
@@ -63,7 +63,7 @@ void QuestEnemyArmies::update_targets()
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 //=======================================================================
-QuestEnemyArmies::QuestEnemyArmies(QuestsManager& q_mgr, Uint32 hero)
+QuestEnemyArmies::QuestEnemyArmies(QuestsManager& q_mgr, guint32 hero)
     : Quest(q_mgr, hero, Quest::KILLARMIES), d_killed(0)
 {
     // have us be informed when hostilities break out
@@ -79,7 +79,7 @@ QuestEnemyArmies::QuestEnemyArmies(QuestsManager& q_mgr, Uint32 hero)
 QuestEnemyArmies::QuestEnemyArmies(QuestsManager& q_mgr, XML_Helper* helper) 
     : Quest(q_mgr, helper)
 {
-    Uint32 ui;
+    guint32 ui;
     
     helper->getData(d_to_kill, "to_kill");
     helper->getData(d_killed,  "killed");
@@ -91,8 +91,8 @@ QuestEnemyArmies::QuestEnemyArmies(QuestsManager& q_mgr, XML_Helper* helper)
     initDescription();
 }
 //=======================================================================
-QuestEnemyArmies::QuestEnemyArmies(QuestsManager& q_mgr, Uint32 hero,
-                                   Uint32 armies_to_kill, Uint32 victim_player)
+QuestEnemyArmies::QuestEnemyArmies(QuestsManager& q_mgr, guint32 hero,
+                                   guint32 armies_to_kill, guint32 victim_player)
     : Quest(q_mgr, hero, Quest::KILLARMIES), d_killed(0)
 {
     // have us be informed when hostilities break out
@@ -119,17 +119,12 @@ bool QuestEnemyArmies::save(XML_Helper *helper) const
 //=======================================================================
 std::string QuestEnemyArmies::getProgress() const
 {
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, _("You have killed %i so far."), d_killed);
-    return std::string(buffer);
+    return String::ucompose (_("You have killed %1 so far."), d_killed);
 }
 //=======================================================================
 void QuestEnemyArmies::getSuccessMsg(std::queue<std::string>& msgs) const
 {
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, "You have managed to slaughter %i armies.", d_killed);
-    
-    msgs.push(std::string(buffer));
+    msgs.push(String::ucompose(_("You have managed to slaughter %1 armies."), d_killed));
     msgs.push(_("Well done!"));
 }
 //=======================================================================
@@ -140,14 +135,11 @@ void QuestEnemyArmies::getExpiredMsg(std::queue<std::string>& msgs) const
 //=======================================================================
 void QuestEnemyArmies::initDescription()
 {
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, "You shall slaughter %i armies of the treacherous %s",
-	     d_to_kill, d_victim_player->getName().c_str());
-
-    d_description = std::string(buffer);
+    d_description = String::ucompose(_("You shall slaughter %1 armies of the treacherous %2."),
+				     d_to_kill, d_victim_player->getName());
 }
 
-bool QuestEnemyArmies::isFeasible(Uint32 heroId)
+bool QuestEnemyArmies::isFeasible(guint32 heroId)
 {
   if (getVictimPlayer(getHeroById(heroId)->getOwner()))
     return true;
