@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,13 +17,14 @@
 
 #include <sstream>
 #include <sigc++/functors/mem_fun.h>
+#include "ucompose.hpp"
 
 #include "QEnemyArmytype.h"
 #include "QuestsManager.h"
 #include "playerlist.h"
 #include "stacklist.h"
-#include "citylist.h"
 #include "armysetlist.h"
+#include "GameMap.h"
 
 using namespace std;
 
@@ -35,7 +36,6 @@ int getVictimArmytype(Player *p, std::list<Vector<int> >&targets)
   Stacklist::const_iterator sit ;
   Stack::iterator it ;
   Stacklist *sl;
-  Citylist *cl = Citylist::getInstance();
   const Playerlist* pl = Playerlist::getInstance();
   for (Playerlist::const_iterator pit = pl->begin(); pit != pl->end(); pit++)
     {
@@ -45,7 +45,7 @@ int getVictimArmytype(Player *p, std::list<Vector<int> >&targets)
       for (sit = sl->begin(); sit != sl->end(); sit++)
         {
           //is this stack not in a city?  no?  it's a target.
-          if (cl->getObjectAt((*sit)->getPos()) == NULL)
+          if (GameMap::getCity((*sit)->getPos()) == NULL)
             targets.push_back((*sit)->getPos());
           for (it = (*sit)->begin(); it != (*sit)->end(); it++)
             {
@@ -65,7 +65,7 @@ int getVictimArmytype(Player *p, std::list<Vector<int> >&targets)
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 //=======================================================================
-QuestEnemyArmytype::QuestEnemyArmytype(QuestsManager& q_mgr, Uint32 hero)
+QuestEnemyArmytype::QuestEnemyArmytype(QuestsManager& q_mgr, guint32 hero)
     : Quest(q_mgr, hero, Quest::KILLARMYTYPE)
 {
     Player *p = getHero()->getOwner();
@@ -84,8 +84,8 @@ QuestEnemyArmytype::QuestEnemyArmytype(QuestsManager& q_mgr, XML_Helper* helper)
     initDescription();
 }
 //=======================================================================
-QuestEnemyArmytype::QuestEnemyArmytype(QuestsManager& q_mgr, Uint32 hero,
-                                       Uint32 type_to_kill)
+QuestEnemyArmytype::QuestEnemyArmytype(QuestsManager& q_mgr, guint32 hero,
+                                       guint32 type_to_kill)
     : Quest(q_mgr, hero, Quest::KILLARMYTYPE)
 {
     // pick a victim
@@ -109,23 +109,18 @@ bool QuestEnemyArmytype::save(XML_Helper *helper) const
 std::string QuestEnemyArmytype::getProgress() const
 {
     Armysetlist *al = Armysetlist::getInstance();
-    Uint32 set = Playerlist::getInstance()->getActiveplayer()->getArmyset();
+    guint32 set = Playerlist::getInstance()->getActiveplayer()->getArmyset();
     const ArmyProto *a = al->getArmy(set, d_type_to_kill);
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, _("You have not killed a unit of enemy %s yet."), 
-	     a->getName().c_str());
-    return std::string(buffer);
+    return String::ucompose(
+	     _("You have not killed a unit of enemy %1 yet."), a->getName());
 }
 //=======================================================================
 void QuestEnemyArmytype::getSuccessMsg(std::queue<std::string>& msgs) const
 {
     Armysetlist *al = Armysetlist::getInstance();
-    Uint32 set = Playerlist::getInstance()->getActiveplayer()->getArmyset();
+    guint32 set = Playerlist::getInstance()->getActiveplayer()->getArmyset();
     const ArmyProto *a = al->getArmy(set, d_type_to_kill);
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, _("You have killed a unit of enemy %s."), a->getName().c_str());
-    
-    msgs.push(std::string(buffer));
+    msgs.push(String::ucompose(_("You have killed a unit of enemy %1."), a->getName()));
     msgs.push(_("Well done!"));
 }
 //=======================================================================
@@ -137,16 +132,13 @@ void QuestEnemyArmytype::getExpiredMsg(std::queue<std::string>& msgs) const
 void QuestEnemyArmytype::initDescription()
 {
     Armysetlist *al = Armysetlist::getInstance();
-    Uint32 set = Playerlist::getInstance()->getActiveplayer()->getArmyset();
+    guint32 set = Playerlist::getInstance()->getActiveplayer()->getArmyset();
     const ArmyProto *a = al->getArmy(set, d_type_to_kill);
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, _("You must destroy a unit of enemy %s."), 
-	     a->getName().c_str());
-
-    d_description = std::string(buffer);
+    d_description = String::ucompose(_("You must destroy a unit of enemy %1."), 
+	     a->getName());
 }
 //=======================================================================
-bool QuestEnemyArmytype::isFeasible(Uint32 heroId)
+bool QuestEnemyArmytype::isFeasible(guint32 heroId)
 {
   std::list< Vector<int> >targets;
   int type = getVictimArmytype(getHeroById(heroId)->getOwner(), targets);
