@@ -5,7 +5,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,6 +22,7 @@
 #include <sstream>
 #include <assert.h>
 #include <sigc++/functors/mem_fun.h>
+#include "ucompose.hpp"
 
 #include "history.h"
 #include "QKillHero.h"
@@ -35,7 +36,7 @@ using namespace std;
 //#define debug(x)
 
 //=======================================================================
-QuestKillHero::QuestKillHero(QuestsManager& mgr, Uint32 hero) 
+QuestKillHero::QuestKillHero(QuestsManager& mgr, guint32 hero) 
     : Quest(mgr, hero, Quest::KILLHERO)
 {
     // find a suitable hero for us
@@ -61,7 +62,7 @@ QuestKillHero::QuestKillHero(QuestsManager& q_mgr, XML_Helper* helper)
     initDescription();
 }
 //=======================================================================
-QuestKillHero::QuestKillHero(QuestsManager& q_mgr, Uint32 hero, Uint32 victim) 
+QuestKillHero::QuestKillHero(QuestsManager& q_mgr, guint32 hero, guint32 victim) 
     : Quest(q_mgr, hero, Quest::KILLHERO)
 {
     d_victim = victim;
@@ -74,7 +75,7 @@ QuestKillHero::QuestKillHero(QuestsManager& q_mgr, Uint32 hero, Uint32 victim)
     initDescription();
 }
 //=======================================================================
-bool QuestKillHero::isFeasible(Uint32 heroId)
+bool QuestKillHero::isFeasible(guint32 heroId)
 {
     // chooseToKill returns 0 if no enemy heroes exist
     return (chooseToKill() != 0);
@@ -109,30 +110,21 @@ std::string QuestKillHero::getProgress() const
 void QuestKillHero::getSuccessMsg(std::queue<std::string>& msgs) const
 {
     std::string name = getHeroNameForDeadHero(d_victim);
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, _("You have slain the wicked hero %s."), name.c_str());
-    msgs.push(std::string(buffer));
+    msgs.push(String::ucompose(_("You have slain the wicked hero %1."), name));
 }
 //=======================================================================
 void QuestKillHero::getExpiredMsg(std::queue<std::string>& msgs) const
 {
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, _("You could not slay the wicked hero %s"),
-            getHeroNameForDeadHero(d_victim).c_str());
-
-    msgs.push(std::string(buffer));
+    msgs.push(String::ucompose(_("You could not slay the wicked hero %1"),
+            getHeroNameForDeadHero(d_victim)));
     msgs.push(_("The hero was slain by other fellows!"));
 }
 //=======================================================================
 void QuestKillHero::initDescription()
 {
-    char buffer[101]; buffer[100]='\0';
     Hero* v = Quest::getHeroById(d_victim);
-    
-    snprintf(buffer, 100, _("Kill the hero named %s, servant of player %s"),
-            v->getName().c_str(), v->getOwner()->getName().c_str());
-    
-    d_description = std::string(buffer);
+    d_description = String::ucompose(_("Kill the hero named %1, servant of player %2."),
+            v->getName(), v->getOwner()->getName());
 }
 //=======================================================================
 Hero* QuestKillHero::chooseToKill()
