@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,6 +17,7 @@
 
 #include <sstream>
 #include <sigc++/functors/mem_fun.h>
+#include "ucompose.hpp"
 
 #include "QPillageGold.h"
 #include "QuestsManager.h"
@@ -27,7 +28,7 @@ using namespace std;
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 //=======================================================================
-QuestPillageGold::QuestPillageGold(QuestsManager& q_mgr, Uint32 hero)
+QuestPillageGold::QuestPillageGold(QuestsManager& q_mgr, guint32 hero)
     : Quest(q_mgr, hero, Quest::PILLAGEGOLD), d_pillaged(0)
 {
     //pick an amount of gold to sack and pillage
@@ -45,7 +46,7 @@ QuestPillageGold::QuestPillageGold(QuestsManager& q_mgr, XML_Helper* helper)
     initDescription();
 }
 //=======================================================================
-QuestPillageGold::QuestPillageGold(QuestsManager& q_mgr, Uint32 hero, Uint32 gold)
+QuestPillageGold::QuestPillageGold(QuestsManager& q_mgr, guint32 hero, guint32 gold)
     : Quest(q_mgr, hero, Quest::PILLAGEGOLD), d_pillaged(0)
 {
     d_to_pillage = gold;
@@ -68,17 +69,12 @@ bool QuestPillageGold::save(XML_Helper *helper) const
 //=======================================================================
 std::string QuestPillageGold::getProgress() const
 {
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, _("You have already stolen %i gold."), d_pillaged);
-    return std::string(buffer);
+    return String::ucompose(_("You have already stolen %1 gold."), d_pillaged);
 }
 //=======================================================================
 void QuestPillageGold::getSuccessMsg(std::queue<std::string>& msgs) const
 {
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, "You have managed to sack and pillage %i gold.", d_pillaged);
-    
-    msgs.push(std::string(buffer));
+    msgs.push(String::ucompose(_("You have managed to sack and pillage %1 gold."), d_pillaged));
     msgs.push(_("Well done!"));
 }
 //=======================================================================
@@ -89,10 +85,7 @@ void QuestPillageGold::getExpiredMsg(std::queue<std::string>& msgs) const
 //=======================================================================
 void QuestPillageGold::initDescription()
 {
-    char buffer[101]; buffer[100]='\0';
-    snprintf(buffer, 100, "You shall sack and pillage %i gold from thy mighty foes", d_to_pillage);
-
-    d_description = std::string(buffer);
+    d_description = String::ucompose(_("You shall sack and pillage %1 gold from thy mighty foes."), d_to_pillage);
 }
 	
 void QuestPillageGold::armyDied(Army *a, bool heroIsCulprit)
