@@ -4,7 +4,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -33,7 +33,7 @@ using namespace std;
 //#define debug(x)
 
 
-Quest::Quest(QuestsManager& q_mgr, Uint32 hero, Type type)
+Quest::Quest(QuestsManager& q_mgr, guint32 hero, Type type)
     :d_q_mgr(q_mgr), d_hero(hero), d_type(type), d_pending(false)
 {
   Hero *h = getHeroById(hero);
@@ -51,7 +51,7 @@ Quest::Quest(QuestsManager& q_mgr, XML_Helper* helper)
     helper->getData(d_player_id, "player");
 }
 
-Hero* Quest::getHeroById(Uint32 hero, Stack** stack)
+Hero* Quest::getHeroById(guint32 hero, Stack** stack)
 {
     Playerlist* pl = Playerlist::getInstance();
 	Playerlist::const_iterator pit;
@@ -108,7 +108,7 @@ std::string Quest::getHeroNameForDeadHero()
   return getHeroNameForDeadHero(d_hero);
 }
 
-std::string Quest::getHeroNameForDeadHero(Uint32 id)
+std::string Quest::getHeroNameForDeadHero(guint32 id)
 {
   std::list<History *>events;
   events = Playerlist::getInstance()->getHistoryForHeroId(id);
