@@ -1,11 +1,11 @@
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2004, 2005 Ulf Lorenz
 // Copyright (C) 2005 Andrea Paternesi
-// Copyright (C) 2007 Ben Asselstine
+// Copyright (C) 2007, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -188,6 +188,12 @@ void Threatlist::findThreats(AICityInfo *info) const
     }
 }
 
+void Threatlist::deleteStack(guint32 id)
+{
+    for (Threatlist::iterator it = begin(); it != end(); it++)
+        (*it)->deleteStack(id);
+}
+
 void Threatlist::deleteStack(Stack* s)
 {
     for (Threatlist::iterator it = begin(); it != end(); it++)
