@@ -4,7 +4,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -99,7 +99,7 @@ TileStyle *Tile::getRandomTileStyle (TileStyle::Type style)
   for (iterator it = begin(); it != end(); ++it)
     {
       TileStyleSet *tilestyleset = *it;
-      for (Uint32 k = 0; k < tilestyleset->size(); k++)
+      for (guint32 k = 0; k < tilestyleset->size(); k++)
 	{
 	  TileStyle *tilestyle = (*tilestyleset)[k];
 	  if (tilestyle->getType() == style)
