@@ -1,11 +1,11 @@
 // Copyright (C) 2002, 2003, 2004, 2005 Ulf Lorenz
 // Copyright (C) 2003 Michael Bartl
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -23,11 +23,12 @@
 
 #include <string>
 #include <list>
-#include <SDL_types.h>
+#include <gtkmm.h>
 
 #include "real_player.h"
 
 class XML_Helper;
+class City;
 
 //! A simple artificial intelligence Player suitable to be the neutral Player.
 /** 
@@ -50,7 +51,7 @@ class AI_Dummy : public RealPlayer
 	 *                     the next free Id it used.
          */
 	//! Default constructor.
-        AI_Dummy (std::string name, Uint32 armyset, SDL_Color color, 
+        AI_Dummy (std::string name, guint32 armyset, Gdk::Color color, 
 		  int width, int height, int player_no = -1);
 
 	//! Copy constructor.
@@ -65,6 +66,9 @@ class AI_Dummy : public RealPlayer
         virtual void invadeCity(City* c);
         virtual void levelArmy(Army* a);
 
+	void setDefensiveProduction(City *city);
+	void examineCities();
+
     private:
 	//DATA
 	bool d_abort_requested;
