@@ -1,12 +1,12 @@
 // Copyright (C) 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2003 Michael Bartl
 // Copyright (C) 2004 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -30,6 +30,7 @@
 #include "AI_Diplomacy.h"
 
 class XML_Helper;
+class City;
 
 
 //! A simple artificial intelligence Player.
@@ -57,7 +58,7 @@ class AI_Fast : public RealPlayer
 	 *                     the next free Id it used.
          */
 	//! Default constructor.
-        AI_Fast(std::string name, Uint32 armyset, SDL_Color color, 
+        AI_Fast(std::string name, guint32 armyset, Gdk::Color color, 
 		int width, int height, int player_no = -1);
 
         //! Copy constructor.
