@@ -1,12 +1,12 @@
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2005, 2006 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -27,7 +27,6 @@
 #include "playerlist.h"
 #include "armysetlist.h"
 #include "stacklist.h"
-#include "citylist.h"
 #include "path.h"
 #include "AI_Analysis.h"
 #include "AI_Allocation.h"
@@ -37,13 +36,15 @@
 #include "armyprodbase.h"
 #include "armyproto.h"
 #include "history.h"
+#include "citylist.h"
+#include "city.h"
 
 using namespace std;
 
 #define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<flush<<endl;}
 //#define debug(x)
 
-AI_Smart::AI_Smart(string name, unsigned int armyset, SDL_Color color, int width, int height, int player_no)
+AI_Smart::AI_Smart(string name, unsigned int armyset, Gdk::Color color, int width, int height, int player_no)
   :RealPlayer(name, armyset, color, width, height, Player::AI_SMART, player_no),
    d_mustmakemoney(0), d_abort_requested(false)
 {
@@ -125,6 +126,10 @@ bool AI_Smart::startTurn()
 void AI_Smart::abortTurn()
 {
   d_abort_requested = true;
+  if (surrendered)
+    aborted_turn.emit();
+  else if (Playerlist::getInstance()->countPlayersAlive() == 1)
+    aborted_turn.emit();
 }
 
 void AI_Smart::invadeCity(City* c)
@@ -204,7 +209,7 @@ int AI_Smart::setBestProduction(City *c)
     int scorebasic = -1;
 
     // we try to determine the most attractive basic production
-    for (Uint32 i = 0; i < c->getMaxNoOfProductionBases(); i++)
+    for (guint32 i = 0; i < c->getMaxNoOfProductionBases(); i++)
     {
         if (c->getArmytype(i) == -1)    // no production in this slot
             continue;
@@ -232,7 +237,7 @@ int AI_Smart::setBestProduction(City *c)
 int AI_Smart::chooseArmyTypeToBuy(City *c)
 {
     int bestScore, bestIndex;
-    Uint32 size = 0;
+    guint32 size = 0;
 
     const Armysetlist* al = Armysetlist::getInstance();
 
