@@ -2,12 +2,12 @@
 // Copyright (C) 2004, 2005 Ulf Lorenz
 // Copyright (C) 2005, 2006 Andrea Paternesi
 // Copyright (C) 2006 Vibhu Rishi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -25,10 +25,9 @@
 
 #include <string>
 #include <list>
-#include <SDL_types.h>
+#include <gtkmm.h>
 
 #include "real_player.h"
-#include "citylist.h"
 
 class Threatlist;
 class Threat;
@@ -36,6 +35,8 @@ class AI_Analysis;
 class XML_Helper;
 class ArmyProdBase;
 class ArmyProto;
+class City;
+class Location;
 
 //! A more complex artificial intelligence Player.
 /** 
@@ -80,7 +81,7 @@ class AI_Smart : public RealPlayer
 	 *                     the next free Id it used.
          */
 	//! Default constructor.
-        AI_Smart(std::string name, Uint32 armyset, SDL_Color color, 
+        AI_Smart(std::string name, guint32 armyset, Gdk::Color color, 
 		 int width, int height, int player_no = -1);
 
         //! Copy constructor.
