@@ -1,12 +1,12 @@
 // Copyright (C) 2000, 2001, 2003 Michael Bartl
 // Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2005 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,7 +22,11 @@
 #ifndef ARMY_PROTO_H
 #define ARMY_PROTO_H
 
+#include <gtkmm.h>
 #include <string>
+#include "PixMask.h"
+#include "shield.h"
+#include "hero.h"
 
 class XML_Helper;
 
@@ -44,18 +48,18 @@ class ArmyProto : public ArmyProtoBase
 	ArmyProto();
 
 	//! Destructor.
-        ~ArmyProto();
+        virtual ~ArmyProto();
 
         // Set functions:
         
 	//! Sets the filename of the image.
-	void setImageName(std::string image) {d_image = image;}
+	void setImageName(Shield::Colour c,std::string name) {d_image_name[c] = name;}
 
         //! Set the basic image of the Army.
-        void setPixmap(SDL_Surface* pixmap) {d_pixmap = pixmap;};
+        void setImage(Shield::Colour c, PixMask* image) {d_image[c] = image;};
 
         //! Set the image mask of the unit type (for player colours).
-        void setMask(SDL_Surface* mask) {d_mask = mask;};
+        void setMask(Shield::Colour c, PixMask* mask) {d_mask[c] = mask;};
 
 	//! Sets whether or not this Army prototype can found in a ruin.
 	void setDefendsRuins(bool defends) {d_defends_ruins = defends; }
@@ -77,13 +81,13 @@ class ArmyProto : public ArmyProtoBase
 	 * The filename does not have a path, and the filename does
 	 * not have an extension (e.g. .png).
 	 */
-	std::string getImageName() const {return d_image;}
+	std::string getImageName(Shield::Colour c) const {return d_image_name[c];}
 
         //! Get the image of the army prototype. 
-        SDL_Surface* getPixmap() const {return d_pixmap;};
+	PixMask* getImage(Shield::Colour c) const {return d_image[c];};
 
         //! Returns the mask (read-only) for player colors.
-        SDL_Surface* getMask() const {return d_mask;}
+	PixMask* getMask(Shield::Colour c) const {return d_mask[c];}
 
 	//! Gets whether or not this army type can found in a ruin.
 	bool getDefendsRuins() const {return d_defends_ruins; }
@@ -99,22 +103,24 @@ class ArmyProto : public ArmyProtoBase
         //! Saves the Army prototype to an opened armyset file.
         virtual bool save(XML_Helper* helper) const;
         
-	//! Set whether or not this is a hero army prototype.
-	void setHero(bool hero) {d_hero = hero;};
-
 	//! Returns whether or not the Army prototype is a Hero.
-	bool isHero() const {return d_hero;};
+	bool isHero() const {return d_gender != Hero::NONE;};
+	
+	//! Returns the gender of the army prototype.
+	Hero::Gender getGender() const {return d_gender;};
 
+	//! Sets the gender of the army prototype.
+	void setGender(Hero::Gender g) {d_gender = g;};
 	
     protected:
 	bool saveData(XML_Helper* helper) const;
     private:
 
 	//! The picture of the Army prototype.
-        SDL_Surface* d_pixmap;
+	PixMask* d_image[MAX_PLAYERS + 1];
 
 	//! The mask portion of the Army prototype picture.
-        SDL_Surface* d_mask;
+	PixMask* d_mask[MAX_PLAYERS + 1];
         
 	//! Whether or not the Army prototype can defend a Ruin.
 	/**
@@ -142,9 +148,9 @@ class ArmyProto : public ArmyProtoBase
 	 * This value does not contain a path, and does not contain an
 	 * extension (e.g. .png).
 	 */
-	std::string d_image;
+	std::string d_image_name[MAX_PLAYERS + 1];
 
-	bool d_hero;
+	Hero::Gender d_gender;
 };
 
 #endif // ARMY_PROTO_H
