@@ -1,12 +1,12 @@
 // Copyright (C) 2000, 2001, 2003 Michael Bartl
 // Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2005 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,8 +22,10 @@
 #ifndef ARMY_PROTO_BASE_H
 #define ARMY_PROTO_BASE_H
 
+#include <gtkmm.h>
 #include <string>
 
+#include "defs.h"
 
 class XML_Helper;
 
@@ -47,59 +49,59 @@ class ArmyProtoBase : public ArmyBase
 
         // Set functions:
         
-        void setTypeId(Uint32 type_id) {d_type_id = type_id;};
+        void setTypeId(guint32 type_id) {d_type_id = type_id;};
 
         //! Sets the descriptive text for this Army.
         void setDescription(std::string text) {d_description = text;};
         
         //! Set the gold pieces needed to add this Army to a city's production.
-        void setProductionCost(Uint32 production_cost)
+        void setProductionCost(guint32 production_cost)
 	  {d_production_cost = production_cost;}
 
 	//! Sets the armyset id for this army.
-	void setArmyset(Uint32 id) {d_armyset = id;};
+	void setArmyset(guint32 id) {d_armyset = id;};
 
         // Get functions
         
 	//! Get the Id of the Armyset to which the Army's type belongs.
-        Uint32 getTypeId() const {return d_type_id;}
+        guint32 getTypeId() const {return d_type_id;}
 
         //! Returns the descriptive text of this Army.
-        std::string getDescription() const {return d_description;}
+        std::string getDescription() const {return _(d_description.c_str());}
 
         //! Returns how much gold setting up the production costs
 	/**
 	 * @return The amount of gold pieces required to add this Army
 	 *         into the City's suite of 4 production slots.
 	 */
-        Uint32 getProductionCost() const {return d_production_cost;}
+        guint32 getProductionCost() const {return d_production_cost;}
 
 	//! Returns the armyset id for this army.
-	Uint32 getArmyset() const {return d_armyset;};
+	guint32 getArmyset() const {return d_armyset;};
 
         //! Set the army bonus of the army prototype.
-        void setArmyBonus(Uint32 bonus) {d_army_bonus = bonus;};
+        void setArmyBonus(guint32 bonus) {d_army_bonus = bonus;};
 
         //! Set the move bonus.
-        void setMoveBonus(Uint32 bonus) {d_move_bonus = bonus;};
+        void setMoveBonus(guint32 bonus) {d_move_bonus = bonus;};
 
         //! Set the movement points of the army.
-        void setMaxMoves(Uint32 moves) {d_max_moves = moves;};
+        void setMaxMoves(guint32 moves) {d_max_moves = moves;};
 
         //! Set the sight of the army.
-        void setSight(Uint32 sight) {d_sight = sight;};
+        void setSight(guint32 sight) {d_sight = sight;};
 
         //! Set the name of the Army.
         void setName(std::string name){d_name = name;}
 
         //! Returns the name of the Army.
-        std::string getName() const {return d_name;};
+        std::string getName() const {return _(d_name.c_str());};
 
         //! Returns how many turns this Army needs to be produced.
-        Uint32 getProduction() const {return d_production;};
+        guint32 getProduction() const {return d_production;};
 
         //! Set how many turns this unit type needs to be produced.
-        void setProduction(Uint32 production){d_production = production;};
+        void setProduction(guint32 production){d_production = production;};
 
     protected:
 	bool saveData(XML_Helper* helper) const;
@@ -108,7 +110,7 @@ class ArmyProtoBase : public ArmyBase
         std::string d_name;
 
 	//! The index of the Army prototype's index in it's Armyset.
-        Uint32 d_type_id;
+        guint32 d_type_id;
 
 	//! The description of the Army unit.
         std::string d_description;
@@ -121,7 +123,7 @@ class ArmyProtoBase : public ArmyBase
 	 *
 	 * This value does not change during gameplay.
 	 */
-        Uint32 d_production_cost;
+        guint32 d_production_cost;
 
 	//! How many turns the Army unit takes to be produced in a City.
 	/**
@@ -129,10 +131,10 @@ class ArmyProtoBase : public ArmyBase
 	 * 1 through 4.
 	 * This value does not change during gameplay.
 	 */
-        Uint32 d_production;
+        guint32 d_production;
 
 	//! The armyset to which this army prototype belongs.
-	Uint32 d_armyset;
+	guint32 d_armyset;
 	
 };
 
