@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,6 +18,7 @@
 #ifndef ARMYSET_H
 #define ARMYSET_H
 
+#include <gtkmm.h>
 #include <string>
 #include <map>
 #include <vector>
@@ -25,7 +26,11 @@
 
 #include "xmlhelper.h"
 #include "armyproto.h"
+#include "defs.h"
+#include "shield.h"
+#include "File.h"
 
+using namespace std;
 
 //! A collection of Army prototype objects.
 /**
@@ -70,12 +75,14 @@ class Armyset: public std::list<ArmyProto *>, public sigc::trackable
 	 *              objects.  Must be more than 0.  
 	 * @param name  The name of the Armyset.  Analagous to Armyset::d_name.
 	 */
-	Armyset(Uint32 id, std::string name);
+	Armyset(guint32 id, std::string name);
 	//! Loading constructor.
 	/**
 	 * Load armyset XML entities from armyset configuration files.
 	 */
-        Armyset(XML_Helper* helper);
+        Armyset(XML_Helper* helper, bool private_collection = false);
+
+	static Armyset *create(std::string filename, bool private_collection = false);
 	//! Destructor.
         ~Armyset();
 
@@ -90,38 +97,38 @@ class Armyset: public std::list<ArmyProto *>, public sigc::trackable
          * @return The number of Army prototype objects in the armyset or 0 
 	 *         on error (an armyset should never have a size of 0).
          */
-        Uint32 getSize() const {return size();}
+        guint32 getSize() const {return size();}
 
 	//! Get the tile size of the Armyset.
 	/**
 	 * The width and height of the Army graphic images as they appear
 	 * on the screen.
-	 * Analagous to the tileset.d_tilesize XML entity in the armyset 
+	 * Analagous to the armyset.d_tilesize XML entity in the armyset 
 	 * configuration file.
 	 */
-        Uint32 getTileSize() const {return d_tilesize;}
+        guint32 getTileSize() const {return d_tilesize;}
 
 	//! Get the unique identifier for this armyset.
 	/**
-	 * Analagous to the tileset.d_id XML entity in the armyset 
+	 * Analagous to the armyset.d_id XML entity in the armyset 
 	 * configuration file.
 	 */
-        Uint32 getId() const {return d_id;}
+        guint32 getId() const {return d_id;}
 
 	//! Set the unique identifier for this armyset.
 	/**
 	 * @note This method is only used in the armyset editor.  
 	 */
-        void setId(Uint32 id) {d_id = id;}
+        void setId(guint32 id) {d_id = id;}
 
 	//! Returns the name of the armyset.
         /** 
-	 * Analagous to the tileset.d_name XML entity in the armyset 
+	 * Analagous to the armyset.d_name XML entity in the armyset 
 	 * configuration file.
 	 *
          * @return The name or an empty string on error.
          */
-        std::string getName() const {return d_name;}
+        std::string getName() const {return _(d_name.c_str());}
 
 	//! Set the name of the armyset.
 	/**
@@ -142,28 +149,40 @@ class Armyset: public std::list<ArmyProto *>, public sigc::trackable
         void setSubDir(std::string dir) {d_dir = dir;}
 
 	//! Get the image of the stack in a ship (minus the mask).
-	SDL_Surface *getShipPic() const {return d_ship;}
+	PixMask* getShipPic() const {return d_ship;}
 
 	//! Set the image of the stack in a ship
-	void setShipImage(SDL_Surface *ship) {d_ship = ship;};
+	void setShipImage(PixMask* ship) {d_ship = ship;};
 
 	//! Get the mask portion of the image of the stack in a ship.
-	SDL_Surface *getShipMask() const {return d_shipmask;}
+	PixMask* getShipMask() const {return d_shipmask;}
 
 	//! Set the mask portion of the image of the stack in a ship.
-	void setShipMask(SDL_Surface *shipmask) {d_shipmask = shipmask;};
+	void setShipMask(PixMask* shipmask) {d_shipmask = shipmask;};
 
 	//! Get the image of the planted standard (minus the mask).
-	SDL_Surface *getStandardPic() const {return d_standard;}
+	PixMask* getStandardPic() const {return d_standard;}
 
 	//! Set the image of the planted standard (minus the mask).
-	void setStandardImage(SDL_Surface *s) {d_standard = s;};
+	void setStandardPic(PixMask* s) {d_standard = s;};
 
 	//! Get the mask portion of the image of the planted standard.
-	SDL_Surface *getStandardMask() const {return d_standard_mask;}
+	PixMask* getStandardMask() const {return d_standard_mask;}
 
 	//! Set the mask portion of the image of the planted standard.
-	void setStandardMask(SDL_Surface *s) {d_standard_mask = s;};
+	void setStandardMask(PixMask* s) {d_standard_mask = s;};
+
+	//! Set the name of the file holding the image of the stack in a boat.
+	void setShipImageName(std::string n) {d_stackship_name = n;};
+
+	//! Get the name of the file holding the image of the stack in a boat.
+	std::string getShipImageName() {return d_stackship_name;};
+
+	//! Set the name of the file holding the image of the hero's flag.
+	void setStandardImageName(std::string n) {d_standard_name = n;};
+
+	//! Get the name of the file holding the image of the hero's flag.
+	std::string getStandardImageName() {return d_standard_name;};
 
 	//! Find an army with a type in this armyset.
 	/**
@@ -178,7 +197,27 @@ class Armyset: public std::list<ArmyProto *>, public sigc::trackable
 	 * @return The Army with the given army type id, or NULL if none
 	 *         could be found.
 	 */
-	ArmyProto * lookupArmyByType(Uint32 army_type);
+	ArmyProto * lookupArmyByType(guint32 army_type);
+
+	//! Return whether this is an armyset in the user's personal collection.
+	bool fromPrivateCollection() {return private_collection;};
+
+
+	//! can this armyset be used within the game?
+	bool validate();
+	bool validateSize();
+	bool validateHero();
+	bool validatePurchasables();
+	bool validateRuinDefenders();
+	bool validateAwardables();
+	bool validateShip();
+	bool validateStandard();
+	bool validateArmyUnitImages();
+	bool validateArmyUnitImage(ArmyProto *a, Shield::Colour &c);
+	bool validateArmyUnitNames();
+	bool validateArmyUnitName(ArmyProto *a);
+	//! get filenames in this armyset, excepting the configuration file.
+	void getFilenames(std::list<std::string> &files);
     private:
 
         //! Callback function for the army tag (see XML_Helper)
@@ -193,14 +232,14 @@ class Armyset: public std::list<ArmyProto *>, public sigc::trackable
 	//! The unique Id of this armyset.
 	/**
 	 * This Id is unique among all other armysets.
-	 * It is analgous to tileset.d_id in the armyset configuration files.
+	 * It is analgous to armyset.d_id in the armyset configuration files.
 	 */
-        Uint32 d_id;
+        guint32 d_id;
 
 	//! The name of the Armyset.
 	/**
 	 * This value appears in game configuration dialogs.
-	 * It is analgous to tileset.d_name in the armyset configuration files.
+	 * It is analgous to armyset.d_name in the armyset configuration files.
 	 */
         std::string d_name;
 
@@ -221,19 +260,28 @@ class Armyset: public std::list<ArmyProto *>, public sigc::trackable
 	 * The tilesize is the height of the army image file, and it is also
 	 * precisely equal to half of the image's width.
 	 */
-	Uint32 d_tilesize;
+	guint32 d_tilesize;
 
 	//! The unshaded picture of the stack when it's in a boat.
-	SDL_Surface *d_ship;
+	PixMask* d_ship;
 
 	//! The mask of what to shade with the player's colour on the boat.
-	SDL_Surface *d_shipmask;
+	PixMask* d_shipmask;
 
 	//! The unshaded picture of the planted standard.
-	SDL_Surface *d_standard;
+	PixMask* d_standard;
 
 	//! The mask of what to shade with the player's colour on the standard.
-	SDL_Surface *d_standard_mask;
+	PixMask* d_standard_mask;
+
+	//! The name of the file that holds the picture of the hero's flag.
+	std::string d_standard_name;
+
+	//! The name of the file that holds the picture of stack on water.
+	std::string d_stackship_name;
+
+	//! Whether this is a system armyset, or one that the user made.
+	bool private_collection;
 };
 
 #endif // ARMYSET_H
