@@ -1,11 +1,11 @@
 // Copyright (C) 2001, 2002, 2003 Michael Bartl
 // Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2005 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,8 +21,7 @@
 #include <iostream>
 #include <algorithm>
 #include <expat.h>
-#include <SDL_image.h>
-#include <SDL.h>
+#include <gtkmm.h>
 #include "rectangle.h"
 #include <sigc++/functors/mem_fun.h>
 
@@ -31,6 +30,7 @@
 #include "File.h"
 #include "defs.h"
 #include "ucompose.hpp"
+#include "PixMask.h"
 
 
 using namespace std;
@@ -56,26 +56,39 @@ void Armysetlist::deleteInstance()
     s_instance = 0;
 }
 
-Armysetlist::Armysetlist()
+void Armysetlist::loadArmysets(std::list<std::string> armysets, 
+			  bool private_collection)
 {
-    // load all armysets
-    std::list<std::string> armysets = File::scanArmysets();
-
     for (std::list<std::string>::const_iterator i = armysets.begin(); 
 	 i != armysets.end(); i++)
       {
-        loadArmyset(*i);
+        bool valid = loadArmyset(*i, private_collection);
+	if (!valid)
+	  continue;
+
 	iterator it = end();
 	it--;
+	//fill out the maps
 	for (Armyset::iterator ait = (*it)->begin(); ait != (*it)->end(); ait++)
 	  d_armies[(*it)->getId()].push_back(*ait);
 	d_names[(*it)->getId()] = (*it)->getName();
 	d_ids[String::ucompose("%1 %2", (*it)->getName(), (*it)->getTileSize())] = (*it)->getId();
 	(*it)->setSubDir(*i);
 	d_armysets[*i] = *it;
+	d_armysetids[(*it)->getId()] = *it;
       }
 }
 
+Armysetlist::Armysetlist()
+{
+    // load all armysets
+    std::list<std::string> armysets = File::scanArmysets();
+    loadArmysets(armysets, false);
+    armysets = File::scanUserArmysets();
+    loadArmysets(armysets, true);
+
+}
+
 Armysetlist::~Armysetlist()
 {
   for (iterator it = begin(); it != end(); it++)
@@ -88,7 +101,7 @@ Armysetlist::~Armysetlist()
             delete ((*it).second)[0];
 }
 
-ArmyProto* Armysetlist::getArmy(Uint32 id, Uint32 index) const
+ArmyProto* Armysetlist::getArmy(guint32 id, guint32 index) const
 {
     // always use ArmyProtoMap::find for searching, else a default entry is 
     // created, which can produce really bad results!!
@@ -105,7 +118,7 @@ ArmyProto* Armysetlist::getArmy(Uint32 id, Uint32 index) const
     return ((*it).second)[index];
 }
 
-ArmyProto* Armysetlist::getScout(Uint32 id) const
+ArmyProto* Armysetlist::getScout(guint32 id) const
 {
     // always use ArmyProtoMap::find for searching, else a default entry is 
     // created, which can produce really bad results!!
@@ -118,7 +131,7 @@ ArmyProto* Armysetlist::getScout(Uint32 id) const
     return ((*it).second)[0];
 }
 
-Uint32 Armysetlist::getSize(Uint32 id) const
+guint32 Armysetlist::getSize(guint32 id) const
 {
     ArmyPrototypeMap::const_iterator it = d_armies.find(id);
 
@@ -137,7 +150,7 @@ std::list<std::string> Armysetlist::getNames()
   return names;
 }
 
-std::list<std::string> Armysetlist::getNames(Uint32 tilesize)
+std::list<std::string> Armysetlist::getNames(guint32 tilesize)
 {
   std::list<std::string> names;
   for (iterator it = begin(); it != end(); it++)
@@ -146,7 +159,7 @@ std::list<std::string> Armysetlist::getNames(Uint32 tilesize)
   return names;
 }
 
-std::string Armysetlist::getName(Uint32 id) const
+std::string Armysetlist::getName(guint32 id) const
 {
     NameMap::const_iterator it = d_names.find(id);
 
@@ -157,9 +170,9 @@ std::string Armysetlist::getName(Uint32 id) const
     return (*it).second;
 }
 
-std::vector<Uint32> Armysetlist::getArmysets() const
+std::vector<guint32> Armysetlist::getArmysets() const
 {
-    std::vector<Uint32> retlist;
+    std::vector<guint32> retlist;
     
     NameMap::const_iterator it;
     for (it = d_names.begin(); it != d_names.end(); it++)
@@ -181,25 +194,33 @@ bool Armysetlist::load(std::string tag, XML_Helper *helper)
 }
 
 
-bool Armysetlist::loadArmyset(std::string name)
+bool Armysetlist::loadArmyset(std::string name, bool private_collection)
 {
   debug("Loading armyset " <<name);
-
-  XML_Helper helper(File::getArmyset(name), ios::in, false);
-
-  helper.registerTag(Armyset::d_tag, sigc::mem_fun((*this), &Armysetlist::load));
-
-  if (!helper.parse())
+  Armyset *armyset = Armyset::create(name, private_collection);
+  if (armyset == NULL)
+    return false;
+  if (armyset->validate() == false)
     {
-      std::cerr << "Error, while loading an armyset. Armyset Name: ";
-      std::cerr <<name <<std::endl <<std::flush;
-      exit(-1);
+      cerr << "Error!  armyset: `" << armyset->getName() << 
+	      "' is invalid." << endl;
+      delete armyset;
+      return false;
     }
-
+  if (d_armysetids.find(armyset->getId()) != d_armysetids.end())
+    {
+      Armyset *a = (*d_armysetids.find(armyset->getId())).second;
+      cerr << "Error!  armyset: `" << armyset->getName() << 
+        "' shares a duplicate armyset id with `" << File::getArmyset(a) << 
+        "'.  Skipping." << endl;
+      delete armyset;
+      return false;
+    }
+  push_back(armyset); 
   return true;
 }
 	
-SDL_Surface * Armysetlist::getShipPic (Uint32 id)
+PixMask* Armysetlist::getShipPic (guint32 id)
 {
   for (iterator it = begin(); it != end(); it++)
     {
@@ -209,7 +230,7 @@ SDL_Surface * Armysetlist::getShipPic (Uint32 id)
   return NULL;
 }
 
-SDL_Surface * Armysetlist::getShipMask (Uint32 id)
+PixMask* Armysetlist::getShipMask (guint32 id)
 {
   for (iterator it = begin(); it != end(); it++)
     {
@@ -219,7 +240,7 @@ SDL_Surface * Armysetlist::getShipMask (Uint32 id)
   return NULL;
 }
 
-Uint32 Armysetlist::getTileSize(Uint32 id)
+guint32 Armysetlist::getTileSize(guint32 id)
 {
   for (iterator it = begin(); it != end(); it++)
     {
@@ -229,7 +250,7 @@ Uint32 Armysetlist::getTileSize(Uint32 id)
   return 0;
 }
 
-SDL_Surface * Armysetlist::getStandardPic (Uint32 id)
+PixMask* Armysetlist::getStandardPic (guint32 id)
 {
   for (iterator it = begin(); it != end(); it++)
     {
@@ -239,7 +260,7 @@ SDL_Surface * Armysetlist::getStandardPic (Uint32 id)
   return NULL;
 }
 
-SDL_Surface * Armysetlist::getStandardMask (Uint32 id)
+PixMask* Armysetlist::getStandardMask (guint32 id)
 {
   for (iterator it = begin(); it != end(); it++)
     {
@@ -249,17 +270,7 @@ SDL_Surface * Armysetlist::getStandardMask (Uint32 id)
   return NULL;
 }
 
-Armyset *Armysetlist::getArmyset(Uint32 id)
-{
-  for (iterator it = begin(); it != end(); it++)
-    {
-      if ((*it)->getId() == id)
-	return (*it);
-    }
-  return NULL;
-}
-
-void Armysetlist::getSizes(std::list<Uint32> &sizes)
+void Armysetlist::getSizes(std::list<guint32> &sizes)
 {
   for (iterator i = begin(); i != end(); i++)
     {
@@ -268,12 +279,46 @@ void Armysetlist::getSizes(std::list<Uint32> &sizes)
     }
 }
 
-Uint32 Armysetlist::getArmysetId(std::string armyset, Uint32 tilesize)
+guint32 Armysetlist::getArmysetId(std::string armyset, guint32 tilesize)
 {
   return d_ids[String::ucompose("%1 %2", armyset, tilesize)];
 }
 
-std::string Armysetlist::getArmysetDir(std::string name, Uint32 tilesize)
+std::string Armysetlist::getArmysetDir(std::string name, guint32 tilesize)
 {
   return getArmyset(getArmysetId(name, tilesize))->getSubDir();
 }
+
+int Armysetlist::getNextAvailableId(int after)
+{
+  std::list<guint32> ids;
+  std::list<std::string> armysets = File::scanArmysets();
+  //there might be IDs in invalid armysets.
+  for (std::list<std::string>::const_iterator i = armysets.begin(); 
+       i != armysets.end(); i++)
+    {
+      Armyset *armyset = Armyset::create(*i, false);
+      if (armyset != NULL)
+	{
+	  ids.push_back(armyset->getId());
+	  delete armyset;
+	}
+    }
+  armysets = File::scanUserArmysets();
+  for (std::list<std::string>::const_iterator i = armysets.begin(); 
+       i != armysets.end(); i++)
+    {
+      Armyset *armyset = Armyset::create(*i, true);
+      if (armyset != NULL)
+	{
+	  ids.push_back(armyset->getId());
+	  delete armyset;
+	}
+    }
+  for (guint32 i = after + 1; i < 1000000; i++)
+    {
+      if (find(ids.begin(), ids.end(), i) == ids.end())
+	return i;
+    }
+  return -1;
+}
