@@ -1,10 +1,10 @@
 // Copyright (C) 2001, 2002, 2003 Michael Bartl
-// Copyright (C) 2003, 2004, 2005  Ulf Lorenz
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2003, 2004, 2005 Ulf Lorenz
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,6 +20,7 @@
 #ifndef ARMYSETLIST_H
 #define ARMYSETLIST_H
 
+#include <gtkmm.h>
 #include <string>
 #include <map>
 #include <vector>
@@ -60,7 +61,7 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 	 *
          * @return The requested army or 0 on error.
          */
-        ArmyProto* getArmy(Uint32 id, Uint32 index) const;
+        ArmyProto* getArmy(guint32 id, guint32 index) const;
 
 	//! Returns an army prototype of a scout from a given armyset.
         /** 
@@ -68,20 +69,20 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 	 *
          * @return The requested scout or 0 on error.
          */
-        ArmyProto* getScout(Uint32 id) const;
+        ArmyProto* getScout(guint32 id) const;
 
 	//! Get the unshaded ship image for the given Armyset.
-	SDL_Surface * getShipPic (Uint32 id);
+	PixMask* getShipPic (guint32 id);
 
 	//! Get the ship mask picture for the given Armyset.
-	SDL_Surface * getShipMask (Uint32 id);
+	PixMask* getShipMask (guint32 id);
 
 	//! Get the unshaded planted standard picture for the given Armyset.
-	SDL_Surface * getStandardPic (Uint32 id);
+	PixMask* getStandardPic (guint32 id);
 
 	//! Get the planted standard mask for the given Armyset.
-	SDL_Surface * getStandardMask (Uint32 id);
-        Uint32 getTileSize(Uint32 id);
+	PixMask* getStandardMask (guint32 id);
+        guint32 getTileSize(guint32 id);
 
 	//! Returns the size of a specific armyset.
         /** 
@@ -90,7 +91,7 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
          * @return The number of Army prototype objects in the Armyset.
 	 *         Returns 0 on error. 
          */
-        Uint32 getSize(Uint32 id) const;
+        guint32 getSize(guint32 id) const;
 
 	//! Return the name of a given armyset.
         /** 
@@ -98,16 +99,16 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 	 *
          * @return The name of the Armyset or an empty string on error.
          */
-        std::string getName(Uint32 id) const;
+        std::string getName(guint32 id) const;
 
         //! Returns the different tilesizes present in the armysetlist.
-	void getSizes(std::list<Uint32> &sizes);
+	void getSizes(std::list<guint32> &sizes);
 
         //! Returns the names of all Armyset objects available to the game.
 	std::list<std::string> getNames();
 
         //! Returns the names of armysets that have the given tile size.
-	std::list<std::string> getNames(Uint32 tilesize);
+	std::list<std::string> getNames(guint32 tilesize);
 
         /** Returns the Id of a specific armyset by name
           * 
@@ -116,8 +117,8 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 	  *
           * @return the id of the armyset (0 on error)
           */
-	Uint32 getArmysetId(std::string armyset, Uint32 tilesize);
-	Armyset *getArmyset(Uint32 id);
+	guint32 getArmysetId(std::string armyset, guint32 tilesize);
+	Armyset *getArmyset(guint32 id) {return d_armysetids[id];};
 
 	//! Return the Armyset object by the name of the subdir.
 	/**
@@ -128,7 +129,7 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 	Armyset *getArmyset(std::string dir) { return d_armysets[dir];}
 
 	//! Returns a list of all Armyset objects available to the game.
-        std::vector<Uint32> getArmysets() const;
+        std::vector<guint32> getArmysets() const;
 
 	//! Return the name of the subdirectory for a given armyset.
         /** 
@@ -139,8 +140,11 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 	 *         Armyset::d_dir for more information about the nature of 
 	 *         the return value.
          */
-	std::string getArmysetDir(std::string name, Uint32 tilesize);
+	std::string getArmysetDir(std::string name, guint32 tilesize);
 
+
+	//! Return an unused armyset number.
+	static int getNextAvailableId(int after = 0);
     private:
         //! Default Constructor.  Loads all armyset objects it can find.
 	/**
@@ -160,15 +164,25 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 	 * this list of armysets.
 	 *
 	 * @param name  The subdirectory name that the Armyset resides in.
+	 * @param private_collection Whether or not the armyset is one from
+	 * the user's personal collection.
 	 *
 	 * @return True if the Armyset could be loaded.  False otherwise.
 	 */
-        bool loadArmyset (std::string name);
+	bool loadArmyset(std::string name, bool private_collection);
+	  
+	//! Loads a bunch of armysets.
+	/**
+	 * Load a list of armysets from the system armyset directory, or the
+	 * user's personal collection.
+	 */
+	void loadArmysets(std::list<std::string> armysets, bool private_collection);
         
-        typedef std::map<Uint32, std::vector<ArmyProto*> > ArmyPrototypeMap;
-        typedef std::map<Uint32, std::string> NameMap;
-        typedef std::map<std::string, Uint32> IdMap;
+        typedef std::map<guint32, std::vector<ArmyProto*> > ArmyPrototypeMap;
+        typedef std::map<guint32, std::string> NameMap;
+        typedef std::map<std::string, guint32> IdMap;
         typedef std::map<std::string, Armyset*> ArmysetMap;
+        typedef std::map<guint32, Armyset*> ArmysetIdMap;
         
 	//! A map that provides Army objects by their index.
         ArmyPrototypeMap d_armies;
@@ -182,6 +196,9 @@ class Armysetlist : public std::list<Armyset*>, public sigc::trackable
 	//! A map that provides an Armyset when supplying a subdirectory name.
         ArmysetMap d_armysets;
 
+	//! A map that provides an Armyset when supplying a subdirectory name.
+        ArmysetIdMap d_armysetids;
+
         //! A static pointer for the singleton instance.
         static Armysetlist* s_instance;
 };
