@@ -2,12 +2,12 @@
 //  Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 //  Copyright (C) 2002 Mark L. Amidon
 //  Copyright (C) 2005 Andrea Paternesi
-//  Copyright (C) 2006, 2007, 2008 Ben Asselstine
+//  Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 //  Copyright (C) 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -46,8 +46,8 @@ using namespace std;
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 
-City::City(Vector<int> pos, string name, Uint32 gold, Uint32 numslots)
-    :Ownable((Player *)0), Location(pos, CITY_TILE_WIDTH), Renamable(name),
+City::City(Vector<int> pos, string name, guint32 gold, guint32 numslots)
+    :Ownable((Player *)0), Location(pos, City::getWidth()), Renamable(name),
     ProdSlotlist(numslots), d_gold(gold), d_defense_level(1), d_burnt(false), 
     d_vectoring(false), d_vector(Vector<int>(-1,-1)), 
     d_capital(false), d_capital_owner(0)
@@ -63,7 +63,7 @@ City::City(Vector<int> pos, string name, Uint32 gold, Uint32 numslots)
 }
 
 City::City(XML_Helper* helper)
-    :Ownable(helper), Location(helper, CITY_TILE_WIDTH), Renamable(helper),
+    :Ownable(helper), Location(helper, City::getWidth()), Renamable(helper),
     ProdSlotlist(helper)
 {
     //initialize the city
@@ -75,7 +75,7 @@ City::City(XML_Helper* helper)
     helper->getData(d_capital, "capital");
     if (d_capital)
       {
-	Uint32 ui;
+	guint32 ui;
         helper->getData(ui, "capital_owner");
         d_capital_owner = Playerlist::getInstance()->getPlayer(ui);
       }
@@ -125,7 +125,7 @@ bool City::save(XML_Helper* helper) const
     retval &= helper->saveData("id", d_id);
     retval &= helper->saveData("x", getPos().x);
     retval &= helper->saveData("y", getPos().y);
-    retval &= helper->saveData("name", getName());
+    retval &= helper->saveData("name", getName(false));
     retval &= helper->saveData("owner", d_owner->getId());
     retval &= helper->saveData("defense", d_defense_level);
     retval &= helper->saveData("gold", d_gold);
@@ -220,7 +220,7 @@ void City::produceStrongestProductionBase()
 void City::produceScout()
 {
   const Armysetlist* al = Armysetlist::getInstance();
-  Uint32 set = d_owner->getArmyset();
+  guint32 set = d_owner->getArmyset();
   ArmyProto *scout = al->getScout(set);
   Army *a = new Army(*scout, d_owner);
   GameMap::getInstance()->addArmy(this, a);
@@ -351,7 +351,7 @@ Army *City::produceArmy()
       //we're an active neutral city
       //check to see if we've made 5 or not.
       //stop producing if we've made 5 armies in our neutral city
-      if (countDefenders() >= MAX_ARMIES_PRODUCED_IN_ACTIVE_NEUTRAL_CITY)
+      if (countDefenders() >= MAX_ARMIES_PRODUCED_IN_NEUTRAL_CITY)
 	setActiveProductionSlot(-1);
       else
 	setActiveProductionSlot(d_active_production_slot);
@@ -361,16 +361,16 @@ Army *City::produceArmy()
   return a;
 }
 
-bool City::canAcceptVectoredUnit()
+bool City::canAcceptMoreVectoring()
 {
-  return canAcceptVectoredUnits(0);
+  return canAcceptMoreVectoring(0);
 }
 
-bool City::canAcceptVectoredUnits(Uint32 number_of_units)
+bool City::canAcceptMoreVectoring(guint32 number_of_cities)
 {
-  VectoredUnitlist *vul = VectoredUnitlist::getInstance();
-  if (vul->getNumberOfVectoredUnitsGoingTo(getPos()) + number_of_units >= 
-      MAX_ARMIES_VECTORED_TO_ONE_CITY)
+  //here we presume that it's one unit per city
+  guint32 num = Citylist::getInstance()->countCitiesVectoringTo(this);
+  if (num + number_of_cities >= MAX_CITIES_VECTORED_TO_ONE_CITY)
     return false;
   return true;
 }
@@ -383,12 +383,12 @@ bool City::changeVectorDestination(Vector<int> dest)
   return true;
 }
 
-Uint32 City::countDefenders()
+guint32 City::countDefenders()
 {
   std::vector<Stack*> defenders;
   defenders = getOwner()->getStacklist()->defendersInCity(this);
 
-  Uint32 armies = 0;
+  guint32 armies = 0;
   std::vector<Stack*>::iterator it = defenders.begin();
   for (;it != defenders.end(); it++)
     armies += (*it)->size();
@@ -419,8 +419,8 @@ void City::randomlyImproveOrDegradeArmy(ArmyProdBase *army)
 
 bool armyCompareStrength (const ArmyProdBase *lhs, const ArmyProdBase *rhs)
 {
-  Uint32 lhs_strength = lhs->getStrength();
-  Uint32 rhs_strength = rhs->getStrength();
+  guint32 lhs_strength = lhs->getStrength();
+  guint32 rhs_strength = rhs->getStrength();
   return lhs_strength < rhs_strength; 
 }
 
@@ -452,7 +452,7 @@ void City::setRandomArmytypes(bool produce_allies, int likely)
     removeProductionBase(i);
 
   const Armysetlist* al = Armysetlist::getInstance();
-  Uint32 set = d_owner->getArmyset();
+  guint32 set = d_owner->getArmyset();
 
   int army_type;
   int num = rand() % 10;
