@@ -2,12 +2,12 @@
 // Copyright (C) 2002 Mark L. Amidon
 // Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2005, 2006 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -42,6 +42,7 @@ class Hero;
 
 #define DEFAULT_CITY_NAME "Noname"
 #define DEFAULT_CITY_INCOME 20
+#define CITY_TILE_WIDTH 2
 
 //! A City on the game map.
 /**
@@ -81,8 +82,8 @@ class City : public Ownable, public Location, public Renamable,
 	  * @param numslots  The number of production slots for this city.
           */
         City(Vector<int> pos, std::string name = DEFAULT_CITY_NAME, 
-	     Uint32 gold = DEFAULT_CITY_INCOME, 
-	     Uint32 numslots = MAX_PRODUCTION_SLOTS_IN_A_CITY);
+	     guint32 gold = DEFAULT_CITY_INCOME, 
+	     guint32 numslots = MAX_PRODUCTION_SLOTS_IN_A_CITY);
 	//! Copy constructor.
         City(const City&);
         //! Loading constructor.
@@ -99,7 +100,7 @@ class City : public Ownable, public Location, public Renamable,
         bool save(XML_Helper* helper) const;
         
         //! Set the gold the city produces each turn.
-        void setGold(Uint32 gold){d_gold = gold;}
+        void setGold(guint32 gold){d_gold = gold;}
 
         //! Set whether or not the city is destroyed.
         void setBurnt(bool burnt){d_burnt = burnt;}
@@ -172,7 +173,7 @@ class City : public Ownable, public Location, public Renamable,
 	int getGoldNeededForUpgrade() const; 
 	
         //! Return the income of the city per turn.
-        Uint32 getGold() const {return d_gold;}
+        guint32 getGold() const {return d_gold;}
 
         //! Returns whether or not the city has been destroyed.
         bool isBurnt() const {return d_burnt;}
@@ -204,29 +205,30 @@ class City : public Ownable, public Location, public Renamable,
 
 	//! Returns true if the city isn't accepting too many vectored armies.
 	/**
-	 * Scans all of the vectoring units going to this city.  If vectoring
+	 * Scans all of the cities vectoring to this city.  If vectoring
 	 * to this city would accrue the count to 
-	 * MAX_ARMIES_VECTORED_TO_ONE_CITY, this method returns false.
+	 * MAX_CITIES_VECTORED_TO_ONE_CITY, this method returns false.
 	 *
 	 * @return True if the city can have another city vectoring to it.
 	 *         Otherwise false.
 	 */
-	bool canAcceptVectoredUnit();
+	bool canAcceptMoreVectoring();
 
-	//! Returns true if the city can accept a number of vectored armies.
+	//! Returns true if the city can accept vectoring from a set of cities.
 	/**
 	 * Instead of checking to see if one unit can be vectored here like in 
-	 * City::canAcceptVectoredUnit, this method checks if the city can
+	 * City::canAcceptMoreVectoring, this method checks if the city can
 	 * receive multiple units (from an equal number of cities, because a
 	 * city can only produce and vector one army at a time).
 	 *
-	 * @param number_of_units  The number of vectored units to check to
-	 *                         see if this city can receive.
+	 * @param number_of_cities The number of cities to check to
+	 *                         see if this city can receive on top of what
+	 *                         it's already receiving.
 	 *
 	 * @return True if the city can have this many more cities vectoring 
 	 *         to it.  Otherwise false.
 	 */
-	bool canAcceptVectoredUnits(Uint32 number_of_units);
+	bool canAcceptMoreVectoring(guint32 number_of_cities);
 
 	//! Changes the vectoring destination, but for en-route units too.
 	/**
@@ -245,14 +247,16 @@ class City : public Ownable, public Location, public Renamable,
 	bool changeVectorDestination(Vector<int> dest);
 
 	//! Return how many armies are in the city.
-	Uint32 countDefenders();
+	guint32 countDefenders();
 
 	//! This makes the army show up.  called when it's time.
 	const Army *armyArrives();
 
 	bool isUnnamed() {return getName() == getDefaultName() ? true : false;};
 
-	static std::string getDefaultName() {return DEFAULT_CITY_NAME;};
+	static std::string getDefaultName() {return _(DEFAULT_CITY_NAME);};
+
+	static guint32 getWidth() {return CITY_TILE_WIDTH;};
 
     private:
 
@@ -281,7 +285,7 @@ class City : public Ownable, public Location, public Renamable,
         // DATA
 
 	//! The City gives the Player this much gold per turn.
-        Uint32 d_gold;
+        guint32 d_gold;
 
 	//! The defense level of the city.
 	/**
