@@ -2,12 +2,12 @@
 // Copyright (C) 2001, 2002, 2003, 2004, 2005 Ulf Lorenz
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2005 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,6 +20,7 @@
 //  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
 //  02110-1301, USA.
 
+#include <assert.h>
 #include <sigc++/functors/mem_fun.h>
 
 #include "citylist.h"
@@ -115,9 +116,9 @@ void Citylist::collectTaxes(Player* p)
 }
 
 //calculate the amount of money new armies will cost in the upcoming turn.
-Uint32 Citylist::calculateUpcomingUpkeep(Player *p)
+guint32 Citylist::calculateUpcomingUpkeep(Player *p)
 {
-  Uint32 total = 0;
+  guint32 total = 0;
   for (const_iterator it = begin(); it != end(); it++)
     if ((*it)->getOwner() == p && (*it)->isBurnt() == false)
       {
@@ -145,7 +146,7 @@ void Citylist::nextTurn(Player* p)
 
     //fixme: here we want the upkeep that we would pay out to all cities.
     //and not the total upkeep.
-    Uint32 upkeep_for_new_armies = calculateUpcomingUpkeep(p);
+    guint32 upkeep_for_new_armies = calculateUpcomingUpkeep(p);
     if (p->getGold() < (int)upkeep_for_new_armies)
       {
 	int diff = upkeep_for_new_armies - p->getGold();
@@ -180,7 +181,7 @@ void Citylist::nextTurn(Player* p)
 
 static bool isFogged(void *object)
 {
-  return ((City*)object)->isFogged(Playerlist::getActiveplayer());
+  return ((City*)object)->isVisible(Playerlist::getActiveplayer()) == false;
 }
 
 static bool isBurnt(void *object)
@@ -215,11 +216,11 @@ static bool isNotOwnedByEnemy(void *object)
   return true;
 }
 
-static bool canNotAcceptVectoring(void *object)
+static bool canNotAcceptMoreVectoring(void *object)
 {
   City *c = ((City*)object);
-  Uint32 num = Citylist::getInstance()->countCitiesVectoringTo(c);
-  if (num < MAX_ARMIES_VECTORED_TO_ONE_CITY)
+  guint32 num = Citylist::getInstance()->countCitiesVectoringTo(c);
+  if (num < MAX_CITIES_VECTORED_TO_ONE_CITY)
     return false;
   return true;
 }
@@ -358,7 +359,7 @@ City* Citylist::getNearestFriendlyVectorableCity(const Vector<int>& pos)
   std::list<bool (*)(void *)> filters;
   filters.push_back(isBurnt);
   filters.push_back(isNotOwnedByActivePlayer);
-  filters.push_back(canNotAcceptVectoring);
+  filters.push_back(canNotAcceptMoreVectoring);
   return getNearestObject(pos, &filters);
 }
 
@@ -389,7 +390,8 @@ bool Citylist::load(std::string tag, XML_Helper* helper)
 {
     if (tag == City::d_tag)
       {
-	push_back(new City(helper));
+	City *c = new City(helper);
+	add(c);
 	return true;
       }
     return false;
@@ -460,6 +462,16 @@ bool Citylist::isVectoringTarget(City *target)
   return false;
 }
 
+std::list<City*> Citylist::getCitiesVectoringTo(Vector<int> target)
+{
+  std::list<City*> cities;
+  for (iterator it = begin(); it != end(); it++)
+    {
+      if (target == (*it)->getVectoring())
+	cities.push_back((*it));
+    }
+  return cities;
+}
 std::list<City*> Citylist::getCitiesVectoringTo(City *target)
 {
   std::list<City*> cities;
@@ -480,9 +492,9 @@ City* Citylist::getNearestCityPast(const Vector<int>& pos, int dist)
   return getNearestObjectAfter(pos, dist, &filters);
 }
 
-Uint32 Citylist::countCitiesVectoringTo(City *dest)
+guint32 Citylist::countCitiesVectoringTo(City *dest)
 {
-  Uint32 count = 0;
+  guint32 count = 0;
   for (iterator it = begin(); it != end(); it++)
     {
       City *c = *it;
@@ -494,4 +506,5 @@ Uint32 Citylist::countCitiesVectoringTo(City *dest)
 
   return count;
 }
+
 // End of file
