@@ -2,11 +2,11 @@
 // Copyright (C) 2001, 2002, 2003, 2004, 2005 Ulf Lorenz
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2005, 2006 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -27,6 +27,7 @@
 
 class City;
 class Player;
+class XML_Helper;
 
 //! A list of City objects on the game map.
 /**
@@ -329,6 +330,9 @@ class Citylist : public LocationList<City*>, public sigc::trackable
 	 */
 	std::list<City*> getCitiesVectoringTo(City *target);
 
+	//! Return the list of cities vectoring to the given spot on the map.
+	std::list<City*> getCitiesVectoringTo(Vector<int> target);
+
 	//! Get the nearest city that is farther than a given number tiles.
 	/**
 	 * Scans through all of the City objects in the list for the nearest
@@ -349,9 +353,9 @@ class Citylist : public LocationList<City*>, public sigc::trackable
 	//! Get the nearest city to POS that can be vectored to.
 	City* getNearestFriendlyVectorableCity(const Vector<int>& pos);
 
-	Uint32 calculateUpcomingUpkeep(Player *p);
+	guint32 calculateUpcomingUpkeep(Player *p);
 
-	Uint32 countCitiesVectoringTo(City *dest);
+	guint32 countCitiesVectoringTo(City *dest);
 
     protected:
         // CREATORS
@@ -369,6 +373,7 @@ class Citylist : public LocationList<City*>, public sigc::trackable
 	//! Destructor.
         ~Citylist();
 
+
     private:
         //! A callback for loading City objects into the list of cities.
         bool load(std::string tag, XML_Helper* helper);
