@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,8 +18,6 @@
 #include <iostream>
 #include <algorithm>
 #include <expat.h>
-#include <SDL_image.h>
-#include <SDL.h>
 #include "rectangle.h"
 #include <sigc++/functors/mem_fun.h>
 
@@ -51,21 +49,39 @@ void Citysetlist::deleteInstance()
     s_instance = 0;
 }
 
+void Citysetlist::loadCitysets(std::list<std::string> citysets, bool p)
+{
+    for (std::list<std::string>::const_iterator i = citysets.begin(); 
+	 i != citysets.end(); i++)
+      {
+        if (loadCityset(*i, p) == true)
+	  {
+	    iterator it = end();
+	    it--;
+	    if (d_citysetids.find((*it)->getId()) != d_citysetids.end())
+	      {
+		Cityset *c = (*d_citysetids.find((*it)->getId())).second;
+		cerr << "Error!  cityset: `" << (*it)->getName() << 
+		  "' has a duplicate cityset id with `" << File::getCityset(c) << 
+		  "'.  Skipping." << endl;
+		continue;
+	      }
+	    (*it)->setSubDir(*i);
+	    d_dirs[String::ucompose("%1 %2", (*it)->getName(), (*it)->getTileSize())] = *i;
+	    d_citysets[*i] = *it;
+	    d_citysetids[(*it)->getId()] = *it;
+	  }
+      }
+}
+
 Citysetlist::Citysetlist()
 {
     // load all citysets
     std::list<std::string> citysets = File::scanCitysets();
+    loadCitysets(citysets, false);
+    citysets = File::scanUserCitysets();
+    loadCitysets(citysets, true);
 
-    for (std::list<std::string>::const_iterator i = citysets.begin(); 
-	 i != citysets.end(); i++)
-      {
-        loadCityset(*i);
-	iterator it = end();
-	it--;
-	(*it)->setSubDir(*i);
-	d_dirs[String::ucompose("%1 %2", (*it)->getName(), (*it)->getTileSize())] = *i;
-	d_citysets[*i] = *it;
-      }
 }
 
 Citysetlist::~Citysetlist()
@@ -82,7 +98,7 @@ std::list<std::string> Citysetlist::getNames()
   return names;
 }
 
-std::list<std::string> Citysetlist::getNames(Uint32 tilesize)
+std::list<std::string> Citysetlist::getNames(guint32 tilesize)
 {
   std::list<std::string> names;
   for (iterator it = begin(); it != end(); it++)
@@ -91,35 +107,28 @@ std::list<std::string> Citysetlist::getNames(Uint32 tilesize)
   return names;
 }
 
-bool Citysetlist::load(std::string tag, XML_Helper *helper)
-{
-  if (tag == Cityset::d_tag)
-    {
-      Cityset *cityset = new Cityset(helper);
-      push_back(cityset); 
-    }
-  return true;
-}
-
-bool Citysetlist::loadCityset(std::string name)
+bool Citysetlist::loadCityset(std::string name, bool p)
 {
   debug("Loading cityset " <<name);
 
-  XML_Helper helper(File::getCityset(name), ios::in, false);
-
-  helper.registerTag(Cityset::d_tag, sigc::mem_fun((*this), &Citysetlist::load));
-
-  if (!helper.parse())
+  Cityset *cityset = Cityset::create(name, p);
+  if (!cityset)
+    return false;
+  if (d_citysetids.find(cityset->getId()) != d_citysetids.end())
     {
-      std::cerr << "Error, while loading a cityset. Cityset Name: ";
-      std::cerr <<name <<std::endl <<std::flush;
-      exit(-1);
+      Cityset *c = (*d_citysetids.find(cityset->getId())).second;
+      cerr << "Error!  cityset: `" << cityset->getName() << 
+	"' shares a duplicate cityset id with `" << File::getCityset(c) << 
+	"'.  Skipping." << endl;
+      delete cityset;
+      return false;
     }
+  push_back(cityset);
 
   return true;
 }
 
-void Citysetlist::getSizes(std::list<Uint32> &sizes)
+void Citysetlist::getSizes(std::list<guint32> &sizes)
 {
   for (iterator i = begin(); i != end(); i++)
     {
@@ -128,7 +137,7 @@ void Citysetlist::getSizes(std::list<Uint32> &sizes)
     }
 }
 
-std::string Citysetlist::getCitysetDir(std::string name, Uint32 tilesize)
+std::string Citysetlist::getCitysetDir(std::string name, guint32 tilesize)
 {
   return d_dirs[String::ucompose("%1 %2", name, tilesize)];
 }
