@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -48,10 +48,10 @@ class Citysetlist : public std::list<Cityset*>, public sigc::trackable
 	std::list<std::string> getNames();
 
         //! Returns the names of citysets that have the given tile size.
-	std::list<std::string> getNames(Uint32 tilesize);
+	std::list<std::string> getNames(guint32 tilesize);
 
         //! Returns the different tilesizes present in the citysetlist.
-	void getSizes(std::list<Uint32> &sizes);
+	void getSizes(std::list<guint32> &sizes);
 
 	//! Return the name of the subdirectory for a given cityset.
         /** 
@@ -62,7 +62,7 @@ class Citysetlist : public std::list<Cityset*>, public sigc::trackable
 	 *         Cityset::d_dir for more information about the nature of 
 	 *         the return value.
          */
-	std::string getCitysetDir(std::string name, Uint32 tilesize);
+	std::string getCitysetDir(std::string name, guint32 tilesize);
 
 	//! Return the Cityset object by the name of the subdir.
 	/**
@@ -72,6 +72,12 @@ class Citysetlist : public std::list<Cityset*>, public sigc::trackable
 	 */
 	Cityset *getCityset(std::string dir) { return d_citysets[dir];}
 
+	//! Return the Cityset object by the id.
+	/**
+	 * @param id   A unique numeric identifier that identifies the cityset
+	 *             among all tilesets in the citysetlist.
+	 */
+	Cityset *getCityset(guint32 id) { return d_citysetids[id];};
     private:
         //! Default constructor.  Loads all citysets it can find.
 	/**
@@ -82,9 +88,6 @@ class Citysetlist : public std::list<Cityset*>, public sigc::trackable
         //! Destructor.
         ~Citysetlist();
 
-        //! Callback for loading Cityset objects into the list.
-	bool load(std::string tag, XML_Helper *helper);
-
         //! Loads a specific Cityset.
 	/**
 	 * Load the Cityset from an cityset configuration file and add it to 
@@ -95,10 +98,12 @@ class Citysetlist : public std::list<Cityset*>, public sigc::trackable
 	 *
 	 * @return True if the Cityset could be loaded.  False otherwise.
 	 */
-        bool loadCityset (std::string name);
+        bool loadCityset (std::string name, bool p);
+        void loadCitysets (std::list<std::string> name, bool p);
         
         typedef std::map<std::string, std::string> DirMap;
         typedef std::map<std::string, Cityset*> CitysetMap;
+        typedef std::map<guint32, Cityset*> CitysetIdMap;
 
 	//! A map that provides a subdirectory when supplying a Cityset name.
 	/**
@@ -110,6 +115,9 @@ class Citysetlist : public std::list<Cityset*>, public sigc::trackable
 	//! A map that provides a Cityset when supplying a subdirectory name.
         CitysetMap d_citysets;
 
+	//! A map that provides a Cityset when supplying a cityset id.
+        CitysetIdMap d_citysetids;
+
         //! A static pointer for the singleton instance.
         static Citysetlist* s_instance;
 };
