@@ -3,11 +3,11 @@
 // Copyright (C) 2003, 2004, 2005, 2006 Andrea Paternesi
 // Copyright (C) 2004 David Sterba
 // Copyright (C) 2005 Bryan Duff
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -28,9 +28,9 @@
 #include <string>
 #include <libintl.h>
 
-#define LORDSAWAR_SAVEGAME_VERSION "0.1.5"
-#define LORDSAWAR_CONFIG_VERSION "0.1.5"
-#define LORDSAWAR_RECENTLY_PLAYED_VERSION "0.1.5"
+#define LORDSAWAR_SAVEGAME_VERSION "0.1.6"
+#define LORDSAWAR_CONFIG_VERSION "0.1.6"
+#define LORDSAWAR_RECENTLY_PLAYED_VERSION "0.1.6"
 #define _(string) gettext(string) // Macro for the gettext
 #define __(astring) std::string(gettext(astring.c_str()))
 
@@ -46,11 +46,11 @@ const unsigned int MAX_PLAYERS=8;
 const unsigned int TEMPLE_TYPES=1; 
 const unsigned int RUIN_TYPES=2; 
 const unsigned int DIPLOMACY_TYPES=3; 
-const unsigned int ROAD_TYPES=16; 
+const unsigned int ROAD_TYPES=15; 
 const unsigned int FOG_TYPES=15; 
 const unsigned int BRIDGE_TYPES=4; 
 const unsigned int CURSOR_TYPES=12; 
-const unsigned int MAX_ARMIES_VECTORED_TO_ONE_CITY = 4;
+const unsigned int MAX_CITIES_VECTORED_TO_ONE_CITY = 4;
 const unsigned int MAX_TURNS_FOR_VECTORING = 2;
 const unsigned int MAX_BOAT_MOVES = 18;
 const unsigned int CUSP_OF_WAR_ROUND = 9;
@@ -59,7 +59,7 @@ const unsigned int DIPLOMACY_MAX_SCORE = 15;
 const unsigned int DIPLOMACY_MIN_SCORE = 0;
 const unsigned int MAX_STACK_SIZE = 8;
 const unsigned int MAX_PRODUCTION_SLOTS_IN_A_CITY = 4;
-const unsigned int MAX_ARMIES_PRODUCED_IN_ACTIVE_NEUTRAL_CITY = 5;
+const unsigned int MAX_ARMIES_PRODUCED_IN_NEUTRAL_CITY = 5;
 
 const unsigned int MAP_SIZE_TINY_WIDTH = 50;
 const unsigned int MAP_SIZE_TINY_HEIGHT = 75;
@@ -70,14 +70,12 @@ const unsigned int MAP_SIZE_NORMAL_HEIGHT = 156;
 
 const unsigned int PRODUCTION_SHIELD_WIDTH = 10;
 const unsigned int PRODUCTION_SHIELD_HEIGHT = 10;
-const unsigned int PRODUCTION_SHIELD_TYPES = 7;
+const unsigned int PRODUCTION_SHIELD_TYPES = 8;
 const unsigned int MOVE_BONUS_WIDTH = 32;
 const unsigned int MOVE_BONUS_HEIGHT = 20;
 const unsigned int MOVE_BONUS_TYPES = 6;
+const unsigned int MEDAL_TYPES = 3;
 
-const unsigned int CITY_TILE_WIDTH = 2;
-const unsigned int RUIN_TILE_WIDTH = 1;
-const unsigned int TEMPLE_TILE_WIDTH = 1;
 const int MAX_GOLD_TO_CARRY_OVER_TO_NEXT_SCENARIO = 5000;
 const unsigned int MAX_ARMY_STRENGTH = 9;
 
@@ -92,6 +90,19 @@ const std::string ARMYSETDIR = "army";
 const std::string TILESETDIR = "tilesets";
 const std::string CITYSETDIR = "citysets";
 const std::string SHIELDSETDIR = "shield";
-const std::string CAMPAIGNDIR = "campaign";
 const std::string MAPDIR = "map";
+const std::string ARMYSET_EXT = ".lwa";
+const std::string TILESET_EXT = ".lwt";
+const std::string CITYSET_EXT = ".lwc";
+const std::string SHIELDSET_EXT = ".lws";
+
+const unsigned int MIN_PRODUCTION_TURNS_FOR_ARMY_UNITS = 1;
+const unsigned int MAX_PRODUCTION_TURNS_FOR_ARMY_UNITS = 5;
+const unsigned int MIN_UPKEEP_FOR_ARMY_UNITS = 0;
+const unsigned int MAX_UPKEEP_FOR_ARMY_UNITS = 20;
+const unsigned int MIN_MOVES_FOR_ARMY_UNITS = 6;
+const unsigned int MAX_MOVES_FOR_ARMY_UNITS = 75;
+const unsigned int MIN_STRENGTH_FOR_ARMY_UNITS = 1;
+const unsigned int MAX_STRENGTH_FOR_ARMY_UNITS = 9;
 #endif // DEFINITIONS_H
+
