@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,26 +20,33 @@
 
 #include <memory>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/entry.h>
-#include <gtkmm/spinbutton.h>
+#include <gtkmm.h>
 #include "armyset.h"
 
 //! Armyset Editor.  Edit the description of the Armyset.
 class ArmySetInfoDialog: public sigc::trackable
 {
  public:
-    ArmySetInfoDialog(Armyset *armyset);
+    ArmySetInfoDialog(Armyset *armyset, bool readonly = false);
+    ~ArmySetInfoDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
-    bool run();
+    int run();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
     Armyset *d_armyset;
     Gtk::Entry *name_entry;
+    Gtk::Entry *subdir_entry;
     Gtk::SpinButton *id_spinbutton;
+    Gtk::Button *accept_button;
+    Gtk::Label *status_label;
+
+    void on_name_changed();
+    void on_subdir_changed();
+
+    bool d_readonly;
 };
 
 #endif
