@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,7 +22,7 @@
 #include <iostream>
 #include <stdlib.h>
 #include <time.h>
-#include <gtkmm/main.h>
+#include <gtkmm.h>
 
 #include "Configuration.h"
 #include "File.h"
@@ -32,11 +32,13 @@
 #include "armyset-window.h"
 
 
+int max_vector_width;
 int main(int argc, char* argv[])
 {
     srand(time(NULL));         // set the random seed
 
     initialize_configuration();
+    Vector<int>::setMaximumWidth(1000);
 
     setlocale(LC_ALL, Configuration::s_lang.c_str());
     textdomain ("lordsawar");
@@ -47,15 +49,20 @@ int main(int argc, char* argv[])
     // init GUI stuff
     g_set_application_name(_("LordsAWar! Armyset Editor"));
 
+    ArmySetWindow* armyset_window = NULL;
     try
     {
 	Gtk::Main kit(argc, argv);
 
-	std::auto_ptr<ArmySetWindow> armyset_window(new ArmySetWindow);
-	armyset_window->init(64, 64);
+	if (argc > 1)
+	  armyset_window = new ArmySetWindow (argv[1]);
+	else
+	  armyset_window = new ArmySetWindow;
+
 	armyset_window->show();
 	
 	kit.run(armyset_window->get_window());
+	delete armyset_window;
     }
     catch (const Glib::Error &ex) {
 	std::cerr << ex.what() << std::endl;
