@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,61 +22,59 @@
 #include <vector>
 #include <sigc++/signal.h>
 #include <sigc++/trackable.h>
-#include <libglademm/xml.h>
-#include <gtkmm/window.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/container.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/treemodelcolumn.h>
-#include <gtkmm/treeview.h>
-#include <gtkmm/textview.h>
-#include <gtkmm/filechooserbutton.h>
-#include <gtkmm/image.h>
-#include <gtkmm/button.h>
-#include <gtkmm/spinbutton.h>
-#include <gtkmm/table.h>
-#include <gtkmm/checkmenuitem.h>
-#include <gtkmm/radiobutton.h>
-#include <gtkmm/tooltips.h>
+#include <gtkmm.h>
 
 #include "armyproto.h"
 #include "armyset.h"
+#include "shield.h"
 
 //! Armyset Editor.  Edit an Armyset.
 class ArmySetWindow: public sigc::trackable
 {
  public:
-    ArmySetWindow();
+    ArmySetWindow(std::string load_filename = "");
     ~ArmySetWindow();
 
     void show();
     void hide();
 
-    // initialize the SDL widget 
-    void init(int width, int height);
-
-    sigc::signal<void> sdl_initialized;
-    Gtk::Window &get_window() { return *window.get(); }
+    Gtk::Window &get_window() { return *window; }
 
  private:
-    std::auto_ptr<Gtk::Window> window;
-    Gtk::Container *sdl_container;
-    Gtk::Widget *sdl_widget;
+    Gtk::Window* window;
     std::string current_save_filename;
     Armyset *d_armyset; //current armyset
     ArmyProto *d_army; //current army
-    Gtk::Image *army_image;
+    Gtk::Image *white_image;
+    Gtk::Image *green_image;
+    Gtk::Image *yellow_image;
+    Gtk::Image *light_blue_image;
+    Gtk::Image *red_image;
+    Gtk::Image *dark_blue_image;
+    Gtk::Image *orange_image;
+    Gtk::Image *black_image;
+    Gtk::Image *neutral_image;
     Gtk::Entry *name_entry;
     Gtk::TreeView *armies_treeview;
     Gtk::TextView *description_textview;
-    Gtk::FileChooserButton *image_filechooserbutton;
+    Gtk::FileChooserButton *white_image_filechooserbutton;
+    Gtk::FileChooserButton *green_image_filechooserbutton;
+    Gtk::FileChooserButton *yellow_image_filechooserbutton;
+    Gtk::FileChooserButton *light_blue_image_filechooserbutton;
+    Gtk::FileChooserButton *red_image_filechooserbutton;
+    Gtk::FileChooserButton *dark_blue_image_filechooserbutton;
+    Gtk::FileChooserButton *orange_image_filechooserbutton;
+    Gtk::FileChooserButton *black_image_filechooserbutton;
+    Gtk::FileChooserButton *neutral_image_filechooserbutton;
     Gtk::SpinButton *production_spinbutton;
     Gtk::SpinButton *cost_spinbutton;
     Gtk::SpinButton *upkeep_spinbutton;
     Gtk::SpinButton *strength_spinbutton;
     Gtk::SpinButton *moves_spinbutton;
     Gtk::SpinButton *exp_spinbutton;
-    Gtk::CheckButton *hero_checkbutton;
+    Gtk::RadioButton *gender_none_radiobutton;
+    Gtk::RadioButton *gender_male_radiobutton;
+    Gtk::RadioButton *gender_female_radiobutton;
     Gtk::CheckButton *awardable_checkbutton;
     Gtk::CheckButton *defends_ruins_checkbutton;
     Gtk::SpinButton *sight_spinbutton;
@@ -101,12 +99,15 @@ class ArmySetWindow: public sigc::trackable
     Gtk::Button *add_army_button;
     Gtk::Button *remove_army_button;
     Gtk::VBox *army_vbox;
-    bool sdl_inited;
     Gtk::MenuItem *new_armyset_menuitem;
     Gtk::MenuItem *load_armyset_menuitem;
     Gtk::MenuItem *save_armyset_menuitem;
-    Gtk::MenuItem *save_armyset_as_menuitem;
+    Gtk::MenuItem *validate_armyset_menuitem;
     Gtk::MenuItem *edit_armyset_info_menuitem;
+    Gtk::MenuItem *edit_ship_picture_menuitem;
+    Gtk::MenuItem *edit_standard_picture_menuitem;
+    Gtk::MenuItem *quit_menuitem;
+    Gtk::MenuItem *help_about_menuitem;
 
     class ArmiesColumns: public Gtk::TreeModelColumnRecord {
     public:
@@ -121,7 +122,7 @@ class ArmySetWindow: public sigc::trackable
 
     bool on_delete_event(GdkEventAny *e);
 
-    void addArmyType(Uint32 army_type);
+    void addArmyType(guint32 army_type);
     void update_army_panel();
     void update_armyset_buttons();
     void update_armyset_menuitems();
@@ -129,11 +130,14 @@ class ArmySetWindow: public sigc::trackable
     void on_new_armyset_activated();
     void on_load_armyset_activated();
     void on_save_armyset_activated();
-    void on_save_armyset_as_activated();
+    void on_validate_armyset_activated();
     void on_quit_activated();
     void on_edit_armyset_info_activated();
+    void on_edit_standard_picture_activated();
+    void on_edit_ship_picture_activated();
     void on_help_about_activated();
     void on_army_selected();
+    void fill_army_image(Gtk::FileChooserButton *button, Gtk::Image *image, Shield::Colour c, ArmyProto *army);
     void fill_army_info(ArmyProto *army);
 
     bool load(std::string tag, XML_Helper *helper);
@@ -141,7 +145,16 @@ class ArmySetWindow: public sigc::trackable
     //callbacks
     void on_name_changed();
     void on_description_changed();
-    void on_image_changed();
+    void on_image_changed(Gtk::FileChooserButton *button, Gtk::Image *image, Shield::Colour c);
+    void on_white_image_changed();
+    void on_green_image_changed();
+    void on_yellow_image_changed();
+    void on_light_blue_image_changed();
+    void on_red_image_changed();
+    void on_dark_blue_image_changed();
+    void on_orange_image_changed();
+    void on_black_image_changed();
+    void on_neutral_image_changed();
     void on_production_changed();
     void on_cost_changed();
     void on_upkeep_changed();
@@ -149,7 +162,9 @@ class ArmySetWindow: public sigc::trackable
     void on_moves_changed();
     void on_exp_changed();
     void on_sight_changed();
-    void on_hero_toggled();
+    void on_gender_none_toggled();
+    void on_gender_male_toggled();
+    void on_gender_female_toggled();
     void on_awardable_toggled();
     void on_defends_ruins_toggled();
 
@@ -173,9 +188,12 @@ class ArmySetWindow: public sigc::trackable
     void on_suballherobonus_toggled();
     void on_add_army_clicked();
     void on_remove_army_clicked();
-public:
-    // not part of the API, but for surface_attached_helper
-    void on_sdl_surface_changed();
+
+    void update_filechooserbutton(Gtk::FileChooserButton *b, ArmyProto *a, Shield::Colour c);
+
+    void on_white_all_checked();
+
+    void load_armyset(std::string filename);
 };
 
 #endif
