@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,7 +18,6 @@
 
 #include <config.h>
 
-#include <SDL_image.h>
 #include <assert.h>
 #include <stdlib.h>
 
@@ -28,15 +27,18 @@
 #include "stacklist.h"
 #include "stack.h"
 #include "citylist.h"
+#include "city.h"
 #include "ruinlist.h"
-#include "signpostlist.h"
-#include "templelist.h"
-#include "bridgelist.h"
-#include "portlist.h"
-#include "roadlist.h"
 #include "ruin.h"
+#include "signpostlist.h"
 #include "signpost.h"
+#include "templelist.h"
 #include "temple.h"
+#include "bridgelist.h"
+#include "bridge.h"
+#include "portlist.h"
+#include "port.h"
+#include "roadlist.h"
 #include "road.h"
 #include "playerlist.h"
 #include "defs.h"
@@ -46,9 +48,11 @@
 #include "rewardlist.h"
 #include "GraphicsCache.h"
 #include "armysetlist.h"
-#include "sdl-draw.h"
 #include "MapRenderer.h"
 #include "CreateScenario.h"
+#include "Backpack.h"
+#include "MapBackpack.h"
+#include "backpack-editor-dialog.h"
 
 
 EditorBigMap::EditorBigMap()
@@ -57,7 +61,7 @@ EditorBigMap::EditorBigMap()
 
     mouse_state = NONE;
     input_locked = false;
-    pointer = EditorBigMap::POINTER;
+    pointer = POINTER;
     pointer_size = 1;
     pointer_terrain = Tile::GRASS;
     pointer_tile_style_id = -1;
@@ -82,6 +86,7 @@ void EditorBigMap::set_pointer(Pointer p, int size, Tile::Type t,
 
     if (redraw)
       draw();
+    
 }
 
 void EditorBigMap::mouse_button_event(MouseButtonEvent e)
@@ -89,7 +94,8 @@ void EditorBigMap::mouse_button_event(MouseButtonEvent e)
     if (input_locked)
 	return;
     
-    Vector<int> tile = mouse_pos_to_tile(e.pos);
+    mouse_pos = e.pos;
+    Vector<int> tile = mouse_pos_to_tile(mouse_pos);
     
     if (e.button == MouseButtonEvent::LEFT_BUTTON
 	&& e.state == MouseButtonEvent::PRESSED)
@@ -97,7 +103,6 @@ void EditorBigMap::mouse_button_event(MouseButtonEvent e)
 	change_map_under_cursor();
     }
 
-	    
     else if (e.button == MouseButtonEvent::RIGHT_BUTTON
 	     && e.state == MouseButtonEvent::PRESSED)
     {
@@ -113,6 +118,10 @@ void EditorBigMap::mouse_button_event(MouseButtonEvent e)
 	    seq.push_back(s);
 	if (Temple* t = Templelist::getInstance()->getObjectAt(tile))
 	    seq.push_back(t);
+	MapBackpack *b = GameMap::getInstance()->getTile(tile)->getBackpack();
+	if (b->empty() == false)
+	  seq.push_back(b);
+
 
 	if (!seq.empty())
 	    objects_selected.emit(seq);
@@ -154,8 +163,7 @@ void EditorBigMap::mouse_motion_event(MouseMotionEvent e)
 	// FIXME: show a drag cursor
 	
 	int ts = GameMap::getInstance()->getTileset()->getTileSize();
-	SDL_Surface *screen = SDL_GetVideoSurface();
-	Vector<int> screen_dim(screen->w, screen->h);
+	Vector<int> screen_dim(image.get_width(), image.get_height());
 	view_pos = clip(Vector<int>(0, 0),
 			view_pos + delta,
 			GameMap::get_dim() * ts - screen_dim);
@@ -178,7 +186,7 @@ void EditorBigMap::mouse_motion_event(MouseMotionEvent e)
 	mouse_state = DRAGGING;
     }
 
-    if (redraw)
+    if (redraw && pointer != POINTER)
 	draw();
     
     prev_mouse_pos = mouse_pos;
@@ -231,103 +239,6 @@ std::vector<Vector<int> > EditorBigMap::get_cursor_tiles()
 }
 
 
-void EditorBigMap::after_draw()
-{
-    int tilesize = GameMap::getInstance()->getTileset()->getTileSize();
-    std::vector<Vector<int> > tiles;
-
-    if (show_tile_types_instead_of_tile_styles)
-      {
-	tiles = get_screen_tiles();
-	for (std::vector<Vector<int> >::iterator i = tiles.begin(),
-	     end = tiles.end(); i != end; ++i)
-	  {
-	    Vector<int> pos = tile_to_buffer_pos(*i);
-	    SDL_Color tc = GameMap::getInstance()->getTile(*i)->getColor();
-	    const Uint32 color = SDL_MapRGB(buffer->format, tc.r, tc.g, tc.b);
-	    draw_filled_rect(buffer, pos.x, pos.y,
-			     pos.x + tilesize, pos.y + tilesize, color);
-	  }
-      }
-
-    // we need to draw a drawing cursor on the map
-    tiles = get_cursor_tiles();
-    // draw each tile
-    for (std::vector<Vector<int> >::iterator i = tiles.begin(),
-	     end = tiles.end(); i != end; ++i)
-    {
-	Vector<int> pos = tile_to_buffer_pos(*i);
-
-	const Uint32 outline = SDL_MapRGB(buffer->format, 200, 200, 200);
-	const Uint32 red_outline = SDL_MapRGB(buffer->format, 200, 50, 50);
-
-	SDL_Rect r;
-	r.x = pos.x;
-	r.y = pos.y;
-	r.w = r.h = tilesize;
-	SDL_Surface *pic = 0;
-	
-	switch (pointer)
-	{
-	case POINTER:
-	    break;
-	    
-	case TERRAIN:
-	    draw_rect_clipped(buffer, pos.x + 1, pos.y + 1,
-			      pos.x + tilesize - 2, pos.y + tilesize - 2,
-			      outline);
-	    break;
-	    
-	case ERASE:
-	    draw_rect_clipped(buffer, pos.x + 1, pos.y + 1,
-			      pos.x + tilesize - 2, pos.y + tilesize - 2,
-			      red_outline);
-	    break;
-
-	case STACK:
-	    pic = GraphicsCache::getInstance()->getArmyPic(
-		Playerlist::getInstance()->getNeutral()->getArmyset(), 0,
-		Playerlist::getInstance()->getNeutral(), NULL);
-	    SDL_BlitSurface(pic, 0, buffer, &r);
-	    break;
-	    
-	case CITY:
-	    pic = GraphicsCache::getInstance()->getCityPic(
-		0, Playerlist::getInstance()->getNeutral());
-	    r.w = r.h = tilesize * 2;
-	    SDL_BlitSurface(pic, 0, buffer, &r);
-	    break;
-	    
-	case RUIN:
-	    pic = GraphicsCache::getInstance()->getRuinPic(0);
-	    SDL_BlitSurface(pic, 0, buffer, &r);
-	    break;
-	    
-	case TEMPLE:
-	    pic = GraphicsCache::getInstance()->getTemplePic(0);
-	    SDL_BlitSurface(pic, 0, buffer, &r);
-	    break;
-	    
-	case SIGNPOST:
-	    pic = GraphicsCache::getInstance()->getSignpostPic();
-	    SDL_BlitSurface(pic, 0, buffer, &r);
-	    break;
-	    
-	case ROAD:
-	    pic = GraphicsCache::getInstance()->getRoadPic(CreateScenario::calculateRoadType(*i));
-	    SDL_BlitSurface(pic, 0, buffer, &r);
-	    break;
-	case PORT:
-	    pic = GraphicsCache::getInstance()->getPortPic();
-	    SDL_BlitSurface(pic, 0, buffer, &r);
-	    break;
-	case BRIDGE:
-	    pic = GraphicsCache::getInstance()->getBridgePic(tile_to_bridge_type(*i));
-	    SDL_BlitSurface(pic, 0, buffer, &r);
-	    break;
-	}
-    }
-}
 
 int EditorBigMap::tile_to_bridge_type(Vector<int> t)
 {
@@ -525,6 +436,8 @@ void EditorBigMap::change_map_under_cursor()
 	    remove_from_map(Signpostlist::getInstance(), tile);
 	    // ... or a city
 	    remove_from_map(Citylist::getInstance(), tile);
+	    // ... or a bag
+	    GameMap::getInstance()->getTile(tile)->getBackpack()->removeAllFromBackpack();
 	    break;
 
 	case STACK:
@@ -596,7 +509,7 @@ void EditorBigMap::change_map_under_cursor()
 	    // create the city
 	    City *c = new City(tile);
 	    c->setOwner(Playerlist::getInstance()->getNeutral());
-	    Citylist::getInstance()->push_back(c);
+	    Citylist::getInstance()->add(c);
 
 	    bool replaced_grass = false;
 	    // notify the maptiles that a city has been placed here
@@ -620,6 +533,10 @@ void EditorBigMap::change_map_under_cursor()
 						      c->getPos().y + y);
 		    if (s)
 		      {
+			if (c->getOwner() == 
+			    Playerlist::getInstance()->getNeutral() &&
+			    s->getFortified() == true)
+			  s->setFortified(false);
 			if (s->getOwner() != c->getOwner())
 			  {
 			    //remove it from the old player's list of stacks
@@ -655,7 +572,7 @@ void EditorBigMap::change_map_under_cursor()
 		  replaced_grass = true;
 		maptile->setType(grass_index);
 		Ruin *ruin = new Ruin(tile);
-		Ruinlist::getInstance()->push_back(ruin);
+		Ruinlist::getInstance()->add(ruin);
 		if (replaced_grass)
 		  GameMap::getInstance()->applyTileStyles
 		    (0, 0, GameMap::getHeight(), GameMap::getWidth(), true);
@@ -671,7 +588,7 @@ void EditorBigMap::change_map_under_cursor()
 		if (maptile->getMaptileType() != Tile::GRASS)
 		  replaced_grass = true;
 		maptile->setType(grass_index);
-		Templelist::getInstance()->push_back(new Temple(tile));
+		Templelist::getInstance()->add(new Temple(tile));
 		if (replaced_grass)
 		  GameMap::getInstance()->applyTileStyles
 		    (0, 0, GameMap::getHeight(), GameMap::getWidth(), true);
@@ -683,7 +600,7 @@ void EditorBigMap::change_map_under_cursor()
 		&& maptile->getMaptileType() == Tile::GRASS)
 	    {
 		maptile->setBuilding(Maptile::SIGNPOST);
-		Signpostlist::getInstance()->push_back(new Signpost(tile));
+		Signpostlist::getInstance()->add(new Signpost(tile));
 	    }
 	    break;
 	    
@@ -693,7 +610,7 @@ void EditorBigMap::change_map_under_cursor()
 		maptile->getTileStyle()->getType() != TileStyle::INNERMIDDLECENTER)
 	    {
 		maptile->setBuilding(Maptile::PORT);
-		Portlist::getInstance()->push_back(new Port(tile));
+		Portlist::getInstance()->add(new Port(tile));
 		if (Stacklist::getObjectAt(tile))
 		  {
 		    Stack* s = Stacklist::getObjectAt(tile);
@@ -718,7 +635,7 @@ void EditorBigMap::change_map_under_cursor()
 		else
 		{
 		    maptile->setBuilding(Maptile::BRIDGE);
-		    Bridgelist::getInstance()->push_back(new Bridge(tile, type));
+		    Bridgelist::getInstance()->add(new Bridge(tile, type));
 		    if (Stacklist::getObjectAt(tile))
 		      {
 			Stack* s = Stacklist::getObjectAt(tile);
@@ -743,7 +660,7 @@ void EditorBigMap::change_map_under_cursor()
 		if (maptile->getBuilding() == Maptile::NONE)
 		{
 		    maptile->setBuilding(Maptile::ROAD);
-		    Roadlist::getInstance()->push_back(new Road(tile, type));
+		    Roadlist::getInstance()->add(new Road(tile, type));
 		}
 
 		// now reconfigure all roads in the surroundings
@@ -766,10 +683,21 @@ void EditorBigMap::change_map_under_cursor()
 		changed_tiles.dim = Vector<int>(3, 3);
 	    }
 	    break;
+	case BAG:
+	    if (maptile->getMaptileType() != Tile::WATER)
+	    {
+	      //open the dialog
+	      MapBackpack *bag = 
+		GameMap::getInstance()->getTile(tile)->getBackpack();
+	      BackpackEditorDialog d(dynamic_cast<Backpack*>(bag));
+	      d.run();
+	    }
+	    break;
+	    
 	}
 
 	if (changed_tiles.w > 0 && changed_tiles.h > 0)
-	    map_changed.emit(changed_tiles);
+	    map_tiles_changed.emit(changed_tiles);
     }
 
     draw();
@@ -781,3 +709,109 @@ void EditorBigMap::smooth_view()
 					  view.x+view.w, true);
   draw();
 }
+
+void EditorBigMap::after_draw()
+{
+    int tilesize = GameMap::getInstance()->getTileset()->getTileSize();
+    std::vector<Vector<int> > tiles;
+
+    if (show_tile_types_instead_of_tile_styles)
+      {
+	tiles = get_screen_tiles();
+	for (std::vector<Vector<int> >::iterator i = tiles.begin(),
+	     end = tiles.end(); i != end; ++i)
+	  {
+	    Vector<int> pos = tile_to_buffer_pos(*i);
+	    buffer_gc->set_rgb_fg_color(GameMap::getInstance()->getTile(*i)->getColor());
+	    int x = pos.x;
+	    int y = pos.y;
+	    int ts = tilesize;
+	    if (d_grid_toggled)
+	      {
+		x++;
+		y++;
+		ts--;
+	      }
+	    buffer->draw_rectangle (buffer_gc, true, x, y, ts, ts);
+	  }
+      }
+
+    // we need to draw a drawing cursor on the map
+    tiles = get_cursor_tiles();
+    // draw each tile
+	
+    Gdk::Color terrain_box_color = Gdk::Color();
+    terrain_box_color.set_rgb_p(200.0/255.0, 200.0/255.0, 200.0/255.0);
+    Gdk::Color erase_box_color = Gdk::Color();
+    erase_box_color.set_rgb_p(200.0/255.0, 50.0/255.0, 50.0/255.0);
+    for (std::vector<Vector<int> >::iterator i = tiles.begin(),
+	     end = tiles.end(); i != end; ++i)
+      {
+	Vector<int> pos = tile_to_buffer_pos(*i);
+
+	PixMask *pic;
+
+
+	switch (pointer)
+	  {
+	  case POINTER:
+	    break;
+
+	  case TERRAIN:
+	    buffer_gc->set_rgb_fg_color (terrain_box_color);
+	    buffer->draw_rectangle (buffer_gc, false, pos.x + 1, pos.y + 1, 
+				    tilesize - 1, tilesize -1);
+	    break;
+
+	  case ERASE:
+	    buffer_gc->set_rgb_fg_color (erase_box_color);
+	    buffer->draw_rectangle (buffer_gc, false, pos.x + 1, pos.y + 1, 
+				    tilesize - 1, tilesize -1);
+	    break;
+
+	  case STACK:
+	    pic = GraphicsCache::getInstance()->getArmyPic
+	      (Playerlist::getInstance()->getNeutral()->getArmyset(), 0,
+	       Playerlist::getInstance()->getNeutral(), NULL);
+	    pic->blit(buffer, pos);
+	    break;
+
+	  case CITY:
+	    pic = GraphicsCache::getInstance()->getCityPic(0, Playerlist::getInstance()->getNeutral(), 1);
+	    pic->blit(buffer, pos);
+	    break;
+
+	  case RUIN:
+	    pic = GraphicsCache::getInstance()->getRuinPic(0, 1);
+	    pic->blit(buffer, pos);
+	    break;
+
+	  case TEMPLE:
+	    pic = GraphicsCache::getInstance()->getTemplePic(0, 1);
+	    pic->blit(buffer, pos);
+	    break;
+
+	  case SIGNPOST:
+	    pic = GraphicsCache::getInstance()->getSignpostPic();
+	    pic->blit(buffer, pos);
+	    break;
+
+	  case ROAD:
+	    pic = GraphicsCache::getInstance()->getRoadPic(CreateScenario::calculateRoadType(*i));
+	    pic->blit(buffer, pos);
+	    break;
+	  case PORT:
+	    pic = GraphicsCache::getInstance()->getPortPic();
+	    pic->blit(buffer, pos);
+	    break;
+	  case BRIDGE:
+	    pic = GraphicsCache::getInstance()->getBridgePic(tile_to_bridge_type(*i));
+	    pic->blit(buffer, pos);
+	    break;
+	  case BAG:
+	    pic = GraphicsCache::getInstance()->getBagPic();
+	    pic->blit(buffer, pos);
+	    break;
+	  }
+      }
+}
