@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -25,19 +25,9 @@
 #include <sigc++/functors/mem_fun.h>
 #include <sigc++/functors/ptr_fun.h>
 
-#include <gtkmm/widget.h>
-#include <gtkmm/eventbox.h>
-#include <gtkmm/image.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/aboutdialog.h>
-#include <gtkmm/stock.h>
-#include <gtkmm/filechooserdialog.h>
-#include <gtkmm/menu.h>
-#include <gtkmm/menuitem.h>
-
+#include <gtkmm.h>
 #include "main-window.h"
 
-#include "gtksdl.h"
 #include "image-helpers.h"
 #include "input-helpers.h"
 #include "error-utils.h"
@@ -58,67 +48,98 @@
 #include "Itemlist.h"
 #include "playerlist.h"
 #include "shieldsetlist.h"
+#include "citysetlist.h"
 #include "ai_dummy.h"
 
 #include "stack.h"
-#include "city.h"
-#include "ruin.h"
 #include "signpost.h"
-#include "temple.h"
 #include "citylist.h"
+#include "city.h"
 #include "templelist.h"
+#include "temple.h"
 #include "ruinlist.h"
+#include "ruin.h"
 #include "signpostlist.h"
+#include "signpost.h"
 #include "roadlist.h"
+#include "road.h"
 #include "bridgelist.h"
+#include "bridge.h"
 #include "portlist.h"
+#include "port.h"
 #include "MapGenerator.h"
 #include "counter.h"
 
 #include "glade-helpers.h"
 #include "editorbigmap.h"
 
-#include "signpost-dialog.h"
-#include "temple-dialog.h"
-#include "ruin-dialog.h"
-#include "stack-dialog.h"
+#include "signpost-editor-dialog.h"
+#include "temple-editor-dialog.h"
+#include "ruin-editor-dialog.h"
+#include "stack-editor-dialog.h"
 #include "players-dialog.h"
-#include "city-dialog.h"
+#include "city-editor-dialog.h"
 #include "map-info-dialog.h"
 #include "new-map-dialog.h"
 #include "itemlist-dialog.h"
 #include "rewardlist-dialog.h"
 #include "timed-message-dialog.h"
+#include "backpack-editor-dialog.h"
+#include "MapBackpack.h"
 
 
 MainWindow::MainWindow()
 {
-    sdl_inited = false;
-    
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path() + "/main-window.glade");
+  bigmap = NULL;
+  smallmap = NULL;
+  game_scenario = NULL;
+  d_create_scenario_names = NULL;
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path() + "/main-window.ui");
 
-    Gtk::Window *w = 0;
-    xml->get_widget("window", w);
-    window.reset(w);
+    xml->get_widget("window", window);
+    window->set_icon_from_file(File::getMiscFile("various/tileset_icon.png"));
 
-    w->signal_delete_event().connect(
+    window->signal_delete_event().connect(
 	sigc::mem_fun(*this, &MainWindow::on_delete_event));
 
-    xml->get_widget("sdl_container", sdl_container);
-
     // the map image
-    xml->get_widget("map_image", map_image);
+    xml->get_widget("bigmap_drawingarea", bigmap_drawingarea);
+    //bigmap_drawingarea->set_double_buffered(false);
+    //bigmap_drawingarea->set_app_paintable(true);
+    bigmap_drawingarea->signal_expose_event().connect
+      (sigc::mem_fun(*this, &MainWindow::on_bigmap_exposed));
+    bigmap_drawingarea->signal_size_allocate().connect
+      (sigc::mem_fun(*this, &MainWindow::on_bigmap_surface_changed));
+    xml->get_widget("bigmap_eventbox", bigmap_eventbox);
+
+    bigmap_eventbox->add_events(Gdk::BUTTON_PRESS_MASK | 
+				Gdk::BUTTON_RELEASE_MASK | 
+				Gdk::POINTER_MOTION_MASK |
+				Gdk::KEY_PRESS_MASK);
+    bigmap_eventbox->signal_button_press_event().connect(
+	sigc::mem_fun(*this, &MainWindow::on_bigmap_mouse_button_event));
+    bigmap_eventbox->signal_button_release_event().connect(
+	sigc::mem_fun(*this, &MainWindow::on_bigmap_mouse_button_event));
+    bigmap_eventbox->signal_motion_notify_event().connect(
+	sigc::mem_fun(*this, &MainWindow::on_bigmap_mouse_motion_event));
+    bigmap_eventbox->signal_key_press_event().connect(
+	sigc::mem_fun(*this, &MainWindow::on_bigmap_key_event));
+    bigmap_eventbox->signal_leave_notify_event().connect(
+	sigc::mem_fun(*this, &MainWindow::on_bigmap_leave_event));
+    xml->get_widget("map_drawingarea", map_drawingarea);
+    map_drawingarea->signal_expose_event().connect
+      (sigc::mem_fun(*this, &MainWindow::on_smallmap_exposed));
     Gtk::EventBox *map_eventbox;
     xml->get_widget("map_eventbox", map_eventbox);
     map_eventbox->add_events(Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK |
 			     Gdk::POINTER_MOTION_MASK);
     map_eventbox->signal_button_press_event().connect(
-	sigc::mem_fun(*this, &MainWindow::on_map_mouse_button_event));
+	sigc::mem_fun(*this, &MainWindow::on_smallmap_mouse_button_event));
     map_eventbox->signal_button_release_event().connect(
-	sigc::mem_fun(*this, &MainWindow::on_map_mouse_button_event));
+	sigc::mem_fun(*this, &MainWindow::on_smallmap_mouse_button_event));
     map_eventbox->signal_motion_notify_event().connect(
-	sigc::mem_fun(*this, &MainWindow::on_map_mouse_motion_event));
+	sigc::mem_fun(*this, &MainWindow::on_smallmap_mouse_motion_event));
 
     xml->get_widget("terrain_tile_style_hbox", terrain_tile_style_hbox);
 
@@ -153,6 +174,8 @@ MainWindow::MainWindow()
 			      EditorBigMap::PORT, 1);
     setup_pointer_radiobutton(xml, "draw_bridge", "button_bridge",
 			      EditorBigMap::BRIDGE, 1);
+    setup_pointer_radiobutton(xml, "draw_bag", "button_bag",
+			      EditorBigMap::BAG, 1);
     on_pointer_radiobutton_toggled();
 
 
@@ -160,78 +183,105 @@ MainWindow::MainWindow()
     
     
     // connect callbacks for the menu
-    xml->connect_clicked("new_map_menuitem",
-			 sigc::mem_fun(this, &MainWindow::on_new_map_activated));
-    xml->connect_clicked("load_map_menuitem",
-			 sigc::mem_fun(this, &MainWindow::on_load_map_activated));
-    xml->connect_clicked("save_map_menuitem",
-			 sigc::mem_fun(this, &MainWindow::on_save_map_activated));
-    xml->connect_clicked("save_map_as_menuitem", 
-			 sigc::mem_fun(this, &MainWindow::on_save_map_as_activated));
-    xml->connect_clicked("export_as_bitmap_menuitem",
-			 sigc::mem_fun(this, &MainWindow::on_export_as_bitmap_activated));
-    xml->connect_clicked("export_as_bitmap_no_game_objects_menuitem",
-			 sigc::mem_fun(this, &MainWindow::on_export_as_bitmap_no_game_objects_activated));
-    xml->connect_clicked("validate_menuitem",
-			 sigc::mem_fun(this, &MainWindow::on_validate_activated));
-    xml->connect_clicked("quit_menuitem", 
-			 sigc::mem_fun(this, &MainWindow::on_quit_activated));
+    xml->get_widget("new_map_menuitem", new_map_menuitem);
+    new_map_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_new_map_activated));
+    xml->get_widget("load_map_menuitem", load_map_menuitem);
+    load_map_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_load_map_activated));
+    xml->get_widget("save_map_menuitem", save_map_menuitem);
+    save_map_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_save_map_activated));
+    xml->get_widget("save_map_as_menuitem", save_map_as_menuitem);
+    save_map_as_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_save_map_as_activated));
+    xml->get_widget("export_as_bitmap_menuitem", export_as_bitmap_menuitem);
+    export_as_bitmap_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_export_as_bitmap_activated));
+    xml->get_widget("export_as_bitmap_no_game_objects_menuitem",
+		    export_as_bitmap_no_game_objects_menuitem);
+    export_as_bitmap_no_game_objects_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_export_as_bitmap_no_game_objects_activated));
+    xml->get_widget("validate_menuitem", validate_menuitem);
+    validate_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_validate_activated));
+    xml->get_widget("quit_menuitem", quit_menuitem);
+    quit_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_quit_activated));
 
-    xml->connect_clicked("edit_players_menuitem", 
-			 sigc::mem_fun(this, &MainWindow::on_edit_players_activated));
-    xml->connect_clicked("edit_map_info_menuitem", 
-			 sigc::mem_fun(this, &MainWindow::on_edit_map_info_activated));
+    xml->get_widget("edit_players_menuitem", edit_players_menuitem);
+    edit_players_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_edit_players_activated));
+    xml->get_widget("edit_map_info_menuitem", edit_map_info_menuitem);
+    edit_map_info_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_edit_map_info_activated));
     
-    xml->connect_clicked("fullscreen_menuitem", 
-			 sigc::mem_fun(this, &MainWindow::on_fullscreen_activated));
-    xml->connect_clicked("toggle_tile_graphics_menuitem", 
-			 sigc::mem_fun(this, &MainWindow::on_tile_graphics_toggled));
     xml->get_widget("fullscreen_menuitem", fullscreen_menuitem);
-    xml->connect_clicked("smooth_map_menuitem", 
-			 sigc::mem_fun(this, 
-				       &MainWindow::on_smooth_map_activated));
-    xml->connect_clicked("smooth_screen_menuitem", sigc::mem_fun
-			 (this, &MainWindow::on_smooth_screen_activated));
-    xml->connect_clicked("edit_items_menuitem", 
-			 sigc::mem_fun(this, 
-				       &MainWindow::on_edit_items_activated));
-    xml->connect_clicked("edit_rewards_menuitem", 
-			 sigc::mem_fun(this, 
-				       &MainWindow::on_edit_rewards_activated));
-    xml->connect_clicked
-      ("random_all_cities_menuitem", 
-       sigc::mem_fun(this, &MainWindow::on_random_all_cities_activated));
-    xml->connect_clicked
-      ("random_unnamed_cities_menuitem", 
-       sigc::mem_fun(this, &MainWindow::on_random_unnamed_cities_activated));
-    xml->connect_clicked
-      ("random_all_ruins_menuitem", 
-       sigc::mem_fun(this, &MainWindow::on_random_all_ruins_activated));
-    xml->connect_clicked
-      ("random_unnamed_ruins_menuitem", 
-       sigc::mem_fun(this, &MainWindow::on_random_unnamed_ruins_activated));
-    xml->connect_clicked
-      ("random_all_temples_menuitem", 
-       sigc::mem_fun(this, &MainWindow::on_random_all_temples_activated));
-    xml->connect_clicked
-      ("random_unnamed_temples_menuitem", 
-       sigc::mem_fun(this, &MainWindow::on_random_unnamed_temples_activated));
-    xml->connect_clicked
-      ("random_all_signs_menuitem", 
-       sigc::mem_fun(this, &MainWindow::on_random_all_signs_activated));
-    xml->connect_clicked
-      ("random_unnamed_signs_menuitem", 
-       sigc::mem_fun(this, &MainWindow::on_random_unnamed_signs_activated));
-    xml->connect_clicked
-      ("help_about_menuitem", 
-       sigc::mem_fun(this, &MainWindow::on_help_about_activated));
+    fullscreen_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_fullscreen_activated));
+    xml->get_widget("toggle_tile_graphics_menuitem", toggle_tile_graphics_menuitem);
+    toggle_tile_graphics_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_tile_graphics_toggled));
+    xml->get_widget("toggle_grid_menuitem", toggle_grid_menuitem);
+    toggle_grid_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_grid_toggled));
+    xml->get_widget("smooth_map_menuitem", smooth_map_menuitem);
+    smooth_map_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_smooth_map_activated));
+    xml->get_widget("smooth_screen_menuitem", smooth_screen_menuitem);
+    smooth_screen_menuitem->signal_activate().connect
+      (sigc::mem_fun (this, &MainWindow::on_smooth_screen_activated));
+    xml->get_widget("edit_items_menuitem", edit_items_menuitem);
+    edit_items_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_edit_items_activated));
+    xml->get_widget("edit_rewards_menuitem", edit_rewards_menuitem);
+    edit_rewards_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_edit_rewards_activated));
+    xml->get_widget ("random_all_cities_menuitem", random_all_cities_menuitem);
+    random_all_cities_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_random_all_cities_activated));
+    xml->get_widget ("random_unnamed_cities_menuitem", 
+		     random_unnamed_cities_menuitem);
+    random_unnamed_cities_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_random_unnamed_cities_activated));
+    xml->get_widget ("random_all_ruins_menuitem", random_all_ruins_menuitem);
+    random_all_ruins_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_random_all_ruins_activated));
+    xml->get_widget ("random_unnamed_ruins_menuitem", 
+		     random_unnamed_ruins_menuitem);
+    random_unnamed_ruins_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_random_unnamed_ruins_activated));
+    xml->get_widget ("random_all_temples_menuitem", 
+		     random_all_temples_menuitem);
+    random_all_temples_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_random_all_temples_activated));
+    xml->get_widget ("random_unnamed_temples_menuitem", 
+		     random_unnamed_temples_menuitem);
+    random_unnamed_temples_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_random_unnamed_temples_activated));
+    xml->get_widget ("random_all_signs_menuitem", 
+		     random_all_signs_menuitem);
+    random_all_signs_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &MainWindow::on_random_all_signs_activated));
+    xml->get_widget ("random_unnamed_signs_menuitem", 
+		     random_unnamed_signs_menuitem);
+    random_unnamed_signs_menuitem->signal_activate().connect
+       (sigc::mem_fun(this, &MainWindow::on_random_unnamed_signs_activated));
+    xml->get_widget ("help_about_menuitem", help_about_menuitem);
+    help_about_menuitem->signal_activate().connect
+       (sigc::mem_fun(this, &MainWindow::on_help_about_activated));
 }
 
 MainWindow::~MainWindow()
 {
+  delete bigmap;
+  delete smallmap;
+  delete game_scenario;
+  delete d_create_scenario_names;
+  delete window;
 }
 
-void MainWindow::setup_pointer_radiobutton(Glib::RefPtr<Gnome::Glade::Xml> xml,
+void MainWindow::setup_pointer_radiobutton(Glib::RefPtr<Gtk::Builder> xml,
 					   std::string prefix,
 					   std::string image_file,
 					   EditorBigMap::Pointer pointer,
@@ -285,10 +335,11 @@ void MainWindow::setup_terrain_radiobuttons()
 	item.button->signal_toggled().connect(
 	    sigc::mem_fun(this, &MainWindow::on_terrain_radiobutton_toggled));
 
-	//SDL_Surface *surf = (*(*tile)[0])[0]->getPixmap();
-	SDL_Surface *surf = (*(*(*tile).begin())->begin())->getPixmap();
-	Glib::RefPtr<Gdk::Pixbuf> pic = to_pixbuf(surf)->scale_simple(20, 20, Gdk::INTERP_NEAREST);
-	item.button->add(*manage(new Gtk::Image(pic)));
+	Glib::RefPtr<Gdk::Pixbuf> pic;
+	PixMask *pix = (*(*(*tile).begin())->begin())->getImage()->copy();
+	PixMask::scale(pix, 20, 20);
+	item.button->add(*manage(new Gtk::Image(pix->to_pixbuf())));
+	delete pix;
 
 	item.terrain = tile->getType();
 	terrain_items.push_back(item);
@@ -299,8 +350,59 @@ void MainWindow::setup_terrain_radiobuttons()
 
 void MainWindow::show()
 {
-    sdl_container->show_all();
-    window->show();
+  bigmap_drawingarea->show_all();
+  window->show();
+  on_bigmap_surface_changed(bigmap_drawingarea->get_allocation());
+}
+
+void MainWindow::on_bigmap_surface_changed(Gtk::Allocation box)
+{
+  if (!bigmap)
+    return;
+  static Gtk::Allocation last_box = Gtk::Allocation(0,0,1,1);
+
+  if (box.get_width() != last_box.get_width() || box.get_height() != last_box.get_height())
+    {
+      bigmap->screen_size_changed(bigmap_drawingarea->get_allocation());
+      bigmap->draw();
+      smallmap->draw(Playerlist::getActiveplayer());
+    }
+  last_box = box;
+}
+bool MainWindow::on_bigmap_exposed(GdkEventExpose *event)
+{
+  Glib::RefPtr<Gdk::Window> window = bigmap_drawingarea->get_window();
+  if (window)
+    {
+      Glib::RefPtr<Gdk::Pixmap> surface = bigmap->get_surface();
+      window->draw_drawable(bigmap_drawingarea->get_style()->get_white_gc(),
+			     surface, event->area.x, event->area.y, 
+			     event->area.x, event->area.y, 
+			     event->area.width, event->area.height);
+    }
+  return true;
+}
+bool MainWindow::on_smallmap_exposed(GdkEventExpose *event)
+{
+  Glib::RefPtr<Gdk::Window> window = map_drawingarea->get_window();
+  if (window)
+    {
+      Glib::RefPtr<Gdk::Pixmap> surface = smallmap->get_surface();
+      window->draw_drawable(map_drawingarea->get_style()->get_white_gc(),
+			     surface, event->area.x, event->area.y, 
+			     event->area.x, event->area.y, 
+			     event->area.width, event->area.height);
+    }
+  return true;
+}
+
+void MainWindow::init()
+{
+  GraphicsLoader::instantiateImages(Armysetlist::getInstance());
+  GraphicsLoader::instantiateImages(Tilesetlist::getInstance());
+  GraphicsLoader::instantiateImages(Shieldsetlist::getInstance());
+  GraphicsLoader::instantiateImages(Citysetlist::getInstance());
+  show_initial_map();
 }
 
 void MainWindow::hide()
@@ -308,45 +410,6 @@ void MainWindow::hide()
     window->hide();
 }
 
-namespace 
-{
-    void surface_attached_helper(GtkSDL *gtksdl, gpointer data)
-    {
-	static_cast<MainWindow *>(data)->on_sdl_surface_changed();
-    }
-}
-
-void MainWindow::init(int width, int height)
-{
-    sdl_widget
-	= Gtk::manage(Glib::wrap(gtk_sdl_new(width, height, 0, SDL_SWSURFACE)));
-
-    sdl_widget->set_flags(Gtk::CAN_FOCUS);
-
-    sdl_widget->grab_focus();
-    sdl_widget->add_events(Gdk::KEY_PRESS_MASK |
-		  Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK |
-	          Gdk::POINTER_MOTION_MASK | Gdk::LEAVE_NOTIFY_MASK);
-
-    sdl_widget->signal_button_press_event().connect(
-	sigc::mem_fun(*this, &MainWindow::on_sdl_mouse_button_event));
-    sdl_widget->signal_button_release_event().connect(
-	sigc::mem_fun(*this, &MainWindow::on_sdl_mouse_button_event));
-    sdl_widget->signal_motion_notify_event().connect(
-	sigc::mem_fun(*this, &MainWindow::on_sdl_mouse_motion_event));
-    sdl_widget->signal_key_press_event().connect(
-	sigc::mem_fun(*this, &MainWindow::on_sdl_key_event));
-    sdl_widget->signal_leave_notify_event().connect(
-	sigc::mem_fun(*this, &MainWindow::on_sdl_leave_event));
-    
-    // connect to the special signal that signifies that a new surface has been
-    // generated and attached to the widget
-    g_signal_connect(G_OBJECT(sdl_widget->gobj()), "surface-attached",
-		     G_CALLBACK(surface_attached_helper), this);
-    
-    sdl_container->add(*sdl_widget);
-}
-
 bool MainWindow::on_delete_event(GdkEventAny *e)
 {
     hide();
@@ -375,9 +438,13 @@ void MainWindow::set_filled_map(int width, int height, int fill_style, std::stri
     GameMap::getInstance(tileset, shieldset, cityset);
     Itemlist::createStandardInstance();
 
+    if (game_scenario)
+      delete game_scenario;
     // sets up the lists
-    game_scenario.reset(new GameScenario(_("Untitled"), _("No description"), true));
-    d_create_scenario_names.reset(new CreateScenarioRandomize());
+    game_scenario = new GameScenario(_("Untitled"), _("No description"), true);
+    if (d_create_scenario_names)
+      delete d_create_scenario_names;
+    d_create_scenario_names = new CreateScenarioRandomize();
     //zip past the player IDs (+1 for neutral)
     for (unsigned int i = 0; i < MAX_PLAYERS + 1; i++)
       fl_counter->getNextId();
@@ -385,11 +452,12 @@ void MainWindow::set_filled_map(int width, int height, int fill_style, std::stri
 
     // ...however we need to do some of the setup by hand. We need to create a
     // neutral player to give cities a player upon creation...
-    Uint32 armyset_id = 
+    guint32 armyset_id = 
       Armysetlist::getInstance()->getArmyset(armyset)->getId();
     Shieldsetlist *ssl = Shieldsetlist::getInstance();
+    Shieldset *ss = ssl->getShieldset(shieldset);
     Player* neutral = new AI_Dummy(_("Neutral"), armyset_id, 
-				   ssl->getColor(shieldset, MAX_PLAYERS), 
+				   ssl->getColor(ss->getId(), MAX_PLAYERS), 
 				   width, height, MAX_PLAYERS);
     neutral->setType(Player::AI_DUMMY);
     Playerlist::getInstance()->push_back(neutral);
@@ -432,11 +500,12 @@ void MainWindow::set_random_map(int width, int height,
     
     // We need to create a neutral player to give cities a player upon
     // creation...
-    Uint32 armyset_id = 
+    guint32 armyset_id = 
       Armysetlist::getInstance()->getArmyset(armyset)->getId();
     Shieldsetlist *ssl = Shieldsetlist::getInstance();
+    Shieldset *ss = ssl->getShieldset(shieldset);
     Player* neutral = new AI_Dummy(_("Neutral"), armyset_id, 
-				   ssl->getColor(shieldset, MAX_PLAYERS), 
+				   ssl->getColor(ss->getId(), MAX_PLAYERS), 
 				   width, height, MAX_PLAYERS);
     neutral->setType(Player::AI_DUMMY);
     Playerlist::getInstance()->push_back(neutral);
@@ -473,8 +542,12 @@ void MainWindow::set_random_map(int width, int height,
 
     Itemlist::createStandardInstance();
     // sets up the lists
-    game_scenario.reset(new GameScenario(_("Untitled"), _("No description"), true));
-    d_create_scenario_names.reset(new CreateScenarioRandomize());
+    if (game_scenario)
+      delete game_scenario;
+    game_scenario = new GameScenario(_("Untitled"), _("No description"), true);
+    if (d_create_scenario_names)
+      delete d_create_scenario_names;
+    d_create_scenario_names = new CreateScenarioRandomize();
     
     // now fill the lists
     const Maptile::Building* build = gen.getBuildings(width, height);
@@ -483,27 +556,27 @@ void MainWindow::set_random_map(int width, int height,
 	    switch(build[j * width + i])
 	    {
 	    case Maptile::CITY:
-		Citylist::getInstance()->push_back(new City(Vector<int>(i,j)));
+		Citylist::getInstance()->add(new City(Vector<int>(i,j)));
 		(*Citylist::getInstance()->rbegin())->setOwner(
 		    Playerlist::getInstance()->getNeutral());
 		break;
 	    case Maptile::TEMPLE:
-		Templelist::getInstance()->push_back(new Temple(Vector<int>(i,j)));
+		Templelist::getInstance()->add(new Temple(Vector<int>(i,j)));
 		break;
 	    case Maptile::RUIN:
-		Ruinlist::getInstance()->push_back(new Ruin(Vector<int>(i,j)));
+		Ruinlist::getInstance()->add(new Ruin(Vector<int>(i,j)));
 		break;
 	    case Maptile::SIGNPOST:
-		Signpostlist::getInstance()->push_back(new Signpost(Vector<int>(i,j)));
+		Signpostlist::getInstance()->add(new Signpost(Vector<int>(i,j)));
 		break;
 	    case Maptile::ROAD:
-		Roadlist::getInstance()->push_back(new Road(Vector<int>(i,j)));
+		Roadlist::getInstance()->add(new Road(Vector<int>(i,j)));
 		break;
 	    case Maptile::BRIDGE:
-		Bridgelist::getInstance()->push_back(new Bridge(Vector<int>(i,j)));
+		Bridgelist::getInstance()->add(new Bridge(Vector<int>(i,j)));
 		break;
 	    case Maptile::PORT:
-		Portlist::getInstance()->push_back(new Port(Vector<int>(i,j)));
+		Portlist::getInstance()->add(new Port(Vector<int>(i,j)));
 		break;
 	    case Maptile::NONE:
 		break;
@@ -514,10 +587,26 @@ void MainWindow::set_random_map(int width, int height,
 
 void MainWindow::clear_map_state()
 {
-    bigmap.reset();
-    smallmap.reset();
-    game_scenario.reset();
-    d_create_scenario_names.reset();
+  if (bigmap)
+    {
+      delete bigmap;
+      bigmap = NULL;
+    }
+  if (smallmap)
+    {
+      delete smallmap;
+      smallmap = NULL;
+    }
+  if (game_scenario)
+    {
+      delete game_scenario;
+      game_scenario = NULL;
+    }
+  if (d_create_scenario_names)
+    {
+      delete d_create_scenario_names;
+      d_create_scenario_names = NULL;
+    }
     GraphicsCache::deleteInstance();
 }
 
@@ -525,36 +614,34 @@ void MainWindow::init_map_state()
 {
     pointer_radiobutton->set_active();
     init_maps();
-    bigmap->screen_size_changed();
 }
 
 
-bool MainWindow::on_sdl_mouse_button_event(GdkEventButton *e)
+bool MainWindow::on_bigmap_mouse_button_event(GdkEventButton *e)
 {
     if (e->type != GDK_BUTTON_PRESS && e->type != GDK_BUTTON_RELEASE)
 	return true;	// useless event
 
-    if (bigmap.get())
+    if (bigmap)
     {
 	button_event = e;	// save it for later use
 	bigmap->mouse_button_event(to_input_event(e));
-	if (smallmap.get())
+	if (smallmap)
 	  smallmap->draw(Playerlist::getActiveplayer());
     }
     
     return true;
 }
 
-bool MainWindow::on_sdl_mouse_motion_event(GdkEventMotion *e)
+bool MainWindow::on_bigmap_mouse_motion_event(GdkEventMotion *e)
 {
   static guint prev = 0;
-  if (bigmap.get())
+  if (bigmap)
     {
       guint delta = e->time - prev;
       if (delta > 40 || delta < 0)
 	{
 	  bigmap->mouse_motion_event(to_input_event(e));
-	  sdl_widget->grab_focus();
 	  prev = e->time;
 	}
     }
@@ -562,10 +649,10 @@ bool MainWindow::on_sdl_mouse_motion_event(GdkEventMotion *e)
     return true;
 }
 
-bool MainWindow::on_sdl_key_event(GdkEventKey *e)
+bool MainWindow::on_bigmap_key_event(GdkEventKey *e)
 {
 #if 0
-    if (bigmap.get()) {
+    if (bigmap) {
 	KeyPressEvent k;
 	bigmap->key_press_event(k);
     }
@@ -574,9 +661,9 @@ bool MainWindow::on_sdl_key_event(GdkEventKey *e)
     return true;
 }
 
-bool MainWindow::on_sdl_leave_event(GdkEventCrossing *e)
+bool MainWindow::on_bigmap_leave_event(GdkEventCrossing *e)
 {
-    if (bigmap.get())
+    if (bigmap)
     {
 	bigmap->mouse_leave_event();
     }
@@ -584,50 +671,39 @@ bool MainWindow::on_sdl_leave_event(GdkEventCrossing *e)
     return true;
 }
 
-bool MainWindow::on_map_mouse_button_event(GdkEventButton *e)
+bool MainWindow::on_smallmap_mouse_button_event(GdkEventButton *e)
 {
     if (e->type != GDK_BUTTON_PRESS && e->type != GDK_BUTTON_RELEASE)
 	return true;	// useless event
     
-    if (smallmap.get())
+    if (smallmap)
 	smallmap->mouse_button_event(to_input_event(e));
     
     return true;
 }
 
-bool MainWindow::on_map_mouse_motion_event(GdkEventMotion *e)
+bool MainWindow::on_smallmap_mouse_motion_event(GdkEventMotion *e)
 {
-    if (smallmap.get())
-	smallmap->mouse_motion_event(to_input_event(e));
+  static guint prev = 0;
+  if (smallmap)
+    {
+      guint delta = e->time - prev;
+      if (delta > 100 || delta < 0)
+	{
+	  smallmap->mouse_motion_event(to_input_event(e));
+	  prev = e->time;
+	}
+    }
     
     return true;
 }
 
-void MainWindow::on_sdl_surface_changed()
-{
-    if (!sdl_inited) {
-	GraphicsLoader::instantiatePixmaps(Armysetlist::getInstance());
-	GraphicsLoader::instantiatePixmaps(Tilesetlist::getInstance());
-	GraphicsLoader::instantiatePixmaps(Shieldsetlist::getInstance());
-	sdl_inited = true;
-	sdl_initialized.emit();
-    }
-
-    if (bigmap.get()) {
-	bigmap->screen_size_changed();
-	bigmap->draw();
-    }
-    
-    if (smallmap.get())
-	smallmap->draw(Playerlist::getActiveplayer());
-}
-
 void MainWindow::on_new_map_activated()
 {
     current_save_filename = "";
 
     NewMapDialog d;
-    d.set_parent_window(*window.get());
+    d.set_parent_window(*window);
     d.run();
 
     if (d.map_set)
@@ -648,11 +724,11 @@ void MainWindow::on_new_map_activated()
 
 void MainWindow::on_load_map_activated()
 {
-    Gtk::FileChooserDialog chooser(*window.get(), _("Choose Map to Load"));
+    Gtk::FileChooserDialog chooser(*window, _("Choose Map to Load"));
     Gtk::FileFilter sav_filter;
     sav_filter.add_pattern("*.map");
     chooser.set_filter(sav_filter);
-    chooser.set_current_folder(Configuration::s_savePath);
+    chooser.set_current_folder(File::getUserMapDir());
 
     chooser.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
     chooser.add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT);
@@ -669,8 +745,12 @@ void MainWindow::on_load_map_activated()
 	clear_map_state();
 
 	bool broken;
-	game_scenario.reset(new GameScenario(current_save_filename, broken));
-	d_create_scenario_names.reset(new CreateScenarioRandomize());
+	if (game_scenario)
+	  delete game_scenario;
+	game_scenario = new GameScenario(current_save_filename, broken);
+	if (d_create_scenario_names)
+	  delete d_create_scenario_names;
+	d_create_scenario_names = new CreateScenarioRandomize();
 
 	if (broken)
 	{
@@ -681,6 +761,7 @@ void MainWindow::on_load_map_activated()
 	}
 
 	init_map_state();
+	bigmap->screen_size_changed(bigmap_drawingarea->get_allocation()); 
     }
 }
 
@@ -698,12 +779,13 @@ void MainWindow::on_save_map_activated()
 
 void MainWindow::on_export_as_bitmap_activated()
 {
-    Gtk::FileChooserDialog chooser(*window.get(), _("Choose a Name"),
+    Gtk::FileChooserDialog chooser(*window, _("Choose a Name"),
 				   Gtk::FILE_CHOOSER_ACTION_SAVE);
     Gtk::FileFilter sav_filter;
-    sav_filter.add_pattern("*.bmp");
+    sav_filter.add_pattern("*.png");
     chooser.set_filter(sav_filter);
-    chooser.set_current_folder(Configuration::s_savePath);
+    chooser.set_current_folder(Glib::get_home_dir());
+    chooser.set_do_overwrite_confirmation();
 
     chooser.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
     chooser.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
@@ -725,12 +807,13 @@ void MainWindow::on_export_as_bitmap_activated()
 
 void MainWindow::on_export_as_bitmap_no_game_objects_activated()
 {
-    Gtk::FileChooserDialog chooser(*window.get(), _("Choose a Name"),
+    Gtk::FileChooserDialog chooser(*window, _("Choose a Name"),
 				   Gtk::FILE_CHOOSER_ACTION_SAVE);
     Gtk::FileFilter sav_filter;
-    sav_filter.add_pattern("*.bmp");
+    sav_filter.add_pattern("*.png");
     chooser.set_filter(sav_filter);
-    chooser.set_current_folder(Configuration::s_savePath);
+    chooser.set_current_folder(Glib::get_home_dir());
+    chooser.set_do_overwrite_confirmation();
 
     chooser.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
     chooser.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
@@ -752,12 +835,12 @@ void MainWindow::on_export_as_bitmap_no_game_objects_activated()
 
 void MainWindow::on_save_map_as_activated()
 {
-    Gtk::FileChooserDialog chooser(*window.get(), _("Choose a Name"),
+    Gtk::FileChooserDialog chooser(*window, _("Choose a Name"),
 				   Gtk::FILE_CHOOSER_ACTION_SAVE);
     Gtk::FileFilter sav_filter;
     sav_filter.add_pattern("*.map");
     chooser.set_filter(sav_filter);
-    chooser.set_current_folder(Configuration::s_savePath);
+    chooser.set_current_folder(File::getUserMapDir());
 
     chooser.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
     chooser.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
@@ -790,14 +873,14 @@ void MainWindow::on_quit_activated()
 void MainWindow::on_edit_players_activated()
 {
     PlayersDialog d(d_width, d_height);
-    d.set_parent_window(*window.get());
+    d.set_parent_window(*window);
     d.run();
 }
 
 void MainWindow::on_edit_map_info_activated()
 {
-    MapInfoDialog d(game_scenario.get());
-    d.set_parent_window(*window.get());
+    MapInfoDialog d(game_scenario);
+    d.set_parent_window(*window);
     d.run();
 }
 
@@ -814,6 +897,11 @@ void MainWindow::on_tile_graphics_toggled()
   bigmap->toggleViewStylesOrTypes();
   bigmap->draw();
 }
+void MainWindow::on_grid_toggled()
+{
+  bigmap->toggle_grid();
+}
+
 
 void MainWindow::remove_tile_style_buttons()
 {
@@ -833,7 +921,7 @@ void MainWindow::setup_tile_style_buttons(Tile::Type terrain)
   Gtk::RadioButton::Group group;
   //iterate through tilestyles of a certain TERRAIN tile
   Tileset *tileset = GameMap::getInstance()->getTileset();
-  Uint32 index = tileset->getIndex(terrain);
+  guint32 index = tileset->getIndex(terrain);
   Tile *tile = (*tileset)[index];
   if (tile == NULL)
     return;
@@ -873,8 +961,7 @@ void MainWindow::setup_tile_style_buttons(Tile::Type terrain)
 	    (sigc::mem_fun(this, 
 			   &MainWindow::on_tile_style_radiobutton_toggled));
 
-	  SDL_Surface *surf = tilestyle->getPixmap();
-	  Glib::RefPtr<Gdk::Pixbuf> pic = to_pixbuf(surf);
+	  Glib::RefPtr<Gdk::Pixbuf> pic = tilestyle->getImage()->to_pixbuf();
 	  item.button->add(*manage(new Gtk::Image(pic)));
 	  item.tile_style_id = tilestyle->getId();
 
@@ -950,7 +1037,7 @@ void MainWindow::on_pointer_radiobutton_toggled()
 	}
     }
     
-    if (bigmap.get())
+    if (bigmap)
 	bigmap->set_pointer(pointer, size, get_terrain(),
 			    get_tile_style_id());
     terrain_type_table->set_sensitive(pointer == EditorBigMap::TERRAIN);
@@ -989,32 +1076,66 @@ int MainWindow::get_tile_style_id()
     return tile_style_id;
 }
 
-void MainWindow::on_smallmap_changed(SDL_Surface *map)
+void MainWindow::on_bigmap_changed(Glib::RefPtr<Gdk::Pixmap> map)
 {
-    map_image->property_pixbuf() = to_pixbuf(map);
+  int width = 0;
+  int height = 0;
+  map->get_size(width, height);
+  Glib::RefPtr<Gdk::Window> window = bigmap_drawingarea->get_window();
+  if (window)
+    {
+      Gdk::Rectangle r = Gdk::Rectangle(0, 0, width, height);
+      window->invalidate_rect(r, true);
+    }
 }
+void MainWindow::on_smallmap_changed(Glib::RefPtr<Gdk::Pixmap> map, Gdk::Rectangle r)
+{
+  int width = 0;
+  int height = 0;
+  map->get_size(width, height);
+  map_drawingarea->property_width_request() = width;
+  map_drawingarea->property_height_request() = height;
+      
+  Glib::RefPtr<Gdk::Window> window = map_drawingarea->get_window();
+  if (window)
+    {
+      window->invalidate_rect(r, false);
+    }
+  //map_image->property_pixmap() = map;
+  //map.clear();
+  //still resides at smallmap->get_surface()
+}
+
 
 void MainWindow::init_maps()
 {
     // init the bigmap
-    bigmap.reset(new EditorBigMap);
+    if (bigmap)
+      delete bigmap;
+    bigmap = new EditorBigMap;
     bigmap->mouse_on_tile.connect(
 	sigc::mem_fun(this, &MainWindow::on_mouse_on_tile));
     bigmap->objects_selected.connect(
 	sigc::mem_fun(this, &MainWindow::on_objects_selected));
+    bigmap->map_changed.connect(
+	sigc::mem_fun(this, &MainWindow::on_bigmap_changed));
+    // grid is on by default
+    bigmap->toggle_grid();
     
     // init the smallmap
-    smallmap.reset(new SmallMap);
+    if (smallmap)
+      delete smallmap;
+    smallmap =new SmallMap;
     smallmap->map_changed.connect(
 	sigc::mem_fun(this, &MainWindow::on_smallmap_changed));
 
     // connect the two maps
     bigmap->view_changed.connect(
-	sigc::mem_fun(smallmap.get(), &SmallMap::set_view));
-    bigmap->map_changed.connect(
-	sigc::mem_fun(smallmap.get(), &SmallMap::redraw_tiles));
+	sigc::mem_fun(smallmap, &SmallMap::set_view));
+    bigmap->map_tiles_changed.connect(
+	sigc::mem_fun(smallmap, &SmallMap::redraw_tiles));
     smallmap->view_changed.connect(
-	sigc::mem_fun(bigmap.get(), &EditorBigMap::set_view));
+	sigc::mem_fun(bigmap, &EditorBigMap::set_view));
 
     smallmap->resize(GameMap::get_dim() * 2);
 }
@@ -1055,6 +1176,8 @@ void MainWindow::on_objects_selected(std::vector<UniquelyIdentified *> objects)
 		s = _("Signpost");
 	    else if (dynamic_cast<Temple *>(*i))
 		s = _("Temple");
+	    else if (dynamic_cast<MapBackpack*>(*i))
+		s = _("Bag");
 	    
 	    Gtk::MenuItem *item = manage(new Gtk::MenuItem(s));
 	    item->signal_activate().connect(
@@ -1070,8 +1193,8 @@ void MainWindow::popup_dialog_for_object(UniquelyIdentified *object)
 {
     if (Stack *o = dynamic_cast<Stack *>(object))
     {
-	StackDialog d(o);
-	d.set_parent_window(*window.get());
+	StackEditorDialog d(o);
+	d.set_parent_window(*window);
 	d.run();
 
 	// we might have changed something visible
@@ -1080,8 +1203,8 @@ void MainWindow::popup_dialog_for_object(UniquelyIdentified *object)
     }
     else if (City *o = dynamic_cast<City *>(object))
     {
-	CityDialog d(o, d_create_scenario_names.get());
-	d.set_parent_window(*window.get());
+	CityEditorDialog d(o, d_create_scenario_names);
+	d.set_parent_window(*window);
 	d.run();
 
 	// we might have changed something visible
@@ -1090,25 +1213,30 @@ void MainWindow::popup_dialog_for_object(UniquelyIdentified *object)
     }
     else if (Ruin *o = dynamic_cast<Ruin *>(object))
     {
-	RuinDialog d(o, d_create_scenario_names.get());
-	d.set_parent_window(*window.get());
+	RuinEditorDialog d(o, d_create_scenario_names);
+	d.set_parent_window(*window);
 	d.run();
     }
     else if (Signpost *o = dynamic_cast<Signpost *>(object))
     {
-	SignpostDialog d(o, d_create_scenario_names.get());
-	d.set_parent_window(*window.get());
+	SignpostEditorDialog d(o, d_create_scenario_names);
+	d.set_parent_window(*window);
 	d.run();
     }
     else if (Temple *o = dynamic_cast<Temple *>(object))
     {
-	TempleDialog d(o, d_create_scenario_names.get());
-	d.set_parent_window(*window.get());
+	TempleEditorDialog d(o, d_create_scenario_names);
+	d.set_parent_window(*window);
 	d.run();
 
 	// we might have changed something visible
 	bigmap->draw();
     }
+    else if (MapBackpack *b = dynamic_cast<MapBackpack*>(object))
+      {
+	BackpackEditorDialog d(b);
+	d.run();
+      }
 }
 
 void MainWindow::on_smooth_map_activated()
@@ -1126,14 +1254,14 @@ void MainWindow::on_smooth_screen_activated()
 void MainWindow::on_edit_items_activated()
 {
   ItemlistDialog d;
-  d.set_parent_window(*window.get());
+  d.set_parent_window(*window);
   d.run();
 }
 
 void MainWindow::on_edit_rewards_activated()
 {
   RewardlistDialog d;
-  d.set_parent_window(*window.get());
+  d.set_parent_window(*window);
   d.run();
 }
 
@@ -1256,21 +1384,20 @@ void MainWindow::on_random_unnamed_signs_activated()
 
 void MainWindow::on_help_about_activated()
 {
-  std::auto_ptr<Gtk::AboutDialog> dialog;
+  Gtk::AboutDialog* dialog;
 
-  Glib::RefPtr<Gnome::Glade::Xml> xml
-    = Gnome::Glade::Xml::create(get_glade_path() + "/../about-dialog.glade");
+  Glib::RefPtr<Gtk::Builder> xml
+    = Gtk::Builder::create_from_file(get_glade_path() + "/../about-dialog.ui");
 
-  Gtk::AboutDialog *d;
-  xml->get_widget("dialog", d);
-  dialog.reset(d);
-  dialog->set_transient_for(*window.get());
+  xml->get_widget("dialog", dialog);
+  dialog->set_transient_for(*window);
+  dialog->set_icon_from_file(File::getMiscFile("various/tileset_icon.png"));
 
   dialog->set_version(PACKAGE_VERSION);
-  SDL_Surface *logo = GraphicsLoader::getMiscPicture("castle_icon.png");
-  dialog->set_logo(to_pixbuf(logo));
+  dialog->set_logo(GraphicsLoader::getMiscPicture("castle_icon.png")->to_pixbuf());
   dialog->show_all();
   dialog->run();
+  delete dialog;
 
   return;
 }
@@ -1294,7 +1421,7 @@ void MainWindow::on_validate_activated()
     s += String::ucompose(ngettext("\nThere is %1 more error", "\nThere are %1 more errors", errors.size() - 1), errors.size() - 1);
   if (warnings.size())
     s += String::ucompose(ngettext("\nThere is %1 warning", "\nThere are %1 warnings", warnings.size()), warnings.size());
-  TimedMessageDialog dialog(*window.get(), s, 0);
+  TimedMessageDialog dialog(*window, s, 0);
   dialog.show_all();
   dialog.run();
   dialog.hide();
