@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -23,22 +23,12 @@
 #include <vector>
 #include <sigc++/signal.h>
 #include <sigc++/trackable.h>
-#include <libglademm/xml.h>
-#include <gtkmm/window.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/container.h>
-#include <gtkmm/image.h>
-#include <gtkmm/button.h>
-#include <gtkmm/table.h>
-#include <gtkmm/checkmenuitem.h>
-#include <gtkmm/radiobutton.h>
-#include <gtkmm/tooltips.h>
+#include <gtkmm.h>
 
 #include "map-tip-position.h"
 #include "editorbigmap.h"
 #include "RenamableLocation.h"
 
-class SDL_Surface;
 class EditorBigMap;
 class SmallMap;
 class GameScenario;
@@ -56,45 +46,65 @@ class MainWindow: public sigc::trackable
     void show();
     void hide();
 
-    // initialize the SDL widget 
-    void init(int width, int height);
-
-    sigc::signal<void> sdl_initialized;
-    
+    void init();
     void show_initial_map();
-    Gtk::Window &get_window() { return *window.get(); }
+    Gtk::Window &get_window() { return *window; }
 
  private:
-    std::auto_ptr<Gtk::Window> window;
-    Gtk::Container *sdl_container;
-    Gtk::Widget *sdl_widget;
+    Gtk::Window* window;
+    EditorBigMap* bigmap;
+    SmallMap* smallmap;
+    GameScenario* game_scenario;
+    CreateScenarioRandomize* d_create_scenario_names;
+
+    Gtk::DrawingArea *bigmap_drawingarea;
+    Gtk::EventBox *bigmap_eventbox;
     Gtk::CheckMenuItem *fullscreen_menuitem;
+    Gtk::MenuItem *new_map_menuitem;
+    Gtk::MenuItem *load_map_menuitem;
+    Gtk::MenuItem *save_map_menuitem;
+    Gtk::MenuItem *save_map_as_menuitem;
+    Gtk::MenuItem *export_as_bitmap_menuitem;
+    Gtk::MenuItem *export_as_bitmap_no_game_objects_menuitem;
+    Gtk::MenuItem *validate_menuitem;
+    Gtk::MenuItem *quit_menuitem;
+    Gtk::MenuItem *edit_players_menuitem;
+    Gtk::MenuItem *edit_map_info_menuitem;
+    Gtk::MenuItem *toggle_tile_graphics_menuitem;
+    Gtk::MenuItem *toggle_grid_menuitem;
+    Gtk::MenuItem *smooth_map_menuitem;
+    Gtk::MenuItem *smooth_screen_menuitem;
+    Gtk::MenuItem *edit_items_menuitem ;
+    Gtk::MenuItem *edit_rewards_menuitem;
+    Gtk::MenuItem *random_all_cities_menuitem;
+    Gtk::MenuItem *random_unnamed_cities_menuitem;
+    Gtk::MenuItem *random_all_ruins_menuitem;
+    Gtk::MenuItem *random_unnamed_ruins_menuitem;
+    Gtk::MenuItem *random_all_temples_menuitem;
+    Gtk::MenuItem *random_unnamed_temples_menuitem;
+    Gtk::MenuItem *random_all_signs_menuitem;
+    Gtk::MenuItem *random_unnamed_signs_menuitem;
+    Gtk::MenuItem *help_about_menuitem;
     Gtk::HBox *terrain_tile_style_hbox;
-    Gtk::Image *map_image;
+    Gtk::DrawingArea *map_drawingarea;
     std::string current_save_filename;
     Gtk::Table *terrain_type_table;
     Gtk::Label *mouse_position_label;
     Gtk::RadioButton *pointer_radiobutton;
     Gtk::Tooltips tooltips;
 
-    std::auto_ptr<EditorBigMap> bigmap;
-    std::auto_ptr<SmallMap> smallmap;
     
-    bool sdl_inited;
-
-    std::auto_ptr<GameScenario> game_scenario;
-    std::auto_ptr<CreateScenarioRandomize> d_create_scenario_names;
     GdkEventButton *button_event;
 
     bool on_delete_event(GdkEventAny *e);
 
-    bool on_sdl_mouse_button_event(GdkEventButton *e);
-    bool on_sdl_mouse_motion_event(GdkEventMotion *e);
-    bool on_sdl_key_event(GdkEventKey *e);
-    bool on_sdl_leave_event(GdkEventCrossing *e);
+    bool on_bigmap_mouse_button_event(GdkEventButton *e);
+    bool on_bigmap_mouse_motion_event(GdkEventMotion *e);
+    bool on_bigmap_key_event(GdkEventKey *e);
+    bool on_bigmap_leave_event(GdkEventCrossing *e);
 
-    bool on_map_mouse_button_event(GdkEventButton *e);
-    bool on_map_mouse_motion_event(GdkEventMotion *e);
+    bool on_smallmap_mouse_button_event(GdkEventButton *e);
+    bool on_smallmap_mouse_motion_event(GdkEventMotion *e);
     
     void on_new_map_activated();
     void on_load_map_activated();
@@ -113,6 +123,7 @@ class MainWindow: public sigc::trackable
 
     void on_fullscreen_activated();
     void on_tile_graphics_toggled();
+    void on_grid_toggled();
 
     void on_random_all_cities_activated();
     void on_random_unnamed_cities_activated();
@@ -155,7 +166,7 @@ class MainWindow: public sigc::trackable
     
     Tile::Type get_terrain();
     int get_tile_style_id();
-    void setup_pointer_radiobutton(Glib::RefPtr<Gnome::Glade::Xml> xml,
+    void setup_pointer_radiobutton(Glib::RefPtr<Gtk::Builder> xml,
 	std::string prefix, std::string image_file,
 	EditorBigMap::Pointer pointer, int size);
     void setup_terrain_radiobuttons();
@@ -180,7 +191,8 @@ class MainWindow: public sigc::trackable
     void randomize_ruin(Ruin *ruin);
 
     // map callbacks
-    void on_smallmap_changed(SDL_Surface *map);
+    void on_smallmap_changed(Glib::RefPtr<Gdk::Pixmap> map, Gdk::Rectangle r);
+    void on_bigmap_changed(Glib::RefPtr<Gdk::Pixmap> map);
     void on_objects_selected(std::vector<UniquelyIdentified *> objects);
     void on_mouse_on_tile(Vector<int> tile);
     
@@ -188,12 +200,13 @@ class MainWindow: public sigc::trackable
 
     void auto_select_appropriate_pointer();
 
+    bool on_bigmap_exposed(GdkEventExpose *event);
+    bool on_smallmap_exposed(GdkEventExpose *event);
+    void on_bigmap_surface_changed(Gtk::Allocation box);
+
     int d_width;
     int d_height;
     
-public:
-    // not part of the API, but for surface_attached_helper
-    void on_sdl_surface_changed();
 };
 
 #endif
