@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -23,7 +23,7 @@
 #include <iostream>
 #include <stdlib.h>
 #include <time.h>
-#include <gtkmm/main.h>
+#include <gtkmm.h>
 
 #include "Configuration.h"
 #include "File.h"
@@ -38,11 +38,13 @@ sigc::connection on_timer_registered(Timing::timer_slot s, int msecs_interval)
     return Glib::signal_timeout().connect(s, msecs_interval);
 }
 
+int max_vector_width;
 int main(int argc, char* argv[])
 {
     srand(time(NULL));         // set the random seed
 
     initialize_configuration();
+    Vector<int>::setMaximumWidth(1000);
 
     setlocale(LC_ALL, Configuration::s_lang.c_str());
     textdomain ("lordsawar");
@@ -55,22 +57,22 @@ int main(int argc, char* argv[])
     Timing::instance().timer_registered.connect(
 	sigc::ptr_fun(on_timer_registered));
 
+	
+    MainWindow* main_window = NULL;
     try
     {
 	Gtk::Main kit(argc, argv);
 
-	std::auto_ptr<MainWindow> main_window(new MainWindow);
-	main_window->init(640, 480);
-    
-	main_window->sdl_initialized.connect(
-	    sigc::mem_fun(main_window.get(), &MainWindow::show_initial_map));
+	MainWindow* main_window = new MainWindow;
 	main_window->show();
 	
+	main_window->init();
 	kit.run(main_window->get_window());
     }
     catch (const Glib::Error &ex) {
 	std::cerr << ex.what() << std::endl;
     }
+    delete main_window;
     
     return EXIT_SUCCESS;
 }
