@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,9 +21,7 @@
 
 #include <memory>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/textview.h>
-#include <gtkmm/entry.h>
+#include <gtkmm.h>
 
 class GameScenario;
 
@@ -32,13 +30,14 @@ class MapInfoDialog: public sigc::trackable
 {
  public:
     MapInfoDialog(GameScenario *game_scenario);
+    ~MapInfoDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
     void run();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
     Gtk::Entry *name_entry;
     Gtk::TextView *description_textview;
     GameScenario *game_scenario;
