@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,8 +20,7 @@
 
 #include <assert.h>
 #include <sigc++/functors/mem_fun.h>
-#include <libglademm/xml.h>
-#include <gtkmm/alignment.h>
+#include <gtkmm.h>
 
 #include "new-map-dialog.h"
 
@@ -41,12 +40,10 @@ NewMapDialog::NewMapDialog()
 {
     map_set = false;
     
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path() + "/new-map-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path() + "/new-map-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
+    xml->get_widget("dialog", dialog);
 
     xml->get_widget("map_size_combobox", map_size_combobox);
     xml->get_widget("random_map_container", random_map_container);
@@ -64,17 +61,17 @@ NewMapDialog::NewMapDialog()
 
     // fill in tile themes combobox
     
-    Uint32 counter = 0;
-    Uint32 default_id = 0;
+    guint32 counter = 0;
+    guint32 default_id = 0;
     Gtk::Box *box;
 
     //fill in tile sizes combobox
     tile_size_combobox = manage(new Gtk::ComboBoxText);
-    std::list<Uint32> sizes;
+    std::list<guint32> sizes;
     Tilesetlist::getInstance()->getSizes(sizes);
     Citysetlist::getInstance()->getSizes(sizes);
     Armysetlist::getInstance()->getSizes(sizes);
-    for (std::list<Uint32>::iterator it = sizes.begin(); it != sizes.end();
+    for (std::list<guint32>::iterator it = sizes.begin(); it != sizes.end();
 	 it++)
       {
 	Glib::ustring s = String::ucompose("%1x%1", *it);
@@ -112,7 +109,7 @@ NewMapDialog::NewMapDialog()
     for (std::list<std::string>::iterator i = shield_themes.begin(),
 	 end = shield_themes.end(); i != end; ++i)
       {
-	if (*i == "Default")
+	if (*i == _("Default"))
 	  default_id = counter;
 	shield_theme_combobox->append_text(Glib::filename_to_utf8(*i));
 	counter++;
@@ -155,6 +152,7 @@ NewMapDialog::NewMapDialog()
 
 NewMapDialog::~NewMapDialog()
 {
+  delete dialog;
 }
 
 void NewMapDialog::set_parent_window(Gtk::Window &parent)
@@ -166,7 +164,7 @@ void NewMapDialog::run()
 {
   dialog->show_all();
   int response = dialog->run();
-  if (response == 0)		// accepted
+  if (response == Gtk::RESPONSE_ACCEPT)	// accepted
     {
       switch (map_size_combobox->get_active_row_number()) {
       case MAP_SIZE_SMALL:
@@ -265,15 +263,15 @@ void NewMapDialog::add_fill_style(Tile::Type tile_type)
   fill_style.push_back(tile_type);
 }
 
-Uint32 NewMapDialog::get_active_tile_size()
+guint32 NewMapDialog::get_active_tile_size()
 {
-  return (Uint32) atoi(tile_size_combobox->get_active_text().c_str());
+  return (guint32) atoi(tile_size_combobox->get_active_text().c_str());
 }
 
 void NewMapDialog::on_tile_size_changed()
 {
-  Uint32 default_id = 0;
-  Uint32 counter = 0;
+  guint32 default_id = 0;
+  guint32 counter = 0;
 
   tile_theme_combobox->clear_items();
   Tilesetlist *tl = Tilesetlist::getInstance();
@@ -281,7 +279,7 @@ void NewMapDialog::on_tile_size_changed()
   for (std::list<std::string>::iterator i = tile_themes.begin(),
        end = tile_themes.end(); i != end; ++i)
     {
-      if (*i == "Default")
+      if (*i == _("Default"))
 	default_id = counter;
       tile_theme_combobox->append_text(Glib::filename_to_utf8(*i));
       counter++;
@@ -299,7 +297,7 @@ void NewMapDialog::on_tile_size_changed()
   for (std::list<std::string>::iterator i = army_themes.begin(),
        end = army_themes.end(); i != end; ++i)
     {
-      if (*i == "Default")
+      if (*i == _("Default"))
 	default_id = counter;
       army_theme_combobox->append_text(Glib::filename_to_utf8(*i));
       counter++;
@@ -317,7 +315,7 @@ void NewMapDialog::on_tile_size_changed()
   for (std::list<std::string>::iterator i = city_themes.begin(),
        end = city_themes.end(); i != end; ++i)
     {
-      if (*i == "Default")
+      if (*i == _("Default"))
 	default_id = counter;
       city_theme_combobox->append_text(Glib::filename_to_utf8(*i));
       counter++;
