@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,12 +22,7 @@
 #include <memory>
 #include <vector>
 #include <sigc++/signal.h>
-#include <gtkmm/window.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/combobox.h>
-#include <gtkmm/widget.h>
-#include <gtkmm/scale.h>
+#include <gtkmm.h>
 
 #include "Tile.h"
 #include "game-parameters.h"
@@ -61,7 +56,7 @@ class NewMapDialog
     bool map_set;
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
 
     Gtk::ComboBox *map_size_combobox;
     Gtk::ComboBoxText *fill_style_combobox;
@@ -90,7 +85,7 @@ class NewMapDialog
 
     void add_fill_style(Tile::Type tile_type);
 
-    Uint32 get_active_tile_size();
+    guint32 get_active_tile_size();
     void on_tile_size_changed();
     std::vector<int> fill_style;
 };
