@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -19,8 +19,8 @@
 #include <config.h>
 
 #include <assert.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
-#include <libglademm/xml.h>
 
 #include "players-dialog.h"
 
@@ -33,10 +33,7 @@
 #include "stacklist.h"
 #include "citylist.h"
 #include "player.h"
-//#include "real_player.h"
-//#include "ai_fast.h"
-//#include "ai_smart.h"
-//#include "ai_dummy.h"
+#include "ucompose.hpp"
 #include "game-parameters.h"
 
 
@@ -44,7 +41,7 @@ namespace
 {
     const int default_gold = 1000;
 
-    Glib::ustring player_type_to_string(Uint32 type)
+    Glib::ustring player_type_to_string(guint32 type)
     {
 	switch (type)
 	{
@@ -57,16 +54,16 @@ namespace
 }
 
 PlayersDialog::PlayersDialog(int width, int height)
-    : type_column(_("Type"), type_renderer)
+  : type_column(_("Type"), type_renderer),
+    gold_column(_("Gold"), gold_renderer),
+    name_column(_("Name"), name_renderer)
 {
   d_width = width;
   d_height = height;
-  Glib::RefPtr<Gnome::Glade::Xml> xml
-    = Gnome::Glade::Xml::create(get_glade_path() + "/players-dialog.glade");
+  Glib::RefPtr<Gtk::Builder> xml
+    = Gtk::Builder::create_from_file(get_glade_path() + "/players-dialog.ui");
 
-  Gtk::Dialog *d = 0;
-  xml->get_widget("dialog", d);
-  dialog.reset(d);
+  xml->get_widget("dialog", dialog);
 
   // setup the player settings
   player_list = Gtk::ListStore::create(player_columns);
@@ -97,20 +94,31 @@ PlayersDialog::PlayersDialog(int width, int height)
     ( type_renderer, sigc::mem_fun(*this, &PlayersDialog::cell_data_type));
   player_treeview->append_column(type_column);
 
+  // name column
+  name_renderer.property_editable() = true;
+  name_renderer.signal_edited().connect
+    (sigc::mem_fun(*this, &PlayersDialog::on_name_edited));
+  name_column.set_cell_data_func
+    (name_renderer, sigc::mem_fun(*this, &PlayersDialog::cell_data_name));
+  player_treeview->append_column(name_column);
 
-  // remaining columns
-  player_treeview->append_column_editable(_("Name"), player_columns.name);
-  player_treeview->append_column_editable(_("Gold"), player_columns.gold);
+  // gold column
+  gold_renderer.property_editable() = true;
+  gold_renderer.signal_edited().connect
+    (sigc::mem_fun(*this, &PlayersDialog::on_gold_edited));
+  gold_column.set_cell_data_func
+    (gold_renderer, sigc::mem_fun(*this, &PlayersDialog::cell_data_gold));
+  player_treeview->append_column(gold_column);
 
   // add default players
-  default_player_names.push_back("The Sirians");
-  default_player_names.push_back("Elvallie");
-  default_player_names.push_back("Storm Giants");
-  default_player_names.push_back("The Selentines");
-  default_player_names.push_back("Grey Dwarves");
-  default_player_names.push_back("Horse Lords");
-  default_player_names.push_back("Orcs of Kor");
-  default_player_names.push_back("Lord Bane");
+  default_player_names.push_back(_("The Sirians"));
+  default_player_names.push_back(_("Elvallie"));
+  default_player_names.push_back(_("Storm Giants"));
+  default_player_names.push_back(_("The Selentines"));
+  default_player_names.push_back(_("Grey Dwarves"));
+  default_player_names.push_back(_("Horse Lords"));
+  default_player_names.push_back(_("Orcs of Kor"));
+  default_player_names.push_back(_("Lord Bane"));
 
   Playerlist *pl = Playerlist::getInstance();
 
@@ -142,6 +150,7 @@ PlayersDialog::PlayersDialog(int width, int height)
 
 PlayersDialog::~PlayersDialog()
 {
+  delete dialog;
 }
 
 void PlayersDialog::set_parent_window(Gtk::Window &parent)
@@ -155,7 +164,7 @@ void PlayersDialog::run()
   int response = dialog->run();
   Playerlist *pl = Playerlist::getInstance();
 
-  if (response == 0)		// accepted
+  if (response == Gtk::RESPONSE_ACCEPT)	// accepted
     {
 
       // update the player list
@@ -214,3 +223,32 @@ void PlayersDialog::add_player(const Glib::ustring &type,
 
   player_treeview->get_selection()->select(i);
 }
+
+void PlayersDialog::cell_data_gold(Gtk::CellRenderer *renderer,
+				  const Gtk::TreeIter& i)
+{
+    dynamic_cast<Gtk::CellRendererSpin*>(renderer)->property_adjustment()
+          = new Gtk::Adjustment((*i)[player_columns.gold], 0, 10000, 1);
+    dynamic_cast<Gtk::CellRendererSpin*>(renderer)->property_text() = 
+      String::ucompose("%1", (*i)[player_columns.gold]);
+}
+
+void PlayersDialog::on_gold_edited(const Glib::ustring &path,
+				   const Glib::ustring &new_text)
+{
+  int gold = atoi(new_text.c_str());
+  (*player_list->get_iter(Gtk::TreePath(path)))[player_columns.gold] = gold;
+}
+
+void PlayersDialog::cell_data_name(Gtk::CellRenderer *renderer,
+				  const Gtk::TreeIter& i)
+{
+    dynamic_cast<Gtk::CellRendererText*>(renderer)->property_text() = 
+      String::ucompose("%1", (*i)[player_columns.name]);
+}
+
+void PlayersDialog::on_name_edited(const Glib::ustring &path,
+				   const Glib::ustring &new_text)
+{
+  (*player_list->get_iter(Gtk::TreePath(path)))[player_columns.name] = new_text;
+}
