@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,14 +22,7 @@
 #include <memory>
 #include <vector>
 #include <sigc++/signal.h>
-#include <gtkmm/window.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/combobox.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/treemodelcolumn.h>
-#include <gtkmm/cellrenderercombo.h>
-#include <gtkmm/treeview.h>
-
+#include <gtkmm.h>
 
 class Player;
 
@@ -45,7 +38,7 @@ class PlayersDialog
     void run();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
 
     Gtk::TreeView *player_treeview;
     
@@ -63,6 +56,10 @@ class PlayersDialog
     
     Gtk::CellRendererCombo type_renderer;
     Gtk::TreeViewColumn type_column;
+    Gtk::CellRendererSpin gold_renderer;
+    Gtk::TreeViewColumn gold_column;
+    Gtk::CellRendererText name_renderer;
+    Gtk::TreeViewColumn name_column;
     
     class PlayerTypeColumns: public Gtk::TreeModelColumnRecord {
     public:
@@ -80,6 +77,10 @@ class PlayersDialog
     void cell_data_type(Gtk::CellRenderer *renderer, const Gtk::TreeIter &i);
     void on_type_edited(const Glib::ustring &path,
 			const Glib::ustring &new_text);
+    void cell_data_gold(Gtk::CellRenderer *renderer, const Gtk::TreeIter& i);
+    void on_gold_edited(const Glib::ustring &path, const Glib::ustring &new_text);
+    void cell_data_name(Gtk::CellRenderer *renderer, const Gtk::TreeIter& i);
+    void on_name_edited(const Glib::ustring &path, const Glib::ustring &new_text);
     
     void add_player(const Glib::ustring &type, const Glib::ustring &name,
 		    int gold, Player *player);
