@@ -1,8 +1,8 @@
-//  Copyright (C) 2008, Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -25,12 +25,7 @@
 #include <sigc++/functors/mem_fun.h>
 #include <sigc++/functors/ptr_fun.h>
 
-#include <gtkmm/widget.h>
-#include <gtkmm/eventbox.h>
-#include <gtkmm/image.h>
-#include <gtkmm/box.h>
-#include <gtkmm/dialog.h>
-
+#include <gtkmm.h>
 #include "rewardlist-dialog.h"
 
 #include "gui/input-helpers.h"
@@ -44,18 +39,16 @@
 #include "playerlist.h"
 
 #include "glade-helpers.h"
-#include "reward-dialog.h"
+#include "reward-editor-dialog.h"
 
 
 RewardlistDialog::RewardlistDialog()
 {
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path() + 
-				    "/reward-list-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path() + 
+				    "/reward-list-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
+    xml->get_widget("dialog", dialog);
 
     xml->get_widget("rewards_treeview", rewards_treeview);
     xml->get_widget("add_button", add_button);
@@ -78,7 +71,7 @@ RewardlistDialog::RewardlistDialog()
     for (;iter != rewardlist->end(); iter++)
       addReward(*iter);
       
-    Uint32 max = rewardlist->size();
+    guint32 max = rewardlist->size();
     if (max)
       {
 	Gtk::TreeModel::Row row;
@@ -110,6 +103,7 @@ RewardlistDialog::update_rewardlist_buttons()
 
 RewardlistDialog::~RewardlistDialog()
 {
+  delete dialog;
 }
 
 void RewardlistDialog::addReward(Reward *reward)
@@ -127,7 +121,7 @@ void RewardlistDialog::on_reward_selected()
 void RewardlistDialog::on_add_clicked()
 {
   Player *neutral = Playerlist::getInstance()->getNeutral();
-  RewardDialog d(neutral, true, NULL);
+  RewardEditorDialog d(neutral, true, NULL);
   d.run();
   if (d.get_reward())
     {
@@ -167,7 +161,7 @@ void RewardlistDialog::on_edit_clicked()
       Gtk::TreeModel::Row row = *iterrow;
       Reward *reward = row[rewards_columns.reward];
       Player *neutral = Playerlist::getInstance()->getNeutral();
-      RewardDialog d(neutral, true, reward);
+      RewardEditorDialog d(neutral, true, reward);
       d.run();
       if (d.get_reward())
 	{
