@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,12 +22,7 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/label.h>
-#include <gtkmm/table.h>
-#include <gtkmm/togglebutton.h>
-#include <gtkmm/button.h>
-#include <SDL/SDL_types.h>
+#include <gtkmm.h>
 
 #include "gui/army-info-tip.h"
 
@@ -39,8 +34,10 @@ class Player;
 class SelectArmyDialog: public sigc::trackable
 {
  public:
-    SelectArmyDialog(Player *p, bool defends_ruins = false,
+    SelectArmyDialog(Player *p, bool hero_too = false,
+		     bool defends_ruins = false,
 		     bool rewardable = false);
+    ~SelectArmyDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -49,18 +46,19 @@ class SelectArmyDialog: public sigc::trackable
     const ArmyProto *get_selected_army() { return selected_army; }
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
-    std::auto_ptr<ArmyInfoTip> army_info_tip;
+    Gtk::Dialog* dialog;
+    ArmyInfoTip* army_info_tip;
     Gtk::Label *army_info_label1;
     Gtk::Label *army_info_label2;
     Gtk::Table *toggles_table;
     Gtk::Button *select_button;
-    std::vector<Uint32> armysets;
+    std::vector<guint32> armysets;
 
     const ArmyProto *selected_army;
     Player *player;
     bool d_defends_ruins;
     bool d_awardable;
+    bool d_hero_too;
 
     std::vector<Gtk::ToggleButton *> army_toggles;
     bool ignore_toggles;
