@@ -1,8 +1,8 @@
-//  Copyright (C) 2008, Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,10 +17,7 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/image.h>
-#include <gtkmm/table.h>
-#include <gtkmm/alignment.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
 #include <assert.h>
 
@@ -37,13 +34,11 @@ SelectItemDialog::SelectItemDialog()
 {
     selected_item = 0;
     
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/select-item-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/select-item-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
+    xml->get_widget("dialog", dialog);
     
     xml->get_widget("select_button", select_button);
 
@@ -51,6 +46,7 @@ SelectItemDialog::SelectItemDialog()
     items_list = Gtk::ListStore::create(items_columns);
     items_treeview->set_model(items_list);
     items_treeview->append_column("", items_columns.name);
+    items_treeview->append_column("", items_columns.attributes);
     items_treeview->set_headers_visible(false);
 
     Itemlist *itemlist = Itemlist::getInstance();
@@ -58,7 +54,7 @@ SelectItemDialog::SelectItemDialog()
     for (;iter != itemlist->end(); iter++)
       addItemProto((*iter).second);
       
-    Uint32 max = itemlist->size();
+    guint32 max = itemlist->size();
     if (max)
       {
 	Gtk::TreeModel::Row row;
@@ -68,10 +64,15 @@ SelectItemDialog::SelectItemDialog()
       }
 }
 
+SelectItemDialog::~SelectItemDialog()
+{
+  delete dialog;
+}
 void SelectItemDialog::addItemProto(ItemProto *item)
 {
   Gtk::TreeIter i = items_list->append();
   (*i)[items_columns.name] = item->getName();
+  (*i)[items_columns.attributes] = item->getBonusDescription();
   (*i)[items_columns.item] = item;
 }
 
@@ -86,7 +87,7 @@ void SelectItemDialog::run()
     dialog->show_all();
     int response = dialog->run();
 
-    if (response != 1)
+    if (response != Gtk::RESPONSE_ACCEPT)
 	selected_item = 0;
     else
       {
