@@ -1,8 +1,8 @@
-//  Copyright (C) 2008 Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,11 +20,7 @@
 
 #include <memory>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/button.h>
-#include <gtkmm/image.h>
-#include <gtkmm/label.h>
-#include <gtkmm/table.h>
+#include <gtkmm.h>
 #include "Tile.h"
 #include "tile-preview-scene.h"
 
@@ -33,7 +29,8 @@
 class TilePreviewDialog: public sigc::trackable
 {
  public:
-    TilePreviewDialog(Tile *tile, Uint32 tileSize);
+    TilePreviewDialog(Tile *tile, guint32 tileSize);
+    ~TilePreviewDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -41,14 +38,13 @@ class TilePreviewDialog: public sigc::trackable
     
  private:
     Tile *d_tile;
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
     Gtk::Button *next_button;
     Gtk::Button *previous_button;
     Gtk::Button *refresh_button;
-    Gtk::HBox *scene_box;
-    Gtk::Table *scene_table;
+    Gtk::Image *preview_image;
 
-    std::vector<Glib::RefPtr<Gdk::Pixbuf> > tilestyle_images;
+    std::vector<PixMask* > tilestyle_images;
 
     void on_next_clicked();
     void on_previous_clicked();
@@ -57,7 +53,7 @@ class TilePreviewDialog: public sigc::trackable
     void update_scene(TilePreviewScene *scene);
     std::list<TilePreviewScene*> scenes;
     std::list<TilePreviewScene*>::iterator current_scene;
-    Uint32 d_tileSize;
+    guint32 d_tileSize;
 };
 
 #endif
