@@ -1,8 +1,8 @@
-//  Copyright (C) 2008 Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,7 +17,6 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
 #include <sigc++/functors/mem_fun.h>
 
 #include "tile-preview-scene.h"
@@ -30,9 +29,9 @@
 
 
 TilePreviewScene::TilePreviewScene (Tile *tile, 
-				    std::vector<Glib::RefPtr<Gdk::Pixbuf> > 
+				    std::vector<PixMask* > 
 				      standard_images, 
-				    Uint32 height, Uint32 width, 
+				    guint32 height, guint32 width, 
 				    std::string scene)
 {
   std::list<TileStyle::Type> tilescene;
@@ -72,8 +71,20 @@ void TilePreviewScene::regenerate()
       TileStyle *tilestyle = d_tile->getRandomTileStyle(type);
       d_tilestyles.push_back(tilestyle);
       if (tilestyle)
-	d_view.push_back(to_pixbuf(tilestyle->getPixmap()));
+	d_view.push_back(tilestyle->getImage()->to_pixbuf());
       else
-	d_view.push_back(d_standard_images[type]);
+	d_view.push_back(d_standard_images[type]->to_pixbuf());
     }
 }
+  
+Glib::RefPtr<Gdk::Pixbuf> TilePreviewScene::renderScene(guint32 tilesize)
+{
+  Glib::RefPtr<Gdk::Pixbuf> dest;
+  dest = Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB,true, 8, (int)(d_height * tilesize), (int)(d_width * tilesize));
+  for (unsigned int i = 0; i < d_width; i++)
+    for (unsigned int j = 0; j < d_height; j++)
+      {
+	getTileStylePixbuf(i,j)->copy_area (0, 0, tilesize, tilesize, dest, j * tilesize, i *tilesize);
+      }
+  return dest;
+}
