@@ -1,8 +1,8 @@
-//  Copyright (C) 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,29 +20,34 @@
 
 #include <memory>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/textview.h>
-#include <gtkmm/entry.h>
-#include <gtkmm/colorbutton.h>
+#include <gtkmm.h>
 #include "tileset.h"
 
-//! Scenario editor.  Edits the description of the scenario.
+//! Tileset Editor.  Edit the description of the Tileset.
 class TileSetInfoDialog: public sigc::trackable
 {
  public:
-    TileSetInfoDialog(Tileset *tileset);
+    TileSetInfoDialog(Tileset *tileset, bool readonly = false);
+    ~TileSetInfoDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
-    bool run();
+    int run();
     
  private:
+    Gtk::Dialog* dialog;
     Tileset *d_tileset;
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::SpinButton *id_spinbutton;
     Gtk::Entry *name_entry;
+    Gtk::Entry *subdir_entry;
+    Gtk::Button *accept_button;
     Gtk::TextView *description_textview;
-    Gtk::ColorButton *road_colorbutton;
+    Gtk::Label *status_label;
 
+    void on_name_changed();
+    void on_subdir_changed();
+
+    bool d_readonly;
 };
 
 #endif
