@@ -1,8 +1,8 @@
-//  Copyright (C) 2008 Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,7 +22,7 @@
 #include <iostream>
 #include <stdlib.h>
 #include <time.h>
-#include <gtkmm/main.h>
+#include <gtkmm.h>
 
 #include "Configuration.h"
 #include "File.h"
@@ -31,12 +31,13 @@
 
 #include "tileset-window.h"
 
-
+int max_vector_width;
 int main(int argc, char* argv[])
 {
     srand(time(NULL));         // set the random seed
 
     initialize_configuration();
+    Vector<int>::setMaximumWidth(1000);
 
     setlocale(LC_ALL, Configuration::s_lang.c_str());
     textdomain ("lordsawar");
@@ -47,15 +48,19 @@ int main(int argc, char* argv[])
     // init GUI stuff
     g_set_application_name(_("LordsAWar! Tileset Editor"));
 
+    TileSetWindow *tileset_window = NULL;
     try
     {
 	Gtk::Main kit(argc, argv);
 
-	std::auto_ptr<TileSetWindow> tileset_window(new TileSetWindow);
-	tileset_window->init(64, 64);
+	if (argc > 1)
+	  tileset_window = new TileSetWindow(argv[1]);
+	else
+	  tileset_window = new TileSetWindow;
 	tileset_window->show();
 	
 	kit.run(tileset_window->get_window());
+	delete tileset_window;
     }
     catch (const Glib::Error &ex) {
 	std::cerr << ex.what() << std::endl;
