@@ -1,8 +1,8 @@
-//  Copyright (C) 2008 Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,7 +17,7 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
 #include <stdlib.h>
 
@@ -34,14 +34,14 @@
 
 TilesetSelectorEditorDialog::TilesetSelectorEditorDialog(Tileset *tileset)
 {
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/tileset-selector-editor-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/tileset-selector-editor-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
+    xml->get_widget("dialog", dialog);
     d_tileset = tileset;
+    small_filename = d_tileset->getSmallSelectorFilename();
+    large_filename = d_tileset->getLargeSelectorFilename();
 
     Gtk::Box *box;
     xml->get_widget("shieldset_box", box);
@@ -61,6 +61,10 @@ TilesetSelectorEditorDialog::TilesetSelectorEditorDialog(Tileset *tileset)
 
     on_large_toggled();
 }
+TilesetSelectorEditorDialog::~TilesetSelectorEditorDialog()
+{
+  delete dialog;
+}
 
 void TilesetSelectorEditorDialog::set_parent_window(Gtk::Window &parent)
 {
@@ -68,12 +72,12 @@ void TilesetSelectorEditorDialog::set_parent_window(Gtk::Window &parent)
     //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
 }
 
-void TilesetSelectorEditorDialog::run()
+int TilesetSelectorEditorDialog::run()
 {
     dialog->show_all();
-    dialog->run();
+    int response = dialog->run();
 
-    return;
+    return response;
 }
 
 void TilesetSelectorEditorDialog::setup_shield_theme_combobox(Gtk::Box *box)
@@ -88,7 +92,7 @@ void TilesetSelectorEditorDialog::setup_shield_theme_combobox(Gtk::Box *box)
   for (std::list<std::string>::iterator i = shield_themes.begin(),
        end = shield_themes.end(); i != end; ++i)
     {
-      if (*i == "Default")
+      if (*i == _("Default"))
 	default_id = counter;
       shield_theme_combobox->append_text(Glib::filename_to_utf8(*i));
       counter++;
@@ -110,20 +114,7 @@ void TilesetSelectorEditorDialog::on_image_chosen()
   if (selected_filename.empty())
     return;
 
-  std::string str = Configuration::s_dataPath + "/tilesets/" +  
-    d_tileset->getSubDir() +"/";
-  char mypath[PATH_MAX]; //god i hate path_max.  die die die
-  char *tmp = realpath(str.c_str(), mypath);
-  std::string path = tmp;
-  if (selected_filename.substr(0, path.size()) !=path)
-    return;
-  std::string filename = &selected_filename.c_str()[path.size() + 1];
-  if (large_selector_radiobutton->get_active() == true)
-    d_tileset->setLargeSelectorFilename(filename);
-  else
-    d_tileset->setSmallSelectorFilename(filename);
-
-  show_preview_selectors(filename);
+  show_preview_selectors(selected_filename);
 }
 
 void TilesetSelectorEditorDialog::show_preview_selectors(std::string filename)
@@ -144,12 +135,12 @@ void TilesetSelectorEditorDialog::show_preview_selectors(std::string filename)
 
 void TilesetSelectorEditorDialog::clearSelector()
 {
-  for (std::map< Uint32, std::list<SDL_Surface*>* >::iterator it = selectors.begin();
+  for (std::map< guint32, std::list<Glib::RefPtr<Gdk::Pixbuf> >* >::iterator it = selectors.begin();
        it != selectors.end(); it++)
     {
-      for (std::list<SDL_Surface *>::iterator lit = (*it).second->begin(); lit != (*it).second->end(); lit++)
+      for (std::list<Glib::RefPtr<Gdk::Pixbuf> >::iterator lit = (*it).second->begin(); lit != (*it).second->end(); lit++)
 	{
-	  SDL_FreeSurface(*lit);
+	  (*lit).clear();
 	}
       (*it).second->clear();
       delete ((*it).second);
@@ -159,9 +150,9 @@ void TilesetSelectorEditorDialog::clearSelector()
 
 bool TilesetSelectorEditorDialog::loadSelector(std::string filename)
 {
-  std::vector<SDL_Surface *> images;
-  std::vector<SDL_Surface *> masks;
-  bool success = GraphicsCache::loadSelectorImages(d_tileset->getSubDir(), filename, d_tileset->getTileSize(), images, masks);
+  std::vector<PixMask *> images;
+  std::vector<PixMask *> masks;
+  bool success = GraphicsCache::loadSelectorImages(filename, d_tileset->getTileSize(), images, masks);
   if (success)
     {
       std::string subdir = Shieldsetlist::getInstance()->getShieldsetDir 
@@ -170,29 +161,27 @@ bool TilesetSelectorEditorDialog::loadSelector(std::string filename)
 
       for (unsigned int i = 0; i < MAX_PLAYERS; i++)
 	{
-	  std::list<SDL_Surface *> *mylist = new std::list<SDL_Surface*>();
+	  std::list<Glib::RefPtr<Gdk::Pixbuf> > *mylist = new std::list<Glib::RefPtr<Gdk::Pixbuf> >();
 	  selectors[i] = mylist;
 	}
 
-      for (std::vector<SDL_Surface*>::iterator it = images.begin(), mit = masks.begin(); it != images.end(); it++, mit++)
+      for (std::vector<PixMask*>::iterator it = images.begin(), mit = masks.begin(); it != images.end(); it++, mit++)
 	{
 	  for (Shieldset::iterator sit = shieldset->begin(); sit != shieldset->end(); sit++)
 	    {
 	      if ((*sit)->getOwner() == 8) //ignore neutral
 		continue;
-	      SDL_Surface *image = GraphicsCache::applyMask(*it, *mit, (*sit)->getMaskColor(), false);
-		selectors[(*sit)->getOwner()]->push_back(image);
+		selectors[(*sit)->getOwner()]->push_back
+		  (GraphicsCache::applyMask(*it, *mit, (*sit)->getMaskColorShifts(), false)->to_pixbuf());
 		
 		frame[(*sit)->getOwner()] = selectors[(*sit)->getOwner()]->begin();
 	    }
 	}
 
-      for (std::vector<SDL_Surface*>::iterator it = images.begin(); it != images.end(); it++)
-	SDL_FreeSurface(*it);
-      images.clear();
-      for (std::vector<SDL_Surface*>::iterator it = masks.begin(); it != masks.end(); it++)
-	SDL_FreeSurface(*it);
-      masks.clear();
+      for (std::vector<PixMask*>::iterator it = images.begin(); it != images.end(); it++)
+	delete *it;
+      for (std::vector<PixMask*>::iterator it = masks.begin(); it != masks.end(); it++)
+	delete *it;
 
     }
 
@@ -215,20 +204,14 @@ void TilesetSelectorEditorDialog::update_selector_panel()
   if (large_selector_radiobutton->get_active() == true)
     {
       std::string filename = d_tileset->getLargeSelectorFilename();
-      if (filename.c_str()[0] == '/')
-	selector_filechooserbutton->set_filename (filename);
-      else
-	selector_filechooserbutton->set_filename
-	  (File::getTilesetFile(d_tileset->getSubDir(), filename));
+      selector_filechooserbutton->set_filename
+	  (File::getTilesetFile(d_tileset, filename));
     }
   else
     {
       std::string filename = d_tileset->getSmallSelectorFilename();
-      if (filename.c_str()[0] == '/')
-	selector_filechooserbutton->set_filename (filename);
-      else
-	selector_filechooserbutton->set_filename
-	  (File::getTilesetFile(d_tileset->getSubDir(), filename));
+      selector_filechooserbutton->set_filename
+	  (File::getTilesetFile(d_tileset, filename));
     }
 
 }
@@ -241,7 +224,7 @@ void TilesetSelectorEditorDialog::on_heartbeat()
   int x = 0;
   int y = 0;
   int count = 0;
-  for (std::map< Uint32, std::list<SDL_Surface*>* >::iterator it = selectors.begin();
+  for (std::map< guint32, std::list<Glib::RefPtr<Gdk::Pixbuf> >* >::iterator it = selectors.begin();
        it != selectors.end(); it++)
     {
       //make a pixbuf and attach it
@@ -256,7 +239,7 @@ void TilesetSelectorEditorDialog::on_heartbeat()
 	case 6: x = 1; y = 2; break;
 	case 7: x = 1; y = 3; break;
 	}
-      preview_table->attach(*manage(new Gtk::Image(to_pixbuf(*frame[count]))), y, y+1, x, x+1, Gtk::SHRINK, Gtk::SHRINK, 8, 8);
+      preview_table->attach(*manage(new Gtk::Image(*frame[count])), y, y+1, x, x+1, Gtk::SHRINK, Gtk::SHRINK, 8, 8);
   
       frame[count]++;
       if (frame[count] == selectors[count]->end())
