@@ -1,8 +1,8 @@
-//  Copyright (C) 2008 Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,28 +22,21 @@
 #include <iomanip>
 #include <assert.h>
 #include <libgen.h>
+#include <string.h>
 
 #include <sigc++/functors/mem_fun.h>
 #include <sigc++/functors/ptr_fun.h>
+#include "ucompose.hpp"
 
-#include <gtkmm/widget.h>
-#include <gtkmm/eventbox.h>
-#include <gtkmm/image.h>
-#include <gtkmm/box.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/aboutdialog.h>
-#include <gtkmm/stock.h>
-#include <gtkmm/filechooserdialog.h>
-#include <gtkmm/filechooser.h>
-#include <gtkmm/menu.h>
-#include <gtkmm/menuitem.h>
-
+#include <gtkmm.h>
 #include "tileset-window.h"
 #include "tileset-info-dialog.h"
 #include "tile-preview-dialog.h"
 #include "tileset-selector-editor-dialog.h"
+#include "tileset-flag-editor-dialog.h"
+#include "tileset-explosion-picture-editor-dialog.h"
+#include "image-editor-dialog.h"
 
-#include "gtksdl.h"
 #include "image-helpers.h"
 #include "input-helpers.h"
 #include "error-utils.h"
@@ -62,30 +55,77 @@
 #include "glade-helpers.h"
 
 
-TileSetWindow::TileSetWindow()
+TileSetWindow::TileSetWindow(std::string load_filename)
 {
   d_tileset = NULL;
-    sdl_inited = false;
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path() + "/tileset-window.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path() + "/tileset-window.ui");
 
-    Gtk::Window *w = 0;
-    xml->get_widget("window", w);
-    window.reset(w);
+    xml->get_widget("window", window);
+    window->set_icon_from_file(File::getMiscFile("various/tileset_icon.png"));
 
     xml->get_widget("tiles_treeview", tiles_treeview);
     xml->get_widget("tile_name_entry", tile_name_entry);
     tile_name_entry->signal_changed().connect
       (sigc::mem_fun(this, &TileSetWindow::on_tile_name_changed));
 
-    xml->get_widget("tile_type_combobox", tile_type_combobox);
+    Gtk::HBox *type_combo_container;
+    xml->get_widget("type_combo_container", type_combo_container);
+    tile_type_combobox = new Gtk::ComboBoxText();
+    tile_type_combobox->append_text(_("Grass"));
+    tile_type_combobox->append_text(_("Water"));
+    tile_type_combobox->append_text(_("Forest"));
+    tile_type_combobox->append_text(_("Hills"));
+    tile_type_combobox->append_text(_("Mountains"));
+    tile_type_combobox->append_text(_("Swamp"));
+    tile_type_combobox->append_text(_("Void"));
+    type_combo_container->add(*manage(tile_type_combobox));
+    type_combo_container->show_all();
     tile_type_combobox->signal_changed().connect
       (sigc::mem_fun(this, &TileSetWindow::on_tile_type_changed));
-    xml->get_widget("tile_moves_spinbutton", tile_moves_spinbutton);
-    xml->get_widget("tile_smallmap_pattern_combobox", 
-		    tile_smallmap_pattern_combobox);
+
+    Gtk::HBox *tilestyle_combo_container;
+    xml->get_widget("tilestyle_combo_container", tilestyle_combo_container);
+    tilestyle_combobox = new Gtk::ComboBoxText();
+    tilestyle_combobox->append_text(_("Lone"));
+    tilestyle_combobox->append_text(_("Outer Top-Left"));
+    tilestyle_combobox->append_text(_("Outer Top-Center"));
+    tilestyle_combobox->append_text(_("Outer Top-Right"));
+    tilestyle_combobox->append_text(_("Outer Bottom-Left"));
+    tilestyle_combobox->append_text(_("Outer Bottom-Center"));
+    tilestyle_combobox->append_text(_("Outer Bottom-Right"));
+    tilestyle_combobox->append_text(_("Outer Middle-Left"));
+    tilestyle_combobox->append_text(_("Inner Middle-Center"));
+    tilestyle_combobox->append_text(_("Outer Middle-Right"));
+    tilestyle_combobox->append_text(_("Inner Top-Left"));
+    tilestyle_combobox->append_text(_("Inner Top-Right"));
+    tilestyle_combobox->append_text(_("Inner Bottom-Left"));
+    tilestyle_combobox->append_text(_("Inner Bottom-Right"));
+    tilestyle_combobox->append_text(_("Top-Left To Bottom-Right"));
+    tilestyle_combobox->append_text(_("Bottom-Left To Top-Right"));
+    tilestyle_combobox->append_text(_("Other"));
+    tilestyle_combo_container->add(*manage(tilestyle_combobox));
+    tilestyle_combo_container->show_all();
+    tilestyle_combobox->signal_changed().connect
+      (sigc::mem_fun(this, &TileSetWindow::on_tilestyle_changed));
+
+    Gtk::HBox *pattern_container;
+    xml->get_widget("pattern_container", pattern_container);
+    tile_smallmap_pattern_combobox = new Gtk::ComboBoxText();
+    tile_smallmap_pattern_combobox->append_text(_("Solid"));
+    tile_smallmap_pattern_combobox->append_text(_("Stippled"));
+    tile_smallmap_pattern_combobox->append_text(_("Randomized"));
+    tile_smallmap_pattern_combobox->append_text(_("Sunken"));
+    tile_smallmap_pattern_combobox->append_text(_("Tablecloth"));
+    tile_smallmap_pattern_combobox->append_text(_("Diagonal"));
+    tile_smallmap_pattern_combobox->append_text(_("Crosshatched"));
+    tile_smallmap_pattern_combobox->append_text(_("Sunken Striped"));
+    pattern_container->add(*manage(tile_smallmap_pattern_combobox));
+    pattern_container->show_all();
     tile_smallmap_pattern_combobox->signal_changed().connect
-    (sigc::mem_fun(this, &TileSetWindow::on_tile_pattern_changed));
+      (sigc::mem_fun(this, &TileSetWindow::on_tile_pattern_changed));
+
+    xml->get_widget("tile_moves_spinbutton", tile_moves_spinbutton);
     xml->get_widget("tile_smallmap_first_colorbutton", 
 		    tile_smallmap_first_colorbutton);
     tile_smallmap_first_colorbutton->signal_color_set().connect
@@ -117,28 +157,41 @@ TileSetWindow::TileSetWindow()
     xml->get_widget("save_tileset_menuitem", save_tileset_menuitem);
     save_tileset_menuitem->signal_activate().connect
       (sigc::mem_fun(this, &TileSetWindow::on_save_tileset_activated));
-    xml->get_widget("save_tileset_as_menuitem", save_tileset_as_menuitem);
-    save_tileset_as_menuitem->signal_activate().connect
-      (sigc::mem_fun(this, &TileSetWindow::on_save_tileset_as_activated));
-    xml->connect_clicked 
-      ("quit_menuitem", 
-       sigc::mem_fun(this, &TileSetWindow::on_quit_activated));
+    xml->get_widget("quit_menuitem", quit_menuitem);
+    quit_menuitem->signal_activate().connect
+       (sigc::mem_fun(this, &TileSetWindow::on_quit_activated));
     xml->get_widget("edit_tileset_info_menuitem", edit_tileset_info_menuitem);
     edit_tileset_info_menuitem->signal_activate().connect
       (sigc::mem_fun(this, &TileSetWindow::on_edit_tileset_info_activated));
     xml->get_widget("army_unit_selector_menuitem", army_unit_selector_menuitem);
     army_unit_selector_menuitem->signal_activate().connect
       (sigc::mem_fun(this, &TileSetWindow::on_army_unit_selector_activated));
+    xml->get_widget("roads_picture_menuitem", roads_picture_menuitem);
+    roads_picture_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &TileSetWindow::on_roads_picture_activated));
+    xml->get_widget("bridges_picture_menuitem", bridges_picture_menuitem);
+    bridges_picture_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &TileSetWindow::on_bridges_picture_activated));
+    xml->get_widget("fog_picture_menuitem", fog_picture_menuitem);
+    fog_picture_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &TileSetWindow::on_fog_picture_activated));
+    xml->get_widget("flags_picture_menuitem", flags_picture_menuitem);
+    flags_picture_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &TileSetWindow::on_flags_picture_activated));
+
+    xml->get_widget("explosion_picture_menuitem", explosion_picture_menuitem);
+    explosion_picture_menuitem->signal_activate().connect
+      (sigc::mem_fun(this, &TileSetWindow::on_explosion_picture_activated));
     xml->get_widget("preview_tile_menuitem", preview_tile_menuitem);
     preview_tile_menuitem->signal_activate().connect
       (sigc::mem_fun(this, &TileSetWindow::on_preview_tile_activated));
-    xml->connect_clicked 
-      ("help_about_menuitem", 
-       sigc::mem_fun(this, &TileSetWindow::on_help_about_activated));
+    xml->get_widget ("help_about_menuitem", help_about_menuitem);
+    help_about_menuitem->signal_activate().connect
+       (sigc::mem_fun(this, &TileSetWindow::on_help_about_activated));
     xml->get_widget("tilestyle_image", tilestyle_image);
 
-    w->signal_delete_event().connect(
-	sigc::mem_fun(*this, &TileSetWindow::on_delete_event));
+    window->signal_delete_event().connect
+      (sigc::mem_fun(*this, &TileSetWindow::on_delete_event));
 
     tiles_list = Gtk::ListStore::create(tiles_columns);
     tiles_treeview->set_model(tiles_list);
@@ -171,9 +224,6 @@ TileSetWindow::TileSetWindow()
       (sigc::mem_fun(this, &TileSetWindow::on_remove_tilestyleset_clicked));
     xml->get_widget("tilestyleset_frame", tilestyleset_frame);
     xml->get_widget("tilestyle_frame", tilestyle_frame);
-    xml->get_widget("tilestyle_combobox", tilestyle_combobox);
-    tilestyle_combobox->signal_changed().connect
-      (sigc::mem_fun(this, &TileSetWindow::on_tilestyle_changed));
     xml->get_widget("image_filechooser_button", image_filechooser_button);
     image_filechooser_button->signal_selection_changed().connect
       (sigc::mem_fun(*this, &TileSetWindow::on_image_chosen));
@@ -184,8 +234,7 @@ TileSetWindow::TileSetWindow()
     Gtk::FileFilter sav_filter;
     sav_filter.add_pattern("*.png");
     image_filechooser_button->set_filter(sav_filter);
-    image_filechooser_button->set_current_folder
-      (Configuration::s_dataPath + "/tilesets/");
+    image_filechooser_button->set_current_folder (File::getUserTilesetDir());
 
     xml->get_widget("tilestyle_standard_image", tilestyle_standard_image);
     tilestyle_standard_images = 
@@ -197,17 +246,17 @@ TileSetWindow::TileSetWindow()
     update_tileset_buttons();
     update_tilestyleset_buttons();
 
-    xml->get_widget("sdl_container", sdl_container);
     update_tileset_buttons();
     update_tilestyleset_buttons();
     update_tileset_menuitems();
     update_tile_preview_menuitem();
 
-    tile_smallmap_surface = SDL_CreateRGBSurface(SDL_SWSURFACE, 32, 32, 24,
-						 0xFFu, 0xFFu << 8, 
-						 0xFFu << 16, 0);
+    tile_smallmap_surface = Gdk::Pixmap::create(Glib::RefPtr<Gdk::Drawable>(0), 32, 32, 24);
+    tile_smallmap_surface_gc = Gdk::GC::create(tile_smallmap_surface);
 
     inhibit_image_change = false;
+    if (load_filename.empty() == false)
+      load_tileset(load_filename);
 }
 
 void
@@ -215,15 +264,25 @@ TileSetWindow::update_tileset_menuitems()
 {
   if (d_tileset == NULL)
     {
-      save_tileset_as_menuitem->set_sensitive(false);
       save_tileset_menuitem->set_sensitive(false);
       army_unit_selector_menuitem->set_sensitive(false);
+      edit_tileset_info_menuitem->set_sensitive(false);
+      explosion_picture_menuitem->set_sensitive(false);
+      roads_picture_menuitem->set_sensitive(false);
+      bridges_picture_menuitem->set_sensitive(false);
+      fog_picture_menuitem->set_sensitive(false);
+      flags_picture_menuitem->set_sensitive(false);
     }
   else
     {
-      save_tileset_as_menuitem->set_sensitive(true);
       save_tileset_menuitem->set_sensitive(true);
       army_unit_selector_menuitem->set_sensitive(true);
+      edit_tileset_info_menuitem->set_sensitive(true);
+      explosion_picture_menuitem->set_sensitive(true);
+      roads_picture_menuitem->set_sensitive(true);
+      bridges_picture_menuitem->set_sensitive(true);
+      fog_picture_menuitem->set_sensitive(true);
+      flags_picture_menuitem->set_sensitive(true);
     }
 }
 
@@ -272,16 +331,13 @@ TileSetWindow::update_tilestyle_panel()
   if (t)
     {
       tilestyle_combobox->set_active(t->getType());
-      SDL_Surface *pixmap = t->getPixmap();
-      if (pixmap)
-	{
-	  tilestyle_image->clear();
-	  tilestyle_image->property_pixbuf() = to_pixbuf(pixmap);
-	  tilestyle_image->show_all();
-	}
+      Glib::RefPtr<Gdk::Pixbuf> pixbuf= t->getImage()->to_pixbuf();
+      tilestyle_image->clear();
+      tilestyle_image->property_pixbuf() = pixbuf;
+      tilestyle_image->show_all();
       int idx = t->getType();
       tilestyle_standard_image->property_pixbuf() = 
-	tilestyle_standard_images[idx];
+	tilestyle_standard_images[idx]->to_pixbuf();
     }
 }
 
@@ -310,12 +366,12 @@ void TileSetWindow::fill_tilestyleset_info(TileStyleSet *t)
     subdir = d_tileset->getSubDir();
   else
     subdir = t->getSubDir();
-  std::string n = Configuration::s_dataPath + "/tilesets/" + subdir + "/" + t->getName() + ".png";
+  std::string n = File::getTilesetFile(d_tileset, t->getName());
   int height = get_image_height (n);
   if (height)
     {
       d_tileset->setTileSize(height);
-      GraphicsLoader::instantiatePixmaps(t, d_tileset->getTileSize());
+      GraphicsLoader::instantiateImages(d_tileset, t, d_tileset->getTileSize());
     }
   inhibit_image_change = true;
   image_filechooser_button->set_filename(n);
@@ -325,9 +381,8 @@ void TileSetWindow::fill_tilestyleset_info(TileStyleSet *t)
   for (unsigned int i = 0; i < t->size(); i++)
     {
       Gtk::TreeIter l = tilestyles_list->append();
-      char buf[10];
-      snprintf (buf, sizeof(buf), "0x%02x", (*t)[i]->getId());
-      (*l)[tilestyles_columns.name] = buf;
+      (*l)[tilestyles_columns.name] = 
+	String::ucompose("0x%1", Glib::ustring::format(std::hex, std::setfill(L'0'), std::setw(2), (*t)[i]->getId()));
       (*l)[tilestyles_columns.tilestyle] = (*t)[i];
     }
 }
@@ -339,8 +394,10 @@ TileSetWindow::update_tilestyleset_panel()
     {
       //clear all values
       tilestyleset_frame->set_sensitive(false);
-      image_filechooser_button->set_current_folder
-	(Configuration::s_dataPath + "/tilesets/");
+      if (d_tileset)
+	image_filechooser_button->set_current_folder (File::getTilesetDir(d_tileset));
+      else
+	image_filechooser_button->set_current_folder (File::getUserTilesetDir());
       tilestyles_list->clear();
       refresh_button->set_sensitive(false);
       return;
@@ -387,12 +444,12 @@ TileSetWindow::update_tile_panel()
 }
 TileSetWindow::~TileSetWindow()
 {
-  SDL_FreeSurface (tile_smallmap_surface);
+  tile_smallmap_surface.reset();
+  delete window;
 }
 
 void TileSetWindow::show()
 {
-  sdl_container->show_all();
   window->show();
 }
 
@@ -401,34 +458,6 @@ void TileSetWindow::hide()
   window->hide();
 }
 
-namespace 
-{
-  void surface_attached_helper(GtkSDL *gtksdl, gpointer data)
-    {
-      static_cast<TileSetWindow *>(data)->on_sdl_surface_changed();
-    }
-}
-
-void TileSetWindow::init(int width, int height)
-{
-  sdl_widget
-    = Gtk::manage(Glib::wrap(gtk_sdl_new(width, height, 0, SDL_SWSURFACE)));
-
-  sdl_widget->set_flags(Gtk::CAN_FOCUS);
-
-  sdl_widget->grab_focus();
-  sdl_widget->add_events(Gdk::KEY_PRESS_MASK |
-			 Gdk::BUTTON_PRESS_MASK | Gdk::BUTTON_RELEASE_MASK |
-			 Gdk::POINTER_MOTION_MASK | Gdk::LEAVE_NOTIFY_MASK);
-
-  // connect to the special signal that signifies that a new surface has been
-  // generated and attached to the widget
-  g_signal_connect(G_OBJECT(sdl_widget->gobj()), "surface-attached",
-		   G_CALLBACK(surface_attached_helper), this);
-
-  sdl_container->add(*sdl_widget);
-}
-
 bool TileSetWindow::on_delete_event(GdkEventAny *e)
 {
   hide();
@@ -446,133 +475,73 @@ bool TileSetWindow::load(std::string tag, XML_Helper *helper)
 
 void TileSetWindow::on_new_tileset_activated()
 {
-  bool retval;
-  current_save_filename.clear();
-  if (d_tileset)
-    {
-      tiles_list->clear();
-      delete d_tileset;
-    }
   std::string name = "";
-  d_tileset = new Tileset(name);
-  TileSetInfoDialog d(d_tileset);
-  d.set_parent_window(*window.get());
-  retval = d.run();
-  if (retval == false)
+  int id = Tilesetlist::getNextAvailableId(0);
+  Tileset *tileset = new Tileset(id, name);
+  TileSetInfoDialog d(tileset, false);
+  d.set_parent_window(*window);
+  int response = d.run();
+  if (response != Gtk::RESPONSE_ACCEPT)
     {
-      delete d_tileset;
-      d_tileset = NULL;
+      delete tileset;
+      return;
     }
+  if (d_tileset)
+    delete d_tileset;
+  d_tileset = tileset;
+  tiles_list->clear();
+  current_save_filename = File::getTileset(d_tileset);
 
+  File::create_dir(File::getUserTilesetDir() + "/" + d_tileset->getSubDir());
 
+  //copy images??
   update_tileset_buttons();
   update_tilestyleset_buttons();
   update_tileset_menuitems();
   update_tile_preview_menuitem();
+
+  XML_Helper helper(current_save_filename, std::ios::out, false);
+  d_tileset->save(&helper);
+  helper.close();
 }
 
 void TileSetWindow::on_load_tileset_activated()
 {
-  Gtk::FileChooserDialog chooser(*window.get(), 
+  Gtk::FileChooserDialog chooser(*window, 
 				 _("Choose a Tileset to Load"));
   Gtk::FileFilter sav_filter;
-  sav_filter.add_pattern("*.xml");
+  sav_filter.add_pattern("*" + TILESET_EXT);
   chooser.set_filter(sav_filter);
-  chooser.set_current_folder(Configuration::s_savePath);
+  chooser.set_current_folder(File::getUserTilesetDir());
 
   chooser.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   chooser.add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT);
   chooser.set_default_response(Gtk::RESPONSE_ACCEPT);
-
-  chooser.set_current_folder(Configuration::s_dataPath + "/tilesets/");
-
+      
   chooser.show_all();
   int res = chooser.run();
 
   if (res == Gtk::RESPONSE_ACCEPT)
     {
-      current_save_filename = chooser.get_filename();
+      load_tileset(chooser.get_filename());
       chooser.hide();
-
-      tiles_list->clear();
-      if (d_tileset)
-	delete d_tileset;
-      XML_Helper helper(current_save_filename, std::ios::in, false);
-
-      helper.registerTag("tileset", 
-			 sigc::mem_fun((*this), &TileSetWindow::load));
-
-
-      if (!helper.parse())
-	{
-	  std::cerr <<_("Error, while loading an tileset. Tileset Name: ");
-	  std::cerr <<current_save_filename <<std::endl <<std::flush;
-	  exit(-1);
-	}
-
-      char *dir = strdup(current_save_filename.c_str());
-      char *tmp = strrchr (dir, '/');
-      if (tmp)
-	tmp[0] = '\0';
-      //hackus horribilium
-      std::string back = "../../../../../../../../../../../../../../../../";
-      d_tileset->setSubDir(back + dir);
-      GraphicsLoader::instantiatePixmaps(d_tileset);
-      for (Tileset::iterator i = d_tileset->begin(); i != d_tileset->end(); ++i)
-	{
-	  Gtk::TreeIter l = tiles_list->append();
-	  (*l)[tiles_columns.name] = (*i)->getName();
-	  (*l)[tiles_columns.tile] = *i;
-	}
-      if (d_tileset->size())
-	tiles_treeview->set_cursor (Gtk::TreePath ("0"));
-
-      update_tileset_buttons();
-      update_tilestyleset_buttons();
-      update_tileset_menuitems();
-      update_tile_panel();
-      update_tilestyleset_panel();
-      update_tilestyle_panel();
-      update_tile_preview_menuitem();
     }
 }
 
 void TileSetWindow::on_save_tileset_activated()
 {
   if (current_save_filename.empty())
-    on_save_tileset_as_activated();
-  else
-    {
-      XML_Helper helper(current_save_filename, std::ios::out, false);
-      helper.openTag("tileset");
-      d_tileset->save(&helper);
-      helper.closeTag();
-      helper.close();
-    }
-}
+    current_save_filename = File::getTilesetDir(d_tileset);
+  
+  //Reorder the tileset according to the treeview
+  d_tileset->clear();
+  for (Gtk::TreeIter i = tiles_list->children().begin(),
+       end = tiles_list->children().end(); i != end; ++i) 
+    d_tileset->push_back((*i)[tiles_columns.tile]);
 
-void TileSetWindow::on_save_tileset_as_activated()
-{
-  Gtk::FileChooserDialog chooser(*window.get(), _("Choose a Name"),
-				 Gtk::FILE_CHOOSER_ACTION_SAVE);
-  Gtk::FileFilter sav_filter;
-  sav_filter.add_pattern("*.xml");
-  chooser.set_filter(sav_filter);
-  chooser.set_current_folder(Configuration::s_dataPath + "/tilesets/");
-
-  chooser.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-  chooser.add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_ACCEPT);
-  chooser.set_default_response(Gtk::RESPONSE_ACCEPT);
-
-  chooser.show_all();
-  int res = chooser.run();
-
-  if (res == Gtk::RESPONSE_ACCEPT)
-    {
-      current_save_filename = chooser.get_filename();
-      chooser.hide();
-      on_save_tileset_activated();
-    }
+  XML_Helper helper(current_save_filename, std::ios::out, false);
+  d_tileset->save(&helper);
+  helper.close();
 }
 
 void TileSetWindow::on_quit_activated()
@@ -587,41 +556,32 @@ void TileSetWindow::on_quit_activated()
 
 void TileSetWindow::on_edit_tileset_info_activated()
 {
-  TileSetInfoDialog d(d_tileset);
-  d.set_parent_window(*window.get());
+  TileSetInfoDialog d(d_tileset, true);
+  d.set_parent_window(*window);
   d.run();
 }
 
 void TileSetWindow::on_help_about_activated()
 {
-  std::auto_ptr<Gtk::AboutDialog> dialog;
+  Gtk::AboutDialog* dialog;
 
-  Glib::RefPtr<Gnome::Glade::Xml> xml
-    = Gnome::Glade::Xml::create(get_glade_path() + "/../about-dialog.glade");
+  Glib::RefPtr<Gtk::Builder> xml
+    = Gtk::Builder::create_from_file(get_glade_path() + "/../about-dialog.ui");
 
-  Gtk::AboutDialog *d;
-  xml->get_widget("dialog", d);
-  dialog.reset(d);
-  dialog->set_transient_for(*window.get());
+  xml->get_widget("dialog", dialog);
+  dialog->set_transient_for(*window);
+  dialog->set_icon_from_file(File::getMiscFile("various/tileset_icon.png"));
 
   dialog->set_version(PACKAGE_VERSION);
-  SDL_Surface *logo = GraphicsLoader::getMiscPicture("tileset_icon.png");
-  dialog->set_logo(to_pixbuf(logo));
+  dialog->set_logo(GraphicsLoader::getMiscPicture("tileset_icon.png")->to_pixbuf());
   dialog->show_all();
   dialog->run();
+  dialog->hide();
+  delete dialog;
 
   return;
 }
 
-void TileSetWindow::on_sdl_surface_changed()
-{
-  if (!sdl_inited) {
-    GraphicsLoader::instantiatePixmaps(Tilesetlist::getInstance());
-    sdl_inited = true;
-    sdl_initialized.emit();
-  }
-}
-
 void TileSetWindow::update_tile_preview_menuitem()
 {
   if (get_selected_tile())
@@ -689,9 +649,7 @@ void TileSetWindow::on_add_tile_clicked()
   (*i)[tiles_columns.name] = t->getName();
   (*i)[tiles_columns.tile] = t;
   d_tileset->push_back(t);
-  char path[20];
-  snprintf (path, sizeof (path), "%d", d_tileset->size() - 1);
-  tiles_treeview->set_cursor (Gtk::TreePath (path));
+  tiles_treeview->set_cursor (Gtk::TreePath (String::ucompose("%1", d_tileset->size() - 1)));
   update_tile_preview_menuitem();
 }
 
@@ -729,13 +687,7 @@ void TileSetWindow::on_tile_first_color_changed()
     {
       Gtk::TreeModel::Row row = *iterrow;
       Tile *t = row[tiles_columns.tile];
-      Gdk::Color c = tile_smallmap_first_colorbutton->get_color();
-      SDL_Color sdl;
-      memset (&sdl, 0, sizeof (sdl));
-      sdl.r = c.get_red() / 255;
-      sdl.g = c.get_green() / 255;
-      sdl.b = c.get_blue() / 255;
-      t->getSmallTile()->setColor(sdl);
+      t->getSmallTile()->setColor(tile_smallmap_first_colorbutton->get_color());
       fill_tile_smallmap(t);
     }
 }
@@ -749,13 +701,7 @@ void TileSetWindow::on_tile_second_color_changed()
     {
       Gtk::TreeModel::Row row = *iterrow;
       Tile *t = row[tiles_columns.tile];
-      Gdk::Color c = tile_smallmap_second_colorbutton->get_color();
-      SDL_Color sdl;
-      memset (&sdl, 0, sizeof (sdl));
-      sdl.r = c.get_red() / 255;
-      sdl.g = c.get_green() / 255;
-      sdl.b = c.get_blue() / 255;
-      t->getSmallTile()->setSecondColor(sdl);
+      t->getSmallTile()->setSecondColor(tile_smallmap_second_colorbutton->get_color());
       fill_tile_smallmap(t);
     }
 }
@@ -769,13 +715,7 @@ void TileSetWindow::on_tile_third_color_changed()
     {
       Gtk::TreeModel::Row row = *iterrow;
       Tile *t = row[tiles_columns.tile];
-      Gdk::Color c = tile_smallmap_third_colorbutton->get_color();
-      SDL_Color sdl;
-      memset (&sdl, 0, sizeof (sdl));
-      sdl.r = c.get_red() / 255;
-      sdl.g = c.get_green() / 255;
-      sdl.b = c.get_blue() / 255;
-      t->getSmallTile()->setThirdColor(sdl);
+      t->getSmallTile()->setThirdColor(tile_smallmap_third_colorbutton->get_color());
       fill_tile_smallmap(t);
     }
 }
@@ -783,38 +723,25 @@ void TileSetWindow::on_tile_third_color_changed()
 void TileSetWindow::fill_colours(Tile *tile)
 {
   Gdk::Color c;
-  SDL_Color sdl;
   switch (tile->getSmallTile()->getPattern())
     {
     case SmallTile::SOLID:
       tile_smallmap_second_colorbutton->set_sensitive(false);
       tile_smallmap_third_colorbutton->set_sensitive(false);
-      sdl = tile->getSmallTile()->getColor();
-      c.set_red(sdl.r * 255); c.set_green(sdl.g * 255); c.set_blue(sdl.b * 255);
-      tile_smallmap_first_colorbutton->set_color(c);
+      tile_smallmap_first_colorbutton->set_color(tile->getSmallTile()->getColor());
       break;
     case SmallTile::STIPPLED: case SmallTile::SUNKEN:
       tile_smallmap_second_colorbutton->set_sensitive(true);
       tile_smallmap_third_colorbutton->set_sensitive(false);
-      sdl = tile->getSmallTile()->getColor();
-      c.set_red(sdl.r * 255); c.set_green(sdl.g * 255); c.set_blue(sdl.b * 255);
-      tile_smallmap_first_colorbutton->set_color(c);
-      sdl = tile->getSmallTile()->getSecondColor();
-      c.set_red(sdl.r * 255); c.set_green(sdl.g * 255); c.set_blue(sdl.b * 255);
-      tile_smallmap_second_colorbutton->set_color(c);
+      tile_smallmap_first_colorbutton->set_color(tile->getSmallTile()->getColor());
+      tile_smallmap_second_colorbutton->set_color(tile->getSmallTile()->getSecondColor());
       break;
     case SmallTile::RANDOMIZED: case SmallTile::TABLECLOTH: case SmallTile::DIAGONAL: case SmallTile::CROSSHATCH: case SmallTile::SUNKEN_STRIPED:
       tile_smallmap_second_colorbutton->set_sensitive(true);
       tile_smallmap_third_colorbutton->set_sensitive(true);
-      sdl = tile->getSmallTile()->getColor();
-      c.set_red(sdl.r * 255); c.set_green(sdl.g * 255); c.set_blue(sdl.b * 255);
-      tile_smallmap_first_colorbutton->set_color(c);
-      sdl = tile->getSmallTile()->getSecondColor();
-      c.set_red(sdl.r * 255); c.set_green(sdl.g * 255); c.set_blue(sdl.b * 255);
-      tile_smallmap_second_colorbutton->set_color(c);
-      sdl = tile->getSmallTile()->getThirdColor();
-      c.set_red(sdl.r * 255); c.set_green(sdl.g * 255); c.set_blue(sdl.b * 255);
-      tile_smallmap_third_colorbutton->set_color(c);
+      tile_smallmap_first_colorbutton->set_color(tile->getSmallTile()->getColor());
+      tile_smallmap_second_colorbutton->set_color(tile->getSmallTile()->getSecondColor());
+      tile_smallmap_third_colorbutton->set_color(tile->getSmallTile()->getThirdColor());
       break;
     }
 }
@@ -875,27 +802,28 @@ void TileSetWindow::fill_tile_smallmap(Tile *tile)
 	    shadowed = true;
 	  else if (j == 32 - 1)
 	    shadowed = true;
-	  OverviewMap::draw_tile_pixel (tile_smallmap_surface, 
-					tile->getSmallTile()->getPattern(),
-					tile->getSmallTile()->getColor(),
-					tile->getSmallTile()->getSecondColor(),
-					tile->getSmallTile()->getThirdColor(),
-					i, j, shadowed);
+	  OverviewMap::draw_terrain_tile (tile_smallmap_surface,
+					  tile_smallmap_surface_gc,
+					  tile->getSmallTile()->getPattern(),
+					  tile->getSmallTile()->getColor(),
+					  tile->getSmallTile()->getSecondColor(),
+					  tile->getSmallTile()->getThirdColor(),
+					  i, j, shadowed);
 	}
     }
 
-  tile_smallmap_image->property_pixbuf() = to_pixbuf(tile_smallmap_surface);
+  tile_smallmap_image->property_pixmap() = tile_smallmap_surface;
 }
 
 void TileSetWindow::on_add_tilestyleset_clicked()
 {
 
-  Gtk::FileChooserDialog chooser(*window.get(), _("Choose a Name"),
+  Gtk::FileChooserDialog chooser(*window, _("Choose a Name"),
 				 Gtk::FILE_CHOOSER_ACTION_OPEN);
   Gtk::FileFilter sav_filter;
   sav_filter.add_pattern("*.png");
   chooser.set_filter(sav_filter);
-  chooser.set_current_folder(Configuration::s_dataPath + "/tilesets/");
+  chooser.set_current_folder(Glib::get_home_dir());
 
   chooser.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
   chooser.add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_ACCEPT);
@@ -918,9 +846,7 @@ void TileSetWindow::on_add_tilestyleset_clicked()
 
       Tile *tile = get_selected_tile ();
       tile->push_back(t);
-      char path[20];
-      snprintf (path, sizeof (path), "%d", tile->size() - 1);
-      tilestylesets_treeview->set_cursor (Gtk::TreePath (path));
+      tilestylesets_treeview->set_cursor (Gtk::TreePath (String::ucompose("%1", tile->size() - 1)));
       image_filechooser_button->set_filename(filename);
     }
 }
@@ -997,7 +923,7 @@ void TileSetWindow::on_tilestyle_changed()
       t->setType(TileStyle::Type(tilestyle_combobox->get_active_row_number()));
       int idx = t->getType();
       tilestyle_standard_image->property_pixbuf() = 
-	tilestyle_standard_images[idx];
+	tilestyle_standard_images[idx]->to_pixbuf();
     }
 }
 
@@ -1013,13 +939,15 @@ void TileSetWindow::on_image_chosen()
     }
 
   unsigned int height = get_image_height (selected_filename);
-  if (height != d_tileset->getTileSize() && d_tileset->getTileSize() > 0)
-    return;
-
   unsigned int width = get_image_width (selected_filename);
   if ((width % height) != 0)
     return;
 
+  std::string file = File::get_basename(selected_filename);
+      
+  if (selected_filename != File::getTilesetFile(d_tileset, file))
+    File::copy (selected_filename, File::getTilesetFile(d_tileset, file));
+
   d_tileset->setTileSize(height);
 
   on_remove_tilestyleset_clicked();
@@ -1027,27 +955,12 @@ void TileSetWindow::on_image_chosen()
   //now make a new one
   TileStyleSet *set = new TileStyleSet();
   Gtk::TreeIter i = tilestylesets_list->append();
-  char *dir = strdup (selected_filename.c_str());
-  char *tmp = strrchr (dir, '/');
-  if (!tmp)
-    return;
-  tmp[0] = '\0';
 
-  //hackus horribilium
-  std::string back = "../../../../../../../../../../../../../../../../";
-
-  set->setSubDir(back + dir + "/");
+  set->setSubDir(d_tileset->getSubDir());
   (*i)[tilestylesets_columns.subdir] = set->getSubDir();
 
-  tmp++;
-  char *name = strdup (tmp);
-  tmp = strrchr (name, '.');
-  if (tmp)
-    tmp[0] = '\0';
 
-  set->setName(name);
-  free (name);
-  free (dir);
+  set->setName(File::get_basename(selected_filename));
   (*i)[tilestylesets_columns.name] = set->getName();
   (*i)[tilestylesets_columns.tilestyleset] = set;
   Tile *tile = get_selected_tile ();
@@ -1070,7 +983,7 @@ void TileSetWindow::on_image_chosen()
 void TileSetWindow::on_refresh_clicked()
 {
   TileStyleSet *set = get_selected_tilestyleset ();
-  GraphicsLoader::instantiatePixmaps(set, d_tileset->getTileSize());
+  GraphicsLoader::instantiateImages(d_tileset, set, d_tileset->getTileSize());
 }
 
 void TileSetWindow::on_preview_tile_activated()
@@ -1083,8 +996,168 @@ void TileSetWindow::on_preview_tile_activated()
     }
 }
       
+void TileSetWindow::on_roads_picture_activated()
+{
+  ImageEditorDialog d(File::getTilesetFile(d_tileset, 
+					   d_tileset->getRoadsFilename()),
+		      ROAD_TYPES);
+  d.set_icon_from_file(File::getMiscFile("various/tileset_icon.png"));
+  d.set_parent_window(*window);
+  int response = d.run();
+  if (response == Gtk::RESPONSE_ACCEPT)
+    {
+      std::string filename = d.get_selected_filename();
+      std::string name = File::get_basename(filename);
+      File::copy(filename, File::getTilesetFile(d_tileset, name));
+      d_tileset->setRoadsFilename(name);
+    }
+}
+void TileSetWindow::on_bridges_picture_activated()
+{
+  ImageEditorDialog d(File::getTilesetFile(d_tileset, 
+					   d_tileset->getBridgesFilename()),
+		      BRIDGE_TYPES);
+  d.set_icon_from_file(File::getMiscFile("various/tileset_icon.png"));
+  d.set_parent_window(*window);
+  int response = d.run();
+  if (response == Gtk::RESPONSE_ACCEPT)
+    {
+      std::string filename = d.get_selected_filename();
+      std::string name = File::get_basename(filename);
+      File::copy(filename, File::getTilesetFile(d_tileset, name));
+      d_tileset->setBridgesFilename(name);
+    }
+}
+void TileSetWindow::on_fog_picture_activated()
+{
+  ImageEditorDialog d(File::getTilesetFile(d_tileset, 
+					   d_tileset->getFogFilename()),
+		      FOG_TYPES);
+  d.set_icon_from_file(File::getMiscFile("various/tileset_icon.png"));
+  d.set_parent_window(*window);
+  int response = d.run();
+  if (response == Gtk::RESPONSE_ACCEPT)
+    {
+      std::string filename = d.get_selected_filename();
+      std::string name = File::get_basename(filename);
+      File::copy(filename, File::getTilesetFile(d_tileset, name));
+      d_tileset->setFogFilename(name);
+    }
+}
+void TileSetWindow::on_flags_picture_activated()
+{
+  TilesetFlagEditorDialog d(d_tileset);
+  d.set_icon_from_file(File::getMiscFile("various/tileset_icon.png"));
+  d.set_parent_window(*window);
+  int response = d.run();
+  if (response == Gtk::RESPONSE_ACCEPT)
+    {
+      std::string filename= d.get_selected_filename();
+
+      //copy the file, and set the image name
+      std::string name = File::get_basename(filename);
+      if (filename != File::getTilesetFile(d_tileset, name))
+	File::copy(filename, File::getTilesetFile(d_tileset, name));
+
+      d_tileset->setFlagsFilename(name);
+    }
+}
 void TileSetWindow::on_army_unit_selector_activated()
 {
   TilesetSelectorEditorDialog d(d_tileset);
-  d.run();
+  d.set_icon_from_file(File::getMiscFile("various/tileset_icon.png"));
+  int response = d.run();
+  if (response == Gtk::RESPONSE_ACCEPT)
+    {
+      std::string small = d.get_small_selector_filename();
+      std::string large = d.get_large_selector_filename();
+
+      //copy the files, and set the image names
+      std::string name = File::get_basename(small);
+      if (small != File::getTilesetFile(d_tileset, name))
+	File::copy(small, File::getTilesetFile(d_tileset, name));
+      d_tileset->setSmallSelectorFilename(name);
+
+      name = File::get_basename(large);
+      if (large != File::getTilesetFile(d_tileset, name))
+	File::copy(large, File::getTilesetFile(d_tileset, name));
+      d_tileset->setLargeSelectorFilename(name);
+
+    }
+}
+
+void TileSetWindow::on_explosion_picture_activated()
+{
+  TilesetExplosionPictureEditorDialog d(d_tileset);
+  d.set_icon_from_file(File::getMiscFile("various/tileset_icon.png"));
+  int response = d.run();
+  if (response == Gtk::RESPONSE_ACCEPT)
+    {
+      std::string filename = d.get_selected_filename();
+      std::string name = File::get_basename(filename);
+      if (filename != File::getTilesetFile(d_tileset, name))
+	{
+	  File::copy (filename, File::getTilesetFile(d_tileset, name));
+	  d_tileset->setExplosionFilename(name);
+	}
+    }
+}
+
+void TileSetWindow::load_tileset(std::string filename)
+{
+  current_save_filename = filename;
+
+  bool priv = true;
+  std::string dir = Glib::path_get_dirname(filename);
+  dir = Glib::path_get_dirname(dir) + "/";
+  if (dir == File::getTilesetDir())
+    priv = false;
+  else if (dir == File::getUserTilesetDir())
+    priv = true;
+  else
+    {
+      std::string msg;
+      msg = "Tilesets can only be loaded from:\n" + File::getTilesetDir() +
+	"\n or \n" + File::getUserTilesetDir();
+      Gtk::MessageDialog dialog(*window, msg);
+      dialog.run();
+      dialog.hide();
+      return;
+    }
+  std::string name = File::get_basename(filename);
+
+  Tileset *tileset = Tileset::create(name, priv);
+  if (tileset == NULL)
+    {
+      std::string msg;
+      msg = "The tileset could not be loaded.";
+      Gtk::MessageDialog dialog(*window, msg);
+      dialog.run();
+      dialog.hide();
+    }
+  tiles_list->clear();
+  if (d_tileset)
+    delete d_tileset;
+  d_tileset = tileset;
+
+  //was this from the user's own private collection?
+
+  d_tileset->setSubDir(name);
+  GraphicsLoader::instantiateImages(d_tileset);
+  for (Tileset::iterator i = d_tileset->begin(); i != d_tileset->end(); ++i)
+    {
+      Gtk::TreeIter l = tiles_list->append();
+      (*l)[tiles_columns.name] = (*i)->getName();
+      (*l)[tiles_columns.tile] = *i;
+    }
+  if (d_tileset->size())
+    tiles_treeview->set_cursor (Gtk::TreePath ("0"));
+
+  update_tileset_buttons();
+  update_tilestyleset_buttons();
+  update_tileset_menuitems();
+  update_tile_panel();
+  update_tilestyleset_panel();
+  update_tilestyle_panel();
+  update_tile_preview_menuitem();
 }
