@@ -1,8 +1,8 @@
-//  Copyright (C) 2008 Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,50 +22,26 @@
 #include <vector>
 #include <sigc++/signal.h>
 #include <sigc++/trackable.h>
-#include <libglademm/xml.h>
-#include <gtkmm/window.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/container.h>
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/combobox.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/treemodelcolumn.h>
-#include <gtkmm/treeview.h>
-#include <gtkmm/textview.h>
-#include <gtkmm/filechooserbutton.h>
-#include <gtkmm/image.h>
-#include <gtkmm/button.h>
-#include <gtkmm/spinbutton.h>
-#include <gtkmm/frame.h>
-#include <gtkmm/colorbutton.h>
-#include <gtkmm/table.h>
-#include <gtkmm/checkmenuitem.h>
-#include <gtkmm/radiobutton.h>
-#include <gtkmm/tooltips.h>
+#include <gtkmm.h>
 
 #include "Tile.h"
 #include "tileset.h"
+#include "PixMask.h"
 
 //! Tileset Editor.  Edit an Tileset.
 class TileSetWindow: public sigc::trackable
 {
  public:
-    TileSetWindow();
+    TileSetWindow(std::string load_filename = "");
     ~TileSetWindow();
 
     void show();
     void hide();
 
-    // initialize the SDL widget 
-    void init(int width, int height);
-
-    sigc::signal<void> sdl_initialized;
-    Gtk::Window &get_window() { return *window.get(); }
+    Gtk::Window &get_window() { return *window; }
 
  private:
-    std::auto_ptr<Gtk::Window> window;
-    Gtk::Container *sdl_container;
-    Gtk::Widget *sdl_widget;
+    Gtk::Window* window;
     std::string current_save_filename;
     Tileset *d_tileset; //current tileset
     Tile *d_tile; //current tile
@@ -77,29 +53,35 @@ class TileSetWindow: public sigc::trackable
     Gtk::Button *remove_tile_button;
     Gtk::VBox *tile_vbox;
     Gtk::Entry *tile_name_entry;
-    Gtk::ComboBox *tile_type_combobox;
+    Gtk::ComboBoxText *tile_type_combobox;
     Gtk::SpinButton *tile_moves_spinbutton;
-    Gtk::ComboBox *tile_smallmap_pattern_combobox;
+    Gtk::ComboBoxText *tile_smallmap_pattern_combobox;
     Gtk::ColorButton *tile_smallmap_first_colorbutton;
     Gtk::ColorButton *tile_smallmap_second_colorbutton;
     Gtk::ColorButton *tile_smallmap_third_colorbutton;
     Gtk::Image *tile_smallmap_image;
     Gtk::Button *add_tilestyleset_button;
     Gtk::Button *remove_tilestyleset_button;
-    bool sdl_inited;
     Gtk::MenuItem *new_tileset_menuitem;
     Gtk::MenuItem *load_tileset_menuitem;
     Gtk::MenuItem *save_tileset_menuitem;
-    Gtk::MenuItem *save_tileset_as_menuitem;
     Gtk::MenuItem *edit_tileset_info_menuitem;
+    Gtk::MenuItem *roads_picture_menuitem;
+    Gtk::MenuItem *bridges_picture_menuitem;
+    Gtk::MenuItem *fog_picture_menuitem;
+    Gtk::MenuItem *flags_picture_menuitem;
     Gtk::MenuItem *army_unit_selector_menuitem;
+    Gtk::MenuItem *explosion_picture_menuitem;
     Gtk::MenuItem *preview_tile_menuitem;
-    Gtk::ComboBox *tilestyle_combobox;
+    Gtk::MenuItem *quit_menuitem;
+    Gtk::MenuItem *help_about_menuitem;
+    Gtk::ComboBoxText *tilestyle_combobox;
     Gtk::Image *tilestyle_image;
     Gtk::FileChooserButton *image_filechooser_button;
     Gtk::Button *refresh_button;
-    std::vector<Glib::RefPtr<Gdk::Pixbuf> > tilestyle_standard_images;
-    std::vector<Glib::RefPtr<Gdk::Pixbuf> > tilestyle_images;
+
+    std::vector<PixMask* > tilestyle_standard_images;
+    std::vector<PixMask* > tilestyle_images;
     Gtk::Image *tilestyle_standard_image;
 
     class TilesColumns: public Gtk::TreeModelColumnRecord {
@@ -125,7 +107,8 @@ class TileSetWindow: public sigc::trackable
     };
     const TileStyleSetsColumns tilestylesets_columns;
     Glib::RefPtr<Gtk::ListStore> tilestylesets_list;
-    SDL_Surface *tile_smallmap_surface;
+    Glib::RefPtr<Gdk::Pixmap> tile_smallmap_surface;
+    Glib::RefPtr<Gdk::GC> tile_smallmap_surface_gc;
     Gtk::TreeView *tilestyles_treeview;
     class TileStylesColumns: public Gtk::TreeModelColumnRecord {
     public:
@@ -161,6 +144,11 @@ class TileSetWindow: public sigc::trackable
     void on_quit_activated();
     void on_edit_tileset_info_activated();
     void on_army_unit_selector_activated();
+    void on_explosion_picture_activated();
+    void on_roads_picture_activated();
+    void on_bridges_picture_activated();
+    void on_fog_picture_activated();
+    void on_flags_picture_activated();
     void on_preview_tile_activated();
     void on_help_about_activated();
     void on_tile_selected();
@@ -175,8 +163,6 @@ class TileSetWindow: public sigc::trackable
 
     bool load(std::string tag, XML_Helper *helper);
 
-
-
     //callbacks
     void on_tile_type_changed();
     void on_tile_name_changed();
@@ -194,10 +180,8 @@ class TileSetWindow: public sigc::trackable
     void on_remove_tilestyleset_clicked();
     void on_refresh_clicked();
 
-public:
-    // not part of the API, but for surface_attached_helper
-    void on_sdl_surface_changed();
-      
+    void load_tileset(std::string filename);
+
 };
 
 #endif
