@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007 Ole Laursen
 //  Copyright (C) 2007, 2008 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -39,7 +39,7 @@ struct GameParameters
     {
 	int width, height;
 	int grass, water, swamp, forest, hills, mountains;
-	int cities, ruins;
+	int cities, ruins, temples, signposts;
     };
 
     Map map;
@@ -64,7 +64,7 @@ struct GameParameters
     bool diplomacy;
 
     enum NeutralCities {
-        AVERAGE = 0, STRONG, ACTIVE
+        AVERAGE = 0, STRONG, ACTIVE, DEFENSIVE
     };
     NeutralCities neutral_cities;
     enum RazingCities {
