@@ -3,7 +3,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,7 +21,7 @@
 #include <algorithm>
 #include <vector>
 #include <assert.h>
-#include <SDL.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
 #include <sigc++/adaptors/bind.h>
 
@@ -66,7 +66,6 @@
 #include "history.h"
 #include "pbm-game-server.h"
 #include "LocationBox.h"
-#include "Campaign.h"
 #include "Backpack.h"
 #include "MapBackpack.h"
 
@@ -87,6 +86,7 @@ void Game::addPlayer(Player *p)
     (*it).disconnect();
   connections[p->getId()].clear();
 
+  //now setup the connections that are specific for human players
   if (p->getType() == Player::HUMAN)
     {
       connections[p->getId()].push_back
@@ -109,8 +109,15 @@ void Game::addPlayer(Player *p)
       connections[p->getId()].push_back
 	(p->advice_asked.connect
 	 (sigc::mem_fun(advice_asked, &sigc::signal<void, float>::emit)));
+      connections[p->getId()].push_back
+	(p->shaltedStack.connect
+	 (sigc::mem_fun(this, &Game::on_stack_halted)));
+      connections[p->getId()].push_back
+	(p->getStacklist()->sgrouped.connect
+	 (sigc::mem_fun(this, &Game::on_stack_grouped)));
     }
       
+  //now do all of the common connections
   connections[p->getId()].push_back
     (p->aborted_turn.connect (sigc::mem_fun
 	   (game_stopped, &sigc::signal<void>::emit)));
@@ -150,6 +157,19 @@ void Game::addPlayer(Player *p)
     unlock_inputs();
 }
 
+void Game::on_stack_halted(Stack *stack)
+{
+  if (stack == NULL)
+    return;
+  bigmap->reset_path_calculator(stack);
+  //tell gamebigmap that a stack just stopped
+}
+void Game::on_stack_grouped(Stack *stack, bool grouped)
+{
+  bigmap->reset_path_calculator(stack);
+  //tell gamebigmap that we just grouped/ungrouped a stack.
+  return;
+}
 #include "game-server.h"
 
 Game::Game(GameScenario* gameScenario, NextTurn *nextTurn)
@@ -166,6 +186,8 @@ Game::Game(GameScenario* gameScenario, NextTurn *nextTurn)
 		  GameScenario::s_military_advisor));
     bigmap->stack_selected.connect(
 	sigc::mem_fun(this, &Game::on_stack_selected));
+    bigmap->stack_grouped_or_ungrouped.connect(
+	sigc::mem_fun(this, &Game::on_stack_grouped_or_ungrouped));
     bigmap->path_set.connect(
 	sigc::mem_fun(this, &Game::update_control_panel));
     bigmap->city_queried.connect(
@@ -185,16 +207,20 @@ Game::Game(GameScenario* gameScenario, NextTurn *nextTurn)
     smallmap->resize();
     smallmap->map_changed.connect(
 	sigc::mem_fun(smallmap_changed,
-		      &sigc::signal<void, SDL_Surface *>::emit));
+		      &sigc::signal<void, Glib::RefPtr<Gdk::Pixmap>, 
+		      Gdk::Rectangle>::emit));
 
     // connect the two maps
     bigmap->view_changed.connect(
 	sigc::mem_fun(smallmap.get(), &SmallMap::set_view));
+    bigmap->map_changed.connect(
+	sigc::mem_fun(bigmap_changed,
+		      &sigc::signal<void, Glib::RefPtr<Gdk::Pixmap> >::emit));
     smallmap->view_changed.connect(
 	sigc::mem_fun(bigmap.get(), &GameBigMap::set_view));
 
     // get the maps up and running
-    bigmap->screen_size_changed();
+    bigmap->screen_size_changed(Gtk::Allocation(0,0,320,200));
 
     // connect player callbacks
     Playerlist* pl = Playerlist::getInstance();
@@ -203,8 +229,7 @@ Game::Game(GameScenario* gameScenario, NextTurn *nextTurn)
 	Player *p = *i;
 	addPlayer(p);
     }
-    if (gameScenario->getPlayMode() == GameScenario::HOTSEAT ||
-	gameScenario->getPlayMode() == GameScenario::CAMPAIGN)
+    if (gameScenario->getPlayMode() == GameScenario::HOTSEAT)
       pl->splayerDead.connect(sigc::mem_fun(this, &Game::on_player_died));
     pl->ssurrender.connect(sigc::mem_fun(this, &Game::on_surrender_offered));
 
@@ -322,6 +347,11 @@ void Game::select_next_movable_stack()
   select_active_stack();
 }
 
+void Game::move_map_dir(int diffx, int diffy)
+{
+  smallmap->move_map_in_dir(Vector<int>(diffx, diffy));
+}
+
 void Game::move_selected_stack_dir(int diffx, int diffy)
 {
   Stack *stack = Playerlist::getActiveplayer()->getActivestack();
@@ -329,17 +359,13 @@ void Game::move_selected_stack_dir(int diffx, int diffy)
     return;
   // Get rid of the old path if there is one
   if (stack->getPath()->size())
-    stack->getPath()->flClear();
+    stack->getPath()->clear();
   //See if we can move there
   Vector<int> dest = stack->getPos();
-  dest.x += diffx;
-  dest.y += diffy;
-  if (stack->getPath()->canMoveThere(stack, dest))
-    {
-      // Set in a new path
-      stack->getPath()->calculate(stack, dest);
-      move_selected_stack_along_path();
-    }
+  dest += Vector<int>(diffx, diffy);
+  int mp = stack->getPath()->calculate(stack, dest);
+  if (mp > 0)
+    move_selected_stack_along_path();
   else
     {
       Playerlist::getActiveplayer()->getStacklist()->setActivestack(0);
@@ -349,42 +375,66 @@ void Game::move_selected_stack_dir(int diffx, int diffy)
 
 void Game::move_selected_stack_northwest()
 {
-  move_selected_stack_dir(-1, -1);
+  if (Playerlist::getActiveplayer()->getActivestack() != NULL)
+    move_selected_stack_dir(-1, -1);
+  else
+    move_map_dir(-1,-1);
 }
 
 void Game::move_selected_stack_north()
 {
-  move_selected_stack_dir(0, -1);
+  if (Playerlist::getActiveplayer()->getActivestack() != NULL)
+    move_selected_stack_dir(0, -1);
+  else
+    move_map_dir(0, -1);
 }
 
 void Game::move_selected_stack_northeast()
 {
-  move_selected_stack_dir(1, -1);
+  if (Playerlist::getActiveplayer()->getActivestack() != NULL)
+    move_selected_stack_dir(1, -1);
+  else
+    move_map_dir(1, -1);
 }
 
 void Game::move_selected_stack_east()
 {
-  move_selected_stack_dir(1, 0);
+  if (Playerlist::getActiveplayer()->getActivestack() != NULL)
+    move_selected_stack_dir(1, 0);
+  else
+    move_map_dir(1, 0);
 }
 
 void Game::move_selected_stack_west()
 {
-  move_selected_stack_dir(-1, 0);
+  if (Playerlist::getActiveplayer()->getActivestack() != NULL)
+    move_selected_stack_dir(-1, 0);
+  else
+    move_map_dir(-1, 0);
 }
 
 void Game::move_selected_stack_southwest()
 {
-  move_selected_stack_dir(-1, 1);
+  if (Playerlist::getActiveplayer()->getActivestack() != NULL)
+    move_selected_stack_dir(-1, 1);
+  else
+    move_map_dir(-1, 1);
 }
 
 void Game::move_selected_stack_south()
 {
-  move_selected_stack_dir(0, 1);
+  if (Playerlist::getActiveplayer()->getActivestack() != NULL)
+    move_selected_stack_dir(0, 1);
+  else
+    move_map_dir(0, 1);
 }
 
 void Game::move_selected_stack_southeast()
 {
-  move_selected_stack_dir(1, 1);
+  if (Playerlist::getActiveplayer()->getActivestack() != NULL)
+    move_selected_stack_dir(1, 1);
+  else
+    move_map_dir(1, 1);
 }
 
 void Game::move_selected_stack_along_path()
@@ -484,8 +534,8 @@ void Game::search_selected_stack()
   Player *player = Playerlist::getActiveplayer();
   Stack* stack = player->getActivestack();
 
-  Ruin* ruin = Ruinlist::getInstance()->getObjectAt(stack->getPos());
-  Temple* temple = Templelist::getInstance()->getObjectAt(stack->getPos());
+  Ruin* ruin = GameMap::getRuin(stack->getPos());
+  Temple* temple = GameMap::getTemple(stack->getPos());
 
   if (ruin && !ruin->isSearched() && stack->hasHero() &&
       stack->getFirstHero()->getMoves() > 0 &&
@@ -527,7 +577,7 @@ void Game::search_selected_stack()
       int blessCount;
       blessCount = player->stackVisitTemple(stack, temple);
       bool wants_quest = temple_searched.emit(stack->hasHero(), temple, blessCount);
-      if (wants_quest)
+      if (wants_quest && stack->hasHero())
 	{
 	  Quest *q = player->stackGetQuest
 	    (stack, temple, 
@@ -564,7 +614,8 @@ void Game::stackUpdate(Stack* s)
   update_control_panel();
 
   // sleep for a specified amount of time
-  SDL_Delay(Configuration::s_displaySpeedDelay);
+  //SDL_Delay(Configuration::s_displaySpeedDelay);
+  Glib::usleep(Configuration::s_displaySpeedDelay);
 }
 
 Army::Stat Game::newLevelArmy(Army* a)
@@ -577,7 +628,7 @@ Army::Stat Game::newLevelArmy(Army* a)
   return army_gains_level.emit(a);
 }
 
-void Game::newMedalArmy(Army* a)
+void Game::newMedalArmy(Army* a, int medaltype)
 {
   // We don't want to have medal awards of computer players displayed
   if (!a->getOwner()
@@ -585,10 +636,17 @@ void Game::newMedalArmy(Army* a)
       || a->getOwner() != Playerlist::getInstance()->getActiveplayer())
     return;
 
-  medal_awarded_to_army.emit(a);
+  medal_awarded_to_army.emit(a, medaltype);
   update_stack_info();
 }
 
+void Game::on_stack_grouped_or_ungrouped(Stack *s)
+{
+  //this only happens when we double-click on a stack on the bigmap.
+  update_stack_info();
+  update_control_panel();
+}
+
 void Game::on_stack_selected(Stack* s)
 {
   update_stack_info();
@@ -750,8 +808,9 @@ void Game::invading_city(City* city, int gold)
 	break;
 
       case CITY_DEFEATED_RAZE:
-	player->cityRaze(city);
-	city_razed.emit (city);
+	//the razing just happened in the are-you-sure dialog, and the user
+	//was sure.
+	city_razed.emit(city);
 	player->deteriorateDiplomaticRelationship (5);
 	break;
 
@@ -764,7 +823,7 @@ void Game::invading_city(City* city, int gold)
 	break;
 
       case CITY_DEFEATED_SACK:
-	std::list<Uint32> sacked_types;
+	std::list<guint32> sacked_types;
 	player->citySack(city, gold, &sacked_types);
 	city_sacked.emit(city, gold, sacked_types);
 	break;
@@ -808,7 +867,6 @@ void Game::update_control_panel()
       can_park_selected_stack.emit(false);
       can_deselect_selected_stack.emit(false);
       can_search_selected_stack.emit(false);
-      can_inspect_selected_stack.emit(false);
       can_plant_standard_selected_stack.emit(false);
       can_move_selected_stack.emit(false);
       can_move_selected_stack_along_path.emit(false);
@@ -818,6 +876,7 @@ void Game::update_control_panel()
       can_disband_stack.emit(false);
       can_change_signpost.emit(false);
       can_see_history.emit(false);
+      can_see_diplomacy.emit(false);
 
       return;
     }
@@ -870,18 +929,17 @@ void Game::update_control_panel()
       if (stack->getGroupMoves() > 0)
 	{
 	  Temple *temple;
-	  temple = Templelist::getInstance()->getObjectAt(stack->getPos());
+	  temple = GameMap::getTemple(stack->getPos());
 	  can_search_selected_stack.emit(temple);
 	  can_move_selected_stack.emit(true);
 	}
 
       if (stack->hasHero())
 	{
-	  Ruin *ruin = Ruinlist::getInstance()->getObjectAt(stack->getPos());
+	  Ruin *ruin = GameMap::getRuin(stack->getPos());
 	  if (stack->getFirstHero()->getMoves() > 0 && ruin)
 	    can_search_selected_stack.emit(!ruin->isSearched());
 
-	  can_inspect_selected_stack.emit(true);
 	  //does the hero have the player's standard?
 	  for (Stack::iterator it = stack->begin(); it != stack->end(); it++)
 	    {
@@ -891,14 +949,10 @@ void Game::update_control_panel()
 		  if (hero->getBackpack()->getPlantableItem(player))
 		    {
 			  //can't plant on city/ruin/temple/signpost
-			  Citylist *cl = Citylist::getInstance();
-			  City *city = cl->getObjectAt(stack->getPos());
-			  Templelist *tl = Templelist::getInstance();
-			  Temple *temple = tl->getObjectAt(stack->getPos());
-			  Ruinlist *rl = Ruinlist::getInstance();
-			  Ruin *ruin = rl->getObjectAt(stack->getPos());
-			  Signpostlist *spl = Signpostlist::getInstance();
-			  Signpost *sign = spl->getObjectAt(stack->getPos());
+			  City *city = GameMap::getCity(stack->getPos());
+			  Temple *temple = GameMap::getTemple(stack->getPos());
+			  Ruin *ruin = GameMap::getRuin(stack->getPos());
+			  Signpost *sign = GameMap::getSignpost(stack->getPos());
 			  if (!city && !temple && !ruin && !sign)
 			    {
 			      GameMap *gm = GameMap::getInstance();
@@ -917,11 +971,10 @@ void Game::update_control_panel()
 	}
       else
 	{
-	  can_inspect_selected_stack.emit(false);
 	  can_plant_standard_selected_stack.emit(false);
 	}
 
-      if (Signpostlist::getInstance()->getObjectAt(stack->getPos()))
+      if (GameMap::getSignpost(stack->getPos()))
 	can_change_signpost.emit(true);
 
       can_disband_stack.emit(true);
@@ -934,7 +987,6 @@ void Game::update_control_panel()
       can_move_selected_stack_along_path.emit(false);
       can_disband_stack.emit(false);
       can_group_ungroup_selected_stack.emit(false);
-      can_inspect_selected_stack.emit(false);
       can_plant_standard_selected_stack.emit(false);
     }
 
@@ -942,6 +994,8 @@ void Game::update_control_panel()
     can_see_history.emit(true);
   else
     can_see_history.emit(false);
+    
+  can_see_diplomacy.emit(GameScenarioOptions::s_diplomacy);
 
   can_end_turn.emit(true);
 }
@@ -985,7 +1039,7 @@ void Game::loadGame()
       player = Playerlist::getActiveplayer();
     }
 
-  if (player->getType() == Player::HUMAN && (d_gameScenario->getPlayMode() == GameScenario::HOTSEAT || d_gameScenario->getPlayMode() == GameScenario::CAMPAIGN))
+  if (player->getType() == Player::HUMAN && (d_gameScenario->getPlayMode() == GameScenario::HOTSEAT))
     {
       //human players want access to the controls and an info box
       unlock_inputs();
@@ -1047,7 +1101,7 @@ void Game::init_turn_for_player(Player* p)
 {
   Playerlist* pl = Playerlist::getInstance();
 
-  if (GameScenario::s_hidden_map && p->getType() == Player::HUMAN)
+  if (GameScenario::s_hidden_map)
     {
       smallmap->blank();
       bigmap->blank();
@@ -1065,6 +1119,7 @@ void Game::init_turn_for_player(Player* p)
       update_sidebar_stats();
       update_stack_info();
       update_control_panel();
+      redraw();
 
       // update the diplomacy icon if we've received a proposal
       bool proposal_received = false;
@@ -1107,21 +1162,7 @@ void Game::on_player_died(Player *player)
 {
   const Playerlist* pl = Playerlist::getInstance();
   if (pl->getNoOfPlayers() <= 1)
-    {
-      Campaign *campaign = Campaign::getInstance();
-      if (campaign->getNextScenario() != "" &&
-	  pl->getFirstLiving()->getType() == Player::HUMAN)
-	{
-	  Player *p = pl->getFirstLiving();
-	  Uint32 num_heroes = campaign->getNumberOfHeroesToCarryOver();
-	  std::list<Hero*> heroes;
-	  heroes = p->getStacklist()->getTopHeroes(num_heroes);
-	  next_scenario.emit(File::getCampaignFile(campaign->getNextScenario()),
-			     p->getGold(), heroes, p->getName());
-	}
-      else
-	game_over.emit(pl->getFirstLiving());
-    }
+    game_over.emit(pl->getFirstLiving());
   else
     player_died.emit(player);
 }
@@ -1245,6 +1286,7 @@ void Game::on_surrender_offered(Player *recipient)
   Playerlist *plist = Playerlist::getInstance();
   if (enemy_offers_surrender.emit(plist->countPlayersAlive() - 1))
     {
+      plist->surrender();
       surrender_answered.emit(true);
       game_over.emit(recipient);
     }
@@ -1284,7 +1326,7 @@ void Game::on_city_fight_finished(City *city, Fight::Result result)
 	  if (o)
 	    {
 	      int army_type = o->getStrongestArmy()->getTypeId();
-	      for (Uint32 i = 0; i < city->getMaxNoOfProductionBases(); i++)
+	      for (guint32 i = 0; i < city->getMaxNoOfProductionBases(); i++)
 		{
 		  if (city->getArmytype(i) == army_type)
 		    {
@@ -1315,3 +1357,29 @@ bool Game::saveTurnFile(std::string turnfile)
     PbmGameServer::getInstance()->endTurn(turnfile, broken);
   return true;
 }
+
+void Game::inhibitAutosaveRemoval(bool inhibit)
+{
+  if (d_gameScenario)
+    d_gameScenario->inhibitAutosaveRemoval(inhibit);
+}
+
+void Game::endOfGameRoaming(Player *winner)
+{
+  Playerlist* pl = Playerlist::getInstance();
+  pl->setWinningPlayer(winner);
+
+  winner->immobilize();
+  d_gameScenario->s_see_opponents_stacks = true;
+  d_gameScenario->s_see_opponents_production = true;
+  bigmap->d_see_opponents_stacks = true;
+  bigmap->d_see_opponents_production = true;
+  center_view_on_city();
+
+  unlock_inputs();
+
+  update_sidebar_stats();
+  update_stack_info();
+  update_control_panel();
+  redraw();
+}
