@@ -1,9 +1,9 @@
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -99,7 +99,8 @@ class Game
     
     // signals
     sigc::signal<void, Vector<int> > current_map_position;
-    sigc::signal<void, SDL_Surface *> smallmap_changed;
+    sigc::signal<void, Glib::RefPtr<Gdk::Pixmap>, Gdk::Rectangle> smallmap_changed;
+    sigc::signal<void, Glib::RefPtr<Gdk::Pixmap> > bigmap_changed;
     sigc::signal<void, SidebarStats> sidebar_stats_changed;
     sigc::signal<void, std::string> progress_status_changed;
     sigc::signal<void> progress_changed;
@@ -110,7 +111,6 @@ class Game
 	can_park_selected_stack,
 	can_deselect_selected_stack,
 	can_search_selected_stack,
-	can_inspect_selected_stack,
 	can_plant_standard_selected_stack,
 	can_move_selected_stack_along_path,
 	can_move_selected_stack,
@@ -119,6 +119,7 @@ class Game
 	can_disband_stack,
 	can_change_signpost,
 	can_see_history,
+	can_see_diplomacy,
 	received_diplomatic_proposal,
 	city_too_poor_to_produce,
 	can_end_turn;
@@ -139,7 +140,7 @@ class Game
     sigc::signal<void, Hero *, Quest *> quest_assigned;
     sigc::signal<CityDefeatedAction, City *, int> city_defeated;
     sigc::signal<void, City *, int, unsigned int> city_pillaged;
-    sigc::signal<void, City *, int, std::list<Uint32> > city_sacked;
+    sigc::signal<void, City *, int, std::list<guint32> > city_sacked;
     sigc::signal<void, City *> city_razed;
     sigc::signal<void, City *> city_visited;
     sigc::signal<void, Ruin *> ruin_visited;
@@ -147,21 +148,24 @@ class Game
     sigc::signal<void, Player *, unsigned int> next_player_turn;
     sigc::signal<void> remote_next_player_turn;
     sigc::signal<void, int> hero_arrives;
-    sigc::signal<void, Army *> medal_awarded_to_army;
+    sigc::signal<void, Army *, int> medal_awarded_to_army;
     sigc::signal<Army::Stat, Army *> army_gains_level;
     sigc::signal<void, Player *> game_loaded;
     sigc::signal<void, Player *> game_over;
-    sigc::signal<void, std::string, int, std::list<Hero*>, std::string > next_scenario;
     sigc::signal<void, Player *> player_died;
     sigc::signal<void> game_stopped;
     
     void addPlayer(Player *p);
 
+    void inhibitAutosaveRemoval(bool inhibit);
+
+    void endOfGameRoaming(Player *winner);
  private:
     static Game *current_game;
 
     // move the selected stack one tile in a given direction
     void move_selected_stack_dir(int diffx, int diffy);
+    void move_map_dir(int diffx, int diffy);
 
     // centers the map on a city of the active player
     void center_view_on_city();
@@ -180,6 +184,7 @@ class Game
 
     // bigmap callbacks
     void on_stack_selected(Stack* s);
+    void on_stack_grouped_or_ungrouped(Stack *s);
     void on_city_queried (City* c, bool brief);
     void on_ruin_queried (Ruin* r, bool brief);
     void on_temple_queried (Temple* t, bool brief);
@@ -187,7 +192,8 @@ class Game
     void on_stack_queried (Stack* s);
 
     // smallmap callbacks
-    void on_smallmap_changed(SDL_Surface *map);
+    void on_smallmap_changed(Glib::RefPtr<Gdk::Pixmap> map);
+    void on_bigmap_changed(Glib::RefPtr<Gdk::Pixmap> map);
     
     // misc. callbacks
     void invading_city(City* city, int gold);
@@ -196,7 +202,7 @@ class Game
     //! Callback when the army of a human player reaches a new level.
     Army::Stat newLevelArmy(Army* a);
     //! Callback when an army gets a new medal.
-    void newMedalArmy(Army* a);
+    void newMedalArmy(Army* a, int medaltype);
     //! Called whenever a stack has changed, updates the map etc.
     void stackUpdate(Stack* s);
     //! Called whenever players fight
@@ -212,6 +218,9 @@ class Game
     void select_active_stack();
     bool recruitHero(HeroProto *hero, City *city, int gold);
 
+    void on_stack_grouped(Stack *stack, bool grouped);
+    void on_stack_halted(Stack *stack);
+
     GameScenario* d_gameScenario;
     NextTurn* d_nextTurn;
     std::auto_ptr<GameBigMap> bigmap;
