@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
+//  Copyright (C) 2007 Ole Laursen
 //  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,9 +18,9 @@
 
 #include <config.h>
 
-#include <SDL_image.h>
 #include <assert.h>
 #include <stdlib.h>
+#include <glibmm/timeval.h>
 
 #include "gamebigmap.h"
 
@@ -28,16 +28,14 @@
 #include "path.h"
 #include "stacklist.h"
 #include "stack.h"
-#include "citylist.h"
-#include "ruinlist.h"
-#include "signpostlist.h"
-#include "templelist.h"
-#include "roadlist.h"
-#include "bridgelist.h"
+#include "city.h"
 #include "ruin.h"
 #include "signpost.h"
 #include "temple.h"
+#include "roadlist.h"
 #include "road.h"
+#include "bridgelist.h"
+#include "bridge.h"
 #include "playerlist.h"
 #include "File.h"
 #include "GameMap.h"
@@ -46,6 +44,9 @@
 #include "game.h"
 #include "FogMap.h"
 #include "LocationBox.h"
+#include "Configuration.h"
+#include "gui/image-helpers.h"
+#include "PathCalculator.h"
 
 #include "timing.h"
 
@@ -64,6 +65,7 @@ GameBigMap::GameBigMap(bool intense_combat, bool see_opponents_production,
 		       bool see_opponents_stacks, bool military_advisor)
 :d_fighting(LocationBox(Vector<int>(-1,-1)))
 {
+  path_calculator = NULL;
   d_intense_combat = intense_combat;
   d_see_opponents_production = see_opponents_production;
   d_see_opponents_stacks = see_opponents_stacks;
@@ -73,7 +75,7 @@ GameBigMap::GameBigMap(bool intense_combat, bool see_opponents_production,
   mouse_state = NONE;
   input_locked = false;
 
-  d_waypoints = GraphicsLoader::getMiscPicture("waypoints.png");
+  d_waypoint = disassemble_row(File::getMiscFile("various/waypoints.png"), 2);
   prev_mouse_pos = Vector<int>(0, 0);
 
   // setup timeout
@@ -82,11 +84,13 @@ GameBigMap::GameBigMap(bool intense_combat, bool see_opponents_production,
 				      sigc::mem_fun(*this, &GameBigMap::on_selection_timeout),
 				      selection_timeout);
   shift_key_is_down = false;
+  control_key_is_down = false;
 }
 
 GameBigMap::~GameBigMap()
 {
-  SDL_FreeSurface(d_waypoints);
+  if (path_calculator)
+    delete path_calculator;
 }
 
 void GameBigMap::select_active_stack()
@@ -94,11 +98,14 @@ void GameBigMap::select_active_stack()
   Stack* stack = Playerlist::getActiveplayer()->getActivestack();
   if (!stack)
     return;
+  reset_path_calculator(stack);
 
-  if (!stack->getPath()->checkPath(stack))
+  if (stack->getPath()->checkPath(stack) == false)
     {
-      //error handling is required here, up to now we only barf on cerr
+      //original path was blocked, so let's find a new way there.
+      //this shouldn't happen because nextTurn of stack recalculates.
       cerr << "original path of stack was blocked\n";
+      stack->getPath()->recalculate(stack);
     }
 
   stack_selected.emit(stack);
@@ -108,6 +115,12 @@ void GameBigMap::unselect_active_stack()
 {
   draw();
   stack_selected.emit(0);
+  if (path_calculator)
+    {
+      delete path_calculator;
+      path_calculator = NULL;
+    }
+  determine_mouse_cursor(NULL, current_tile);
 }
 
 bool GameBigMap::on_selection_timeout()
@@ -126,41 +139,128 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 
   Player *active = Playerlist::getActiveplayer();
   Vector<int> tile = mouse_pos_to_tile(e.pos);
+  current_tile = tile;
 
   if (e.button == MouseButtonEvent::LEFT_BUTTON
       && e.state == MouseButtonEvent::PRESSED)
     {
+      bool double_clicked = false;
+      static Glib::TimeVal last_clicked;
+      if (last_clicked.as_double() == 0.0)
+	last_clicked.assign_current_time();
+      else
+	{
+	  Glib::TimeVal clicked_now;
+	  clicked_now.assign_current_time();
+	  double click_delta = clicked_now.as_double() - 
+	    last_clicked.as_double();
+	  if (click_delta <= Configuration::s_double_click_threshold / 1000.0)
+	    double_clicked = true;
+	  last_clicked = clicked_now;
+	}
       if (active->getFogMap()->isCompletelyObscuredFogTile(tile) == true)
 	return;
 
       Stack* stack = Playerlist::getActiveplayer()->getActivestack();
 
+      if (d_cursor == GraphicsCache::HAND)
+	return;
+
       if (stack)
 	{
 	  bool path_already_set = stack->getPath()->size() > 0;
 	  // ask for military advice
 	  if (d_cursor == GraphicsCache::QUESTION)
 	    {
+	      set_shift_key_down (false);
 	      Playerlist::getActiveplayer()->stackFightAdvise
 		(stack, tile, d_intense_combat); 
-	      set_shift_key_down (false);
+	      return;
+	    }
+	  else if (d_cursor == GraphicsCache::RUIN)
+	    {
+	      if (Ruin *r = GameMap::getRuin(tile))
+		{
+		  if ((r->isHidden() == true && 
+		       r->getOwner() == Playerlist::getActiveplayer()) ||
+		      r->isHidden() == false)
+		    {
+		      set_shift_key_down (false);
+		      ruin_queried (r, false);
+		    }
+		}
+	      else if (Temple *t = GameMap::getTemple(tile))
+		{
+		  temple_queried (t, false);
+		  set_shift_key_down (false);
+		}
+	      return;
+	    }
+	  else if (d_cursor == GraphicsCache::ROOK)
+	    {
+	      City* c = GameMap::getCity(tile);
+	      if (c != NULL)
+		{
+		  if (!c->isBurnt())
+		    {
+		      set_control_key_down (false);
+		      if (d_see_opponents_production == true)
+			{
+			  city_queried (c, false);
+			  set_shift_key_down (false);
+			  return;
+			}
+		      else
+			{
+			  if (c->getOwner() == Playerlist::getActiveplayer())
+			    {
+			      city_queried (c, false);
+			      set_shift_key_down (false);
+			      return;
+			    }
+			}
+		    }
+		}
+	    }
+	  else if (d_cursor == GraphicsCache::GOTO_ARROW)
+	    {
+	      //set in a course, mr crusher.
+	      stack->getPath()->calculate(stack, tile);
+	      path_set.emit();
+	      draw();
 	      return;
 	    }
 	  Vector<int> p;
 	  p.x = tile.x; p.y = tile.y;
 
 	  // clicked on the already active stack
-	  if (stack->getPos().x == tile.x && stack->getPos().y == tile.y)
+	  if (stack->getPos() == tile)
 	    {
-	      // clear the path
-	      stack->getPath()->flClear();
-	      path_set.emit();
-	      draw();
-	      return;
+	      if (double_clicked == true)
+		{
+		  if (stack->isGrouped() == true)
+		    stack->ungroup();
+		  else
+		    stack->group();
+		  if (path_calculator)
+		    delete path_calculator;
+		  path_calculator = new PathCalculator(stack);
+		  draw();
+		  stack_grouped_or_ungrouped.emit(stack);
+		  return;
+		}
+	      else
+		{
+		  // clear the path
+		  stack->getPath()->clear();
+		  path_set.emit();
+		  draw();
+		  return;
+		}
 	    }
 
 	  //clicked on an enemy city that is too far away
-	  City *c = Citylist::getInstance()->getObjectAt(tile);
+	  City *c = GameMap::getCity(tile);
 	  if (c)
 	    {
 	      //restrict going into enemy cities unless they're only
@@ -182,11 +282,11 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 	  if (dist == -2)
 	    cerr << "error calculating path!";
 
-	  Vector<int>* dest = 0;
+	  Vector<int> dest = Vector<int>(-1,-1);
 	  if (!stack->getPath()->empty())
-	    dest = *stack->getPath()->rbegin();
+	    dest = stack->getLastPointInPath();
 
-	  if (dest && dest->x == tile.x && dest->y == tile.y)
+	  if (dest.x == tile.x && dest.y == tile.y)
 	    {
 	      Playerlist::getActiveplayer()->stackMove(stack);
 	      if (!Playerlist::getActiveplayer()->getActivestack())
@@ -250,35 +350,44 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
       // Stack hasn't been active yet
       else
 	{
-	  stack = Stacklist::getObjectAt(tile.x, tile.y);
-	  if (stack && stack->isFriend(Playerlist::getActiveplayer()))
+	  stack = GameMap::getStack(tile);
+	  if (stack && stack->isFriend(Playerlist::getActiveplayer()) && 
+	      d_cursor == GraphicsCache::TARGET)
 	    {
 	      Playerlist::getActiveplayer()->getStacklist()->setActivestack(stack);
 	      select_active_stack();
 	    }
 	  else
 	    {
-	      if (City* c = Citylist::getInstance()->getObjectAt(tile))
+	      City* c = GameMap::getCity(tile);
+	      if (c != NULL && d_cursor == GraphicsCache::ROOK)
 		{
 		  if (!c->isBurnt())
 		    {
+		      set_control_key_down (false);
 		      if (d_see_opponents_production == true)
-			city_queried (c, false);
+			{
+			  city_queried (c, false);
+			  set_shift_key_down (false);
+			}
 		      else
 			{
 			  if (c->getOwner() == Playerlist::getActiveplayer())
-			    city_queried (c, false);
+			    {
+			      city_queried (c, false);
+			      set_shift_key_down (false);
+			    }
 			}
 		    }
 		}
-	      else if (Ruin *r = Ruinlist::getInstance()->getObjectAt(tile))
+	      else if (Ruin *r = GameMap::getRuin(tile))
 		{
 		  if ((r->isHidden() == true && 
 		       r->getOwner() == Playerlist::getActiveplayer()) ||
 		      r->isHidden() == false)
 		    ruin_queried (r, false);
 		}
-	      else if (Temple *t = Templelist::getInstance()->getObjectAt(tile))
+	      else if (Temple *t = GameMap::getTemple(tile))
 		{
 		  temple_queried (t, false);
 		}
@@ -288,7 +397,14 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
   else if (e.button == MouseButtonEvent::LEFT_BUTTON
       && e.state == MouseButtonEvent::RELEASED)
     {
-      if (mouse_state == DRAGGING_STACK)
+      if (mouse_state == DRAGGING_ENDPOINT)
+	{
+	  mouse_state = NONE;
+	  d_cursor = GraphicsCache::FEET;
+	  cursor_changed.emit(d_cursor);
+	  path_set.emit();
+	}
+      else if (mouse_state == DRAGGING_STACK)
 	{
 	  Stack* stack = Playerlist::getActiveplayer()->getActivestack();
 	  //march a dragged stack!
@@ -305,7 +421,7 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 	      if (mouse_pos_to_tile(e.pos) != stack->getPos())
 		{
 		  int ts = GameMap::getInstance()->getTileset()->getTileSize();
-		  e.pos = tile_to_buffer_pos (*stack->getPath()->back());
+		  e.pos = tile_to_buffer_pos (stack->getLastPointInPath());
 		  e.pos.x -= ts/2;
 		  e.pos.y -= ts/2;
 		  mouse_button_event(e);
@@ -325,12 +441,12 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 	{
 	  if (active->getFogMap()->isCompletelyObscuredFogTile(tile) == true)
 	    return;
-	  if (City* c = Citylist::getInstance()->getObjectAt(tile))
+	  if (City* c = GameMap::getCity(tile))
 	    {
 	      city_queried (c, true);
 	      mouse_state = SHOWING_CITY;
 	    }
-	  else if (Ruin* r = Ruinlist::getInstance()->getObjectAt(tile))
+	  else if (Ruin* r = GameMap::getRuin(tile))
 	    {
 	      if ((r->isHidden() == true && 
 		   r->getOwner() == Playerlist::getActiveplayer()) ||
@@ -340,17 +456,17 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 		  mouse_state = SHOWING_RUIN;
 		}
 	    }
-	  else if (Signpost* s = Signpostlist::getInstance()->getObjectAt(tile))
+	  else if (Signpost* s = GameMap::getSignpost(tile))
 	    {
 	      signpost_queried (s);
 	      mouse_state = SHOWING_SIGNPOST;
 	    }
-	  else if (Temple* t = Templelist::getInstance()->getObjectAt(tile))
+	  else if (Temple* t = GameMap::getTemple(tile))
 	    {
 	      temple_queried.emit(t, true);
 	      mouse_state = SHOWING_TEMPLE;
 	    }
-	  else if (Stack *st = Stacklist::getObjectAt(tile))
+	  else if (Stack *st = GameMap::getStack(tile))
 	    {
 	      if (d_see_opponents_stacks == true)
 		{
@@ -370,13 +486,6 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 	  switch(mouse_state)
 	    {
 
-	    case DRAGGING_STACK:
-	      //no-op
-	      break;
-
-	    case DRAGGING_MAP:
-	      break;
-
 	    case SHOWING_CITY:
 	      city_queried.emit(0, true);
 	      break;
@@ -397,12 +506,17 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
 	      stack_queried.emit(0);
 	      break;
 
+	    case DRAGGING_ENDPOINT:
+	    case DRAGGING_STACK:
+	    case DRAGGING_MAP:
 	    case NONE:
 	      Stack* stack = Playerlist::getActiveplayer()->getActivestack();
 	      if (stack)
 		{
 		  Playerlist::getActiveplayer()->getStacklist()->setActivestack(0);
 		  unselect_active_stack();
+		  mouse_state = NONE;
+		  determine_mouse_cursor(NULL, current_tile);
 		}
 	      break;
 	    }
@@ -413,11 +527,11 @@ void GameBigMap::mouse_button_event(MouseButtonEvent e)
     }
   else if (e.button == MouseButtonEvent::WHEEL_UP)
     {
-      zoom_in();
+      //zoom_in();
     }
   else if (e.button == MouseButtonEvent::WHEEL_DOWN)
     {
-      zoom_out();
+      //zoom_out();
     }
 }
 
@@ -427,12 +541,11 @@ void GameBigMap::zoom_in()
     return;
   if ((zoom_step / 100.0) + magnification_factor <= max_magnification_factor / 100.0)
     {
-      SDL_Surface *v = SDL_GetVideoSurface();
       int ts = GameMap::getInstance()->getTileset()->getTileSize();
       Rectangle new_view;
       double mag = magnification_factor + (zoom_step / 100.0);
-      new_view.w = v->w / (ts * mag) + 1;
-      new_view.h = v->h / (ts * mag) + 1;
+      new_view.w = image.get_width() / (ts * mag) + 1;
+      new_view.h = image.get_height() / (ts * mag) + 1;
       if (new_view.w <= GameMap::getWidth() && 
 	  new_view.h <= GameMap::getHeight() && 
 	  new_view.w >= 0 && new_view.h >= 0)
@@ -446,12 +559,11 @@ void GameBigMap::zoom_out()
     return;
   if (magnification_factor - (zoom_step / 100.0) >= min_magnification_factor / 100.0)
     {
-      SDL_Surface *v = SDL_GetVideoSurface();
       int ts = GameMap::getInstance()->getTileset()->getTileSize();
       Rectangle new_view;
       double mag = magnification_factor - (zoom_step / 100.0);
-      new_view.w = v->w / (ts * mag) + 1;
-      new_view.h = v->h / (ts * mag) + 1;
+      new_view.w = image.get_width() / (ts * mag) + 1;
+      new_view.h = image.get_height() / (ts * mag) + 1;
       if (new_view.w <= GameMap::getWidth() && 
 	  new_view.h <= GameMap::getHeight() && 
 	  new_view.w >= 0 && new_view.h >= 0)
@@ -466,7 +578,10 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
     {
       d_cursor = GraphicsCache::HAND;
     }
-  else if (stack && mouse_state == DRAGGING_STACK)
+  else if (mouse_state == DRAGGING_MAP)
+    d_cursor = GraphicsCache::HAND;
+  else if (stack && 
+	   (mouse_state == DRAGGING_STACK || mouse_state == DRAGGING_ENDPOINT))
     {
       d_cursor = GraphicsCache::GOTO_ARROW;
     }
@@ -477,7 +592,7 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 	d_cursor = GraphicsCache::TARGET;
       else
 	{
-	  City *c = Citylist::getInstance()->getObjectAt(tile);
+	  City *c = GameMap::getCity(tile);
 	  if (c)
 	    {
 	      if (c->getOwner() == active)
@@ -518,7 +633,7 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 	  else
 	    {
 	      Maptile *t = GameMap::getInstance()->getTile(tile);
-	      Stack *st = Stacklist::getObjectAt(tile);
+	      Stack *st = GameMap::getStack(tile);
 	      if (st && st->getOwner() != active)
 		{
 		  int delta = abs(stack->getPos().x - st->getPos().x);
@@ -545,15 +660,20 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 		}
 	      else
 		{
-		  Path path;
-		  int moves = path.calculate(stack, tile);
-		  if (moves == 0)
+		  //Path path;
+		  //why is this slower than without a stack selected?
+		  //because we need to see if we can get there eventually!
+
+		  //int moves = path.calculate(stack, tile);
+		  if (path_calculator == NULL)
+		    path_calculator = new PathCalculator(stack);
+		  if (path_calculator->isReachable(tile) == false)
+		  //if (moves == 0)
 		    d_cursor = GraphicsCache::HAND;
 		  else
 		    {
-		      Bridgelist *bl = Bridgelist::getInstance();
 		      if (t->getMaptileType() == Tile::WATER &&
-			  bl->getObjectAt(tile) == NULL)
+			  GameMap::getBridge(tile) == NULL)
 			{
 			  if (stack->isFlying() == true)
 			    d_cursor = GraphicsCache::FEET;
@@ -565,6 +685,8 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 		    }
 		}
 	    }
+	  if (d_cursor == GraphicsCache::FEET && is_control_key_down())
+	    d_cursor = GraphicsCache::GOTO_ARROW;
 	}
     }
   else
@@ -585,7 +707,7 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 	  Maptile *t = GameMap::getInstance()->getTile(tile);
 	  if (t->getBuilding() == Maptile::CITY)
 	    {
-	      City *c = Citylist::getInstance()->getObjectAt(tile);
+	      City *c = GameMap::getCity(tile);
 	      if (c->isBurnt() == true)
 		d_cursor = GraphicsCache::HAND;
 	      else if (c->getOwner() == active)
@@ -595,7 +717,7 @@ void GameBigMap::determine_mouse_cursor(Stack *stack, Vector<int> tile)
 	    }
 	  else if (t->getBuilding() == Maptile::RUIN)
 	    {
-	      Ruin *ruin = Ruinlist::getInstance()->getObjectAt(tile);
+	      Ruin *ruin = GameMap::getRuin(tile);
 	      if (ruin->isHidden() == true && ruin->getOwner() == active)
 		d_cursor = GraphicsCache::RUIN;
 	      else if (ruin->isHidden() == false)
@@ -619,6 +741,7 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
   Player *active = Playerlist::getActiveplayer();
   Stack* stack = active->getActivestack();
   Vector<int> tile = mouse_pos_to_tile(e.pos);
+  current_tile = tile;
   if (tile.x < 0)
     tile.x = 0;
   if (tile.y < 0)
@@ -631,13 +754,19 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 
   if (e.pressed[MouseMotionEvent::LEFT_BUTTON]
       && (mouse_state == NONE || mouse_state == SHOWING_STACK) && 
-      stack && stack->getPos() == tile && active->getFogMap()->isCompletelyObscuredFogTile(tile) == false)
+      stack && stack->getPos() == tile && active->getFogMap()->isCompletelyObscuredFogTile(tile) == false && d_cursor != GraphicsCache::HAND)
     {
-      //initial drag
+      //initial dragging of stack from it's tile
       mouse_state = DRAGGING_STACK;
     }
+  else if (e.pressed[MouseMotionEvent::LEFT_BUTTON] && stack &&
+	   d_cursor == GraphicsCache::GOTO_ARROW && mouse_state == NONE)
+    {
+      //initial dragging of endpoint from it's tile
+      mouse_state = DRAGGING_ENDPOINT;
+    }
   else if (e.pressed[MouseMotionEvent::LEFT_BUTTON]
-	   && (mouse_state == NONE || mouse_state == DRAGGING_MAP) && !stack)
+	   && (mouse_state == NONE || mouse_state == DRAGGING_MAP) && d_cursor == GraphicsCache::HAND)
     {
       Vector<int> delta = -(e.pos - prev_mouse_pos);
 
@@ -647,8 +776,7 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 	return;
 
       int ts = GameMap::getInstance()->getTileset()->getTileSize();
-      SDL_Surface *screen = SDL_GetVideoSurface();
-      Vector<int> screen_dim(screen->w, screen->h);
+      Vector<int> screen_dim(image.get_width(), image.get_height());
       view_pos = clip(Vector<int>(0, 0),
 		      view_pos + delta,
 		      GameMap::get_dim() * ts *magnification_factor - screen_dim);
@@ -656,17 +784,18 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
       // calculate new view position in tiles, rounding up
       Vector<int> new_view = (view_pos + Vector<int>(ts * magnification_factor - 1, ts * magnification_factor - 1)) / (ts * magnification_factor);
 
-      bool redraw_buffer = false;
-
       if (new_view != view.pos)
 	{
+	  //here we have a case of the new view overlapping with the view.
+	  //why redraw what we've already drawn?
+	  Rectangle old_view = view;
 	  view.x = new_view.x;
 	  view.y = new_view.y;
 	  view_changed.emit(view);
-	  redraw_buffer = true;
+	  draw(true);
 	}
-
-      draw(redraw_buffer);
+      else
+	draw(false);
       mouse_state = DRAGGING_MAP;
     }
 
@@ -679,7 +808,7 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 
   // drag stack with left mouse button
   if (e.pressed[MouseMotionEvent::LEFT_BUTTON]
-      && (mouse_state == DRAGGING_STACK) && 
+      && (mouse_state == DRAGGING_STACK || mouse_state == DRAGGING_ENDPOINT) && 
       active->getFogMap()->isCompletelyObscuredFogTile(tile) == false)
     {
       //subsequent dragging
@@ -702,19 +831,31 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 	  set_view (new_view);
 	  view_changed.emit(view);
 	}
+      mouse_state_enum orig_state = mouse_state;
       mouse_state = NONE;
       determine_mouse_cursor(stack, tile);
-      mouse_state = DRAGGING_STACK;
+      mouse_state = orig_state;
       if (d_cursor == GraphicsCache::FEET ||
 	  d_cursor == GraphicsCache::SHIP || 
+	  d_cursor == GraphicsCache::GOTO_ARROW || 
 	  d_cursor == GraphicsCache::TARGET)
 	{
-	  stack->getPath()->calculate(stack, tile);
+	  guint32 moves = 0, turns = 0;
+	  Path *new_path = path_calculator->calculate(tile, moves, turns, true);
+	  if (new_path->size())
+	    stack->setPath(*new_path);
+	  delete new_path;
+	  //stack->getPath()->calculate(stack, tile);
+	  path_set.emit();
 	  draw();
 	}
     }
 
   determine_mouse_cursor (stack, tile);
+  if (control_key_is_down == true)
+    set_control_key_down (true);
+  if (shift_key_is_down == true)
+    set_shift_key_down (true);
 
   prev_mouse_pos = e.pos;
   last_tile = tile;
@@ -723,7 +864,7 @@ void GameBigMap::mouse_motion_event(MouseMotionEvent e)
 void GameBigMap::reset_zoom()
 {
   magnification_factor = 1.0;
-  screen_size_changed();
+  screen_size_changed(image);
   draw(true);
   view_changed.emit(view);
 }
@@ -736,7 +877,7 @@ void GameBigMap::zoom_view(double percent)
   //new_view.dim += Vector<int>(tiles, tiles);
   //new_view.pos += Vector<int>(tiles*-1/2, tiles*-1/2);
   //set_view (new_view);
-  screen_size_changed();
+  screen_size_changed(image);
   draw(true);
   view_changed.emit(view);
 }
@@ -753,61 +894,39 @@ void GameBigMap::after_draw()
       stack->getOwner()->getType() == Player::HUMAN)
     {
       Vector<int> pos;
-      SDL_Color c;
-      c.r = c.g = c.b = 0;
 
       // draw all waypoints
-      Uint32 pathcount = 0;
+      guint32 pathcount = 0;
       bool canMoveThere = true;
-      list<Vector<int>*>::iterator end = stack->getPath()->end();
+      Path::iterator end = stack->getPath()->end();
       //if we're dragging, we don't draw the last waypoint circle
-      if (stack->getPath()->size() > 0 && mouse_state == DRAGGING_STACK)
+      if (stack->getPath()->size() > 0 && 
+	  (mouse_state == DRAGGING_STACK || mouse_state == DRAGGING_ENDPOINT))
 	end--;
-      for (list<Vector<int>*>::iterator it = stack->getPath()->begin();
+      for (Path::iterator it = stack->getPath()->begin();
 	   it != end; it++)
 	{
-	  size_t wpsize = 40; //waypoint images are always 40x40
-	  pos = tile_to_buffer_pos(**it);
-	  SDL_Rect r1, r2;
-	  r1.y = 0;
-	  r1.w = r1.h = wpsize; 
-	  int offset = (tilesize - wpsize) / 2;
-	  if (offset < 0)
-	    offset = 0;
-	  r2.x = pos.x + offset;
-	  r2.y = pos.y + offset;
-	  r2.w = r2.h = wpsize;
+	  pos = tile_to_buffer_pos(*it);
 
 	  canMoveThere = (pathcount < stack->getPath()->getMovesExhaustedAtPoint());
 	  if (canMoveThere)
-	    r1.x = 0;
+	    d_waypoint[0]->blit_centered(buffer, pos + (Vector<int>(tilesize,tilesize)/2));
 	  else
-	    r1.x = wpsize;
+	    d_waypoint[1]->blit_centered(buffer, pos + (Vector<int>(tilesize,tilesize)/2));
 
-	  SDL_BlitSurface(d_waypoints, &r1, buffer, &r2);
 	  pathcount++;
 
 	}
 
-      if (mouse_state == DRAGGING_STACK)
+      if (mouse_state == DRAGGING_STACK || mouse_state == DRAGGING_ENDPOINT 
+	  || d_cursor == GraphicsCache::GOTO_ARROW)
 	{
-	  list<Vector<int>*>::iterator it = stack->getPath()->end();
+	  Path::iterator it = stack->getPath()->end();
 	  it--;
 	  //this is where the ghosted army unit picture goes.
-	  Army *a = *stack->begin();
-	  SDL_Surface *tmp = gc->getArmyPic(a);
-	  size_t wpsize = tmp->w;
-	  pos = tile_to_buffer_pos(**it);
-	  SDL_Rect r1, r2;
-	  r1.y = 0;
-	  r1.w = r1.h = tmp->w; 
-	  int offset = (tilesize - tmp->w) / 2;
-	  if (offset < 0)
-	    offset = 0;
-	  r2.x = pos.x + offset;
-	  r2.y = pos.y + offset;
-	  r2.w = r2.h = wpsize;
-	  SDL_BlitSurface(tmp, 0, buffer, &r2);
+	  PixMask *armypic = gc->getArmyPic(*stack->begin(), true);
+	  pos = tile_to_buffer_pos(*it);
+	  armypic->blit_centered(buffer, pos + (Vector<int>(tilesize,tilesize)/2));
 	}
     }
 
@@ -821,20 +940,16 @@ void GameBigMap::after_draw()
 	  static int bigframe = -1;
 	  static int smallframe = -1;
 
+	  Tileset *t = GameMap::getInstance()->getTileset();
 	  bigframe++;
-	  if (bigframe >= (int)gc->getNumberOfLargeSelectorFrames())
+	  if (bigframe >= (int)t->getNumberOfSelectorFrames())
 	    bigframe = 0;
 
 	  smallframe++;
-	  if (smallframe >= (int)gc->getNumberOfSmallSelectorFrames())
+	  if (smallframe >= (int)t->getNumberOfSmallSelectorFrames())
 	    smallframe = 0;
 
 	  p = tile_to_buffer_pos(p);
-	  SDL_Rect r;
-	  r.x = p.x;
-	  r.y = p.y;
-	  r.w = r.h = tilesize;
-	  SDL_Surface *tmp;
 	  int num_selected = 0;
 	  for (Stack::iterator it = stack->begin(); it != stack->end(); it++)
 	    {
@@ -842,15 +957,16 @@ void GameBigMap::after_draw()
 		num_selected++;
 	    }
 
-	  draw_stack (stack);
+	  draw_stack (stack, buffer, buffer_gc);
 
 	  if (input_locked == false)
 	    {
+	      PixMask *tmp = NULL;
 	      if (num_selected > 1)
 		tmp = gc->getSelectorPic(0, bigframe, stack->getOwner());
 	      else
 		tmp = gc->getSelectorPic(1, smallframe, stack->getOwner());
-	      SDL_BlitSurface(tmp, 0, buffer, &r);
+	      tmp->blit(buffer, p);
 	    }
 	}
     }
@@ -858,54 +974,158 @@ void GameBigMap::after_draw()
   if (d_fighting.getPos() != Vector<int>(-1,-1))
     {
       Vector<int> p = tile_to_buffer_pos(d_fighting.getPos());
-      SDL_Rect r;
-      r.x = p.x;
-      r.y = p.y;
-      r.w = r.h = tilesize * d_fighting.getSize();
-      SDL_Surface *tmp = gc->getExplosionPic();
-      SDL_SetAlpha(tmp, 0, 0);
-      SDL_PixelFormat* fmt = tmp->format;
-      SDL_Surface *explode = SDL_CreateRGBSurface
-	(SDL_SWSURFACE, d_fighting.getSize() * tilesize, 
-	 d_fighting.getSize() * tilesize,
-       fmt->BitsPerPixel, fmt->Rmask, fmt->Gmask, fmt->Bmask, fmt->Amask);
-      SDL_SoftStretch(tmp, 0, explode, 0);
-      SDL_BlitSurface(explode, 0, buffer, &r);
-      SDL_FreeSurface(explode);
+      PixMask *tmp = gc->getExplosionPic()->copy();
+      if (d_fighting.getSize() > 1)
+	{
+	  PixMask::scale(tmp, d_fighting.getSize() * tilesize,
+			 d_fighting.getSize() * tilesize);
+	}
+      tmp->blit(buffer, p);
+      delete tmp;
+    }
+}
+
+void GameBigMap::set_control_key_down (bool down)
+{
+  control_key_is_down = down;
+  Player *active = Playerlist::getActiveplayer();
+  if (active->getFogMap()->isCompletelyObscuredFogTile(current_tile) == true)
+    return;
+  Stack* active_stack = active->getActivestack();
+  //if the key has been released, just show what we'd normally show.
+  if (control_key_is_down == false)
+    {
+      determine_mouse_cursor(active_stack, current_tile);
+      return;
+    }
+  if (!active_stack)
+    {
+      if (GameMap::getInstance()->getTile(current_tile)->getBuilding() != 
+	  Maptile::CITY)
+	return;
+
+      Stack* stack;
+      stack = Playerlist::getActiveplayer()->getStacklist()->getObjectAt(current_tile);
+      if (!stack)
+	return;
+
+      if (d_cursor == GraphicsCache::TARGET)
+	{
+	  City *city = GameMap::getCity(current_tile);
+	  if (city->isBurnt() == false)
+	    {
+	      d_cursor = GraphicsCache::ROOK;
+	      cursor_changed.emit(d_cursor);
+	    }
+	}
+      else if (d_cursor == GraphicsCache::HAND && 
+	       d_see_opponents_production == true)
+	{
+	  City *city = GameMap::getCity(current_tile);
+	  if (city->isBurnt() == false)
+	    {
+	      d_cursor = GraphicsCache::ROOK;
+	      cursor_changed.emit(d_cursor);
+	    }
+	}
+    }
+  else
+    {
+      if (d_cursor == GraphicsCache::FEET)
+	{
+	  d_cursor = GraphicsCache::GOTO_ARROW;
+	  cursor_changed.emit(d_cursor);
+	}
     }
 }
 
 void GameBigMap::set_shift_key_down (bool down)
 {
-  if (d_military_advisor == false)
-    return;
-  static GraphicsCache::CursorType prev_cursor = GraphicsCache::HEART;
+  shift_key_is_down = down;
+  Player *active = Playerlist::getActiveplayer();
+  if (active->getFogMap()->isCompletelyObscuredFogTile(current_tile) == true)
+      return;
 
-  Stack* stack = Playerlist::getActiveplayer()->getActivestack();
-  if (!stack)
-    return;
+  Stack* active_stack = active->getActivestack();
 
-  if (d_cursor == GraphicsCache::HEART ||
-      d_cursor == GraphicsCache::SWORD)
+  //if the key has been released, just show what we'd normally show.
+  if (shift_key_is_down == false)
     {
-      if (shift_key_is_down == false)
+      determine_mouse_cursor(active_stack, current_tile);
+      return;
+    }
+
+  //otherwise the shift key is down and we need to do some more checking
+  Maptile::Building b = GameMap::getInstance()->getTile(current_tile)->getBuilding();
+  if (b == Maptile::RUIN)
+    {
+      Ruin *r = GameMap::getRuin(current_tile);
+      if (r)
 	{
-	  shift_key_is_down = down;
-	  prev_cursor = d_cursor;
-	  d_cursor = GraphicsCache::QUESTION;
+	  if ((r->isHidden() == true && 
+	       r->getOwner() == Playerlist::getActiveplayer()) ||
+	      r->isHidden() == false)
+	    b = Maptile::RUIN;
+	  else
+	    b = Maptile::NONE;
+	}
+    }
+  else if (b == Maptile::CITY)
+    {
+      if (d_cursor == GraphicsCache::TARGET)
+	{
+	  d_cursor = GraphicsCache::ROOK;
+	  cursor_changed.emit(d_cursor);
+	}
+      else if (d_cursor == GraphicsCache::FEET)
+	{
+	  d_cursor = GraphicsCache::ROOK;
+	  cursor_changed.emit(d_cursor);
+	}
+      else if (d_cursor == GraphicsCache::HAND &&
+	       d_see_opponents_production == true)
+	{
+	  d_cursor = GraphicsCache::ROOK;
 	  cursor_changed.emit(d_cursor);
 	}
     }
-  else if (d_cursor == GraphicsCache::QUESTION)
+
+  if (active_stack)
     {
-      if (shift_key_is_down == true)
+      if (d_cursor == GraphicsCache::SHIP || d_cursor == GraphicsCache::FEET) 
 	{
-	  shift_key_is_down = down;
-	  d_cursor = prev_cursor;
+	  if (b == Maptile::RUIN || b == Maptile::TEMPLE)
+	    d_cursor = GraphicsCache::RUIN;
+	  else
+	    d_cursor = GraphicsCache::HAND;
 	  cursor_changed.emit(d_cursor);
 	}
     }
   else
-    shift_key_is_down = down;
-}
+    {
+      if (d_cursor != GraphicsCache::RUIN)
+	{
+	  if (b == Maptile::RUIN || b == Maptile::TEMPLE)
+	    {
+	      d_cursor = GraphicsCache::RUIN;
+	      cursor_changed.emit(d_cursor);
+	    }
+	}
+    }
 
+  if (d_military_advisor == true)
+    {
+      if (active_stack && d_cursor == GraphicsCache::SWORD)
+	{
+	      d_cursor = GraphicsCache::QUESTION;
+	      cursor_changed.emit(d_cursor);
+	}
+    }
+}
+    
+void GameBigMap::reset_path_calculator(Stack *s)
+{
+  if (path_calculator)
+    delete path_calculator;
+  path_calculator = new PathCalculator(s);
+}
