@@ -1,9 +1,9 @@
 //  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -28,12 +28,14 @@
 #include "GraphicsCache.h"
 #include "bigmap.h"
 #include "LocationBox.h"
+#include "PixMask.h"
 
 class Stack;
 class City;
 class Ruin;
 class Signpost;
 class Temple;
+class PathCalculator;
 
 /** Specialization of BigMap for the game (as opposed to the editor)
   */
@@ -50,13 +52,16 @@ class GameBigMap: public BigMap
     void mouse_button_event(MouseButtonEvent e);
     void mouse_motion_event(MouseMotionEvent e);
     void set_shift_key_down (bool down);
-    bool is_shift_key_down () const {return shift_key_is_down;}
+    bool is_shift_key_down () const {return control_key_is_down;}
+    void set_control_key_down (bool down);
+    bool is_control_key_down () const {return control_key_is_down;}
 
     // whether the map accepts input events
     void set_input_locked(bool locked) { input_locked = locked; }
 
     // signals for mouse clicks, deselect is signified with a null pointer
     sigc::signal<void, Stack*> stack_selected;
+    sigc::signal<void, Stack*> stack_grouped_or_ungrouped;
     sigc::signal<void, City*, bool> city_queried; // true => show brief info
     sigc::signal<void, Ruin*, bool> ruin_queried; //true => show brief info
     sigc::signal<void, Signpost*> signpost_queried;
@@ -80,18 +85,25 @@ class GameBigMap: public BigMap
     static const double max_magnification_factor = 200.0;
     static const double min_magnification_factor = 50.0;
 
+    void reset_path_calculator(Stack *s);
+
+    bool d_intense_combat; 
+    bool d_see_opponents_production;
+    bool d_see_opponents_stacks;
+    bool d_military_advisor;
  private:
-    SDL_Surface* d_waypoints;
+    std::vector<PixMask*> d_waypoint;
     Vector<int> current_tile, prev_mouse_pos;
     
     bool input_locked;
 	
-    enum {
+    enum mouse_state_enum {
 	NONE, DRAGGING_MAP, SHOWING_CITY, SHOWING_RUIN,
 	SHOWING_TEMPLE, SHOWING_SIGNPOST, SHOWING_STACK,
-	DRAGGING_STACK
+	DRAGGING_STACK, DRAGGING_ENDPOINT
     } mouse_state;
     bool shift_key_is_down;
+    bool control_key_is_down;
 	
     GraphicsCache::CursorType d_cursor;
     void determine_mouse_cursor(Stack *stack, Vector<int> tile);
@@ -102,11 +114,8 @@ class GameBigMap: public BigMap
     void zoom_view(double percent);
 
     virtual void after_draw();
-    bool d_intense_combat; 
-    bool d_see_opponents_production;
-    bool d_see_opponents_stacks;
-    bool d_military_advisor;
     LocationBox d_fighting;
+    PathCalculator *path_calculator;
 };
 
 #endif
