@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,9 +18,7 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/image.h>
-#include <gtkmm/label.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
 
 #include "army-gains-level-dialog.h"
@@ -38,19 +36,21 @@ ArmyGainsLevelDialog::ArmyGainsLevelDialog(Army *a, bool show_sight_stat)
     GraphicsCache *gc = GraphicsCache::getInstance();
     army = a;
     
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/army-gains-level-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/army-gains-level-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
     
     Gtk::Image *image;
     xml->get_widget("image", image);
-    image->property_pixbuf() = to_pixbuf(gc->getArmyPic(army));
+    image->property_pixbuf() = gc->getArmyPic(army)->to_pixbuf();
+    Gtk::Image *hero_image;
+    xml->get_widget("hero_image", hero_image);
+    hero_image->property_pixbuf() = 
+      gc->getNewLevelPic(Playerlist::getActiveplayer())->to_pixbuf();
     
     Gtk::Label *label;
     xml->get_widget("label", label);
@@ -74,6 +74,11 @@ ArmyGainsLevelDialog::ArmyGainsLevelDialog(Army *a, bool show_sight_stat)
     on_stat_toggled();
 }
 
+ArmyGainsLevelDialog::~ArmyGainsLevelDialog()
+{
+  delete dialog;
+}
+
 void ArmyGainsLevelDialog::set_parent_window(Gtk::Window &parent)
 {
     dialog->set_transient_for(parent);
