@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -22,9 +22,7 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/box.h>
-#include <gtkmm/radiobutton.h>
+#include <gtkmm.h>
 
 #include "army.h"
 
@@ -34,6 +32,7 @@ class ArmyGainsLevelDialog: public Decorated
 {
  public:
     ArmyGainsLevelDialog(Army *army, bool show_sight_stat);
+    ~ArmyGainsLevelDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -43,7 +42,7 @@ class ArmyGainsLevelDialog: public Decorated
     Army::Stat get_selected_stat() { return selected_stat; }
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
     Gtk::VBox *stats_vbox;
 
     Army *army;
