@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,9 +18,7 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/image.h>
-#include <gtkmm/label.h>
+#include <gtkmm.h>
 
 #include "army-info-tip.h"
 
@@ -35,17 +33,20 @@
 #include "armyproto.h"
 #include "GraphicsCache.h"
 #include "playerlist.h"
+#include "city.h"
+#include "decorated.h"
+#include "File.h"
 
 
 ArmyInfoTip::ArmyInfoTip(Gtk::Widget *target, const Army *army)
 {
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/army-info-window.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/army-info-window.ui");
 
-    Gtk::Window *w = 0;
-    xml->get_widget("window", w);
-    window.reset(w);
+    xml->get_widget("window", window);
+    Decorated decorator;
+    decorator.decorate(window,File::getMiscFile("various/background.png"), 200);
 
     Gtk::Image *army_image;
     xml->get_widget("army_image", army_image);
@@ -54,15 +55,14 @@ ArmyInfoTip::ArmyInfoTip(Gtk::Widget *target, const Army *army)
     p = army->getOwner();
     armyset = army->getArmyset();
     GraphicsCache *gc = GraphicsCache::getInstance();
-    army_image->property_pixbuf() = to_pixbuf (gc->getArmyPic(armyset, 
-							      army->getTypeId(), 
-							      p, NULL));
+    army_image->property_pixbuf() = 
+      gc->getArmyPic(armyset, army->getTypeId(), p, 
+		     army->getMedalBonuses())->to_pixbuf();
 
     // fill in terrain image
     Gtk::Image *terrain_image;
     xml->get_widget("terrain_image", terrain_image);
-    SDL_Surface *terrain = gc->getMoveBonusPic(army->getMoveBonus(), false);
-    terrain_image->property_pixbuf() = to_pixbuf(terrain);
+    terrain_image->property_pixbuf() = gc->getMoveBonusPic(army->getMoveBonus(), false)->to_pixbuf();
     //terrain_image->hide();
 
     // fill in info
@@ -102,31 +102,30 @@ ArmyInfoTip::ArmyInfoTip(Gtk::Widget *target, const Army *army)
     window->show();
 }
 
-ArmyInfoTip::ArmyInfoTip(Gtk::Widget *target, const ArmyProdBase *army)
+ArmyInfoTip::ArmyInfoTip(Gtk::Widget *target, const ArmyProdBase *army, 
+			 City *city)
 {
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/army-info-window.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/army-info-window.ui");
 
-    Gtk::Window *w = 0;
-    xml->get_widget("window", w);
-    window.reset(w);
+    xml->get_widget("window", window);
+    Decorated decorator;
+    decorator.decorate(window,File::getMiscFile("various/background.png"), 200);
 
     Gtk::Image *army_image;
     xml->get_widget("army_image", army_image);
-    Player *p = Playerlist::getInstance()->getActiveplayer();
+    Player *p = city->getOwner();
     int armyset;
     armyset = army->getArmyset();
     GraphicsCache *gc = GraphicsCache::getInstance();
-    army_image->property_pixbuf() = to_pixbuf (gc->getArmyPic(armyset, 
-							      army->getTypeId(), 
-							      p, NULL));
+    army_image->property_pixbuf() = gc->getArmyPic(armyset, army->getTypeId(), 
+						   p, NULL)->to_pixbuf();
 
     // fill in terrain image
     Gtk::Image *terrain_image;
     xml->get_widget("terrain_image", terrain_image);
-    SDL_Surface *terrain = gc->getMoveBonusPic(army->getMoveBonus(), false);
-    terrain_image->property_pixbuf() = to_pixbuf(terrain);
+    terrain_image->property_pixbuf() = gc->getMoveBonusPic(army->getMoveBonus(), false)->to_pixbuf();
     //terrain_image->hide();
 
     // fill in info
@@ -168,13 +167,13 @@ ArmyInfoTip::ArmyInfoTip(Gtk::Widget *target, const ArmyProdBase *army)
 
 ArmyInfoTip::ArmyInfoTip(Gtk::Widget *target, const ArmyProto *army)
 {
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/army-info-window.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/army-info-window.ui");
 
-    Gtk::Window *w = 0;
-    xml->get_widget("window", w);
-    window.reset(w);
+    xml->get_widget("window", window);
+    Decorated decorator;
+    decorator.decorate(window,File::getMiscFile("various/background.png"), 200);
 
     Gtk::Image *army_image;
     xml->get_widget("army_image", army_image);
@@ -182,15 +181,13 @@ ArmyInfoTip::ArmyInfoTip(Gtk::Widget *target, const ArmyProto *army)
     int armyset;
     armyset = army->getArmyset();
     GraphicsCache *gc = GraphicsCache::getInstance();
-    army_image->property_pixbuf() = to_pixbuf (gc->getArmyPic(armyset, 
-							      army->getTypeId(), 
-							      p, NULL));
+    army_image->property_pixbuf() = gc->getArmyPic(armyset, army->getTypeId(), 
+						   p, NULL)->to_pixbuf();
 
     // fill in terrain image
     Gtk::Image *terrain_image;
     xml->get_widget("terrain_image", terrain_image);
-    SDL_Surface *terrain = gc->getMoveBonusPic(army->getMoveBonus(), false);
-    terrain_image->property_pixbuf() = to_pixbuf(terrain);
+    terrain_image->property_pixbuf() = gc->getMoveBonusPic(army->getMoveBonus(), false)->to_pixbuf();
     //terrain_image->hide();
 
     // fill in info
@@ -229,3 +226,8 @@ ArmyInfoTip::ArmyInfoTip(Gtk::Widget *target, const ArmyProto *army)
     window->move(pos.x, pos.y);
     window->show();
 }
+
+ArmyInfoTip::~ArmyInfoTip()
+{
+  delete window;
+}
