@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,9 +18,7 @@
 #ifndef DECORATED_H
 #define DECORATED_H
 
-#include <gtkmm/window.h>
-#include <gtkmm/button.h>
-
+#include <gtkmm.h>
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
 
@@ -32,6 +30,8 @@ class Decorated: public sigc::trackable
 
     void decorate(Gtk::Window *window, std::string background_filename="", int alpha = 255);
 
+    void decorate_border(Gtk::Viewport *container, int alpha = 255);
+
     void set_title(std::string title);
 
     sigc::signal<void> window_closed;
