@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,11 +18,7 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/eventbox.h>
-#include <gtkmm/label.h>
-#include <gtkmm/image.h>
-#include <gtkmm/togglebutton.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
 
 #include "destination-dialog.h"
@@ -46,15 +42,13 @@ DestinationDialog::DestinationDialog(City *c, bool *see_all)
   d_see_all = see_all;
     city = c;
     
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/destination-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/destination-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
 
     xml->get_widget("map_image", map_image);
     xml->get_widget("see_all_togglebutton", see_all_toggle);
@@ -84,8 +78,7 @@ DestinationDialog::DestinationDialog(City *c, bool *see_all)
       sigc::bind(sigc::mem_fun(this, &DestinationDialog::on_change_toggled),
                                change_toggle));
 
-    vectormap.reset(new VectorMap(c, VectorMap::SHOW_ORIGIN_CITY_VECTORING,
-		    false));
+    vectormap = new VectorMap(c, VectorMap::SHOW_ORIGIN_CITY_VECTORING, false);
     vectormap->map_changed.connect(
 	sigc::mem_fun(this, &DestinationDialog::on_map_changed));
 
@@ -97,6 +90,12 @@ DestinationDialog::DestinationDialog(City *c, bool *see_all)
   fill_in_vectoring_info();
 }
 
+DestinationDialog::~DestinationDialog()
+{
+  delete dialog;
+  delete vectormap;
+}
+
 void DestinationDialog::set_parent_window(Gtk::Window &parent)
 {
     dialog->set_transient_for(parent);
@@ -117,7 +116,7 @@ void DestinationDialog::run()
     dialog->run();
 }
 
-void DestinationDialog::on_map_changed(SDL_Surface *map)
+void DestinationDialog::on_map_changed(Glib::RefPtr<Gdk::Pixmap> map)
 {
   if (vectormap->getClickAction() == VectorMap::CLICK_SELECTS &&
       vector_toggle->get_active() == true)
@@ -129,7 +128,7 @@ void DestinationDialog::on_map_changed(SDL_Surface *map)
       city = vectormap->getCity();
       fill_in_vectoring_info();
     }
-  map_image->property_pixbuf() = to_pixbuf(map);
+  map_image->property_pixmap() = map;
 }
 
 bool DestinationDialog::on_map_mouse_button_event(GdkEventButton *e)
@@ -202,10 +201,10 @@ void DestinationDialog::fill_in_vectoring_info()
   Glib::RefPtr<Gdk::Pixbuf> pic;
   GraphicsCache *gc = GraphicsCache::getInstance();
   int slot = city->getActiveProductionSlot();
-  SDL_Surface *s
-    = GraphicsCache::getInstance()->getArmyPic(as, 0, player, NULL);
+  Glib::RefPtr<Gdk::Pixbuf> s
+    = GraphicsCache::getInstance()->getArmyPic(as, 0, player, NULL)->to_pixbuf();
   Glib::RefPtr<Gdk::Pixbuf> empty_pic
-    = Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, true, 8, s->w, s->h);
+    = Gdk::Pixbuf::create(Gdk::COLORSPACE_RGB, true, 8, s->get_width(), s->get_height());
   empty_pic->fill(0x00000000);
 
   vector_toggle->set_sensitive(slot != -1 ? true : false);
@@ -236,12 +235,12 @@ void DestinationDialog::fill_in_vectoring_info()
   else
     {
       const ArmyProdBase* a = city->getProductionBase(slot);
-      pic = to_pixbuf(gc->getArmyPic(as, a->getTypeId(), player, NULL));
+      pic = gc->getArmyPic(as, a->getTypeId(), player, NULL)->to_pixbuf();
       s1 = String::ucompose(_("%1t"), city->getDuration());
       turns_label->set_markup("<i>" + s1 + "</i>");
     }
     
-  current_image->set(pic);
+  current_image->property_pixbuf() = pic;
   current_label->set_markup("<i>" + s4 + "</i>");
 
   //show the units that have been vectored from this city
@@ -251,13 +250,13 @@ void DestinationDialog::fill_in_vectoring_info()
       int armytype = (*it)->getArmy()->getTypeId();
       if ((*it)->getDuration() == 2)
         {
-          pic = to_pixbuf(gc->getArmyPic(as, armytype, player, NULL));
-          one_turn_away_image->set(pic);
+          pic = gc->getArmyPic(as, armytype, player, NULL)->to_pixbuf();
+          one_turn_away_image->property_pixbuf() = pic;
         }
       else if ((*it)->getDuration() == 1)
         {
-          pic = to_pixbuf(gc->getArmyPic(as, armytype, player, NULL));
-          two_turns_away_image->set(pic);
+          pic = gc->getArmyPic(as, armytype, player, NULL)->to_pixbuf();
+          two_turns_away_image->property_pixbuf() = pic;
         }
     }
 
@@ -278,8 +277,8 @@ void DestinationDialog::fill_in_vectoring_info()
           case 2: image = next_turn_3_image; break;
           case 3: image = next_turn_4_image; break;
         }
-      pic = to_pixbuf(gc->getArmyPic(as, (*it)->getArmy()->getTypeId(), player, NULL));
-      image->set(pic);
+      pic = gc->getArmyPic(as, (*it)->getArmy()->getTypeId(), player, NULL)->to_pixbuf();
+      image->property_pixbuf() = pic;
       count++;
     }
   count = 0;
@@ -294,8 +293,8 @@ void DestinationDialog::fill_in_vectoring_info()
           case 2: image = turn_after_3_image; break;
           case 3: image = turn_after_4_image; break;
         }
-      pic = to_pixbuf(gc->getArmyPic(as, (*it)->getArmy()->getTypeId(), player, NULL));
-      image->set(pic);
+      pic = gc->getArmyPic(as, (*it)->getArmy()->getTypeId(), player, NULL)->to_pixbuf();
+      image->property_pixbuf() = pic;
       count++;
     }
 }
