@@ -3,7 +3,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,6 +20,7 @@
 #include <sigc++/functors/mem_fun.h>
 #include <sigc++/bind.h>
 #include <errno.h>
+#include <string.h>
 
 #include "driver.h"
 
@@ -39,7 +40,6 @@
 #include "armysetlist.h"
 #include "playerlist.h"
 #include "player.h"
-#include "stacklist.h"
 #include "citylist.h"
 #include "xmlhelper.h"
 #include "Configuration.h"
@@ -66,12 +66,14 @@
 
 Driver::Driver(std::string load_filename)
 {
+    game_window = NULL;
+    game_lobby_dialog = NULL;
+    splash_window = NULL;
+    download_window = NULL;
   game_scenario_downloaded = "";
-    splash_window.reset(new SplashWindow);
+    splash_window = new SplashWindow;
     splash_window->new_game_requested.connect(
 	sigc::mem_fun(*this, &Driver::on_new_game_requested));
-    splash_window->new_campaign_requested.connect(
-	sigc::mem_fun(*this, &Driver::on_new_campaign_requested));
     splash_window->new_hosted_network_game_requested.connect(
 	sigc::mem_fun(*this, &Driver::on_new_hosted_network_game_requested));
     splash_window->new_remote_network_game_requested.connect(
@@ -84,6 +86,8 @@ Driver::Driver(std::string load_filename)
 	sigc::mem_fun(*this, &Driver::on_quit_requested));
 
     d_load_filename = load_filename;
+
+    //here are the command-line options that don't bring up the splash screen:
     if (Main::instance().start_stress_test) 
       {
 	Sound::deleteInstance();
@@ -95,8 +99,9 @@ Driver::Driver(std::string load_filename)
 	run();
 	return;
       }
-    splash_window->sdl_initialized.connect(sigc::mem_fun(*this, &Driver::run));
     splash_window->show();
+    //here are the ones that do
+    run();
 }
 
 void Driver::run()
@@ -179,7 +184,7 @@ void Driver::run()
 	  game_scenario->saveGame(d_load_filename);
 	  if (Playerlist::getActiveplayer()->getType() != Player::NETWORKED)
 	    {
-	      if (splash_window.get())
+	      if (splash_window)
 		splash_window->hide();
 
 	      init_game_window();
@@ -204,7 +209,7 @@ void Driver::run()
 	  size_t found = d_load_filename.find(".map");
 	  if (found != std::string::npos)
 	    {
-	      GamePreferencesDialog d(d_load_filename);
+	      GamePreferencesDialog d(d_load_filename, GameScenario::HOTSEAT);
 	      d.set_parent_window(*splash_window->get_window());
 	      d.game_started.connect(sigc::mem_fun
 				     (*this, &Driver::on_new_game_requested));
@@ -225,11 +230,19 @@ void Driver::run()
 
 Driver::~Driver()
 {
+  if (game_window)
+    delete game_window;
+  if (game_lobby_dialog)
+    delete game_lobby_dialog;
+  if (splash_window)
+    delete splash_window;
+  if (download_window)
+    delete download_window;
 }
 
 void Driver::on_hosted_player_sat_down(Player *player)
 {
-  Uint32 id = player->getId();
+  guint32 id = player->getId();
   GameServer *game_server = GameServer::getInstance();
   game_server->sit_down(player);
   player_replaced.emit(Playerlist::getInstance()->getPlayer(id));
@@ -237,7 +250,7 @@ void Driver::on_hosted_player_sat_down(Player *player)
 
 void Driver::on_hosted_player_stood_up(Player *player)
 {
-  Uint32 id = player->getId();
+  guint32 id = player->getId();
   GameServer *game_server = GameServer::getInstance();
   game_server->stand_up(player);
   player_replaced.emit(Playerlist::getInstance()->getPlayer(id));
@@ -270,7 +283,7 @@ void Driver::on_client_player_chat(std::string message)
 void Driver::on_new_hosted_network_game_requested(GameParameters g, int port,
 						  std::string nick)
 {
-    if (splash_window.get())
+    if (splash_window)
 	splash_window->hide();
 
     NewGameProgressWindow pw(g, GameScenario::NETWORKED, 
@@ -295,12 +308,14 @@ void Driver::on_new_hosted_network_game_requested(GameParameters g, int port,
     next_turn->snextRound.connect (sigc::mem_fun(GameServer::getInstance(), 
 						 &GameServer::sendTurnOrder));
   next_turn->snextPlayerUnavailable.connect(sigc::mem_fun(this, &Driver::on_player_unavailable));
-  game_lobby_dialog.reset(new GameLobbyDialog(game_scenario, next_turn, 
-					      game_server, true));
+  if (game_lobby_dialog)
+    delete game_lobby_dialog;
+  game_lobby_dialog = new GameLobbyDialog(game_scenario, next_turn, 
+					      game_server, true);
   game_server->round_begins.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start));
   Playerlist::getInstance()->splayerDead.connect
     (sigc::mem_fun(GameServer::getInstance(), &GameServer::sendKillPlayer));
-  game_lobby_dialog->set_parent_window(*splash_window.get()->get_window());
+  game_lobby_dialog->set_parent_window(*splash_window->get_window());
   game_lobby_dialog->player_sat_down.connect
     (sigc::mem_fun(this, &Driver::on_hosted_player_sat_down));
   game_lobby_dialog->player_stood_up.connect
@@ -317,7 +332,7 @@ void Driver::on_new_hosted_network_game_requested(GameParameters g, int port,
     {
       GameServer::deleteInstance();
       delete game_scenario;
-      if (splash_window.get())
+      if (splash_window)
 	splash_window->show();
     }
 }
@@ -326,11 +341,11 @@ void Driver::on_new_hosted_network_game_requested(GameParameters g, int port,
 void Driver::on_server_went_away()
 {
   heartbeat_conn.disconnect();
-  if (game_lobby_dialog.get())
+  if (game_lobby_dialog)
     game_lobby_dialog->hide();
-  if (download_window.get())
+  if (download_window)
     download_window->hide();
-  if (splash_window.get())
+  if (splash_window)
     splash_window->show();
   GameClient::deleteInstance();
   TimedMessageDialog dialog(*splash_window->get_window(), 
@@ -342,11 +357,11 @@ void Driver::on_server_went_away()
 void Driver::on_client_could_not_connect()
 {
   heartbeat_conn.disconnect();
-  if (game_lobby_dialog.get())
+  if (game_lobby_dialog)
     game_lobby_dialog->hide();
-  if (download_window.get())
+  if (download_window)
     download_window->hide();
-  if (splash_window.get())
+  if (splash_window)
     splash_window->show();
   GameClient::deleteInstance();
   TimedMessageDialog dialog(*splash_window->get_window(), 
@@ -357,7 +372,7 @@ void Driver::on_client_could_not_connect()
 
 void Driver::on_new_remote_network_game_requested(std::string host, unsigned short port, std::string nick)
 {
-  if (splash_window.get())
+  if (splash_window)
     splash_window->hide();
   GameClient *game_client = GameClient::getInstance();
   game_client->game_scenario_received.connect
@@ -368,7 +383,9 @@ void Driver::on_new_remote_network_game_requested(std::string host, unsigned sho
     (sigc::mem_fun(this, &Driver::on_client_could_not_connect));
   game_scenario_received.connect
     (sigc::mem_fun(this, &Driver::on_game_scenario_received));
-  download_window.reset(new NewNetworkGameDownloadWindow());
+  if (download_window)
+    delete download_window;
+  download_window = new NewNetworkGameDownloadWindow();
   download_window->pulse();
   game_client->start(host, port, nick);
   heartbeat_conn = Glib::signal_timeout().connect
@@ -383,7 +400,7 @@ void Driver::heartbeat()
     return;
   if (game_scenario_downloaded == "")
     {
-      if (download_window.get())
+      if (download_window)
 	download_window->pulse();
       return;
     }
@@ -395,21 +412,23 @@ void Driver::heartbeat()
 void Driver::on_game_scenario_received(std::string path)
 {
   heartbeat_conn.disconnect();
-  if (download_window.get())
+  if (download_window)
     download_window->hide();
   GameScenario *game_scenario = load_game(path);
   GameClient *game_client = GameClient::getInstance();
   std::string host = game_client->getHost();
-  Uint32 port = game_client->getPort();
+  guint32 port = game_client->getPort();
   RecentlyPlayedGameList::getInstance()->addNetworkedEntry(game_scenario, host, port);
   RecentlyPlayedGameList::getInstance()->saveToFile(File::getSavePath() + "/recently-played.xml");
 
   NextTurnNetworked *next_turn = new NextTurnNetworked(game_scenario->getTurnmode(), game_scenario->s_random_turns);
   next_turn->snextPlayerUnavailable.connect(sigc::mem_fun(this, &Driver::on_player_unavailable));
   game_client->round_begins.connect(sigc::mem_fun(next_turn, &NextTurnNetworked::start));
-  game_lobby_dialog.reset(new GameLobbyDialog(game_scenario, next_turn, 
-					      GameClient::getInstance(), false));
-  game_lobby_dialog->set_parent_window(*splash_window.get()->get_window());
+  if (game_lobby_dialog)
+    delete game_lobby_dialog;
+  game_lobby_dialog = new GameLobbyDialog(game_scenario, next_turn, 
+					      GameClient::getInstance(), false);
+  game_lobby_dialog->set_parent_window(*splash_window->get_window());
   game_lobby_dialog->player_sat_down.connect
     (sigc::mem_fun(this, &Driver::on_client_player_sat_down));
   game_lobby_dialog->player_stood_up.connect
@@ -424,7 +443,7 @@ void Driver::on_game_scenario_received(std::string path)
 
   if (response == false)
     {
-      if (splash_window.get())
+      if (splash_window)
 	splash_window->show();
     
       GameClient::deleteInstance();
@@ -465,13 +484,18 @@ void Driver::on_new_game_requested(GameParameters g)
 	  (*splash_window->get_window(), 
 	   _("Invalid map file.\n" 
 	     "Please validate it in the scenario editor."), 0);
+	std::list<std::string>::iterator it = e.begin();
+	for (; it != e.end(); it++)
+	  {
+	    printf ("error: %s\n", (*it).c_str());
+	  }
 	dialog.run();
 	dialog.hide();
 	splash_window->show();
 	return;
       }
 
-    if (splash_window.get())
+    if (splash_window)
 	splash_window->hide();
 
     NextTurn *next_turn = new NextTurnHotseat(game_scenario->getTurnmode(),
@@ -482,51 +506,9 @@ void Driver::on_new_game_requested(GameParameters g)
     game_window->new_game(game_scenario, next_turn);
 }
 
-void Driver::on_new_campaign_requested(GameParameters g)
-{
-    if (splash_window.get())
-	splash_window->hide();
-
-    NewGameProgressWindow pw(g, GameScenario::CAMPAIGN,
-			     Main::instance().record);
-    pw.thread_worker();
-    //Gtk::Main::instance()->run(pw);
-    GameScenario *game_scenario = pw.getGameScenario();
-
-    if (game_scenario == NULL)
-      {
-	TimedMessageDialog dialog(*splash_window->get_window(),
-				  _("Corrupted saved game file."), 0);
-	dialog.run();
-	dialog.hide();
-	splash_window->show();
-	return;
-      }
-
-    std::list<std::string> e, w;
-    if (g.map_path != "" && game_scenario->validate(e, w) == false)
-      {
-	TimedMessageDialog dialog
-	  (*splash_window->get_window(), 
-	   _("Invalid map file.\n" 
-	     "Please validate it in the scenario editor."), 0);
-	dialog.run();
-	dialog.hide();
-	splash_window->show();
-	return;
-      }
-
-    NextTurn *next_turn = new NextTurnHotseat(game_scenario->getTurnmode(),
-					      game_scenario->s_random_turns);
-    init_game_window();
-    
-    game_window->show();
-    game_window->new_game(game_scenario, next_turn);
-}
-
 void Driver::on_load_requested(std::string filename)
 {
-    if (splash_window.get())
+    if (splash_window)
 	splash_window->hide();
 
     GameScenario *game_scenario = load_game(filename);
@@ -558,10 +540,10 @@ void Driver::on_load_requested(std::string filename)
 
 void Driver::on_quit_requested()
 {
-    if (splash_window.get())
+    if (splash_window)
 	splash_window->hide();
     
-    if (game_window.get())
+    if (game_window)
 	game_window->hide();
 
     Main::instance().stop_main_loop();
@@ -569,10 +551,9 @@ void Driver::on_quit_requested()
 
 void Driver::on_game_ended()
 {
-  if (game_window.get())
+  if (game_window)
     {
       game_window->hide();
-      //game_window.reset();
     }
   GameClient::deleteInstance();
   PbmGameClient::deleteInstance();
@@ -584,99 +565,27 @@ void Driver::on_game_ended()
   splash_window->show();
 }
 
-void Driver::on_next_scenario(std::string scenario, int gold, std::list<Hero*> heroes, std::string player_name)
-{
-
-  GameClient::deleteInstance();
-  PbmGameClient::deleteInstance();
-  GameServer::deleteInstance();
-  PbmGameServer::deleteInstance();
-
-  //remove load_opts stuff from GameScenario, etc
-  
-  //load up the next scenario 
-  GameParameters g;
-  //players is empty
-  bool broken = false;
-  g = GameScenario::loadGameParameters(scenario, broken);
-  g.map_path = scenario;
-  //go get players from scenario file
-  g.see_opponents_stacks = GameScenarioOptions::s_see_opponents_stacks;
-  g.see_opponents_production = GameScenarioOptions::s_see_opponents_production;
-  g.play_with_quests = GameScenarioOptions::s_play_with_quests;
-  g.hidden_map = GameScenarioOptions::s_hidden_map;
-  g.diplomacy = GameScenarioOptions::s_diplomacy;
-  g.neutral_cities = GameScenarioOptions::s_neutral_cities;
-  g.razing_cities = GameScenarioOptions::s_razing_cities;
-  g.cusp_of_war = GameScenarioOptions::s_cusp_of_war;
-  g.intense_combat = GameScenarioOptions::s_intense_combat;
-  g.military_advisor = GameScenarioOptions::s_military_advisor;
-  g.random_turns = GameScenarioOptions::s_random_turns;
-  g.quick_start = false;
-
-  Uint32 player_id = 0;
-  for (std::vector<GameParameters::Player>::iterator
-       i = g.players.begin(), end = g.players.end(); i != end; ++i) 
-    {
-      if ((*i).type == GameParameters::Player::HUMAN)
-	{
-	  player_id = (Uint32) (*i).id;
-	  (*i).name = player_name;
-	  break;
-	}
-    }
-
-  game_window->hide();
-  NewGameProgressWindow pw(g, GameScenario::CAMPAIGN,
-			   Main::instance().record);
-  pw.thread_worker();
-  //Gtk::Main::instance()->run(pw);
-  GameScenario *game_scenario = pw.getGameScenario();
-
-  Player *player = Playerlist::getInstance()->getPlayer(player_id);
-  player->withdrawGold(player->getGold());
-  if (gold > MAX_GOLD_TO_CARRY_OVER_TO_NEXT_SCENARIO)
-    gold = MAX_GOLD_TO_CARRY_OVER_TO_NEXT_SCENARIO;
-  player->addGold(gold);
-  player->setName(player_name);
-  City *c = Citylist::getInstance()->getFirstCity(player);
-
-  for (std::list<Hero*>::iterator it = heroes.begin(); it != heroes.end(); it++)
-    {
-      //munge the IDs of those heroes.
-      (*it)->assignNewId();
-      //munge the IDs of the items
-      Backpack *backpack = (*it)->getBackpack();
-      for (Backpack::iterator i = backpack->begin(); i != backpack->end(); i++)
-	(*i)->assignNewId();
-      (*it)->setOwner(player);
-      c->addArmy(*it);
-      History_HeroEmerges *item = new History_HeroEmerges();
-      item->fillData((*it), c);
-      player->addHistory(item);
-    }
-
-  NextTurnHotseat *nextTurn;
-  nextTurn = new NextTurnHotseat(game_scenario->getTurnmode(),
-				 game_scenario->s_random_turns);
-  game_window->show();
-  game_window->new_game (game_scenario, nextTurn);
-}
-
 void Driver::init_game_window()
 {
-    game_window.reset(new GameWindow);
+  if (game_window)
+    delete game_window;
+    game_window = new GameWindow;
 
     game_window->game_ended.connect(
 	sigc::mem_fun(*this, &Driver::on_game_ended));
-    game_window->next_scenario.connect(
-	sigc::mem_fun(*this, &Driver::on_next_scenario));
     game_window->show_lobby.connect(
 	sigc::mem_fun(*this, &Driver::on_show_lobby_requested));
     game_window->quit_requested.connect(
 	sigc::mem_fun(*this, &Driver::on_quit_requested));
 
-    game_window->init(640, 480);
+    //make the width+height suitable for the screen size.
+    Glib::RefPtr<Gdk::Screen> screen = Gdk::Display::get_default()->get_default_screen();
+    guint32 screen_height = screen->get_height();
+    guint32 height = 450;
+    if (screen_height <= 600)
+      height = 400;
+    guint32 width = (int)((float)height * 1.42223);
+    game_window->init(width, height);
 
 }
 
@@ -689,6 +598,7 @@ Driver::create_and_dump_scenario(const std::string &file, const GameParameters &
     int c = 0;
     int army_id = Armysetlist::getInstance()->getArmyset(g.army_theme)->getId();
     Shieldsetlist *ssl = Shieldsetlist::getInstance();
+    guint32 id = ssl->getShieldset(g.shield_theme)->getId();
     for (std::vector<GameParameters::Player>::const_iterator
 	     i = g.players.begin(), end = g.players.end();
 	 i != end; ++i, ++c) {
@@ -707,14 +617,13 @@ Driver::create_and_dump_scenario(const std::string &file, const GameParameters &
 	else
 	    type = Player::HUMAN;
 
-	creator.addPlayer(i->name, army_id, ssl->getColor(g.shield_theme, 
-							  c), type);
+	creator.addPlayer(i->name, army_id, ssl->getColor(id, c), type);
     }
 
+	
     // the neutral player must come last so it has the highest id among players
     creator.addNeutral(_("Neutral"), army_id, 
-		       ssl->getColor(g.shield_theme, MAX_PLAYERS),
-		       Player::AI_DUMMY);
+		       ssl->getColor(id, MAX_PLAYERS), Player::AI_DUMMY);
 
     // now fill in some map information
     creator.setMapTiles(g.tile_theme);
@@ -722,7 +631,8 @@ Driver::create_and_dump_scenario(const std::string &file, const GameParameters &
     creator.setCityset(g.city_theme);
     creator.setNoCities(g.map.cities);
     creator.setNoRuins(g.map.ruins);
-    creator.setNoTemples(4);
+    creator.setNoTemples(g.map.temples);
+    creator.setNoSignposts(g.map.signposts);
 
     // terrain: the scenario generator also accepts input with a sum of
     // more than 100%, so the thing is rather easy here
@@ -871,6 +781,7 @@ void Driver::stress_test()
   g.map.mountains = 5;
   g.map.cities = 80;
   g.map.ruins = 15;
+  g.map.temples = 1;
   g.map_path = "";
   g.play_with_quests = false;
   g.hidden_map = false;
@@ -977,13 +888,13 @@ void Driver::on_game_scenario_received_for_robots(std::string path)
 
 void Driver::on_show_lobby_requested()
 {
-  if (game_lobby_dialog.get())
+  if (game_lobby_dialog)
     game_lobby_dialog->show();
 }
     
 void Driver::start_network_game_requested(GameScenario *game_scenario, NextTurnNetworked *next_turn)
 {
-  if (game_window.get())
+  if (game_window)
     {
   
       Player *active = Playerlist::getActiveplayer();
@@ -1001,7 +912,7 @@ void Driver::start_network_game_requested(GameScenario *game_scenario, NextTurnN
     {
       init_game_window();
       player_replaced.connect
-	(sigc::mem_fun(game_window.get(), &GameWindow::on_player_replaced));
+	(sigc::mem_fun(game_window, &GameWindow::on_player_replaced));
       game_window->show();
 
       game_window->new_network_game (game_scenario, next_turn);
