@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -43,10 +43,10 @@ class Driver: public sigc::trackable
 						const GameParameters &g);
   
  private:
-    std::auto_ptr<GameWindow> game_window;
-    std::auto_ptr<GameLobbyDialog> game_lobby_dialog;
-    std::auto_ptr<SplashWindow> splash_window;
-    std::auto_ptr<NewNetworkGameDownloadWindow> download_window;
+    GameWindow* game_window;
+    GameLobbyDialog* game_lobby_dialog;
+    SplashWindow* splash_window;
+    NewNetworkGameDownloadWindow* download_window;
     std::string d_load_filename;
     sigc::connection heartbeat_conn;
     Player::Type robot_player_type;
@@ -56,7 +56,6 @@ class Driver: public sigc::trackable
     sigc::signal<void, Player*> player_replaced;
 
     void on_new_game_requested(GameParameters g);
-    void on_new_campaign_requested(GameParameters g);
     void on_new_remote_network_game_requested(std::string host, unsigned short port, std::string nick);
     void on_new_hosted_network_game_requested(GameParameters g, int port, std::string nick);
     void on_new_pbm_game_requested(GameParameters g);
@@ -66,7 +65,6 @@ class Driver: public sigc::trackable
     void on_quit_requested();
 
     void on_game_ended();
-    void on_next_scenario(std::string scenario, int gold, std::list<Hero*> heroes, std::string player_name);
 
     void init_game_window();
 
