@@ -1,8 +1,8 @@
-//  Copyright (C) 2008 Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,10 +17,8 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/eventbox.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
-#include <gtkmm/label.h>
 
 #include "game-lobby-dialog.h"
 
@@ -44,7 +42,7 @@
 
 namespace
 {
-    Glib::ustring player_type_to_string(Uint32 type)
+    Glib::ustring player_type_to_string(guint32 type)
     {
 	switch (type)
 	{
@@ -61,7 +59,9 @@ void GameLobbyDialog::update_city_map()
 {
   if (d_game_scenario->s_hidden_map == false)
     {
-      citymap.reset(new CityMap());
+      if (citymap)
+	delete citymap;
+      citymap = new CityMap();
       citymap->map_changed.connect
 	(sigc::mem_fun(this, &GameLobbyDialog::on_map_changed));
       if (d_game_scenario->getRound() > 1)
@@ -81,19 +81,18 @@ void GameLobbyDialog::initDialog(GameScenario *gamescenario,
 				 NextTurnNetworked *next_turn,
 				 GameStation *game_station)
 {
-  GraphicsLoader::instantiatePixmaps(Shieldsetlist::getInstance());
+  GraphicsLoader::instantiateImages(Shieldsetlist::getInstance());
   d_game_scenario = gamescenario;
   d_game_station = game_station;
   d_next_turn = next_turn;
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/game-lobby-dialog.glade");
+  citymap = NULL;
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/game-lobby-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
 
     xml->get_widget("player_treeview", player_treeview);
     player_treeview->get_selection()->signal_changed().connect
@@ -123,9 +122,9 @@ void GameLobbyDialog::initDialog(GameScenario *gamescenario,
 
     Gtk::EventBox *map_eventbox;
     xml->get_widget("map_eventbox", map_eventbox);
-    xml->connect_clicked(
-	"show_options_button",
-	sigc::mem_fun(*this, &GameLobbyDialog::on_show_options_clicked));
+    xml->get_widget("show_options_button", show_options_button);
+    show_options_button->signal_clicked().connect
+	(sigc::mem_fun(*this, &GameLobbyDialog::on_show_options_clicked));
 
     game_station->remote_player_moved.connect
       (sigc::mem_fun(*this, &GameLobbyDialog::on_remote_player_ends_turn));
@@ -291,6 +290,9 @@ GameLobbyDialog::GameLobbyDialog(GameScenario *game_scenario,
 
 GameLobbyDialog::~GameLobbyDialog()
 {
+  if (citymap)
+    delete citymap;
+  delete dialog;
 }
 
 void GameLobbyDialog::update_scenario_details()
@@ -323,9 +325,9 @@ void GameLobbyDialog::show()
   return;
 }
 
-void GameLobbyDialog::on_map_changed(SDL_Surface *map)
+void GameLobbyDialog::on_map_changed(Glib::RefPtr<Gdk::Pixmap> map)
 {
-  map_image->property_pixbuf() = to_pixbuf(map);
+  map_image->property_pixmap() = map;
 }
 
 void GameLobbyDialog::on_show_options_clicked()
@@ -387,9 +389,8 @@ void GameLobbyDialog::add_player(const Glib::ustring &type,
   GraphicsCache *gc = GraphicsCache::getInstance();
   Gtk::TreeIter i = player_list->append();
   if (player == Playerlist::getInstance()->getActiveplayer())
-    (*i)[player_columns.turn] = 
-      to_pixbuf(gc->getCursorPic(GraphicsCache::SWORD));
-  (*i)[player_columns.shield] = to_pixbuf(gc->getShieldPic(1, player));
+    (*i)[player_columns.turn] = gc->getCursorPic(GraphicsCache::SWORD)->to_pixbuf();
+  (*i)[player_columns.shield] = gc->getShieldPic(1, player)->to_pixbuf();
   (*i)[player_columns.type] = type;
   (*i)[player_columns.name] = name;
   (*i)[player_columns.player_id] = player->getId();
@@ -507,8 +508,7 @@ void GameLobbyDialog::on_local_player_starts_turn(Player *p)
       Gtk::TreeModel::Row row = *i;
       Player *active = Playerlist::getActiveplayer();
       if (row[player_columns.player_id] == active->getId())
-	(*i)[player_columns.turn] = 
-	  to_pixbuf(gc->getCursorPic(GraphicsCache::SWORD));
+	(*i)[player_columns.turn] = gc->getCursorPic(GraphicsCache::SWORD)->to_pixbuf();
     }
   update_scenario_details();
 }
@@ -536,8 +536,7 @@ void GameLobbyDialog::on_remote_player_ends_turn(Player *p)
 	}
       Player *active = Playerlist::getActiveplayer();
       if (row[player_columns.player_id] == active->getId())
-	(*i)[player_columns.turn] = 
-	  to_pixbuf(gc->getCursorPic(GraphicsCache::SWORD));
+	(*i)[player_columns.turn] = gc->getCursorPic(GraphicsCache::SWORD)->to_pixbuf();
     }
   update_scenario_details();
 }
@@ -667,7 +666,7 @@ bool GameLobbyDialog::run()
 	}
     }
   int response = dialog->run();
-  if (response == 1)
+  if (response == Gtk::RESPONSE_ACCEPT)
     return true;
   else
     return false;
