@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,7 +17,7 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
 
 #include "game-options-dialog.h"
@@ -32,15 +32,14 @@
 
 GameOptionsDialog::GameOptionsDialog(bool readonly)
 {
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/game-options-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/game-options-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
+    dialog->set_icon_from_file(File::getMiscFile("various/castle_icon.png"));
 
     d_readonly = readonly;
     xml->get_widget("difficultoptionstable", difficultoptionstable);
@@ -61,6 +60,11 @@ GameOptionsDialog::GameOptionsDialog(bool readonly)
 	
 }
 
+GameOptionsDialog::~GameOptionsDialog()
+{
+  delete dialog;
+}
+
 void GameOptionsDialog::fill_in_options()
 {
     neutral_cities_combobox->set_active(GameParameters::AVERAGE);
