@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,15 +21,9 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/combobox.h>
-#include <gtkmm/table.h>
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/togglebutton.h>
-#include <gtkmm/checkbutton.h>
-#include <gtkmm/widget.h>
-#include <gtkmm/label.h>
+#include <gtkmm.h>
 #include <sigc++/signal.h>
+#include <gtkmm.h>
 
 #include "game-parameters.h"
 
@@ -39,6 +33,7 @@ class GameOptionsDialog: public Decorated
 {
  public:
     GameOptionsDialog(bool readonly);
+    ~GameOptionsDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -48,7 +43,7 @@ class GameOptionsDialog: public Decorated
     sigc::signal<void> difficulty_option_changed;
 
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
     Gtk::Table *difficultoptionstable;
     Gtk::Table *notdifficultoptionstable;
     Gtk::CheckButton *quests_checkbutton;
