@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, 2008, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -24,18 +24,7 @@
 #include <sigc++/signal.h>
 #include <sigc++/trackable.h>
 #include <sigc++/connection.h>
-#include <gtkmm/window.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/eventbox.h>
-#include <gtkmm/container.h>
-#include <gtkmm/image.h>
-#include <gtkmm/button.h>
-#include <gtkmm/label.h>
-#include <gtkmm/togglebutton.h>
-#include <gtkmm/box.h>
-#include <gtkmm/checkmenuitem.h>
-#include <gtkmm/progressbar.h>
-#include <gtkmm/menubar.h>
+#include <gtkmm.h>
 
 #include "army-info-tip.h"
 #include "stack-info-tip.h"
@@ -53,7 +42,6 @@
 #include "GameScenario.h"
 
 class Game;
-class SDL_Surface;
 class Ruin;
 class Fight;
 class Hero;
@@ -83,7 +71,7 @@ class GameWindow: public Decorated
     void show();
     void hide();
 
-    // initialize the SDL widget 
+    // initialize the big map widget 
     void init(int width, int height);
 
     // setup a new game
@@ -100,26 +88,24 @@ class GameWindow: public Decorated
     // emitted when the game has ended and it is time to show the splash again
     sigc::signal<void> game_ended;
     
-    // emitted when we're in a campaign, and we want to go to the next scenario
-    sigc::signal<void, std::string, int, std::list<Hero*>, std::string > next_scenario;
-    
     sigc::signal<void> show_lobby;
 
     sigc::signal<void> quit_requested;
 
     sigc::signal<void> sdl_initialized;
     
-    Gtk::Window *get_window() const {return window.get();};
+    Gtk::Window *get_window() const {return window;};
 
     void on_player_replaced(Player *p);
  private:
-    std::auto_ptr<Gtk::Window> window;
-    std::auto_ptr<Gtk::Window> map_tip;	// tooltip appears over the map
-    std::auto_ptr<Gtk::Window> stack_tip;// tooltip appears over the map
-    Gtk::Container *sdl_container;
-    Gtk::Widget *sdl_widget;
+    Gtk::Window* window;
+    Gtk::Window* map_tip;	// tooltip appears over the map
+    Gtk::Window* stack_tip;// tooltip appears over the map
+    Gtk::Container *bigmap_container;
+    Gtk::Container *map_container;
     Gtk::MenuBar *menubar;
     Gtk::CheckMenuItem *fullscreen_menuitem;
+    Gtk::MenuItem *new_game_menuitem;
     Gtk::MenuItem *load_game_menuitem;
     Gtk::MenuItem *save_game_menuitem;
     Gtk::MenuItem *save_game_as_menuitem;
@@ -127,10 +113,10 @@ class GameWindow: public Decorated
     Gtk::MenuItem *end_turn_menuitem;
     Gtk::MenuItem *move_all_menuitem;
     Gtk::MenuItem *search_menuitem;
-    Gtk::MenuItem *inspect_menuitem;
     Gtk::MenuItem *disband_menuitem;
     Gtk::MenuItem *stack_info_menuitem;
     Gtk::MenuItem *signpost_menuitem;
+    Gtk::MenuItem *diplomacy_report_menuitem;
     Gtk::MenuItem *city_history_menuitem;
     Gtk::MenuItem *event_history_menuitem;
     Gtk::MenuItem *gold_history_menuitem;
@@ -139,6 +125,29 @@ class GameWindow: public Decorated
     Gtk::MenuItem *group_ungroup_menuitem;
     Gtk::MenuItem *leave_menuitem;
     Gtk::MenuItem *next_menuitem;
+    Gtk::MenuItem *fight_order_menuitem;
+    Gtk::MenuItem *resign_menuitem;
+    Gtk::MenuItem *production_menuitem;
+    Gtk::MenuItem *cities_menuitem;
+    Gtk::MenuItem *build_menuitem;
+    Gtk::MenuItem *vectoring_menuitem;
+    Gtk::MenuItem *levels_menuitem;
+    Gtk::MenuItem *inspect_menuitem;
+    Gtk::MenuItem *ruin_report_menuitem;
+    Gtk::MenuItem *army_bonus_menuitem;
+    Gtk::MenuItem *item_bonus_menuitem;
+    Gtk::MenuItem *production_report_menuitem;
+    Gtk::MenuItem *triumphs_menuitem;
+    Gtk::MenuItem *help_about_menuitem;
+    Gtk::MenuItem *online_help_menuitem;
+    Gtk::MenuItem *quit_menuitem;
+    Gtk::MenuItem *toggle_grid_menuitem;
+    Gtk::MenuItem *army_report_menuitem;
+    Gtk::MenuItem *city_report_menuitem;
+    Gtk::MenuItem *gold_report_menuitem;
+    Gtk::MenuItem *winning_report_menuitem;
+    Gtk::MenuItem *quests_menuitem;
+    Gtk::MenuItem *preferences_menuitem;
     Gtk::Box *stack_info_box;
     Gtk::Box *stack_info_container;
     Gtk::Label *group_moves_label;
@@ -147,7 +156,8 @@ class GameWindow: public Decorated
     Gtk::Box *progress_box;
     Gtk::ProgressBar *turn_progressbar;
     Gtk::Label *progress_status_label;
-    Gtk::Image *map_image;
+    Gtk::DrawingArea *map_drawingarea;
+    Gtk::DrawingArea *bigmap_drawingarea;
 
     Gtk::Label *cities_stats_label;
     Gtk::Label *gold_stats_label;
@@ -178,28 +188,29 @@ class GameWindow: public Decorated
     Gtk::Button *se_keypad_button;
 
     Stack *currently_selected_stack;
-    std::auto_ptr<ArmyInfoTip> army_info_tip;
-    std::auto_ptr<StackInfoTip> stack_info_tip;
+    ArmyInfoTip* army_info_tip;
+    StackInfoTip* stack_info_tip;
     typedef std::vector<Gtk::ToggleButton *> army_buttons_type;
     army_buttons_type army_buttons;
     Gtk::EventBox *map_eventbox;
+    Gtk::EventBox *bigmap_eventbox;
     Gtk::ToggleButton *group_ungroup_toggle;
 
     std::string current_save_filename;
 
-    std::auto_ptr<Game> game;
+    Game* game;
     
     bool sdl_inited;
 
     bool on_delete_event(GdkEventAny *e);
 
-    bool on_sdl_mouse_button_event(GdkEventButton *e);
-    bool on_sdl_mouse_motion_event(GdkEventMotion *e);
-    bool on_sdl_key_event(GdkEventKey *e);
-    bool on_sdl_scroll_event(GdkEventScroll* event);
+    bool on_bigmap_mouse_button_event(GdkEventButton *e);
+    bool on_bigmap_mouse_motion_event(GdkEventMotion *e);
+    bool on_bigmap_key_event(GdkEventKey *e);
+    bool on_bigmap_scroll_event(GdkEventScroll* event);
 
-    bool on_map_mouse_button_event(GdkEventButton *e);
-    bool on_map_mouse_motion_event(GdkEventMotion *e);
+    bool on_smallmap_mouse_button_event(GdkEventButton *e);
+    bool on_smallmap_mouse_motion_event(GdkEventMotion *e);
     
     void on_load_game_activated();
     void on_save_game_activated();
@@ -265,11 +276,12 @@ class GameWindow: public Decorated
     void on_sidebar_stats_changed(SidebarStats s);
     void on_progress_status_changed(std::string status);
     void on_progress_changed();
-    void on_smallmap_changed(SDL_Surface *map);
+    void on_smallmap_changed(Glib::RefPtr<Gdk::Pixmap> map, Gdk::Rectangle r);
     void on_smallmap_slid(Rectangle view);
     void on_bigmap_cursor_changed(GraphicsCache::CursorType cursor);
+    void on_bigmap_changed(Glib::RefPtr<Gdk::Pixmap> map);
     void on_stack_info_changed(Stack *s);
-    void on_map_tip_changed(Glib::ustring tip, MapTipPosition pos);
+    void on_bigmap_tip_changed(Glib::ustring tip, MapTipPosition pos);
     void on_stack_tip_changed(Stack *s, MapTipPosition pos);
     void on_ruin_searched(Ruin *ruin, Stack *s, Reward *reward);
     void on_sage_visited(Ruin *ruin, Stack *s);
@@ -285,7 +297,7 @@ class GameWindow: public Decorated
     void on_quest_assigned(Hero *hero, Quest *quest);
     CityDefeatedAction on_city_defeated(City *city, int gold);
     void on_city_pillaged(City *city, int gold, int pillaged_army_type);
-    void on_city_sacked(City *city, int gold, std::list<Uint32> sacked_types);
+    void on_city_sacked(City *city, int gold, std::list<guint32> sacked_types);
     void on_city_razed(City *city);
     void on_city_visited(City *city);
     void on_ruin_visited(Ruin *ruin);
@@ -293,11 +305,10 @@ class GameWindow: public Decorated
     void on_next_player_turn(Player *player, unsigned int turn_number);
     void on_remote_next_player_turn();
     void on_hero_brings_allies(int alliesCount);
-    void on_medal_awarded_to_army(Army *army);
+    void on_medal_awarded_to_army(Army *army, int medaltype);
     Army::Stat on_army_gains_level(Army *army);
     void on_game_loaded(Player *player);
     void on_game_over(Player *winner);
-    void on_next_scenario(std::string scenario, int gold, std::list<Hero*> heroes, std::string player_name);
     void on_player_died(Player *player);
     void on_advice_asked(float percent);
     void end_turn_play_by_mail ();
@@ -321,11 +332,16 @@ class GameWindow: public Decorated
     
     void setup_menuitem(Gtk::MenuItem*, sigc::slot<void> , sigc::signal<void, bool> &);
     void setup_button(Gtk::Button *, sigc::slot<void> slot, sigc::signal<void, bool> &);
+    void on_bigmap_surface_changed(Gtk::Allocation box);
+    bool on_bigmap_exposed(GdkEventExpose *event);
+    bool on_smallmap_exposed(GdkEventExpose *event);
+
+    Player *game_winner;
+    void give_some_cheese(Player *game_winner);
+
 public:
-    // not part of the API, but for surface_attached_helper
-    void on_sdl_surface_changed();
-    std::vector<Glib::RefPtr<Gdk::Pixbuf> > d_button_images;
-    std::vector<Glib::RefPtr<Gdk::Pixbuf> > d_arrow_images;
+    std::vector<PixMask* > d_button_images;
+    std::vector<PixMask* > d_arrow_images;
     bool d_quick_fights; //do we speed up fights for this player's turn?
     std::string stop_action; //hackhackhack
     std::string d_scenario;
@@ -333,6 +349,10 @@ public:
     std::list<Hero*> d_heroes;
     std::string d_player_name;
     std::string d_load_filename;
+    Gtk::Image *cities_stats_image;
+    Gtk::Image *gold_stats_image;
+    Gtk::Image *income_stats_image;
+    Gtk::Image *upkeep_stats_image;
 };
 
 #endif
