@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,14 +20,15 @@
 
 #include <iomanip>
 
-#include <libglademm/xml.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
-#include <gtkmm/image.h>
+#include <vector>
 
 #include "hero-dialog.h"
 
 #include "glade-helpers.h"
 #include "image-helpers.h"
+#include "input-helpers.h"
 #include "ucompose.hpp"
 #include "defs.h"
 #include "hero.h"
@@ -40,41 +41,83 @@
 
 HeroDialog::HeroDialog(Hero *h, Vector<int> p)
 {
-    GraphicsCache *gc = GraphicsCache::getInstance();
+  inhibit_hero_changed = false;
     hero = h;
     pos = p;
     
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/hero-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/hero-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
-    set_title(hero->getName());
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
+    xml->get_widget("map_image", map_image);
 
-    Gtk::Label *hero_label;
-    xml->get_widget("hero_label", hero_label);
-    hero_label->set_markup("<b>" + hero->getName() + "</b>");
-
-    Gtk::Image *hero_image;
-    xml->get_widget("hero_image", hero_image);
-    hero_image->property_pixbuf() = to_pixbuf(gc->getArmyPic(hero));
+    std::list<Hero*> heroes;
+    heroes = Playerlist::getActiveplayer()->getHeroes();
+    heroesmap = new HeroesMap(heroes);
+    if (hero)
+      heroesmap->setSelectedHero(hero);
+    else
+      {
+	Player *p = Playerlist::getActiveplayer();
+	hero = *heroes.begin();
+	pos = p->getPositionOfArmyById(hero->getId());
+	heroesmap->setSelectedHero(hero);
+      }
+    heroesmap->map_changed.connect(
+	sigc::mem_fun(this, &HeroDialog::on_map_changed));
+    Gtk::EventBox *map_eventbox;
+    xml->get_widget("map_eventbox", map_eventbox);
+    map_eventbox->add_events(Gdk::BUTTON_PRESS_MASK);
+    map_eventbox->signal_button_press_event().connect(
+	sigc::mem_fun(*this, &HeroDialog::on_map_mouse_button_event));
 
     xml->get_widget("info_label1", info_label1);
     xml->get_widget("info_label2", info_label2);
-    fill_in_info_labels();
-	
+
     xml->get_widget("drop_button", drop_button);
     xml->get_widget("pickup_button", pickup_button);
-
     drop_button->signal_clicked()
 	.connect(sigc::mem_fun(this, &HeroDialog::on_drop_clicked));
     pickup_button->signal_clicked()
 	.connect(sigc::mem_fun(this, &HeroDialog::on_pickup_clicked));
     
+    xml->get_widget("next_button", next_button);
+    xml->get_widget("prev_button", prev_button);
+    next_button->signal_clicked()
+	.connect(sigc::mem_fun(this, &HeroDialog::on_next_clicked));
+    prev_button->signal_clicked()
+	.connect(sigc::mem_fun(this, &HeroDialog::on_prev_clicked));
+    if (heroes.size() <= 1)
+      {
+	next_button->set_sensitive(false);
+	prev_button->set_sensitive(false);
+      }
+
+    heroes_list = Gtk::ListStore::create(heroes_columns);
+    xml->get_widget("heroes_treeview", heroes_treeview);
+    heroes_treeview->set_model(heroes_list);
+    heroes_treeview->append_column(_("Hero"), heroes_columns.name);
+
+    heroes_list->clear();
+    guint32 count = 0;
+    for (std::list<Hero*>::iterator it = heroes.begin(); it != heroes.end();
+	 it++)
+      {
+	add_hero (*it);
+      if (*it == hero)
+	{
+	  Gtk::TreeModel::Row row;
+	  row = heroes_treeview->get_model()->children()[count];
+	  heroes_treeview->get_selection()->select(row);
+	}
+      count++;
+      }
+    heroes_treeview->get_selection()->signal_changed()
+	.connect(sigc::mem_fun(this, &HeroDialog::on_hero_changed));
+
     item_list = Gtk::ListStore::create(item_columns);
     xml->get_widget("treeview", item_treeview);
     item_treeview->set_model(item_list);
@@ -84,31 +127,22 @@ HeroDialog::HeroDialog(Hero *h, Vector<int> p)
     item_treeview->append_column(_("Status"), item_columns.status);
 
     item_treeview->get_selection()->signal_changed()
-	.connect(sigc::mem_fun(this, &HeroDialog::on_selection_changed));
+	.connect(sigc::mem_fun(this, &HeroDialog::on_item_selection_changed));
 
     events_list = Gtk::ListStore::create(events_columns);
     xml->get_widget("events_treeview", events_treeview);
     events_treeview->append_column("", events_columns.desc);
     events_treeview->set_model(events_list);
     events_list->clear();
-    std::list<History* > events;
-    events = hero->getOwner()->getHistoryForHeroId(hero->getId());
-    for (std::list<History*>::iterator i = events.begin(); i != events.end();
-	 i++)
-      addHistoryEvent(*i);
 
-    on_selection_changed();
-
-    // populate the item list
-    Backpack *backpack = hero->getBackpack();
-    for (Backpack::iterator i = backpack->begin(); i != backpack->end(); ++i)
-	add_item(*i, true);
-
-    MapBackpack *ground = GameMap::getInstance()->getTile(pos)->getBackpack();
-    for (MapBackpack::iterator i = ground->begin(); i != ground->end(); i++)
-      add_item(*i, false);
+    on_item_selection_changed();
 }
 
+HeroDialog::~HeroDialog()
+{
+  delete heroesmap;
+  delete dialog;
+}
 void HeroDialog::addHistoryEvent(History *history)
 {
   Glib::ustring s = "";
@@ -205,22 +239,64 @@ void HeroDialog::hide()
 
 void HeroDialog::run()
 {
-    GameMap *gm = GameMap::getInstance();
-    dialog->show();
-    dialog->run();
-    if (gm->getTile(pos)->getBackpack()->size() > 0 && 
-        gm->getTile(pos)->getMaptileType() == Tile::WATER)
-      {
-        // splash, items lost forever
-        while (gm->getTile(pos)->getBackpack()->size())
-          {
-	    MapBackpack::iterator i = gm->getTile(pos)->getBackpack()->begin();
-            gm->getTile(pos)->getBackpack()->removeFromBackpack(*i);
-          }
-      }
+  heroesmap->resize();
+  heroesmap->draw(Playerlist::getActiveplayer());
+  GameMap *gm = GameMap::getInstance();
+  dialog->show_all();
+  show_hero();
+  dialog->run();
+  if (gm->getTile(pos)->getBackpack()->size() > 0 && 
+      gm->getTile(pos)->getMaptileType() == Tile::WATER)
+    {
+      // splash, items lost forever
+      while (gm->getTile(pos)->getBackpack()->size())
+        {
+	  MapBackpack::iterator i = gm->getTile(pos)->getBackpack()->begin();
+          gm->getTile(pos)->getBackpack()->removeFromBackpack(*i);
+        }
+    }
 }
 
-void HeroDialog::on_selection_changed()
+void HeroDialog::update_hero_list()
+{
+  inhibit_hero_changed = true;
+    std::list<Hero*> heroes;
+    heroes = Playerlist::getActiveplayer()->getHeroes();
+    guint32 count = 0;
+    for (std::list<Hero*>::iterator it = heroes.begin(); it != heroes.end();
+	 it++)
+      {
+      if (*it == hero)
+	{
+	  Gtk::TreeModel::Row row;
+	  row = heroes_treeview->get_model()->children()[count];
+	  heroes_treeview->get_selection()->select(row);
+	}
+      count++;
+      }
+  inhibit_hero_changed = false;
+}
+
+void HeroDialog::on_hero_changed()
+{
+  if (inhibit_hero_changed == true)
+    return;
+  Glib::RefPtr<Gtk::TreeSelection> selection = heroes_treeview->get_selection();
+  Gtk::TreeModel::iterator iterrow = selection->get_selected();
+
+  if (iterrow)
+    {
+      Gtk::TreeModel::Row row = *iterrow;
+      hero = row[heroes_columns.hero];
+      pos = Playerlist::getActiveplayer()->getPositionOfArmyById(hero->getId());
+      heroesmap->setSelectedHero(hero);
+      show_hero();
+      heroesmap->draw(Playerlist::getActiveplayer());
+    }
+
+}
+
+void HeroDialog::on_item_selection_changed()
 {
     Gtk::TreeIter i = item_treeview->get_selection()->get_selected();
     if (i)
@@ -244,11 +320,47 @@ void HeroDialog::on_drop_clicked()
 	Item *item = (*i)[item_columns.item];
 	hero->getOwner()->heroDropItem (hero, item, pos);
 	(*i)[item_columns.status] = _("On the ground");
-	on_selection_changed();
+	on_item_selection_changed();
 	fill_in_info_labels();
     }
 }
 
+void HeroDialog::on_next_clicked()
+{
+  std::list<Hero*> heroes;
+  heroes = Playerlist::getActiveplayer()->getHeroes();
+  std::list<Hero*>::iterator next;
+  next = find (heroes.begin(), heroes.end(), hero);
+  if (next != heroes.end())
+    {
+      next++;
+      if (next == heroes.end())
+	next = heroes.begin();
+      hero = *next;
+      heroesmap->setSelectedHero(hero);
+      show_hero();
+      heroesmap->draw(Playerlist::getActiveplayer());
+    }
+  update_hero_list();
+}
+void HeroDialog::on_prev_clicked()
+{
+  std::list<Hero*> heroes;
+  heroes = Playerlist::getActiveplayer()->getHeroes();
+  std::list<Hero*>::reverse_iterator prev;
+  prev = find (heroes.rbegin(), heroes.rend(), hero);
+  if (prev != heroes.rend())
+    {
+      prev++;
+      if (prev == heroes.rend())
+	prev = heroes.rbegin();
+      hero = *prev;
+      heroesmap->setSelectedHero(hero);
+      show_hero();
+      heroesmap->draw(Playerlist::getActiveplayer());
+    }
+  update_hero_list();
+}
 void HeroDialog::on_pickup_clicked()
 {
     Gtk::TreeIter i = item_treeview->get_selection()->get_selected();
@@ -259,11 +371,18 @@ void HeroDialog::on_pickup_clicked()
           item->setPlanted(false);
 	hero->getOwner()->heroPickupItem (hero, item, pos);
 	(*i)[item_columns.status] = _("In backpack");
-	on_selection_changed();
+	on_item_selection_changed();
 	fill_in_info_labels();
     }
 }
 
+void HeroDialog::add_hero(Hero *h)
+{
+    Gtk::TreeIter i = heroes_list->append();
+    (*i)[heroes_columns.name] = h->getName();
+    (*i)[heroes_columns.hero] = h;
+}
+
 void HeroDialog::add_item(Item *item, bool in_backpack)
 {
     Gtk::TreeIter i = item_list->append();
@@ -281,7 +400,7 @@ void HeroDialog::add_item(Item *item, bool in_backpack)
 
 void HeroDialog::fill_in_info_labels()
 {
-    Uint32 bonus = 0;
+    guint32 bonus = 0;
     Glib::ustring s;
     // fill in first column
     Backpack *backpack = hero->getBackpack();
@@ -316,7 +435,7 @@ void HeroDialog::fill_in_info_labels()
     s += String::ucompose(_("Level: %1"), hero->getLevel());
     s += "\n";
     s += String::ucompose(_("Experience: %1"),
-			  std::setprecision(2), hero->getXP());
+			  std::setprecision(3), hero->getXP());
     info_label1->set_text(s);
 
     // fill in second column
@@ -332,3 +451,48 @@ void HeroDialog::fill_in_info_labels()
     s += String::ucompose(_("Upkeep: %1"), hero->getUpkeep());
     info_label2->set_text(s);
 }
+
+void HeroDialog::on_map_changed(Glib::RefPtr<Gdk::Pixmap> map)
+{
+    map_image->property_pixmap() = map;
+}
+
+bool HeroDialog::on_map_mouse_button_event(GdkEventButton *e)
+{
+    if (e->type != GDK_BUTTON_PRESS)
+	return true;	// useless event
+    
+    heroesmap->mouse_button_event(to_input_event(e));
+    
+    hero = heroesmap->getSelectedHero();
+    pos = Playerlist::getActiveplayer()->getPositionOfArmyById(hero->getId());
+    show_hero();
+    heroesmap->draw(Playerlist::getActiveplayer());
+    update_hero_list();
+    return true;
+}
+
+void HeroDialog::show_hero()
+{
+    set_title(hero->getName());
+
+    fill_in_info_labels();
+    std::list<History* > events;
+    events = hero->getOwner()->getHistoryForHeroId(hero->getId());
+    events_list->clear();
+    for (std::list<History*>::iterator i = events.begin(); i != events.end();
+	 i++)
+      addHistoryEvent(*i);
+	
+    // populate the item list
+    item_list->clear();
+    Backpack *backpack = hero->getBackpack();
+    for (Backpack::iterator i = backpack->begin(); i != backpack->end(); ++i)
+	add_item(*i, true);
+
+    MapBackpack *ground = GameMap::getInstance()->getTile(pos)->getBackpack();
+    for (MapBackpack::iterator i = ground->begin(); i != ground->end(); i++)
+      add_item(*i, false);
+
+  return;
+}
