@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
 
 #include "hero-levels-dialog.h"
@@ -31,7 +31,6 @@
 #include "player.h"
 #include "army.h"
 #include "armysetlist.h"
-#include "stacklist.h"
 #include "stack.h"
 #include "hero.h"
 #include "GraphicsCache.h"
@@ -40,15 +39,13 @@ void HeroLevelsDialog::init(Player *theplayer)
 {
     player = theplayer;
     
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/hero-levels-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/hero-levels-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
 
     heroes_list = Gtk::ListStore::create(heroes_columns);
     xml->get_widget("treeview", heroes_treeview);
@@ -75,14 +72,15 @@ HeroLevelsDialog::HeroLevelsDialog(Player *theplayer)
 {
 
   init (theplayer);
-    const Stacklist* sl = theplayer->getStacklist();
-    for (Stacklist::const_iterator it = sl->begin(); it != sl->end(); it++)
-      for (Stack::iterator sit = (*it)->begin(); sit != (*it)->end(); sit++)
-        if ((*sit)->isHero()) 
-          addHero(dynamic_cast<Hero*>(*sit));
-     
+  std::list<Hero*> heroes = theplayer->getHeroes();
+  for (std::list<Hero*>::iterator it = heroes.begin(); it != heroes.end(); it++)
+    addHero(*it);
 }
 
+HeroLevelsDialog::~HeroLevelsDialog()
+{
+  delete dialog;
+}
 void HeroLevelsDialog::set_parent_window(Gtk::Window &parent)
 {
     dialog->set_transient_for(parent);
@@ -114,11 +112,11 @@ void HeroLevelsDialog::addHero(Hero *h)
     GraphicsCache *gc = GraphicsCache::getInstance();
     Gtk::TreeIter i = heroes_list->append();
     (*i)[heroes_columns.name] = h->getName();
-    (*i)[heroes_columns.image] = to_pixbuf(gc->getArmyPic(player->getArmyset(),
-                                           h->getTypeId(), player, NULL));
+    (*i)[heroes_columns.image] = gc->getArmyPic(player->getArmyset(),
+						h->getTypeId(), player, NULL)->to_pixbuf();
     (*i)[heroes_columns.level] = String::ucompose(_("%1"), h->getLevel());
-    (*i)[heroes_columns.exp] = (Uint32)h->getXP();
-    (*i)[heroes_columns.needs] = (Uint32)h->getXpNeededForNextLevel();
+    (*i)[heroes_columns.exp] = (guint32)h->getXP();
+    (*i)[heroes_columns.needs] = (guint32)h->getXpNeededForNextLevel();
     (*i)[heroes_columns.str] = h->getStat(Army::STRENGTH, true);
     (*i)[heroes_columns.move] = h->getStat(Army::MOVES, true);
 }
