@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,9 +17,8 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
-#include <gtkmm/label.h>
 
 #include "history-report-dialog.h"
 
@@ -33,6 +32,7 @@
 #include "File.h"
 #include "GameMap.h"
 #include "citylist.h"
+#include "city.h"
 #include "playerlist.h"
 #include "history.h"
 #include "network-history.h"
@@ -41,20 +41,18 @@
 HistoryReportDialog::HistoryReportDialog(Player *p, HistoryReportType type)
 {
   d_player = p;
-  Glib::RefPtr<Gnome::Glade::Xml> xml
-    = Gnome::Glade::Xml::create(get_glade_path()
-				+ "/history-report-dialog.glade");
+  Glib::RefPtr<Gtk::Builder> xml
+    = Gtk::Builder::create_from_file(get_glade_path()
+				+ "/history-report-dialog.ui");
 
-  Gtk::Dialog *d = 0;
-  xml->get_widget("dialog", d);
-  dialog.reset(d);
-  decorate(dialog.get());
+  xml->get_widget("dialog", dialog);
+  decorate(dialog);
 
   generatePastCitylists();
   generatePastEventlists();
 
   xml->get_widget("map_image", map_image);
-  historymap.reset(new HistoryMap(Citylist::getInstance()));
+  historymap = new HistoryMap(Citylist::getInstance());
   historymap->map_changed.connect
     (sigc::mem_fun(this, &HistoryReportDialog::on_map_changed));
 
@@ -98,10 +96,7 @@ HistoryReportDialog::HistoryReportDialog(Player *p, HistoryReportType type)
     {
       if (*pit == Playerlist::getInstance()->getNeutral())
 	continue;
-      SDL_Color sdl = (*pit)->getColor();
-      colour.set_red(sdl.r * 255); 
-      colour.set_green(sdl.g * 255); 
-      colour.set_blue(sdl.b * 255);
+      colour = (*pit)->getColor();
       if (*pit == d_player)
 	d_colours.push_front(colour);
       else
@@ -124,7 +119,7 @@ HistoryReportDialog::HistoryReportDialog(Player *p, HistoryReportType type)
 			     _("Score"), _("Turns"));
   winner_alignment->add(*manage(rank_chart));
 
-  fill_in_turn_info((Uint32)turn_scale->get_value());
+  fill_in_turn_info((guint32)turn_scale->get_value());
 }
 
 HistoryReportDialog::~HistoryReportDialog()
@@ -138,6 +133,8 @@ HistoryReportDialog::~HistoryReportDialog()
       for (; hit != hist.end(); hit++)
 	delete (*hit);
     }
+  delete dialog;
+  delete historymap;
 }
 
 void HistoryReportDialog::generatePastEventlists()
@@ -173,7 +170,7 @@ void HistoryReportDialog::generatePastEventlists()
 	  if (*pit == Playerlist::getInstance()->getNeutral())
 	    continue;
 	  //dump everything up to the next turn
-	  Uint32 id = (*pit)->getId();
+	  guint32 id = (*pit)->getId();
 	  if (hit[id] == hist[id]->end())
 	    continue;
 	  for (; hit[id] != hist[id]->end(); ++hit[id])
@@ -278,7 +275,7 @@ void HistoryReportDialog::generatePastCitylists()
 	  if (*pit == Playerlist::getInstance()->getNeutral())
 	    continue;
 	  //dump everything up to the next turn
-	  Uint32 id = (*pit)->getId();
+	  guint32 id = (*pit)->getId();
 	  if (hit[id] == hist[id]->end())
 	    continue;
 	  for (; hit[id] != hist[id]->end(); hit[id]++)
@@ -290,7 +287,7 @@ void HistoryReportDialog::generatePastCitylists()
 		}
 	      else if ((*hit[id])->getType() == History::CITY_WON)
 		{
-		  Uint32 city_id;
+		  guint32 city_id;
 		  city_id = dynamic_cast<History_CityWon*>(*hit[id])->getCityId();
 		  //find city with this city id in clist
 		  LocationList<City*>::iterator cit = clist->begin();
@@ -303,7 +300,7 @@ void HistoryReportDialog::generatePastCitylists()
 		}
 	      else if ((*hit[id])->getType() == History::CITY_RAZED)
 		{
-		  Uint32 city_id;
+		  guint32 city_id;
 		  city_id = dynamic_cast<History_CityRazed*>(*hit[id])->getCityId();
 		  //find city with this city id in clist
 		  LocationList<City*>::iterator cit = clist->begin();
@@ -358,15 +355,15 @@ void HistoryReportDialog::run()
   dialog->run();
 }
 
-void HistoryReportDialog::on_map_changed(SDL_Surface *map)
+void HistoryReportDialog::on_map_changed(Glib::RefPtr<Gdk::Pixmap> map)
 {
-  map_image->property_pixbuf() = to_pixbuf(map);
+  map_image->property_pixmap() = map;
 }
 
 void HistoryReportDialog::on_turn_changed(Gtk::Scale *scale)
 {
   //tell the historymap to show another set of cities
-  Uint32 turn = (Uint32)turn_scale->get_value();
+  guint32 turn = (guint32)turn_scale->get_value();
   if (turn > past_citylists.size() - 1)
     historymap->updateCities(Citylist::getInstance());
   else
@@ -396,10 +393,10 @@ void HistoryReportDialog::update_window_title()
     }
 }
 
-void HistoryReportDialog::fill_in_turn_info(Uint32 turn)
+void HistoryReportDialog::fill_in_turn_info(guint32 turn)
 {
   Glib::ustring s;
-  Uint32 count;
+  guint32 count;
   update_window_title();
 
   //update the event list
@@ -414,8 +411,8 @@ void HistoryReportDialog::fill_in_turn_info(Uint32 turn)
 
   //update the gold chart
   //on turn # you had # gold pieces
-  std::list<Uint32> goldlist = *past_goldcounts.begin();
-  std::list<Uint32>::iterator it = goldlist.begin();
+  std::list<guint32> goldlist = *past_goldcounts.begin();
+  std::list<guint32>::iterator it = goldlist.begin();
   count=1;
   for (; it != goldlist.end(); it++, count++)
     {
@@ -435,7 +432,7 @@ void HistoryReportDialog::fill_in_turn_info(Uint32 turn)
   gold_label->set_text(s);
 
   //update the city chart
-  std::list<Uint32> citylist = *past_citycounts.begin();
+  std::list<guint32> citylist = *past_citycounts.begin();
   it = citylist.begin();
   count = 0;
   for (; it != citylist.end(); it++, count++)
@@ -456,8 +453,8 @@ void HistoryReportDialog::fill_in_turn_info(Uint32 turn)
   city_label->set_text(s);
 
   //on turn # you were coming #
-  std::list<Uint32> scores;
-  std::list<std::list<Uint32> >::iterator rit = past_rankcounts.begin();
+  std::list<guint32> scores;
+  std::list<std::list<guint32> >::iterator rit = past_rankcounts.begin();
   for (; rit != past_rankcounts.end(); rit++)
     {
       it = (*rit).begin();
@@ -504,7 +501,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  History_FoundSage *ev;
 	  ev = static_cast<History_FoundSage *>(history);
 	  s = String::ucompose(_("%1 finds a sage!"), ev->getHeroName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     case History::HERO_EMERGES:
@@ -513,7 +510,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  ev = static_cast<History_HeroEmerges *>(history);
 	  s = String::ucompose(_("%1 emerges in %2!"), ev->getHeroName(),
 			       ev->getCityName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     case History::HERO_QUEST_STARTED:
@@ -521,7 +518,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  History_HeroQuestStarted *ev;
 	  ev = static_cast<History_HeroQuestStarted*>(history);
 	  s = String::ucompose(_("%1 begins a quest!"), ev->getHeroName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     case History::HERO_QUEST_COMPLETED:
@@ -529,7 +526,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  History_HeroQuestCompleted *ev;
 	  ev = static_cast<History_HeroQuestCompleted *>(history);
 	  s = String::ucompose(_("%1 finishes a quest!"), ev->getHeroName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     case History::HERO_KILLED_IN_CITY:
@@ -538,7 +535,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  ev = static_cast<History_HeroKilledInCity *>(history);
 	  s = String::ucompose(_("%1 is killed in %2!"), ev->getHeroName(),
 			       ev->getCityName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     case History::HERO_KILLED_IN_BATTLE:
@@ -546,7 +543,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  History_HeroKilledInBattle *ev;
 	  ev = static_cast<History_HeroKilledInBattle *>(history);
 	  s = String::ucompose(_("%1 is killed in battle!"), ev->getHeroName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     case History::HERO_KILLED_SEARCHING:
@@ -555,7 +552,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  ev = static_cast<History_HeroKilledSearching *>(history);
 	  s = String::ucompose(_("%1 is killed while searching!"), 
 			       ev->getHeroName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     case History::HERO_CITY_WON:
@@ -564,7 +561,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  ev = static_cast<History_HeroCityWon *>(history);
 	  s = String::ucompose(_("%1 conquers %2!"), ev->getHeroName(), 
 			       ev->getCityName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     case History::PLAYER_VANQUISHED:
@@ -572,7 +569,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  History_PlayerVanquished *ev;
 	  ev = static_cast<History_PlayerVanquished*>(history);
 	  s = String::ucompose(_("%1 utterly vanquished!"), p->getName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     case History::DIPLOMATIC_PEACE:
@@ -603,7 +600,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  Player *opponent = pl->getPlayer(ev->getOpponentId());
 	  s = String::ucompose(_("Treachery by %1 on %2!"), p->getName(),
 			       opponent->getName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     case History::HERO_FINDS_ALLIES:
@@ -611,7 +608,7 @@ void HistoryReportDialog::addHistoryEvent(NetworkHistory *event)
 	  History_HeroFindsAllies *ev;
 	  ev = static_cast<History_HeroFindsAllies*>(history);
 	  s = String::ucompose(_("%1 finds allies!"), ev->getHeroName());
-	  (*i)[events_columns.image] = to_pixbuf(gc->getShieldPic(1, p));
+	  (*i)[events_columns.image] = gc->getShieldPic(1, p)->to_pixbuf();
 	  break;
 	}
     default:
@@ -641,7 +638,7 @@ void HistoryReportDialog::generatePastWinningCounts()
 	continue;
       std::list<History*> *hist = (*pit)->getHistorylist();
       std::list<History*>::iterator hit = hist->begin();
-      std::list<Uint32> line;
+      std::list<guint32> line;
       for (; hit != hist->end(); hit++)
 	{
 	  if ((*hit)->getType() == History::SCORE)
@@ -650,7 +647,7 @@ void HistoryReportDialog::generatePastWinningCounts()
 	      line.push_back (event->getScore());
 	    }
 	}
-      line.push_back ((Uint32)(*pit)->getScore());
+      line.push_back ((guint32)(*pit)->getScore());
       if (*pit == d_player)
 	past_rankcounts.push_front(line);
       else
@@ -670,10 +667,10 @@ void HistoryReportDialog::generatePastCityCounts()
       //go through the past city lists, searching for cities owned by this
       //player
 
-      std::list<Uint32> line;
+      std::list<guint32> line;
       for (unsigned int i = 0; i < past_citylists.size(); i++)
 	{
-	  Uint32 total_cities = 0;
+	  guint32 total_cities = 0;
 	  LocationList<City*>::iterator it = past_citylists[i]->begin();
 	  for (; it != past_citylists[i]->end(); it++)
 	    {
@@ -703,7 +700,7 @@ void HistoryReportDialog::generatePastGoldCounts()
 	continue;
       std::list<History*> *hist = (*pit)->getHistorylist();
       std::list<History*>::iterator hit = hist->begin();
-      std::list<Uint32> line;
+      std::list<guint32> line;
       for (; hit != hist->end(); hit++)
 	{
 	  if ((*hit)->getType() == History::GOLD_TOTAL)
@@ -712,7 +709,7 @@ void HistoryReportDialog::generatePastGoldCounts()
 	      line.push_back (event->getGold());
 	    }
 	}
-      line.push_back ((Uint32)(*pit)->getGold());
+      line.push_back ((guint32)(*pit)->getGold());
       if (*pit == d_player)
 	past_goldcounts.push_front(line);
       else
