@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,15 +21,7 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/image.h>
-#include <gtkmm/label.h>
-#include <gtkmm/scale.h>
-#include <gtkmm/notebook.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/treemodelcolumn.h>
-#include <gtkmm/treeview.h>
-#include <gtkmm/alignment.h>
+#include <gtkmm.h>
 
 #include "line-chart.h"
 
@@ -38,8 +30,8 @@
 #include "history.h"
 #include "player.h"
 class Citylist;
+class City;
 
-struct SDL_Surface;
 class Player;
 #include "decorated.h"
 // dialog for showing all ruins and temples
@@ -62,8 +54,8 @@ class HistoryReportDialog: public Decorated
     void hide();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
-    std::auto_ptr<HistoryMap> historymap;
+    Gtk::Dialog* dialog;
+    HistoryMap* historymap;
 
     Player *d_player;
     Gtk::Scale *turn_scale;
@@ -78,10 +70,10 @@ class HistoryReportDialog: public Decorated
     std::vector<LocationList<City*>* > past_citylists;
     LineChart *city_chart;
     std::vector<std::list<NetworkHistory *> > past_eventlists;
-    std::list<std::list<Uint32> > past_citycounts;
-    std::list<std::list<Uint32> > past_goldcounts;
+    std::list<std::list<guint32> > past_citycounts;
+    std::list<std::list<guint32> > past_goldcounts;
     LineChart *gold_chart;
-    std::list<std::list<Uint32> > past_rankcounts;
+    std::list<std::list<guint32> > past_rankcounts;
     LineChart *rank_chart;
 
     Gtk::Image *map_image;
@@ -103,9 +95,9 @@ class HistoryReportDialog: public Decorated
     Glib::RefPtr<Gtk::ListStore> events_list;
     void addHistoryEvent(NetworkHistory *event);
     void on_close_button();
-    void on_map_changed(SDL_Surface *map);
+    void on_map_changed(Glib::RefPtr<Gdk::Pixmap> map);
     void on_turn_changed(Gtk::Scale *scale);
-    void fill_in_turn_info(Uint32 turn);
+    void fill_in_turn_info(guint32 turn);
     void on_switch_page(GtkNotebookPage *page, guint number);
     void update_window_title();
 
