@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -23,12 +23,7 @@
 #include <string>
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/button.h>
-#include <gtkmm/label.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/treemodelcolumn.h>
-#include <gtkmm/treeview.h>
+#include <gtkmm.h>
 
 class XML_Helper;
 
@@ -38,6 +33,7 @@ class LoadScenarioDialog: public Decorated
 {
  public:
     LoadScenarioDialog();
+    ~LoadScenarioDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -47,13 +43,14 @@ class LoadScenarioDialog: public Decorated
     std::string get_scenario_filename();
 
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
     Gtk::Button *load_button;
-    Gtk::Label *name_label;
-    Gtk::Label *description_label;
+    Gtk::TextView *description_textview;
     Gtk::Label *num_players_label;
     Gtk::Label *num_cities_label;
     Gtk::TreeView *scenarios_treeview;
+    Gtk::Button *add_scenario_button;
+    Gtk::Button *remove_scenario_button;
 
     class ScenariosColumns: public Gtk::TreeModelColumnRecord {
     public:
@@ -76,6 +73,9 @@ class LoadScenarioDialog: public Decorated
     bool scan_scenario_details(std::string tag, XML_Helper* helper);
     bool scan_scenario_name(std::string tag, XML_Helper* helper);
     void add_scenario(std::string filename);
+    void on_add_scenario_clicked();
+    void on_remove_scenario_clicked();
+    int copy_file (Glib::ustring from, Glib::ustring to);
 };
 
 #endif
