@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
 
 #include "preferences-dialog.h"
@@ -40,15 +40,13 @@
 PreferencesDialog::PreferencesDialog(bool readonly)
 {
   d_readonly = readonly;
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/preferences-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/preferences-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
 
     xml->get_widget("show_turn_popup_checkbutton", show_turn_popup_checkbutton);
     xml->get_widget("play_music_checkbutton", play_music_checkbutton);
@@ -65,7 +63,8 @@ PreferencesDialog::PreferencesDialog(bool readonly)
 	if (p == Playerlist::getInstance()->getNeutral())
 	  continue;
 	Gtk::HBox *player_hbox = new Gtk::HBox();
-	Gtk::Image *image = new Gtk::Image(to_pixbuf(gc->getShieldPic(2, p)));
+	Gtk::Image *image = new Gtk::Image();
+	image->property_pixbuf() = gc->getShieldPic(2, p)->to_pixbuf();
 	Gtk::ComboBoxText *type = new Gtk::ComboBoxText();
 	type->signal_changed().connect
 	  (sigc::bind(sigc::mem_fun
@@ -85,7 +84,7 @@ PreferencesDialog::PreferencesDialog(bool readonly)
 	  }
 	else
 	  type->set_active(1);
-	if (p->isDead())
+	if (p->isDead() || Playerlist::getActiveplayer() == p)
 	  {
 	    type->set_sensitive(false);
 	    observe->set_sensitive(false);
@@ -119,6 +118,10 @@ PreferencesDialog::PreferencesDialog(bool readonly)
     
 }
 
+PreferencesDialog::~PreferencesDialog()
+{
+  delete dialog;
+}
 void PreferencesDialog::set_parent_window(Gtk::Window &parent)
 {
     dialog->set_transient_for(parent);
@@ -198,6 +201,7 @@ void PreferencesDialog::run(Game *game)
 		Playerlist::getInstance()->swap(old_player, new_player);
 		//disconnect and connect game signals
 		game->addPlayer(new_player);
+		delete old_player;
 	      }
 	  }
 	else //changing computer to:
@@ -209,7 +213,7 @@ void PreferencesDialog::run(Game *game)
 		Playerlist::getInstance()->swap(old_player, new_player);
 		//disconnect and connect game signals
 		game->addPlayer(new_player);
-		
+		delete old_player;
 	      }
 	    else //computer, no change
 	      ;
