@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -23,12 +23,7 @@
 #include <memory>
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/checkbutton.h>
-#include <gtkmm/image.h>
-#include <gtkmm/comboboxtext.h>
-#include <gtkmm/scale.h>
-#include <gtkmm/box.h>
+#include <gtkmm.h>
 
 #include "vector.h"
 
@@ -40,6 +35,7 @@ class PreferencesDialog: public Decorated
 {
  public:
     PreferencesDialog(bool readonly);
+    ~PreferencesDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -47,7 +43,7 @@ class PreferencesDialog: public Decorated
     void hide();
 
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
+    Gtk::Dialog* dialog;
     Gtk::CheckButton *show_turn_popup_checkbutton;
     Gtk::CheckButton *play_music_checkbutton;
     Gtk::Scale *music_volume_scale;
