@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,10 +17,8 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/eventbox.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
-#include <gtkmm/label.h>
 
 #include "sage-dialog.h"
 
@@ -40,15 +38,13 @@ SageDialog::SageDialog(Player *player, Hero *h, Ruin *r)
     ruin = r;
     hero = h;
     
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/sage-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/sage-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
 
     rewards_list = Gtk::ListStore::create(rewards_columns);
     xml->get_widget("rewardtreeview", rewards_treeview);
@@ -60,7 +56,7 @@ SageDialog::SageDialog(Player *player, Hero *h, Ruin *r)
     xml->get_widget("map_image", map_image);
     xml->get_widget("continue_button", continue_button);
 
-    ruinmap.reset(new RuinMap(ruin));
+    ruinmap = new RuinMap(ruin);
     ruinmap->map_changed.connect(
 	sigc::mem_fun(this, &SageDialog::on_map_changed));
 
@@ -92,6 +88,11 @@ SageDialog::SageDialog(Player *player, Hero *h, Ruin *r)
   continue_button->set_sensitive(false);
 
 }
+SageDialog::~SageDialog()
+{
+  delete dialog;
+  delete ruinmap;
+}
 
 void SageDialog::set_parent_window(Gtk::Window &parent)
 {
@@ -144,9 +145,9 @@ Reward *SageDialog::run()
     return reward;
 }
 
-void SageDialog::on_map_changed(SDL_Surface *map)
+void SageDialog::on_map_changed(Glib::RefPtr<Gdk::Pixmap> map)
 {
-  map_image->property_pixbuf() = to_pixbuf(map);
+  map_image->property_pixmap() = map;
 }
 
 void SageDialog::addReward(Reward *reward)
