@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,18 +21,12 @@
 #include <memory>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <gtkmm/dialog.h>
-#include <gtkmm/image.h>
-#include <gtkmm/treeview.h>
-#include <gtkmm/liststore.h>
-#include <gtkmm/treemodelcolumn.h>
-#include <gtkmm/button.h>
+#include <gtkmm.h>
 
 #include "ruinmap.h"
 #include "player.h"
 #include "hero.h"
 
-struct SDL_Surface;
 
 #include "decorated.h"
 
@@ -41,6 +35,7 @@ class SageDialog: public Decorated
 {
  public:
     SageDialog(Player *player, Hero *hero, Ruin *r);
+    ~SageDialog();
 
     void set_parent_window(Gtk::Window &parent);
 
@@ -48,8 +43,8 @@ class SageDialog: public Decorated
     Reward *run();
     
  private:
-    std::auto_ptr<Gtk::Dialog> dialog;
-    std::auto_ptr<RuinMap> ruinmap;
+    Gtk::Dialog* dialog;
+    RuinMap* ruinmap;
 
     Gtk::TreeView *rewards_treeview;
 
@@ -71,7 +66,7 @@ class SageDialog: public Decorated
     Ruin *ruin;
 
     std::list<Reward*> common_rewards;
-    void on_map_changed(SDL_Surface *map);
+    void on_map_changed(Glib::RefPtr<Gdk::Pixmap> map);
     void addReward(Reward *reward);
     Reward *grabSelectedReward();
     void on_reward_selected();
