@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,12 +20,9 @@
 #define GUI_SPLASH_WINDOW_H
 
 #include <memory>
-#include <gtkmm/window.h>
-#include <gtkmm/button.h>
+#include <gtkmm.h>
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
-#include <gtkmm/container.h>
-#include <gtkmm/widget.h>
 
 #include "game-parameters.h"
 
@@ -48,31 +45,30 @@ class SplashWindow: public Decorated
     void show();
     void hide();
         
-    Gtk::Window *get_window() {return window.get();}
+    Gtk::Window *get_window() {return window;}
 
-    sigc::signal<void> sdl_initialized;
     sigc::signal<void, std::string, unsigned short, std::string> new_remote_network_game_requested;
     sigc::signal<void, GameParameters, int, std::string > new_hosted_network_game_requested;
     sigc::signal<void, GameParameters> new_pbm_game_requested;
     sigc::signal<void, GameParameters> new_game_requested;
-    sigc::signal<void, GameParameters> new_campaign_requested;
     sigc::signal<void, std::string> load_requested;
     sigc::signal<void> quit_requested;
 
  private:
-    std::auto_ptr<Gtk::Window> window;
+    Gtk::Window* window;
     Gtk::Button *crash_button;
-	
-    bool sdl_inited;
-    Gtk::Container *sdl_container;
-    Gtk::Widget *sdl_widget;
+    Gtk::Button *load_game_button;
+    Gtk::Button *load_scenario_button;
+    Gtk::Button *quit_button;
+    Gtk::Button *new_network_game_button;
+    Gtk::Button *new_pbm_game_button;
+    Gtk::Button *preferences_button;
+	    
     bool on_delete_event(GdkEventAny *e);
     void on_window_closed();
   
     std::string network_game_nickname;
     
-    void on_new_campaign_clicked();
-    void on_new_game_clicked();
     void on_new_network_game_clicked();
     void on_new_pbm_game_clicked();
     void on_load_game_clicked();
@@ -82,7 +78,6 @@ class SplashWindow: public Decorated
     void on_rescue_crashed_game_clicked();
 	
     void on_game_started(GameParameters g);
-    void on_campaign_started(GameParameters g);
     void on_network_game_created(GameParameters g);
     void on_pbm_game_created(GameParameters g);
     void on_network_game_selected(std::string ip, unsigned short port);
@@ -99,8 +94,7 @@ class SplashWindow: public Decorated
 #endif
         
  public:
-    void on_sdl_surface_changed();
+    //void on_sdl_surface_changed();
 };
 
-
 #endif
