@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,16 +18,12 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/image.h>
-#include <gtkmm/label.h>
+#include <gtkmm.h>
 
 #include "stack-info-tip.h"
 
 #include "glade-helpers.h"
 #include "image-helpers.h"
-#include "gtksdl.h"
-#include <SDL_video.h>
 
 #include "ucompose.hpp"
 #include "vector.h"
@@ -35,24 +31,29 @@
 #include "stack.h"
 #include "GraphicsCache.h"
 #include "map-tip-position.h"
-
+#include "decorated.h"
+#include "File.h"
 
 StackInfoTip::StackInfoTip(Gtk::Widget *target, MapTipPosition mpos, const Stack *stack)
 {
     GraphicsCache *gc = GraphicsCache::getInstance();
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/stack-info-window.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/stack-info-window.ui");
 
-    Gtk::Window *w = 0;
-    xml->get_widget("window", w);
-    window.reset(w);
+    xml->get_widget("window", window);
+    Decorated decorator;
+    decorator.decorate(window,File::getMiscFile("various/background.png"), 200);
 
     xml->get_widget("image_hbox", image_hbox);
 
     //fill up the hbox with images of the armies in the stack
     for (Stack::const_iterator it = stack->begin(); it != stack->end(); it++)
-      image_hbox->add(*manage(new Gtk::Image(to_pixbuf(gc->getArmyPic(*it)))));
+      {
+	Gtk::Image *image = new Gtk::Image();
+	image->property_pixbuf() = gc->getArmyPic(*it)->to_pixbuf();
+	image_hbox->add(*manage(image));
+      }
 
     image_hbox->show_all();
 
@@ -91,3 +92,7 @@ StackInfoTip::StackInfoTip(Gtk::Widget *target, MapTipPosition mpos, const Stack
     window->move(p.x, p.y);
     window->show();
 }
+StackInfoTip::~StackInfoTip()
+{
+  delete window;
+}
