@@ -1,9 +1,9 @@
-//  Copyright (C) 2007, Ole Laursen
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007 Ole Laursen
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,10 +21,8 @@
 
 #include <memory>
 #include <sigc++/trackable.h>
-#include <gtkmm/window.h>
-#include <gtkmm/widget.h>
+#include <gtkmm.h>
 #include "map-tip-position.h"
-#include <gtkmm/box.h>
 
 class Stack;
 
@@ -34,9 +32,10 @@ class StackInfoTip: public sigc::trackable
  public:
     // the tip is shown above target, simply delete the object to hide it again
     StackInfoTip(Gtk::Widget *target, MapTipPosition map, const Stack *stack);
+    ~StackInfoTip();
 
  private:
-    std::auto_ptr<Gtk::Window> window;
+    Gtk::Window* window;
     Gtk::Box *image_hbox;
 };
 
