@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,10 +17,8 @@
 
 #include <config.h>
 
-#include <libglademm/xml.h>
-#include <gtkmm/eventbox.h>
+#include <gtkmm.h>
 #include <sigc++/functors/mem_fun.h>
-#include <gtkmm/label.h>
 
 #include "surrender-dialog.h"
 
@@ -33,15 +31,13 @@
 
 SurrenderDialog::SurrenderDialog(int numEnemies)
 {
-    Glib::RefPtr<Gnome::Glade::Xml> xml
-	= Gnome::Glade::Xml::create(get_glade_path()
-				    + "/surrender-dialog.glade");
+    Glib::RefPtr<Gtk::Builder> xml
+	= Gtk::Builder::create_from_file(get_glade_path()
+				    + "/surrender-dialog.ui");
 
-    Gtk::Dialog *d = 0;
-    xml->get_widget("dialog", d);
-    dialog.reset(d);
-    decorate(dialog.get());
-    window_closed.connect(sigc::mem_fun(dialog.get(), &Gtk::Dialog::hide));
+    xml->get_widget("dialog", dialog);
+    decorate(dialog);
+    window_closed.connect(sigc::mem_fun(dialog, &Gtk::Dialog::hide));
 
     Gtk::Label *label;
     xml->get_widget("label", label);
@@ -58,6 +54,10 @@ SurrenderDialog::SurrenderDialog(int numEnemies)
       = File::getMiscFile("various/parley_offered.png");
 }
 
+SurrenderDialog::~SurrenderDialog()
+{
+  delete dialog;
+}
 
 void SurrenderDialog::set_parent_window(Gtk::Window &parent)
 {
@@ -71,5 +71,5 @@ void SurrenderDialog::hide()
 }
 bool SurrenderDialog::run()
 {
-  return dialog->run();
+  return dialog->run() == Gtk::RESPONSE_ACCEPT;
 }
