@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,13 +18,15 @@
 #include <config.h>
 
 #include <assert.h>
-#include <gtkmm/messagedialog.h>
+#include <gtkmm.h>
 
 #include "timed-message-dialog.h"
 
 #include "ucompose.hpp"
+#include "decorated.h"
 #include "defs.h"
 #include "timing.h"
+#include "decorated.h"
 
 TimedMessageDialog::TimedMessageDialog(Gtk::Window &parent, std::string message, int timeout, int grace)
 {
@@ -38,6 +40,10 @@ TimedMessageDialog::TimedMessageDialog(Gtk::Window &parent, std::string message,
   window->set_message(message);
   window->signal_response().connect
        (sigc::mem_fun(*this, &TimedMessageDialog::on_response));
+  Decorated decorator;
+  decorator.decorate(window);
+  decorator.window_closed.connect(sigc::mem_fun(window, &Gtk::Dialog::hide));
+  window->set_transient_for(parent);
 }
 
 void TimedMessageDialog::on_response(int id)
