@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,8 +20,7 @@
 
 #include <sigc++/trackable.h>
 #include <glibmm/main.h>
-#include <gtkmm/window.h>
-#include <gtkmm/messagedialog.h>
+#include <gtkmm.h>
 #include <string>
 
 // used for displaying a timed dialog that goes away after a period of time
