@@ -5,7 +5,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -30,6 +30,7 @@
 #include "counter.h"
 #include "Backpack.h"
 #include "xmlhelper.h"
+#include "playerlist.h"
 
 std::string Hero::d_tag = "hero";
 using namespace std;
@@ -40,6 +41,7 @@ Hero::Hero(const HeroProto& a)
 {
   d_level = 1;
   d_backpack = new Backpack();
+  d_owner = Playerlist::getInstance()->getPlayer(a.getOwnerId());
 }
 
 Hero::Hero(Hero& h)
@@ -97,10 +99,10 @@ bool Hero::loadBackpack(std::string tag, XML_Helper* helper)
   return false;
 }
 
-Uint32 Hero::getStat(Stat stat, bool modified) const
+guint32 Hero::getStat(Stat stat, bool modified) const
 {
-    Uint32 bonus = 0;
-    Uint32 value = Army::getStat(stat, modified);
+    guint32 bonus = 0;
+    guint32 value = Army::getStat(stat, modified);
 
     if (!modified)
         return value;
@@ -112,10 +114,10 @@ Uint32 Hero::getStat(Stat stat, bool modified) const
     return value + bonus;
 }
 
-Uint32 Hero::calculateNaturalCommand()
+guint32 Hero::calculateNaturalCommand()
 {
-  Uint32 command = 0;
-  Uint32 strength = getStat(Army::STRENGTH, true);
+  guint32 command = 0;
+  guint32 strength = getStat(Army::STRENGTH, true);
   if (strength == 9)
     command += 3;
   else if (strength > 6)
