@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,7 +17,7 @@
 
 #include "heromap.h"
 
-#include "sdl-draw.h"
+#include "gui/image-helpers.h"
 #include "city.h"
 #include "citylist.h"
 #include "playerlist.h"
@@ -40,18 +40,8 @@ void HeroMap::after_draw()
 
     start += Vector<int>(int(pixels_per_tile/2), int(pixels_per_tile/2));
 
-    SDL_Surface *tmp = gc->getSmallHeroPic();
-    
-    SDL_Rect r;
-    r.x = start.x - (tmp->w/2);
-    if (r.x < 0)
-      r.x = 0;
-    r.y = start.y - (tmp->h/2);
-    if (r.y < 0)
-      r.y = 0;
-    r.w = tmp->w;
-    r.h = tmp->h;
-    SDL_BlitSurface(tmp, 0, surface, &r);
+    PixMask *heropic = gc->getSmallHeroPic(true);
+    heropic->blit_centered(surface, start);
     map_changed.emit(surface);
 }
 
