@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -28,17 +28,18 @@ std::string HeroProto::d_tag = "heroproto";
 #define debug(x)
 
 HeroProto::HeroProto(const HeroProto& a)
-    :ArmyProto(a), d_gender(a.d_gender)
+    :ArmyProto(a), d_gender(a.d_gender), d_owner_id(a.d_owner_id)
 {
 }
 
 HeroProto::HeroProto(const ArmyProto& a)
-    :ArmyProto(a), d_gender(Hero::NONE)
+    :ArmyProto(a), d_owner_id(8)
 {
+  d_gender = a.getGender();
 }
 
 HeroProto::HeroProto()
-  :ArmyProto(), d_gender(Hero::NONE)
+  :ArmyProto(), d_gender(Hero::FEMALE), d_owner_id(0)
 {
 }
 
@@ -54,6 +55,7 @@ HeroProto::HeroProto(XML_Helper* helper)
     d_gender = Hero::NONE;
   else
     d_gender = Hero::genderFromString(gender_str);
+  helper->getData(d_owner_id, "owner");
   helper->getData(d_type_id, "type");
   helper->getData(d_armyset, "armyset");
 }
@@ -67,6 +69,7 @@ bool HeroProto::save(XML_Helper* helper) const
   retval &= ArmyProto::saveData(helper);
   std::string gender_str = Hero::genderToString(Hero::Gender(d_gender));
   retval &= helper->saveData("gender", gender_str);
+  retval &= helper->saveData("owner", d_owner_id);
   retval &= helper->saveData("armyset", d_armyset);
   retval &= helper->saveData("type", d_type_id);
 
