@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -54,14 +54,23 @@ class HeroProto : public ArmyProto
         void setGender(Hero::Gender gender){d_gender = gender;}
 
         //! Return the gender of the hero.
-        Uint32 getGender() const {return d_gender;}
+        guint32 getGender() const {return d_gender;}
         
+	//! Set the owner id for the hero prototype.
+	void setOwnerId(guint32 id) {d_owner_id = id;}
+
+	//! Return the id of the owner of the prototype.
+	guint32 getOwnerId() const {return d_owner_id;}
+
         //! Saves the hero prototype to an action
         virtual bool save(XML_Helper* helper) const;
     private:
 
 	//! Gender of the hero
 	Hero::Gender d_gender;
+
+	//! The player id that this prototype belongs to
+	guint32 d_owner_id;
 };
 
 #endif // HERO_PROTO_H
