@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -813,7 +813,7 @@ bool History_Score::doSave(XML_Helper* helper) const
   return retval;
 }
 
-bool History_Score::fillData(Uint32 score)
+bool History_Score::fillData(guint32 score)
 {
   d_score = score;
   return true;
