@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,9 +21,12 @@
 #include <assert.h>
 
 #include "vector.h"
+#include "gui/image-helpers.h"
+#include <gtkmm.h>
+#include <gdkmm.h>
 
 #include "historymap.h"
-#include "sdl-draw.h"
+#include "city.h"
 #include "GameMap.h"
 #include "GraphicsCache.h"
 
@@ -36,7 +39,7 @@ void HistoryMap::after_draw()
 {
     OverviewMap::after_draw();
     drawCities();
-    map_changed.emit(get_surface());
+    map_changed.emit(surface);
 }
 
 void HistoryMap::drawCities()
@@ -48,8 +51,8 @@ void HistoryMap::drawCities()
   LocationList<City*>::iterator it = d_clist->begin();
   for (; it != d_clist->end(); it++)
   {
-      SDL_Surface *tmp;
-      if ((*it)->isFogged(getViewingPlayer()))
+      PixMask *tmp;
+      if ((*it)->isVisible(getViewingPlayer()) == false)
         continue;
       if ((*it)->isBurnt() == true)
         tmp = gc->getSmallRuinedCityPic();
@@ -58,12 +61,7 @@ void HistoryMap::drawCities()
   
       Vector<int> pos = (*it)->getPos();
       pos = mapToSurface(pos);
-      SDL_Rect r;
-      r.x = pos.x - (tmp->w/2);
-      r.y = pos.y - (tmp->h/2);
-      r.w = tmp->w;
-      r.h = tmp->h;
-      SDL_BlitSurface(tmp, 0, surface, &r);
+      tmp->blit_centered(surface, pos);
   }
 }
 
