@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -25,6 +25,7 @@
 #include "overviewmap.h"
 #include "LocationList.h"
 
+class City;
 //! Draw the given cities on the map.
 /** 
  * Draw a set of cities onto the miniature map graphic.
@@ -32,7 +33,7 @@
  * @note This is called HistoryMap because it is used for the HistoryDialog.
  *
  */
-class HistoryMap: public OverviewMap, public sigc::trackable
+class HistoryMap: public OverviewMap
 {
  public:
      //! Default constructor.  Make a new HistoryMap.
@@ -45,7 +46,7 @@ class HistoryMap: public OverviewMap, public sigc::trackable
      /**
       * Classes that use HistoryMap must catch this signal to display the map.
       */
-     sigc::signal<void, SDL_Surface *> map_changed;
+     sigc::signal<void, Glib::RefPtr<Gdk::Pixmap> > map_changed;
         
      //! Change which cities are shown on the miniature map graphic.
      /**
