@@ -1,11 +1,11 @@
 // Copyright (C) 2003 Michael Bartl
 // Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -24,7 +24,7 @@
 #include "tileset.h"
 #include "MapBackpack.h"
 
-Maptile::Maptile(Tileset* tileSet, int x, int y, Uint32 type, TileStyle *tileStyle)
+Maptile::Maptile(Tileset* tileSet, int x, int y, guint32 type, TileStyle *tileStyle)
     :d_index(type), d_building(NONE) 
 {
     d_tileSet = tileSet;
@@ -57,7 +57,7 @@ Maptile::~Maptile()
     delete d_backpack;
 }
 
-Uint32 Maptile::getMoves() const
+guint32 Maptile::getMoves() const
 {
     if (d_building == Maptile::CITY)
         return 1;
@@ -109,4 +109,60 @@ bool Maptile::isHillyTerrain()
     return true;
   return false;
 }
+
+std::string Maptile::buildingToString(const Maptile::Building bldg)
+{
+  switch (bldg)
+    {
+    case Maptile::NONE:
+      return "Maptile::NONE";
+      break;
+    case Maptile::CITY:
+      return "Maptile::CITY";
+      break;
+    case Maptile::RUIN:
+      return "Maptile::RUIN";
+      break;
+    case Maptile::TEMPLE:
+      return "Maptile::TEMPLE";
+      break;
+    case Maptile::SIGNPOST:
+      return "Maptile::SIGNPOST";
+      break;
+    case Maptile::ROAD:
+      return "Maptile::ROAD";
+      break;
+    case Maptile::PORT:
+      return "Maptile::PORT";
+      break;
+    case Maptile::BRIDGE:
+      return "Maptile::BRIDGE";
+      break;
+    }
+  return "Maptile::NONE";
+}
+
+Maptile::Building Maptile::buildingFromString(std::string str)
+{
+  if (str.size() > 0 && isdigit(str.c_str()[0]))
+    return Maptile::Building(atoi(str.c_str()));
+  if (str == "Maptile::NONE")
+    return Maptile::NONE;
+  else if (str == "Maptile::CITY")
+    return Maptile::CITY;
+  else if (str == "Maptile::RUIN")
+    return Maptile::RUIN;
+  else if (str == "Maptile::TEMPLE")
+    return Maptile::TEMPLE;
+  else if (str == "Maptile::SIGNPOST")
+    return Maptile::SIGNPOST;
+  else if (str == "Maptile::ROAD")
+    return Maptile::ROAD;
+  else if (str == "Maptile::PORT")
+    return Maptile::PORT;
+  else if (str == "Maptile::BRIDGE")
+    return Maptile::BRIDGE;
+    
+  return Maptile::NONE;
+}
 // End of file
