@@ -1,8 +1,22 @@
 // Copyright (C) 2003 Michael Bartl
 // Copyright (C) 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2005 Andrea Paternesi
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
-
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
+//
+//  This program is free software; you can redistribute it and/or modify
+//  it under the terms of the GNU General Public License as published by
+//  the Free Software Foundation; either version 3 of the License, or
+//  (at your option) any later version.
+//
+//  This program is distributed in the hope that it will be useful,
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+//  GNU Library General Public License for more details.
+//
+//  You should have received a copy of the GNU General Public License
+//  along with this program; if not, write to the Free Software
+//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
+//  02110-1301, USA.
 #ifndef MAPTILE_H
 #define MAPTILE_H
 
@@ -65,7 +79,7 @@ class Maptile
          * @param type             The terrain type (index in the tileset).
 	 * @param tileStyle        The look of this tile to use.
          */
-        Maptile(Tileset* tileSet, int x, int y, Uint32 type, 
+        Maptile(Tileset* tileSet, int x, int y, guint32 type, 
 		TileStyle *tileStyle);
 
 	//! Slower constructor.
@@ -85,13 +99,13 @@ class Maptile
         ~Maptile();
 
         //! Set the type of the terrain (type is an index in the tileset).
-        void setType(Uint32 index){d_index = index;}
+        void setType(guint32 index){d_index = index;}
 
         //! Set which kind of building is on this maptile.
         void setBuilding(Building building){d_building = building;}
 
         //! Get the index of the tile type in the tileset.
-        Uint32 getType() const {return d_index;}
+        guint32 getType() const {return d_index;}
 
         //! Get which building is on the maptile.
         Building getBuilding() const {return d_building;}
@@ -104,10 +118,10 @@ class Maptile
 	 * @return The number of movement points required to cross this 
 	 *         Maptile.
 	 */
-        Uint32 getMoves() const;
+        guint32 getMoves() const;
 
         //! Get the smallmap color of this maptile.
-        SDL_Color getColor() const
+	Gdk::Color getColor() const
 	  {return (*d_tileSet)[d_index]->getSmallTile()->getColor();}
 
 	//! Get the pattern of this maptile on the smallmap.
@@ -115,11 +129,11 @@ class Maptile
 	  {return (*d_tileSet)[d_index]->getSmallTile()->getPattern();}
 
 	//! Get the associated colour with the pattern.
-        SDL_Color getSecondColor() const
+       Gdk::Color getSecondColor() const
 	  {return (*d_tileSet)[d_index]->getSmallTile()->getSecondColor();}
 
 	//! Get the associated colour with the pattern.
-        SDL_Color getThirdColor() const
+       Gdk::Color getThirdColor() const
 	  {return (*d_tileSet)[d_index]->getSmallTile()->getThirdColor();}
 
         //! Get the tile type (the type of the underlying terrain).
@@ -166,13 +180,15 @@ class Maptile
 	//! Set the TileStyle associated with this Maptile.
 	void setTileStyle(TileStyle *style) {d_tileStyle = style;}
 
+	static Maptile::Building buildingFromString(const std::string str);
+	static std::string buildingToString(const Maptile::Building bldg);
     private:
 	//! The index of the Tile within the Tileset (Maptile::d_tileSet).
 	/**
 	 * The Maptile has a type, in the form of a Tile.  This Tile is
 	 * identified by it's index within Maptile::d_tileSet.
 	 */
-        Uint32 d_index;
+        guint32 d_index;
 	//! The Tileset of the Tile referred to by Maptile::d_index.
         Tileset* d_tileSet;
 	//! The look of the maptile.
