@@ -1,10 +1,10 @@
 // Copyright (C) 2006 Ulf Lorenz
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,7 +20,8 @@
 #ifndef OVERVIEWMAP_H
 #define OVERVIEWMAP_H
 
-#include <SDL.h>
+#include <sigc++/trackable.h>
+#include <gtkmm.h>
 #include "vector.h"
 #include "rectangle.h"
 #include "Tile.h"
@@ -32,7 +33,7 @@ class Player;
 //! Generates a miniature graphic of the game map.
 /**
  * This is a base class that draws the terrain, ruins, temples, and roads 
- * onto an SDL_Surface.
+ * onto a Gdk::Pixmap.
  * This class is responsible for drawing terrain features using the correct
  * pattern, as specified in Tile::Pattern.  Ruins and Temples are drawn as 
  * white dots, and roads are drawn as brown lines.
@@ -42,7 +43,7 @@ class Player;
  * Derived classes can add their own stuff to the map by overriding the 
  * after_draw method that is called by OverviewMap::draw.
  */
-class OverviewMap
+class OverviewMap : public sigc::trackable
 {
  public:
      //! Default constructor.
@@ -58,6 +59,7 @@ class OverviewMap
      //! Destructor.
      virtual ~OverviewMap();
 
+
     //! Draw and scale the miniature map graphic to the given size.
     /**
      * This method is responsible for drawing the terrain (e.g. grass, water, 
@@ -86,6 +88,9 @@ class OverviewMap
      * Draws the roads, cities, ruins, temples and roads onto the map in the
      * correct aspect ratio.
      *
+     * @param player draw the map from the given player's perspective.
+     *
+     *
      * The aspect ratio for the terrain features is governed by the dimensions 
      * passed to the OverviewMap::resize method.
      *
@@ -110,22 +115,37 @@ class OverviewMap
      * It only makes sense to get the surface after OverviewMap::resize and 
      * OverviewMap::draw have been called.
      */
-    SDL_Surface *get_surface();
+    Glib::RefPtr<Gdk::Pixmap> get_surface();
 
-    static void draw_tile_pixel(SDL_Surface *surface, SmallTile::Pattern pattern,
-				SDL_Color first_color, SDL_Color second_color,
-				SDL_Color third_color,
+
+    static void draw_terrain_tile (Glib::RefPtr<Gdk::Pixmap> surf,
+				Glib::RefPtr<Gdk::GC> gc,
+				SmallTile::Pattern pattern,
+				Gdk::Color first, 
+				Gdk::Color second,
+				Gdk::Color third,
 				int i, int j, bool shadowed);
 
     Player * getViewingPlayer() {return d_player;};
     void setViewingPlayer(Player *player) {d_player = player;};
+
+    static void draw_pixel(Glib::RefPtr<Gdk::Pixmap> surf, Glib::RefPtr<Gdk::GC> gc, int x, int y, Gdk::Color color);
+
+
+    void draw_filled_rect(int x, int y, int width, int height, Gdk::Color color);
+
+    void draw_rect(int x, int y, int width, int height, Gdk::Color color);
+
+    void draw_line( int src_x, int src_y, int dst_x, int dst_y, Gdk::Color color);
+
  private:
     //! An SDL surface of the terrain without the features.
     /**
      * This is the cached surface after the resize method was called.
      * It is cached so that we don't have recalculate it.
      */
-    SDL_Surface* static_surface;
+    Glib::RefPtr<Gdk::Pixmap> static_surface;
+    Glib::RefPtr<Gdk::GC> static_surface_gc;
 
     //! Returns whether or not the given pixel appears sunken (Tile::SUNKEN).
     /**
@@ -142,7 +162,7 @@ class OverviewMap
      *
      * @return True if the given pixel location should be shaded, false if not.
      */
-    bool isShadowed(Uint32 type, int i, int j);
+    bool isShadowed(guint32 type, int i, int j);
 
     //! Draw the given tile at the given pixel location on the map.
     /**
@@ -157,8 +177,16 @@ class OverviewMap
      * @param j     The pixel on the vertical axis of the map graphic.  This
      *              value must be a multiple of OverviewMap::pixels_per_tile.
      */
-    void draw_tile_pixel(Maptile *tile, int i, int j);
+    void draw_terrain_tile (Maptile *tile, int i, int j);
 
+
+    void choose_surface(bool front, Glib::RefPtr<Gdk::Pixmap> &surf,
+				 Glib::RefPtr<Gdk::GC> &gc);
+    void draw_filled_rect(bool front, int x, int y, int width, int height, Gdk::Color color);
+
+    void draw_rect(bool front, int x, int y, int width, int height, Gdk::Color color);
+
+    void draw_line(bool front, int src_x, int src_y, int dst_x, int dst_y, Gdk::Color color);
  protected:
 
     //! Every pixel on the graphic is this wide and tall.
@@ -185,14 +213,16 @@ class OverviewMap
     void draw_cities(bool all_razed);
 
     //! Redraw the specified region.
-    void draw_terrain_pixels(Rectangle r);
+    void draw_terrain_tiles(Rectangle r);
 
     int calculateResizeFactor();
 
     //! The surface containing the drawn map.
-    SDL_Surface* surface;
+    Glib::RefPtr<Gdk::Pixmap> surface;
+    Glib::RefPtr<Gdk::GC> surface_gc;
 
     Player *d_player;
+
 };
 
 #endif // OVERVIEWMAP_H
