@@ -3,12 +3,12 @@
 // Copyright (C) 2003 Marek Publicewicz
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2005 Bryan Duff
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -29,19 +29,20 @@
 #include <vector>
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
-#include <SDL_types.h>
-#include <SDL_video.h>
+#include <gtkmm.h>
 
 #include "vector.h"
 #include "fight.h"
 #include "army.h"
 #include "defs.h"
 
+struct rgb_shift;
 class Stacklist;
 class XML_Helper;
 class Hero;
 class HeroProto;
 class Action;
+class Action_Produce;
 class NetworkAction;
 class History;
 class NetworkHistory;
@@ -172,7 +173,7 @@ class Player: public sigc::trackable
 	 *                     the next free Id it used.
          */
 	//! Default constructor.
-        Player (std::string name, Uint32 armyset, SDL_Color color, int width,
+        Player (std::string name, guint32 armyset, Gdk::Color color, int width,
 		int height, Type type, int player_no = -1);
 
         //! Copy constructor
@@ -196,8 +197,8 @@ class Player: public sigc::trackable
          * @param type     The player's type (Player::Type).
          */
 	//! Create a player.
-        static Player* create(std::string name, Uint32 armyset, 
-			      SDL_Color color, int width, int height, 
+        static Player* create(std::string name, guint32 armyset, 
+			      Gdk::Color color, int width, int height, 
 			      Type type);
         
         /** 
@@ -216,13 +217,13 @@ class Player: public sigc::trackable
         void setName(std::string name){d_name = name;}
         
         //! Change the player's Armyset.
-        void setArmyset(Uint32 armyset){d_armyset = armyset;}
+        void setArmyset(guint32 armyset){d_armyset = armyset;}
 
         //! Set the type of the player (to be used by derived classes only.)
         void setType(Type type) {d_type = type;}
 
         //! Change the player's colour.
-        void setColor(SDL_Color c);
+        void setColor(Gdk::Color c);
 
         //! Makes a player unable to die, even when having no units or cities.
         void setMortality(bool ismortal) {d_immortal = !ismortal;}
@@ -249,7 +250,10 @@ class Player: public sigc::trackable
         bool deleteStack(Stack* stack);
 
         //! Returns the unique ID of the player.
-        Uint32 getId() const {return d_id;}
+        guint32 getId() const {return d_id;}
+
+	//! Returns a list of the player's unit production actions for this turn.
+	std::list<Action_Produce *> getUnitsProducedThisTurn();
 
 	//! Returns a list of the player's actions to show in a report.
 	std::list<Action *> getReportableActions();
@@ -258,7 +262,7 @@ class Player: public sigc::trackable
         std::list<History*>* getHistorylist() {return &d_history;}
 
         //! Return the Id of the player's Armyset.
-        Uint32 getArmyset() const {return d_armyset;}
+        guint32 getArmyset() const {return d_armyset;}
 
         //! Return whether or not the player has been killed.
         bool isDead() const {return d_dead;}
@@ -267,17 +271,17 @@ class Player: public sigc::trackable
         bool isImmortal() const {return d_immortal;}
 
         //! Return the type of the player (Player::Type).
-        Uint32 getType() {return d_type;}
+        guint32 getType() {return d_type;}
 
         /**
 	 * Return the amount of upkeep in gold pieces that the player spent 
 	 * in the previous turn.  
 	 */
 	//! Return the upkeep.
-        Uint32 getUpkeep() {return d_upkeep;}
+        guint32 getUpkeep() {return d_upkeep;}
 
 	//! Return the income from all of the player's cities.
-        Uint32 getIncome () {return d_income;}
+        guint32 getIncome () {return d_income;}
 
 	/**
 	 * Perform a summation of the upkeep value for every Army in the 
@@ -308,10 +312,10 @@ class Player: public sigc::trackable
 	void proposeDiplomacy (DiplomaticProposal proposal, Player *player);
 
 	//! Set this player's rank in diplomatic matters.  Starts at 1.
-	void setDiplomaticRank (Uint32 rank) {d_diplomatic_rank = rank;};
+	void setDiplomaticRank (guint32 rank) {d_diplomatic_rank = rank;};
 
 	//! What diplomatic rank does this player have?  Starts at 1.
-	Uint32 getDiplomaticRank () {return d_diplomatic_rank;};
+	guint32 getDiplomaticRank () {return d_diplomatic_rank;};
 
 	//! What rank do we have?  As a name.
 	std::string getDiplomaticTitle() {return d_diplomatic_title;};
@@ -322,7 +326,7 @@ class Player: public sigc::trackable
 	DiplomaticState negotiateDiplomacy (Player *player);
 
 	//! Get the diplomatic score with respect to an opponent.
-	Uint32 getDiplomaticScore (Player *p);
+	guint32 getDiplomaticScore (Player *p);
 
 	/**
 	 * Change the player's opinion of an opponent for the better.
@@ -333,7 +337,7 @@ class Player: public sigc::trackable
 	 *
 	 */
 	//! Make your diplomatic view of another player increase.
-	void improveDiplomaticRelationship (Player *p, Uint32 amount);
+	void improveDiplomaticRelationship (Player *p, guint32 amount);
 
 	/**
 	 * Change all players opinion of you for the better, except for 
@@ -346,7 +350,7 @@ class Player: public sigc::trackable
 	 * @note Pass except as NULL to not except a player.
 	 */
 	//! Make all other players diplomatic view of you increase.
-	void improveDiplomaticRelationship (Uint32 amount, Player *except);
+	void improveDiplomaticRelationship (guint32 amount, Player *except);
 
 	/**
 	 * Change the player's view of an opponent for the worse.
@@ -357,7 +361,7 @@ class Player: public sigc::trackable
 	 *
 	 */
 	//! Make your diplomatic view of another player decrease.
-	void deteriorateDiplomaticRelationship (Player *player, Uint32 amount);
+	void deteriorateDiplomaticRelationship (Player *player, guint32 amount);
 
 	/**
 	 * Change all players opinion of you for the worse.
@@ -366,7 +370,7 @@ class Player: public sigc::trackable
 	 *                  is 1 and the maximum value is 15.
 	 */
 	//! Make all other players diplomatic view of you worsen
-	void deteriorateDiplomaticRelationship (Uint32 amount);
+	void deteriorateDiplomaticRelationship (guint32 amount);
 
 	/**
 	 * Change all players opinion of another player for the worse, 
@@ -379,7 +383,7 @@ class Player: public sigc::trackable
 	 *                  to make the deterioration happen.
 	 */
 	//! Make players you are at state with you think less of player.
-	void deteriorateAlliesRelationship(Player *player, Uint32 amount, 
+	void deteriorateAlliesRelationship(Player *player, guint32 amount, 
 					   Player::DiplomaticState state);
 
 	/**
@@ -393,14 +397,14 @@ class Player: public sigc::trackable
 	 *                  to make the improvement happen.
 	 */
 	//! Make players who are at STATE with PLAYER think better of you.
-	void improveAlliesRelationship(Player *player, Uint32 amount, 
+	void improveAlliesRelationship(Player *player, guint32 amount, 
 				       Player::DiplomaticState state);
 
         //! Returns the colour of the player.
-        SDL_Color getColor() const {return d_color;}
+	Gdk::Color getColor() const {return d_color;}
 
         //! Returns the player's colour suitable for applying it to masks.
-        SDL_Color getMaskColor() const;
+	struct rgb_shift getMaskColorShifts() const;
 
         //! Returns the amount of gold pieces the player has.
         int getGold() const {return d_gold;}
@@ -409,14 +413,11 @@ class Player: public sigc::trackable
         std::string getName(bool translate = true) const;
 
 	//! Returns the player's current score.
-        Uint32 getScore();
+        guint32 getScore();
 
         //! Returns the list of stacks (Stacklist) owned by the player.
         Stacklist* getStacklist() const {return d_stacklist;}
 
-        //! A shortcut for getting the Stack marked as active.
-        Stack* getActivestack();
-
         //! Get the FogMap of the player.
         FogMap* getFogMap() const {return d_fogmap;}
 
@@ -424,10 +425,10 @@ class Player: public sigc::trackable
         Triumphs* getTriumphs() const {return d_triumphs;}
 
         //! Get the fight order of the player.
-	std::list<Uint32> getFightOrder() const {return d_fight_order;}
+	std::list<guint32> getFightOrder() const {return d_fight_order;}
 
         //! Set the fight order of the player.
-	void setFightOrder(std::list<Uint32> order);
+	void setFightOrder(std::list<guint32> order);
 
         //! Show debugging information for the player's Action list.
         void dumpActionlist() const;
@@ -796,7 +797,7 @@ class Player: public sigc::trackable
          * @return False on error, true otherwise.
          */
 	//! Callback to sack a city.
-        void citySack(City* city, int& gold, std::list<Uint32> *sacked_types);
+        void citySack(City* city, int& gold, std::list<guint32> *sacked_types);
 
         /** 
 	 * Raze (permanently destroy) a city.
@@ -1082,13 +1083,9 @@ class Player: public sigc::trackable
 	 * Callback to change the vectoring destination for all of the
 	 * player's cities that are vectoring to a particular city.
 	 *
-	 * Computer players don't currently consider vectoring units, so
-	 * only human players use this method.
+	 * SRC and DEST can both be the player's planted standard.
 	 *
-	 * This callback must result in one or more Action_Vector elements 
-	 * being given to the addAction method.
-	 *
-	 * @param  city   The city being vectored to.
+	 * @param  src    The place that we want to take all the vectoring from.
          * @param  dest   The place on the map to vector to.  The destination 
 	 *                point should be co-located with a City or a 
 	 *                planted standard Item.
@@ -1096,7 +1093,7 @@ class Player: public sigc::trackable
          * @return False on error, true otherwise.
          */
 	//! Callback to make a mass change to vectoring.
-	bool changeVectorDestination(City *city, Vector<int> dest);
+	bool changeVectorDestination(Vector<int> src, Vector<int> dest);
 
         /** 
 	 * Callback to plant the Player's flag Item on the ground.
@@ -1155,7 +1152,7 @@ class Player: public sigc::trackable
 	 * @param army   The army that has gotten a medal.
 	 */
         //! Emitted whever a player's army gets a new medal.
-        sigc::signal<void, Army*> snewMedalArmy;
+        sigc::signal<void, Army*, int> snewMedalArmy;
 
 	/**
 	 * @param army         The army that has died.
@@ -1163,7 +1160,7 @@ class Player: public sigc::trackable
 	 *                     participated in the death of this player's Army.
 	 */
         //! Emitted when a player's Army dies.
-        sigc::signal<void, Army*, std::vector<Uint32> > sdyingArmy;
+        sigc::signal<void, Army*, std::vector<guint32> > sdyingArmy;
 
 	/**
 	 * @param ruin    The ruin being searched.
@@ -1194,7 +1191,7 @@ class Player: public sigc::trackable
 	 * @param army_types  The list of Army types traded-in for gold pieces.
 	 */
         //! Emitted whenever the player pillages a city.
-        sigc::signal<void, City*, Stack*, int, Uint32> spillagingCity;
+        sigc::signal<void, City*, Stack*, int, guint32> spillagingCity;
 
 	/**
 	 * @param city        The city that has been sacked.
@@ -1203,7 +1200,7 @@ class Player: public sigc::trackable
 	 * @param army_types  The list of Army types traded-in for gold pieces.
 	 */
         //! Emitted whenever the player sacks a city.
-        sigc::signal<void, City*, Stack*, int, std::list<Uint32> > ssackingCity;
+        sigc::signal<void, City*, Stack*, int, std::list<guint32> > ssackingCity;
 
 	/**
 	 * @param city        The city that has been razed.
@@ -1233,6 +1230,9 @@ class Player: public sigc::trackable
         //! Emitted whenever the stack's status has changed.
         sigc::signal<void, Stack*> supdatingStack;
 
+        //! Emitted whenever the active stack comes to a stop.
+        sigc::signal<void, Stack*> shaltedStack;
+
 	/**
 	 * Emitted whenever a city is conquered or razed.
 	 *
@@ -1291,7 +1291,7 @@ class Player: public sigc::trackable
         sigc::signal<void, NetworkHistory *> history_written;
         
 	//! is it safe to vector from the given city?
-	static bool safeFromAttack(City *c, Uint32 safe_mp, Uint32 min_defenders);
+	static bool safeFromAttack(City *c, guint32 safe_mp, guint32 min_defenders);
 	void addHistory(History *history);
 	bool hasAlreadyInitializedTurn() const;
 	bool hasAlreadyEndedTurn() const;
@@ -1299,7 +1299,26 @@ class Player: public sigc::trackable
 	//! Check the history to see if we ever conquered the given city.
 	bool conqueredCity(City *c);
 	std::list<Vector<int> > getStackTrack(Stack *s);
-	std::list<History *> getHistoryForHeroId(Uint32 id);
+	std::list<History *> getHistoryForHeroId(guint32 id);
+	std::list<History *> getHistoryForCityId(guint32 id);
+	//! Set whether or not this player has surrendered.
+	/*
+	 * computer players may surrender to a lone human player who has most
+	 * of the cities on the board.
+	 * this method merely sets the surrendered member so that we can
+	 * quit properly. e.g. it triggers the aborted_Turn signal to be fired
+	 * at a different time in fast, smart and dummy players.
+	 */
+	void setSurrendered(bool surr);
+	guint32 countEndTurnHistoryEntries() const;
+
+	//! accessor methods into encapsulated stacklist object
+	std::list<Hero*> getHeroes();
+	guint32 countArmies();
+	Stack * getActivestack();
+	Vector<int> getPositionOfArmyById(guint32 id);
+	//! Remove movement points from all of the player's army units.
+	void immobilize();
     protected:
         // do some fight cleaning up, setting
         void cleanupAfterFight(std::list<Stack*> &attackers,
@@ -1318,13 +1337,13 @@ class Player: public sigc::trackable
 	/**
 	 * Mask portions of images are shaded in this colour.
 	 */
-        SDL_Color d_color;
+	Gdk::Color d_color;
 
 	//! The name of the Player.
         std::string d_name;
 
 	//! The ArmySet of the Player.
-        Uint32 d_armyset;
+        guint32 d_armyset;
 
 	//! The number of gold pieces the Player has in the treasury.
         int d_gold;
@@ -1336,10 +1355,10 @@ class Player: public sigc::trackable
         bool d_immortal;
 
 	//! The kind of Player (see Player::Type).
-        Uint32 d_type;
+        guint32 d_type;
 
 	//! A unique numeric identifier identifying this Player.
-        Uint32 d_id;
+        guint32 d_id;
 
 	//! A list of actions that this Player made this turn.
         std::list<Action*> d_actions;
@@ -1360,19 +1379,19 @@ class Player: public sigc::trackable
 	/**
 	 * @note This value is related to the Player's ArmySet.
 	 */
-	std::list<Uint32> d_fight_order; 
+	std::list<guint32> d_fight_order; 
 
 	//! How many gold pieces the Player paid out in the last turn.
-	Uint32 d_upkeep;
+	guint32 d_upkeep;
 
 	//! How many gold pieces the Player made from taxes in the last turn.
-	Uint32 d_income;
+	guint32 d_income;
 
 	//! The diplomatic view that this Player has of each other Player.
 	DiplomaticState d_diplomatic_state[MAX_PLAYERS];
 
 	//! The diplomatic rank this Player has among all other Players.
-	Uint32 d_diplomatic_rank;
+	guint32 d_diplomatic_rank;
 
 	//! The title that goes along with the diplomatic rank.
 	std::string d_diplomatic_title;
@@ -1381,11 +1400,14 @@ class Player: public sigc::trackable
 	DiplomaticProposal d_diplomatic_proposal[MAX_PLAYERS];
 
 	//! A quantification of how much this Player likes every other Player.
-	Uint32 d_diplomatic_score[MAX_PLAYERS];
+	guint32 d_diplomatic_score[MAX_PLAYERS];
 
 	//! Whether or not this player is observable by the user.
 	bool d_observable;
 
+	//! Whether or not this player has surrendered.
+	bool surrendered;
+
 	//! assists in scorekeeping for diplomacy
 	void alterDiplomaticRelationshipScore (Player *player, int amount);
 
@@ -1397,7 +1419,7 @@ class Player: public sigc::trackable
         int doStackVisitTemple(Stack *s, Temple *t);
         void doCityOccupy(City *c);
         void doCityPillage(City *c, int& gold, int* pillaged_army_type);
-        void doCitySack(City *c, int& gold, std::list<Uint32> *sacked_types);
+        void doCitySack(City *c, int& gold, std::list<guint32> *sacked_types);
         void doCityRaze(City *c);
         void doCityBuyProduction(City *c, int slot, int type);
         void doCityChangeProduction(City *c, int slot);
@@ -1410,18 +1432,20 @@ class Player: public sigc::trackable
         void doSignpostChange(Signpost *signpost, std::string message);
         void doCityRename(City *c, std::string name);
         void doVectorFromCity(City * c, Vector<int> dest);
-        void doSetFightOrder(std::list<Uint32> order);
+        void doSetFightOrder(std::list<guint32> order);
         void doResign();
         void doHeroPlantStandard(Hero *hero, Item *item, Vector<int> pos);
         void doDeclareDiplomacy (DiplomaticState state, Player *player);
         void doProposeDiplomacy (DiplomaticProposal proposal, Player *player);
         void doConquerCity(City *city, Stack *stack);
-	void doLootCity(Player *looted, Uint32 added, Uint32 subtracted);
+	void doLootCity(Player *looted, guint32 added, guint32 subtracted);
         Hero* doRecruitHero(HeroProto* hero, City *city, int cost, int alliesCount, const ArmyProto *ally);
         void doRename(std::string name);
 	void doKill();
 	const Army *doCityProducesArmy(City *city);
 	Army *doVectoredUnitArrives(VectoredUnit *unit);
+	bool doChangeVectorDestination(Vector<int> src, Vector<int> dest,
+				       std::list<City*> &vectored);
 
 	void AI_maybeBuyScout();
 
@@ -1461,14 +1485,14 @@ class Player: public sigc::trackable
 
 
 
-	bool AI_maybeVector(City *c, Uint32 safe_mp, Uint32 min_defenders,
+	bool AI_maybeVector(City *c, guint32 safe_mp, guint32 min_defenders,
 			    City *target, City **vector_city = NULL);
 
 
-	void AI_setupVectoring(Uint32 safe_mp, Uint32 min_defenders,
-			       Uint32 mp_to_front);
+	void AI_setupVectoring(guint32 safe_mp, guint32 min_defenders,
+			       guint32 mp_to_front);
 
-	bool AI_maybeDisband(Stack *s, City *city, Uint32 min_defenders, 
+	bool AI_maybeDisband(Stack *s, City *city, guint32 min_defenders, 
 			     int safe_mp, bool &stack_died);
 
 	void pruneActionlist();
@@ -1487,7 +1511,7 @@ class Player: public sigc::trackable
          */
 	//! Get heroes.
         void getHeroes(const std::list<Stack*> stacks, 
-		       std::vector<Uint32>& heroes);
+		       std::vector<guint32>& heroes);
 
         /** 
 	 * Goes through a list of stacks and removes all armies with less
@@ -1502,7 +1526,7 @@ class Player: public sigc::trackable
          */
 	//! Remove dead Armies from a list of stacks after a fight.
         double removeDeadArmies(std::list<Stack*>& stacks,
-                                std::vector<Uint32>& culprits);
+                                std::vector<guint32>& culprits);
         
         /** 
 	 * Increases the number of experience points of a stack
@@ -1522,8 +1546,10 @@ class Player: public sigc::trackable
         void adjustDiplomacyFromConqueringCity(City *city);
 
         void lootCity(City *city, Player *looted);
-	void calculateLoot(Player *looted, Uint32 &added, Uint32 &subtracted);
+	void calculateLoot(Player *looted, guint32 &added, guint32 &subtracted);
         void takeCityInPossession(City* c);
+	static void pruneCityVectorings(std::list<Action*> actions);
+	static void pruneCityProductions(std::list<Action*> actions);
 };
 
 extern sigc::signal<void, Player::Type>  sendingTurn;
