@@ -2,12 +2,12 @@
 // Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2005 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -194,7 +194,7 @@ Player* Playerlist::getPlayer(string name) const
     return 0;
 }
 
-Player* Playerlist::getPlayer(Uint32 id) const
+Player* Playerlist::getPlayer(guint32 id) const
 {
     debug("getPlayer()");
     for (const_iterator it = begin(); it != end(); it++)
@@ -206,7 +206,7 @@ Player* Playerlist::getPlayer(Uint32 id) const
     return 0;
 }
 
-Uint32 Playerlist::getNoOfPlayers() const
+guint32 Playerlist::getNoOfPlayers() const
 {
     unsigned int number = 0;
 
@@ -248,8 +248,8 @@ bool Playerlist::save(XML_Helper* helper) const
 
 bool Playerlist::load(string tag, XML_Helper* helper)
 {
-    static Uint32 active = 0;
-    static Uint32 neutral = 0;
+    static guint32 active = 0;
+    static guint32 neutral = 0;
 
     if (tag == Playerlist::d_tag) //only called in the constructor
     {
@@ -288,7 +288,7 @@ Playerlist::iterator Playerlist::flErase(Playerlist::iterator it)
 
 struct rankable_t
 {
-  Uint32 score;
+  guint32 score;
   Player *player;
 };
 
@@ -304,7 +304,7 @@ bool compareDiplomaticScores (const struct rankable_t lhs,
 void Playerlist::calculateDiplomaticRankings()
 {
   unsigned int i = 0;
-  char* titles[MAX_PLAYERS] =
+  const char* titles[MAX_PLAYERS] =
     {
       _("Statesman"),
       _("Diplomat"),
@@ -380,7 +380,7 @@ void Playerlist::calculateDiplomaticRankings()
 	continue;
       if ((*it)->isDead () == true)
 	continue;
-      Uint32 rank = (*it)->getDiplomaticRank();
+      guint32 rank = (*it)->getDiplomaticRank();
       // recall that the first rank is 1, and not 0.
       (*it)->setDiplomaticTitle (available_titles[rank - 1]);
     }
@@ -390,10 +390,10 @@ void Playerlist::calculateDiplomaticRankings()
 
 void Playerlist::calculateWinners()
 {
-    Uint32 score;
-    Uint32 total_gold = 0;
-    Uint32 total_armies = 0;
-    Uint32 total_cities = 0;
+    guint32 score;
+    guint32 total_gold = 0;
+    guint32 total_armies = 0;
+    guint32 total_cities = 0;
     for (const_iterator it = begin(); it != end(); it++)
       {
 	if ((*it) == d_neutral)
@@ -420,7 +420,7 @@ void Playerlist::calculateWinners()
 	float army_component = (float)
 	  ((float) (*it)->getStacklist()->countArmies() / 
 	   (float)total_armies) * 20.0;
-	score = (Uint32) (city_component + gold_component + army_component);
+	score = (guint32) (city_component + gold_component + army_component);
 	History_Score *item = new History_Score();
 	item->fillData(score);
 	(*it)->addHistory(item);
@@ -433,18 +433,18 @@ void Playerlist::calculateWinners()
     return;
 }
 
-Uint32 Playerlist::countHumanPlayersAlive()
+guint32 Playerlist::countHumanPlayersAlive()
 {
-  Uint32 retval = 0;
+  guint32 retval = 0;
   for (const_iterator it = begin(); it != end(); it++)
     if ((*it)->isDead() == false && (*it)->getType() == Player::HUMAN)
       retval++;
   return retval;
 }
 
-Uint32 Playerlist::countPlayersAlive ()
+guint32 Playerlist::countPlayersAlive ()
 {
-  Uint32 numAlive = 0; 
+  guint32 numAlive = 0; 
 
   for (const_iterator it = begin (); it != end (); it++)
     {
@@ -536,7 +536,7 @@ void Playerlist::swap(Player *old_player, Player *new_player)
       d_activeplayer = new_player;
       d_activeplayer->getStacklist()->setActivestack(0);
     }
-  /* note, we don't have to change the player associate with flags
+  /* note, we don't have to change the player associated with flag graphics
      because it's stored as an id. */
 }
 
@@ -563,7 +563,7 @@ bool Playerlist::inOrderOfId(const Player *lhs, const Player *rhs)
 void Playerlist::randomizeOrder()
 {
   sort(randomly);
-  d_activeplayer = getFirstLiving();
+  d_activeplayer = NULL;
 }
 
 void Playerlist::nextRound(bool diplomacy, bool *surrender_already_offered)
@@ -601,11 +601,11 @@ void Playerlist::nextRound(bool diplomacy, bool *surrender_already_offered)
 
 void Playerlist::syncPlayer(GameParameters::Player player)
 {
-  Player *p = getPlayer((Uint32)player.id);
+  Player *p = getPlayer((guint32)player.id);
   if (!p)
     {
       //player was off originally, but now it's on
-      Uint32 armyset = d_neutral->getArmyset();
+      guint32 armyset = d_neutral->getArmyset();
       int width = d_neutral->getFogMap()->getWidth();
       int height = d_neutral->getFogMap()->getHeight();
       int gold = d_neutral->getGold();
@@ -776,14 +776,14 @@ void Playerlist::turnHumansInto(Player::Type type, int number_of_players)
     }
 }
 
-std::list<Uint32> given_turn_order;
+std::list<guint32> given_turn_order;
 bool Playerlist::inGivenOrder(const Player *lhs, const Player *rhs)  
 {
   if (given_turn_order.size() == 0)
     return true;
 
   int count = 0;
-  for(std::list<Uint32>::iterator it = given_turn_order.begin(); 
+  for(std::list<guint32>::iterator it = given_turn_order.begin(); 
       it != given_turn_order.end(); it++)
     {
       count++;
@@ -792,7 +792,7 @@ bool Playerlist::inGivenOrder(const Player *lhs, const Player *rhs)
     }
   int lhs_rank = count;
   count = 0;
-  for(std::list<Uint32>::iterator it = given_turn_order.begin(); 
+  for(std::list<guint32>::iterator it = given_turn_order.begin(); 
       it != given_turn_order.end(); it++)
     {
       count++;
@@ -804,7 +804,7 @@ bool Playerlist::inGivenOrder(const Player *lhs, const Player *rhs)
 }
 
 
-void Playerlist::reorder(std::list<Uint32> order)
+void Playerlist::reorder(std::list<guint32> order)
 {
   given_turn_order = order;
   sort(inGivenOrder);
@@ -812,7 +812,7 @@ void Playerlist::reorder(std::list<Uint32> order)
   d_activeplayer = getFirstLiving();
 }
 
-std::list<History *>Playerlist::getHistoryForHeroId(Uint32 id)
+std::list<History *>Playerlist::getHistoryForHeroId(guint32 id)
 {
   std::list<History*> no_events;
   for (iterator it = begin(); it != end(); ++it)
@@ -823,3 +823,37 @@ std::list<History *>Playerlist::getHistoryForHeroId(Uint32 id)
     }
   return no_events;
 }
+
+void Playerlist::surrender()
+{
+  //the last human player has accepted surrender
+  for (iterator it = begin(); it != end(); it++)
+    {
+      if ((*it)->getType() != Player::HUMAN)
+	{
+	  (*it)->setSurrendered(true);
+	}
+    }
+}
+
+bool Playerlist::isEndOfRound()
+{
+  //check to see if all players have moved this round.
+  //do all players have the same number of history:end_turn events?
+  if (d_activeplayer == NULL)
+    return false;
+  guint32 count = d_activeplayer->countEndTurnHistoryEntries();
+  for (iterator it = begin(); it != end(); it++)
+    {
+      if (*it == d_activeplayer)
+	continue;
+      if (count != (*it)->countEndTurnHistoryEntries())
+	return false;
+    }
+  return true;
+}
+void Playerlist::setWinningPlayer(Player *winner)
+{
+  //only for humans
+  d_activeplayer = winner;
+}
