@@ -1,11 +1,11 @@
 // Copyright (C) 2000, 2001, 2002, 2003 Michael Bartl
 // Copyright (C) 2001, 2002, 2003, 2004, 2005 Ulf Lorenz
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -110,10 +110,10 @@ class Playerlist : public std::list<Player*>, public sigc::trackable
 	 * @return A pointer to the Player if it is found, or NULL if it isn't.
 	 */
         //! Lookup a Player by it's Id.
-        Player* getPlayer(Uint32 id) const;
+        Player* getPlayer(guint32 id) const;
 
         //! Returns the number of living players (neutral player excluded.)
-        Uint32 getNoOfPlayers() const;
+        guint32 getNoOfPlayers() const;
 
         /** 
 	 * Scan the list of players for the first Player that is alive.
@@ -174,14 +174,15 @@ class Playerlist : public std::list<Player*>, public sigc::trackable
 	void nextRound(bool diplomacy, bool *surrender_already_offered);
 
 	//! Return the number of human players left alive in the list.
-	Uint32 countHumanPlayersAlive();
+	guint32 countHumanPlayersAlive();
 
 	//! Return the number of players left alive, not including neutral.
-	Uint32 countPlayersAlive();
+	guint32 countPlayersAlive();
 
 	/**
 	 * The purpose of randomzing the Playerlist is to implement
 	 * random turns.
+	 * Note: This method does not set the active player.
 	 */
 	//! Randomize the order of the players in the list.
 	void randomizeOrder();
@@ -224,9 +225,19 @@ class Playerlist : public std::list<Player*>, public sigc::trackable
     
 	void turnHumansIntoNetworkPlayers();
 	void turnHumansInto(Player::Type type, int num_players = -1);
-	void reorder(std::list<Uint32> order);
+	void reorder(std::list<guint32> order);
+
+	std::list<History *>getHistoryForHeroId(guint32 id);
+
+	void surrender();
+
+	/** 
+	  \brief Check to see if this is the end of the round or not.
+	  */
+	bool isEndOfRound();
+
+	void setWinningPlayer(Player *winner);
 
-	std::list<History *>getHistoryForHeroId(Uint32 id);
     protected:
 	//! Default constructor.
         Playerlist();
