@@ -1,8 +1,8 @@
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -20,7 +20,9 @@
 
 #include <sigc++/trackable.h>
 #include "LocationList.h"
-#include "port.h"
+
+class XML_Helper;
+class Port;
 
 //! A list of the Port objects on the game map.
 /** 
