@@ -3,12 +3,12 @@
 // Copyright (C) 2004, 2006 Andrea Paternesi
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2004 Bryan Duff
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -24,7 +24,6 @@
 #include <fstream>
 #include <algorithm>
 #include <stdlib.h>
-#include <SDL_timer.h>
 
 #include "real_player.h"
 #include "action.h"
@@ -32,6 +31,7 @@
 #include "playerlist.h"
 #include "stacklist.h"
 #include "citylist.h"
+#include "city.h"
 #include "herotemplates.h"
 #include "game.h"
 #include "xmlhelper.h"
@@ -42,7 +42,7 @@ using namespace std;
 //#define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 #define debug(x)
 
-RealPlayer::RealPlayer(string name, Uint32 armyset, SDL_Color color, int width,
+RealPlayer::RealPlayer(string name, guint32 armyset, Gdk::Color color, int width,
 		       int height, Player::Type type, int player_no)
     :Player(name, armyset, color, width, height, type, player_no),
     d_abort_requested(false)
