@@ -3,12 +3,12 @@
 // Copyright (C) 2004 Andrea Paternesi
 // Copyright (C) 2004 John Farrell
 // Copyright (C) 2004 Bryan Duff
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -26,12 +26,13 @@
 
 #include <string>
 #include <list>
-#include <SDL_types.h>
+#include <gtkmm.h>
 
 #include "player.h"
 
 class MoveResult;
 class XML_Helper;
+class City;
 
 //! A local human Player.
 /** 
@@ -46,7 +47,7 @@ class RealPlayer : public Player
 {
     public:
         // CREATORS
-        RealPlayer(std::string name, Uint32 armyset, SDL_Color color, 
+        RealPlayer(std::string name, guint32 armyset, Gdk::Color color, 
 		   int width, int height, Player::Type type = Player::HUMAN, 
 		   int player_no = -1);
         RealPlayer(const Player&);
