@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -128,7 +128,7 @@ bool RecentlyPlayedGameList::load(std::string tag, XML_Helper* helper)
   return false;
 }
 
-void RecentlyPlayedGameList::addNetworkedEntry(GameScenario *game_scenario, std::string host, Uint32 port)
+void RecentlyPlayedGameList::addNetworkedEntry(GameScenario *game_scenario, std::string host, guint32 port)
 {
   if (Configuration::s_remember_recent_games == false)
     return;
@@ -169,14 +169,6 @@ void RecentlyPlayedGameList::addEntry(GameScenario *game_scenario, std::string f
 	    push_back(g);
 	    break;
 	  }
-      case GameScenario::CAMPAIGN:
-	  {
-	    RecentlyPlayedCampaignGame *g = NULL;
-	    g = new RecentlyPlayedCampaignGame(game_scenario);
-	    g->fillData(filename);
-	    push_back(g);
-	    break;
-	  }
       default:
 	break;
     }
