@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,7 +21,7 @@
 #include <list>
 #include <vector>
 #include <sigc++/trackable.h>
-#include <SDL_types.h>
+#include <gtkmm.h>
 #include "reward.h"
 
 class XML_Helper;
