@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,10 +18,11 @@
 #ifndef ROADLIST_H
 #define ROADLIST_H
 
-#include "road.h"
 #include "LocationList.h"
 #include <sigc++/trackable.h>
 
+class XML_Helper;
+class Road;
 //! A list of Road objects on the game map.
 /** 
  * The roadlist keeps track of the roads located on the game map. It
