@@ -1,10 +1,10 @@
 // Copyright (C) 2001, 2003 Michael Bartl
 // Copyright (C) 2002, 2003, 2004, 2005 Ulf Lorenz
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -26,7 +26,7 @@
 std::string Ruin::d_tag = "ruin";
 
 Ruin::Ruin(Vector<int> pos, std::string name, int type, Stack* occupant, bool searched, bool hidden, Player *owner, bool sage)
-:NamedLocation(pos, RUIN_TILE_WIDTH, name,
+:NamedLocation(pos, Ruin::getWidth(), name,
 	        name + _(" is inhabited by monsters and full of treasure!")), 
     d_searched(searched), 
     d_type(type), d_occupant(occupant), d_hidden(hidden), d_owner(owner), 
@@ -51,10 +51,10 @@ Ruin::Ruin(const Ruin& ruin)
 }
 
 Ruin::Ruin(XML_Helper* helper)
-    :NamedLocation(helper, RUIN_TILE_WIDTH), d_type(0), d_occupant(0), 
+    :NamedLocation(helper, Ruin::getWidth()), d_type(0), d_occupant(0), 
     d_hidden(0), d_owner(0), d_sage(0), d_reward(0)
 {
-    Uint32 ui;
+    guint32 ui;
     std::string type_str;
     helper->getData(type_str, "type");
     d_type = ruinTypeFromString(type_str);
@@ -97,7 +97,7 @@ bool Ruin::save(XML_Helper* helper) const
   retval &= helper->saveData("id", d_id);
   retval &= helper->saveData("x", getPos().x);
   retval &= helper->saveData("y", getPos().y);
-  retval &= helper->saveData("name", getName());
+  retval &= helper->saveData("name", getName(false));
   retval &= helper->saveData("description", getDescription());
   std::string type_str = ruinTypeToString(Ruin::Type(d_type));
   retval &= helper->saveData("type", type_str);
@@ -121,7 +121,7 @@ bool Ruin::load(std::string tag, XML_Helper* helper)
 {
   if (tag == Reward::d_tag)
     {
-	Uint32 t;
+	guint32 t;
 	std::string type_str;
 	helper->getData(type_str, "type");
 	t = Reward::rewardTypeFromString(type_str);
