@@ -1,10 +1,10 @@
 // Copyright (C) 2001, 2003 Michael Bartl
 // Copyright (C) 2002, 2003, 2004, 2005 Ulf Lorenz
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,6 +21,7 @@
 #define RUIN_H
 
 #define DEFAULT_RUIN_NAME  "Ruin"
+#define RUIN_TILE_WIDTH 1
 #include <string>
 #include <sigc++/trackable.h>
 #include "NamedLocation.h"
@@ -142,7 +143,8 @@ class Ruin : public NamedLocation, public sigc::trackable
 
 	bool isUnnamed() {return getName() == getDefaultName() ? true : false;};
 	
-	static std::string getDefaultName() {return DEFAULT_RUIN_NAME;};
+	static std::string getDefaultName() {return _(DEFAULT_RUIN_NAME);};
+	static guint32 getWidth() {return RUIN_TILE_WIDTH;};
 
     private:
         // DATA
@@ -150,7 +152,7 @@ class Ruin : public NamedLocation, public sigc::trackable
         bool d_searched;
 
 	//! The type of the ruin.
-        Uint32 d_type;
+        guint32 d_type;
 
 	//! The keeper of the ruin.
 	/**
