@@ -1,8 +1,8 @@
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,7 +17,7 @@
 
 #include "ruinmap.h"
 
-#include "sdl-draw.h"
+#include "gui/image-helpers.h"
 #include "playerlist.h"
 #include "GraphicsCache.h"
 #include "stacklist.h"
@@ -47,9 +47,9 @@ void RuinMap::draw_ruins (bool show_selected)
       if ((*it)->isHidden() == true && 
           (*it)->getOwner() != Playerlist::getInstance()->getActiveplayer())
         continue;
-      if ((*it)->isFogged(getViewingPlayer()) == true)
+      if ((*it)->isVisible(getViewingPlayer()) == false)
         continue;
-      SDL_Surface *tmp;
+      PixMask *tmp;
       if ((*it)->isSearched())
         tmp = gc->getSmallRuinExploredPic();
       else
@@ -62,18 +62,16 @@ void RuinMap::draw_ruins (bool show_selected)
   
       Vector<int> pos = (*it)->getPos();
       pos = mapToSurface(pos);
-      SDL_Rect r;
-      r.x = pos.x - (tmp->w/2);
-      r.y = pos.y - (tmp->h/2);
-      r.w = tmp->w;
-      r.h = tmp->h;
-      SDL_BlitSurface(tmp, 0, surface, &r);
+      tmp->blit_centered(surface, pos);
       if (show_selected)
         {
           if ((*it)->getId() == ruin->getId()) //is this the selected ruin?
             {
-              Uint32 raw = SDL_MapRGBA(surface->format,255, 255, 255, 255);
-              draw_rect(surface, r.x, r.y, r.x + r.w, r.y + r.h, raw);
+	      Gdk::Color box_color = Gdk::Color();
+	      box_color.set_rgb_p(100,100,100);
+              draw_rect(pos.x - (tmp->get_width()/2), 
+			pos.y - (tmp->get_height()/2), 
+			tmp->get_width(), tmp->get_height(), box_color);
             }
         }
   }
@@ -87,25 +85,23 @@ void RuinMap::draw_temples (bool show_selected)
   for (Templelist::iterator it = Templelist::getInstance()->begin();
       it != Templelist::getInstance()->end(); it++)
   {
-      if ((*it)->isFogged(getViewingPlayer()) == true)
+      if ((*it)->isVisible(getViewingPlayer()) == false)
         continue;
-      SDL_Surface *tmp;
-      tmp = gc->getSmallTemplePic();
   
       Vector<int> pos = (*it)->getPos();
       pos = mapToSurface(pos);
-      SDL_Rect r;
-      r.x = pos.x - (tmp->w/2);
-      r.y = pos.y - (tmp->h/2);
-      r.w = tmp->w;
-      r.h = tmp->h;
-      SDL_BlitSurface(tmp, 0, surface, &r);
+      PixMask *templepic = gc->getSmallTemplePic();
+      templepic->blit_centered(surface, pos);
       if (show_selected)
         {
           if ((*it)->getId() == ruin->getId()) //is this the selected ruin?
             {
-              Uint32 raw = SDL_MapRGBA(surface->format,255, 255, 255, 255);
-              draw_rect(surface, r.x, r.y, r.x + r.w, r.y + r.h, raw);
+	      Gdk::Color box_color = Gdk::Color();
+	      box_color.set_rgb_p(100,100,100);
+              draw_rect(pos.x - (templepic->get_width()/2), 
+			pos.y - (templepic->get_height()/2), 
+			templepic->get_width(), templepic->get_height(), 
+			box_color);
             }
         }
   }
