@@ -1,8 +1,8 @@
-//  Copyright (C) 2008, Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,13 +18,14 @@
 #ifndef SHIELD_H
 #define SHIELD_H
 
-#include <SDL.h>
+#include <gtkmm.h>
 #include <string>
 #include <sigc++/trackable.h>
 #include <sigc++/signal.h>
 
 #include "shieldstyle.h"
 
+struct rgb_shift;
 class Player;
 class XML_Helper;
 class Shieldset;
@@ -41,7 +42,7 @@ class Shield : public std::list<ShieldStyle*>, public sigc::trackable
 	static std::string d_tag; 
 
 	//! The notional player that the Shield goes with.
-	enum ShieldColour {WHITE = 0, GREEN = 1, YELLOW = 2, LIGHT_BLUE = 3,
+	enum Colour {WHITE = 0, GREEN = 1, YELLOW = 2, LIGHT_BLUE = 3,
 	RED = 4, DARK_BLUE = 5, ORANGE = 6, BLACK = 7, NEUTRAL = 8};
 
 	//! Loading constructor.
@@ -58,12 +59,14 @@ class Shield : public std::list<ShieldStyle*>, public sigc::trackable
         virtual ~Shield();
 
         //! Get the player that this shield will belong to.
-	Uint32 getOwner() const {return d_owner;}
+	guint32 getOwner() const {return d_owner;}
 
         //! Returns the colour of the player.
-        SDL_Color getColor() const {return d_color;}
+	Gdk::Color getColor() const {return d_color;}
 
-	SDL_Color getMaskColor() const;
+	Gdk::Color getMaskColor() const;
+
+	struct rgb_shift getMaskColorShifts();
 
 	/**
 	 * Get the default colour for the Player with the given Id.
@@ -78,25 +81,27 @@ class Shield : public std::list<ShieldStyle*>, public sigc::trackable
 	 * @return The default colour associated with the player.
 	 */
 	//! Get standard colour for a player.
-	static SDL_Color get_default_color_for_no(int player_no);
+	static Gdk::Color get_default_color_for_no(int player_no);
 
 	//! Get standard colour for the neutral player.
-	static SDL_Color get_default_color_for_neutral();
+	static Gdk::Color get_default_color_for_neutral();
+
+	static std::string colourToString(const Shield::Colour c);
     protected:
 
 	//! The player of the shield.
 	/**
 	 * Equates to the shieldset.shield.d_colour XML entities in the 
 	 * shieldset configuration file.
-	 * Equates to the Shield::ShieldColour enumeration.
+	 * Equates to the Shield::Colour enumeration.
 	 */
-	Uint32 d_owner;
+	guint32 d_owner;
 
 	//! The player's colour.
 	/**
 	 * Mask portions of images are shaded in this colour.
 	 */
-        SDL_Color d_color;
+	Gdk::Color d_color;
 };
 
 #endif // SHIELD_H
