@@ -1,8 +1,8 @@
-//  Copyright (C) 2008, Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,13 +17,13 @@
 
 #include <iostream>
 #include <expat.h>
-#include <SDL.h>
 #include "rectangle.h"
 #include <sigc++/functors/mem_fun.h>
 
 #include "shieldset.h"
 #include "shieldstyle.h"
 #include "File.h"
+#include "rgb_shift.h"
 
 using namespace std;
 
@@ -32,9 +32,11 @@ std::string Shieldset::d_tag = "shieldset";
 #define debug(x) {cerr<<__FILE__<<": "<<__LINE__<<": "<<x<<endl<<flush;}
 //#define debug(x)
 
-Shieldset::Shieldset(XML_Helper *helper)
+Shieldset::Shieldset(XML_Helper *helper, bool from_private_collection)
     : d_dir("")
 {
+    private_collection = from_private_collection;
+  helper->getData(d_id, "id");
   helper->getData(d_name, "name");
   helper->getData(d_small_width, "small_width");
   helper->getData(d_small_height, "small_height");
@@ -71,7 +73,7 @@ bool Shieldset::loadShield(string tag, XML_Helper* helper)
     return false;
 }
 
-ShieldStyle * Shieldset::lookupShieldByTypeAndColour(Uint32 type, Uint32 owner)
+ShieldStyle * Shieldset::lookupShieldByTypeAndColour(guint32 type, guint32 owner)
 {
   for (iterator it = begin(); it != end(); it++)
     {
@@ -84,27 +86,74 @@ ShieldStyle * Shieldset::lookupShieldByTypeAndColour(Uint32 type, Uint32 owner)
   return NULL;
 }
 
-SDL_Color Shieldset::getColor(Uint32 owner)
+Gdk::Color Shieldset::getColor(guint32 owner)
 {
   for (iterator it = begin(); it != end(); it++)
     {
       if ((*it)->getOwner() == owner)
 	return (*it)->getColor();
     }
-  SDL_Color def;
-  memset (&def, 0, sizeof (def));
-  return def;
+  return Gdk::Color("black");
 }
 
-SDL_Color Shieldset::getMaskColor(Uint32 owner)
+struct rgb_shift Shieldset::getMaskColorShifts(guint32 owner)
 {
+  struct rgb_shift empty;
+  empty.r = 0;
+  empty.g = 0;
+  empty.b = 0;
   for (iterator it = begin(); it != end(); it++)
     {
       if ((*it)->getOwner() == owner)
-	return (*it)->getMaskColor();
+	return (*it)->getMaskColorShifts();
     }
-  SDL_Color def;
-  memset (&def, 0, sizeof (def));
-  return def;
+  return empty;
 }
 
+class ShieldsetLoader
+{
+public:
+    ShieldsetLoader(std::string name, bool p) 
+      {
+	shieldset = NULL;
+	private_collection = p;
+	std::string filename = "";
+	if (private_collection == false)
+	  filename = File::getShieldset(name);
+	else
+	  filename = File::getUserShieldset(name);
+	XML_Helper helper(filename, ios::in, false);
+	helper.registerTag(Shieldset::d_tag, sigc::mem_fun((*this), &ShieldsetLoader::load));
+	if (!helper.parse())
+	  {
+	    std::cerr << "Error, while loading an shieldset. Shieldset Name: ";
+	    std::cerr <<name <<std::endl <<std::flush;
+	  }
+      };
+    bool load(std::string tag, XML_Helper* helper)
+      {
+	if (tag == Shieldset::d_tag)
+	  {
+	    shieldset = new Shieldset(helper, private_collection);
+	    return true;
+	  }
+	return false;
+      };
+    bool private_collection;
+    Shieldset *shieldset;
+};
+Shieldset *Shieldset::create(std::string file, bool private_collection)
+{
+  ShieldsetLoader d(file, private_collection);
+  return d.shieldset;
+}
+void Shieldset::getFilenames(std::list<std::string> &files)
+{
+  for (iterator it = begin(); it != end(); it++)
+    for (Shield::iterator i = (*it)->begin(); i != (*it)->end(); i++)
+      {
+	std::string file = (*i)->getImageName();
+	if (std::find(files.begin(), files.end(), file) == files.end())
+	  files.push_back(file);
+      }
+}
