@@ -1,8 +1,8 @@
-//  Copyright (C) 2008, Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,6 +18,7 @@
 #ifndef SHIELDSET_H
 #define SHIELDSET_H
 
+#include <gtkmm.h>
 #include <string>
 #include <map>
 #include <vector>
@@ -26,7 +27,9 @@
 #include "xmlhelper.h"
 #include "shield.h"
 
+#include "defs.h"
 
+struct rgbshift;
 //! A list of Shield graphic objects in a shield theme.
 /**
  * Every scenario has a shield set; it is the theme of the shield graphics 
@@ -62,33 +65,45 @@ class Shieldset: public std::list<Shield *>, public sigc::trackable
 	 * @param helper  The opened shieldset configuration file to load the
 	 *                Shieldset from.
 	 */
-        Shieldset(XML_Helper* helper);
+        Shieldset(XML_Helper* helper, bool private_collection = false);
+
+	static Shieldset *create(std::string filename, bool private_collection = false);
 	//! Destructor.
         ~Shieldset();
 
 	//! Return the number of pixels high the small shields are.
-	Uint32 getSmallHeight() const {return d_small_height;}
+	guint32 getSmallHeight() const {return d_small_height;}
 
 	//! Return the number of pixels wide the small shields are.
-	Uint32 getSmallWidth() const {return d_small_width;}
+	guint32 getSmallWidth() const {return d_small_width;}
 
 	//! Return the number of pixels high the medium shields are.
-	Uint32 getMediumHeight() const {return d_medium_height;}
+	guint32 getMediumHeight() const {return d_medium_height;}
 
 	//! Return the number of pixels wide the medium shields are.
-	Uint32 getMediumWidth() const {return d_medium_width;}
+	guint32 getMediumWidth() const {return d_medium_width;}
 
 	//! Return the number of pixels the large shields are.
-	Uint32 getLargeHeight() const {return d_large_height;}
+	guint32 getLargeHeight() const {return d_large_height;}
 
 	//! Return the number of pixels wide the large shields are.
-	Uint32 getLargeWidth() const {return d_large_width;}
+	guint32 getLargeWidth() const {return d_large_width;}
 
 	//! Return the total number of shields in this shieldset.
-        Uint32 getSize() const {return size();}
+        guint32 getSize() const {return size();}
 
 	//! Return the name of the Shieldset.
-        std::string getName() const {return d_name;}
+        std::string getName() const {return _(d_name.c_str());}
+
+	//! Get the unique identifier for this shieldset.
+	/**
+	 * Analagous to the shieldset.d_id XML entity in the shieldset
+	 * configuration file.
+	 */
+        guint32 getId() const {return d_id;}
+
+	//! Set the unique identifier for this shieldset.
+        void setId(guint32 id) {d_id = id;}
 
 	//! Set the name of the Shieldset.
         void setName(std::string name) {d_name = name;}
@@ -111,15 +126,22 @@ class Shieldset: public std::list<Shield *>, public sigc::trackable
 	 *         If no Shield object could be found that matches the given
 	 *         parameters, NULL is returned.
 	 */
-	ShieldStyle * lookupShieldByTypeAndColour(Uint32 type, Uint32 colour);
+	ShieldStyle * lookupShieldByTypeAndColour(guint32 type, guint32 colour);
 
-	SDL_Color getColor(Uint32 owner);
-	SDL_Color getMaskColor(Uint32 owner);
+	Gdk::Color getColor(guint32 owner);
+	struct rgb_shift getMaskColorShifts(guint32 owner);
+
+	//! Return whether this is a shieldset in the user's personal dir.
+	bool fromPrivateCollection() {return private_collection;};
+
+	//! get filenames in this shieldset, excepting the configuration file.
+	void getFilenames(std::list<std::string> &filenames);
     private:
 
         //! Callback function to load Shield objects into the Shieldset.
         bool loadShield(std::string tag, XML_Helper* helper);
 
+
 	//! The name of the Shieldset.
 	/**
 	 * This equates to the shieldset.d_name XML entity in the shieldset
@@ -129,6 +151,9 @@ class Shieldset: public std::list<Shield *>, public sigc::trackable
 	 */
         std::string d_name;
 
+	//! A unique numeric identifier among all shieldset.
+	guint32 d_id;
+
 	//! The subdirectory of the Shieldset.
 	/**
 	 * This is the name of the subdirectory that the Shieldset files are
@@ -142,42 +167,45 @@ class Shieldset: public std::list<Shield *>, public sigc::trackable
 	 * Equates to the shieldset.d_small_height XML entity in the shieldset 
 	 * configuration file.
 	 */
-	Uint32 d_small_height;
+	guint32 d_small_height;
 
 	//! The number of pixels wide the small shield occupies onscreen.
 	/**
 	 * Equates to the shieldset.d_small_width XML entity in the shieldset 
 	 * configuration file.
 	 */
-	Uint32 d_small_width;
+	guint32 d_small_width;
 
 	//! The number of pixels high the medium shield occupies onscreen.
 	/**
 	 * Equates to the shieldset.d_medium_height XML entity in the shieldset 
 	 * configuration file.
 	 */
-	Uint32 d_medium_height;
+	guint32 d_medium_height;
 
 	//! The number of pixels wide the medium shield occupies onscreen.
 	/**
 	 * Equates to the shieldset.d_medium_width XML entity in the shieldset 
 	 * configuration file.
 	 */
-	Uint32 d_medium_width;
+	guint32 d_medium_width;
 
 	//! The number of pixels high the large shield occupies onscreen.
 	/**
 	 * Equates to the shieldset.d_large_height XML entity in the shieldset 
 	 * configuration file.
 	 */
-	Uint32 d_large_height;
+	guint32 d_large_height;
 
 	//! The number of pixels wide the large shield occupies onscreen.
 	/**
 	 * Equates to the shieldset.d_large_width XML entity in the shieldset 
 	 * configuration file.
 	 */
-	Uint32 d_large_width;
+	guint32 d_large_width;
+
+	//! Whether this is a system shieldset, or one that the user made.
+	bool private_collection;
 };
 
 #endif // SHIELDSET_H
