@@ -1,8 +1,8 @@
-//  Copyright (C) 2008, Ben Asselstine
+//  Copyright (C) 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -17,8 +17,6 @@
 
 #include <iostream>
 #include <expat.h>
-#include <SDL_image.h>
-#include <SDL.h>
 #include "rectangle.h"
 #include <sigc++/functors/mem_fun.h>
 
@@ -26,6 +24,7 @@
 #include "armyset.h"
 #include "File.h"
 #include "defs.h"
+#include "rgb_shift.h"
 
 using namespace std;
 
@@ -50,23 +49,32 @@ void Shieldsetlist::deleteInstance()
     s_instance = 0;
 }
 
-Shieldsetlist::Shieldsetlist()
-{
-    // load all shieldsets
-    std::list<std::string> shieldsets = File::scanShieldsets();
 
+void Shieldsetlist::loadShieldsets(std::list<std::string> shieldsets, bool priv)
+{
     for (std::list<std::string>::const_iterator i = shieldsets.begin(); 
 	 i != shieldsets.end(); i++)
       {
-        loadShieldset(*i);
+        loadShieldset(*i, priv);
 	iterator it = end();
 	it--;
 	(*it)->setSubDir(*i);
 	d_dirs[(*it)->getName()] = *i;
 	d_shieldsets[*i] = *it;
+	d_shieldsetids[(*it)->getId()] = *it;
       }
 }
 
+Shieldsetlist::Shieldsetlist()
+{
+    // load all shieldsets
+    std::list<std::string> shieldsets = File::scanShieldsets();
+    loadShieldsets(shieldsets, false);
+    shieldsets = File::scanUserShieldsets();
+    loadShieldsets(shieldsets, true);
+
+}
+
 Shieldsetlist::~Shieldsetlist()
 {
   for (iterator it = begin(); it != end(); it++)
@@ -81,58 +89,47 @@ std::list<std::string> Shieldsetlist::getNames()
   return names;
 }
 
-bool Shieldsetlist::load(std::string tag, XML_Helper *helper)
-{
-  if (tag == Shieldset::d_tag)
-    {
-      Shieldset *shieldset = new Shieldset(helper);
-      push_back(shieldset); 
-    }
-  return true;
-}
-
-bool Shieldsetlist::loadShieldset(std::string name)
+bool Shieldsetlist::loadShieldset(std::string name, bool p)
 {
   debug("Loading shieldset " <<name);
 
-  XML_Helper helper(File::getShieldset(name), ios::in, false);
+  Shieldset *shieldset = Shieldset::create(name, p);
+  if (!shieldset)
+    return false;
 
-  helper.registerTag(Shieldset::d_tag, sigc::mem_fun((*this), &Shieldsetlist::load));
-
-  if (!helper.parse())
+  if (d_shieldsetids.find(shieldset->getId()) != d_shieldsetids.end())
     {
-      std::cerr << "Error, while loading a shieldset. Shieldset Name: ";
-      std::cerr <<name <<std::endl <<std::flush;
-      exit(-1);
+      Shieldset *s = (*d_shieldsetids.find(shieldset->getId())).second;
+      cerr << "Error!  shieldset: `" << shieldset->getName() << 
+	"' shares a duplicate shieldset id with `" << File::getShieldset(s) << 
+	"'.  Skipping." << endl;
+      delete shieldset;
+      return false;
     }
+    
+  push_back(shieldset);
 
   return true;
 }
         
-SDL_Color Shieldsetlist::getColor(std::string shieldset, Uint32 owner)
+Gdk::Color Shieldsetlist::getColor(guint32 shieldset, guint32 owner)
 {
   Shieldset *s = getShieldset(shieldset);
   if (!s)
-    {
-      SDL_Color def;
-      memset (&def, 0, sizeof (def));
-      return def;
-    }
+    return Gdk::Color("black");
   return s->getColor(owner);
 }
 
-SDL_Color Shieldsetlist::getMaskColor(std::string shieldset, Uint32 owner)
+struct rgb_shift Shieldsetlist::getMaskColorShifts(guint32 shieldset, guint32 owner)
 {
+  struct rgb_shift empty;
+  empty.r = 0; empty.g = 0; empty.b = 0;
   Shieldset *s = getShieldset(shieldset);
   if (!s)
-    {
-      SDL_Color def;
-      memset (&def, 0, sizeof (def));
-      return def;
-    }
-  return s->getMaskColor(owner);
+    return empty;
+  return s->getMaskColorShifts(owner);
 }
-ShieldStyle *Shieldsetlist::getShield(std::string shieldset, Uint32 type, Uint32 colour)
+ShieldStyle *Shieldsetlist::getShield(guint32 shieldset, guint32 type, guint32 colour)
 {
   Shieldset *s = getShieldset(shieldset);
   if (!s)
