@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,6 +18,7 @@
 #ifndef SHIELDSETLIST_H
 #define SHIELDSETLIST_H
 
+#include <gtkmm.h>
 #include <string>
 #include <map>
 #include <vector>
@@ -27,6 +28,7 @@
 #include "shield.h"
 #include "shieldset.h"
 
+struct rgbshift;
 
 //! A list of Shieldset objects available to the game.
 /** 
@@ -64,8 +66,8 @@ class Shieldsetlist : public std::list<Shieldset*>, public sigc::trackable
 	/**
 	 * Scan the given shieldset for a Shield of the given type and colour.
 	 *
-	 * @param shieldset  The directory name of the shieldset.  This value
-	 *                   relates to the Shieldset::d_dir member.
+	 * @param shieldset  The id the shieldset.  This value relates to the 
+	 *                   Shieldset::d_id member.
 	 * @param type       The size of the shield to search for.  This value
 	 *                   relates to the Shield::ShieldType enumeration.
 	 * @param colour     The player of the shield.  This value relates to
@@ -75,13 +77,20 @@ class Shieldsetlist : public std::list<Shieldset*>, public sigc::trackable
 	 *         the given parameters.  If no shield could be found, NULL
 	 *         is returned.
 	 */
-	ShieldStyle *getShield(std::string shieldset, Uint32 type, Uint32 colour);
+	ShieldStyle *getShield(guint32 shieldset, guint32 type, guint32 colour);
 
 	//! Return the Shieldset object that is in the given directory.
 	Shieldset *getShieldset(std::string dir) { return d_shieldsets[dir];}
 
-	SDL_Color getColor(std::string shieldset, Uint32 owner);
-	SDL_Color getMaskColor(std::string shieldset, Uint32 owner);
+	Gdk::Color getColor(guint32 shieldset, guint32 owner);
+	struct rgb_shift getMaskColorShifts(guint32 shieldset, guint32 owner);
+
+	//! Return the Shieldset object by the id.
+	/**
+	 * @param id   A unique numeric identifier that identifies the 
+	 *             shieldset among all shieldsets in the shieldsetlist.
+	 */
+	Shieldset *getShieldset(guint32 id) { return d_shieldsetids[id];};
 
     private:
         //! Default Constructor.
@@ -94,14 +103,13 @@ class Shieldsetlist : public std::list<Shieldset*>, public sigc::trackable
         //! Destructor.
         ~Shieldsetlist();
 
-        //! Callback for loading Shieldsets into the Shieldsetlist.
-	bool load(std::string tag, XML_Helper *helper);
-
         //! Loads a specific shieldset by it's directory name.
-        bool loadShieldset (std::string name);
+	bool loadShieldset(std::string name, bool p);
+	void loadShieldsets(std::list<std::string> shieldsets, bool priv);
         
         typedef std::map<std::string, std::string> DirMap;
         typedef std::map<std::string, Shieldset*> ShieldsetMap;
+        typedef std::map<guint32, Shieldset*> ShieldsetIdMap;
 
 	//! A map that provides a subdirectory when supplying a Shieldset name.
         DirMap d_dirs;
@@ -109,6 +117,9 @@ class Shieldsetlist : public std::list<Shieldset*>, public sigc::trackable
 	//! A map that provides a Shieldset when supplying a subdirectory name.
         ShieldsetMap d_shieldsets;
 
+	//! A map that provides a Shieldset when supplying a shieldset id.
+        ShieldsetIdMap d_shieldsetids;
+
         //! A static pointer for the singleton instance.
         static Shieldsetlist* s_instance;
 };
