@@ -2,12 +2,12 @@
 // Copyright (C) 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2005, 2006 Andrea Paternesi
 // Copyright (C) 2004 Thomas Plonka
-// Copyright (C) 2006, 2007, 2008 Ben Asselstine
+// Copyright (C) 2006, 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -29,7 +29,6 @@
 
 #include "GameScenarioOptions.h"
 #include "smallmap.h"
-#include "sdl-draw.h"
 #include "timing.h"
 #include "GameMap.h"
 #include "Configuration.h"
@@ -58,19 +57,23 @@ void SmallMap::draw_selection()
     int w = int(view.w * pixels_per_tile);
     int h = int(view.h * pixels_per_tile);
 
+    int width;
+    int height;
+    surface->get_size(width, height);
     // this is a bit unfortunate.  we require this catch-all
     // so that our selector box isn't too big for the smallmap
-    if (pos.x + w >= surface->w)
-      pos.x = surface->w - w - 1;
-    if (pos.y + h >= surface->h)
-      pos.y = surface->h - h - 1;
+    if (pos.x + w >= width)
+      pos.x = width - w - 1;
+    if (pos.y + h >= height)
+      pos.y = height - h - 1;
 
-    assert(pos.x >= 0 && pos.x + w < surface->w &&
-	   pos.y >= 0 && pos.y + h < surface->h);
+    assert(pos.x >= 0 && pos.x + w < width &&
+	   pos.y >= 0 && pos.y + h < height);
     
-    Uint32 raw = SDL_MapRGB(surface->format, 255, 255, 255);
-    draw_rect(surface, pos.x, pos.y, pos.x + w, pos.y + h, raw);
-    draw_rect(surface, pos.x+1, pos.y+1, pos.x + w-1, pos.y + h-1, raw);
+    Gdk::Color box_color = Gdk::Color();
+    box_color.set_rgb_p(100,100,100);
+    draw_rect(pos.x, pos.y, w, h, box_color);
+    draw_rect(pos.x-1, pos.y-1, w+2,  h+2, box_color);
 }
 
 void SmallMap::center_view_on_tile(Vector<int> pos, bool slide)
@@ -119,7 +122,9 @@ void SmallMap::after_draw()
       draw_cities(false);
       draw_selection();
     }
-  map_changed.emit(get_surface());
+    int width = 0, height = 0;
+    surface->get_size(width, height);
+    map_changed.emit(surface, Gdk::Rectangle(0, 0, width, height));
 }
 
 void SmallMap::mouse_button_event(MouseButtonEvent e)
@@ -185,19 +190,25 @@ void SmallMap::slide_view(Rectangle new_view)
 
 void SmallMap::blank()
 {
-  Uint32 fog_color = SDL_MapRGB(surface->format, 0, 0, 0);
-  int size = int(pixels_per_tile) > 1 ? int(pixels_per_tile) : 1;
-  //fog it up
-  for (int i = 0; i < GameMap::getWidth(); i++)
-    for (int j = 0; j < GameMap::getHeight(); j++)
-      {
-	Vector <int> pos;
-	pos.x = i;
-	pos.y = j;
-	pos = mapToSurface(pos);
-	draw_filled_rect(surface, pos.x, pos.y,
-			 pos.x + size, pos.y + size, fog_color);
-      }
-  map_changed.emit(get_surface());
+  Gdk::Color fog_color = Gdk::Color();
+  fog_color.set_rgb_p(0,0,0);
+  int width = 0;
+  int height = 0;
+  surface->get_size(width, height);
+  surface_gc->set_rgb_fg_color(fog_color);
+  surface->draw_rectangle(surface_gc, true, 0,0,width, height);
+  map_changed.emit(surface, Gdk::Rectangle(0, 0, width, height));
 }
 
+void SmallMap::move_map_in_dir(Vector<int> dir)
+{
+  Rectangle new_view = view;
+  new_view.pos += dir;
+  if (new_view.pos.x + new_view.w >= GameMap::getWidth() ||
+      new_view.pos.y + new_view.h >= GameMap::getHeight() ||
+      new_view.pos.x < 0 || new_view.pos.y < 0)
+    new_view.pos -= dir;
+
+  set_view(new_view);
+  view_changed.emit(view);
+}
