@@ -1,12 +1,12 @@
 // Copyright (C) 2000, 2001, 2003 Michael Bartl
 // Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Ulf Lorenz
 // Copyright (C) 2004, 2005, 2006 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -115,7 +115,7 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
         void nextTurn();
 
         //! Reduces movement points of the Army units in the Stack.
-        void decrementMoves(Uint32 moves);
+        void decrementMoves(guint32 moves);
 
         //! Sets the stack's position to the next point in it's Path.
         void moveOneStep(bool skipping = false);
@@ -149,15 +149,16 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
         
         //! Returns the Path object of the stack.
         Path* getPath() const {return d_path;}
+	void setPath(const Path p);
 
         //! Returns the minimum number of movement points of all Army units.
-        Uint32 getGroupMoves() const;
+        guint32 getGroupMoves() const;
 
 	//! Returns the maximum MP the stack would have if it were on land
-        Uint32 getMaxGroupLandMoves() const;
+        guint32 getMaxGroupLandMoves() const;
 
 	//! Returns the max MP the stack would have if it were in the water
-        Uint32 getMaxGroupBoatMoves() const;
+        guint32 getMaxGroupBoatMoves() const;
 
 	//! Returns true if all Army units in the stack are grouped.
 	bool isGrouped();
@@ -197,7 +198,7 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
         //! Get the first ungrouped Army unit in the Stack.
         Army* getFirstUngroupedArmy() const;
 
-        Army* getArmyById(Uint32 id) const;
+        Army* getArmyById(guint32 id) const;
         
         //! True if the stack contains a Hero unit.  Otherwise, false.
         bool hasHero() const;
@@ -215,7 +216,7 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 	 *                  units in the stack.
 	 */
 	// Return the Ids of all of the Hero units in the Stack.
-        void getHeroes(std::vector<Uint32>& dst) const;
+        void getHeroes(std::vector<guint32>& dst) const;
 
         //! Return the defending status of the stack.
         bool getDefending() const {return d_defending;}
@@ -227,7 +228,7 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
         bool getDeleting() const {return d_deleting;}
 
         //! Return the maximum sight of the stack.
-        Uint32 getMaxSight() const;
+        guint32 getMaxSight() const;
 
         //! Erase the stack, deleting the Army units too.
         void flClear();
@@ -265,7 +266,7 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 	* @return A bitwise OR-ing of the values in Tile::Type.
         */
 	//! Calculate the move bonus for the Stack.
-        Uint32 calculateMoveBonus() const;
+        guint32 calculateMoveBonus() const;
 
 	//! Calculate if the Stack has the gift of flight.
         bool isFlying () const;
@@ -285,7 +286,7 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 	 *         adjacent tile is impossible.
 	 */
 	//! Return the movement points it costs to travel to an adjacent tile.
-	Uint32 calculateTileMovementCost(Vector<int> pos) const;
+	guint32 calculateTileMovementCost(Vector<int> pos) const;
 
 	//! Set each Army unit in the Stack to a grouped state.
 	void group();
@@ -294,7 +295,7 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 	void ungroup();
 
 	//! Count the number of armies in the stack that are selected.
-	Uint32 countGroupedArmies() const;
+	guint32 countGroupedArmies() const;
 
 	//! Returns true if this stack can join the given stack.
 	/**
@@ -323,7 +324,7 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 	bool getFortified();
 	
 	//! Calculate the number of gold pieces this stack costs this turn.
-	Uint32 getUpkeep();
+	guint32 getUpkeep();
         
 	/**
 	 * This comparator function compares the fight order of two Army units.
@@ -339,28 +340,31 @@ class Stack : public ::UniquelyIdentified, public Movable, public Ownable, publi
 
 	//! Emitted when a stack dies.
         sigc::signal<void, Stack*> sdying;
+	//! Emitted when a stack is about to move one step
+	sigc::signal<void, Stack*> smoving;
+	//! Emitted when a stack has finished moving that one step
+	sigc::signal<void, Stack*> smoved;
+	//! Emitted when a stack is grouped or ungrouped
+	sigc::signal<void, Stack*, bool> sgrouped;
 
 	//! Return a list of army Ids in the stack that can reach the given 
 	//! destination.
-	std::vector<Uint32> determineReachableArmies(Vector<int> dest);
+	std::vector<guint32> determineReachableArmies(Vector<int> dest);
 
 	//! returns how many armies in the stack have visited the given temple.
-	Uint32 countArmiesBlessedAtTemple(Uint32 temple_id);
-
-	//! how many movement points is it for a scout to travel this line.
-	static Uint32 scout(Player *p, Vector<int> src, Vector<int> dest, 
-			    const ArmyProdBase *proto = NULL);
-
-	//! how many movement points is it for the stack to travel this line
-	static Uint32 scout(Stack *stack, Vector<int> dest);
+	guint32 countArmiesBlessedAtTemple(guint32 temple_id);
 
 	void payUpkeep(Player *p);
 
 	bool isMovingToOrFromAShip(Vector<int> dest, bool &on_ship) const;
+
+	Vector<int> getFirstPointInPath() const;
+	Vector<int> getLastPointInPath() const;
+	Vector<int> getLastReachablePointInPath() const;
     private:    
 
 
-	Stack(Uint32 id, Player* player, Vector<int> pos);
+	Stack(guint32 id, Player* player, Vector<int> pos);
 
         //! Callback for loading the stack
         bool load(std::string tag, XML_Helper* helper);
