@@ -2,12 +2,12 @@
 // Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2005 Andrea Paternesi
 // Copyright (C) 2004 John Farrell
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007, 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -21,7 +21,9 @@
 //  02110-1301, USA.
 
 #include "config.h"
+#include "signal.h"
 #include <sigc++/functors/mem_fun.h>
+#include <sigc++/adaptors/bind.h>
 #include <assert.h>
 #include <algorithm>
 
@@ -34,6 +36,7 @@
 #include "Item.h"
 #include "hero.h"
 #include "Backpack.h"
+#include "LocationList.h"
 
 std::string Stacklist::d_tag = "stacklist";
 using namespace std;
@@ -48,16 +51,18 @@ Stack* Stacklist::getObjectAt(int x, int y)
         pit != Playerlist::getInstance()->end(); pit++)
     {
         Stacklist* mylist = (*pit)->getStacklist();
-        for (const_iterator it = mylist->begin(); it !=mylist->end(); it++)
-            if (((*it)->getPos().x == x) && ((*it)->getPos().y == y))
-                return *it;
+	Stack *s1 = NULL;
+	Stack *s2 = NULL;
+	mylist->getObjectAt(Vector<int>(x,y), s1, s2);
+	if (s1)
+	  return s1;
+	else if (s2)
+	  return s2;
     }
-
     return 0;
-
 }
 
-Vector<int> Stacklist::getPosition(Uint32 id)
+Vector<int> Stacklist::getPosition(guint32 id)
 {
     for (Playerlist::iterator pit = Playerlist::getInstance()->begin();
         pit != Playerlist::getInstance()->end(); pit++)
@@ -75,16 +80,20 @@ Vector<int> Stacklist::getPosition(Uint32 id)
 //We only expect one ambiguity at a time with stacks of the same player. This
 //never happens except when a stack comes to halt on another stack during
 //long movements
+//It also happens when two stacks fight.
 Stack* Stacklist::getAmbiguity(Stack* s)
 {
     for (Playerlist::iterator pit = Playerlist::getInstance()->begin();
         pit != Playerlist::getInstance()->end(); pit++)
     {
         Stacklist* mylist = (*pit)->getStacklist();
-        for (const_iterator it = mylist->begin(); it != mylist->end();it++)
-            if ((s->getPos().x == (*it)->getPos().x)
-                && (s->getPos().y == (*it)->getPos().y) && (s != *it))
-                return (*it);
+	Stack *s1 = NULL;
+	Stack *s2 = NULL;
+	mylist->getObjectAt(s->getPos(), s1, s2);
+	if (s1 && s1->getId() != s->getId())
+	  return s1;
+	else if (s2 && s2->getId() != s->getId())
+	  return s2;
     }
 
     return 0;
@@ -103,6 +112,18 @@ bool Stacklist::deleteStack(Stack* s)
     }
     return false;
 }
+bool Stacklist::deleteStack(guint32 id)
+{
+    for (Playerlist::iterator pit = Playerlist::getInstance()->begin();
+        pit != Playerlist::getInstance()->end(); pit++)
+    {
+        Stacklist* mylist = (*pit)->getStacklist();
+        for (const_iterator it = mylist->begin(); it != mylist->end(); it++)
+            if ((*it)->getId() == id)
+                return mylist->flRemove(*it);
+    }
+    return false;
+}
 
 void Stacklist::payUpkeep(Player *p)
 {
@@ -175,7 +196,7 @@ unsigned int Stacklist::countArmies()
 
 unsigned int Stacklist::countHeroes()
 {
-  std::vector<Uint32> heroes;
+  std::vector<guint32> heroes;
   getHeroes(heroes);
   return heroes.size();
 }
@@ -190,7 +211,7 @@ Stacklist::Stacklist(Stacklist *stacklist)
 {
     for (iterator it = stacklist->begin(); it != stacklist->end(); it++)
     {
-        push_back(*it);
+        add(new Stack(**it));
     }
 }
 
@@ -204,6 +225,19 @@ Stacklist::Stacklist(XML_Helper* helper)
 
 Stacklist::~Stacklist()
 {
+  //disconnect the signals
+  for (ConnectionMap::iterator it = d_connections.begin(); 
+       it != d_connections.end(); it++)
+    {
+      std::list<sigc::connection> list = (*it).second;
+      for (std::list<sigc::connection>::iterator lit = list.begin(); lit != list.end(); lit++)
+	(*lit).disconnect();
+    }
+  for (Stacklist::iterator it = begin(); it != end(); it++)
+    {
+      it = flErase(it);
+    }
+
 }
 
 Stack* Stacklist::getNextMovable()
@@ -249,7 +283,7 @@ Stack* Stacklist::getNextMovable()
 	return d_activestack;
 }
 
-Stack *Stacklist::getStackById(Uint32 id)
+Stack *Stacklist::getStackById(guint32 id)
 {
   for (Stacklist::iterator i = begin(), e = end(); i != e; ++i)
     if ((*i)->getId() == id)
@@ -258,7 +292,7 @@ Stack *Stacklist::getStackById(Uint32 id)
   return 0;
 }
 
-Stack *Stacklist::getArmyStackById(Uint32 army)
+Stack *Stacklist::getArmyStackById(guint32 army)
 {
   for (Stacklist::iterator i = begin(), e = end(); i != e; ++i)
     if ((*i)->getArmyById(army))
@@ -287,8 +321,18 @@ Stacklist::iterator Stacklist::flErase(iterator object)
     return erase(object);
 }
 
+bool Stacklist::flRemove(guint32 id)
+{
+  Stack *s = getStackById(id);
+  if (s == NULL)
+    return false;
+  return flRemove(s);
+}
+
 bool Stacklist::flRemove(Stack* object)
 {
+  if (object == NULL)
+    return false;
     debug("removing stack with id " << object->getId() << endl);
     iterator stackit = find(begin(), end(), object);
     if (stackit != end())
@@ -296,10 +340,12 @@ bool Stacklist::flRemove(Stack* object)
         if (d_activestack == object)
             d_activestack = 0;
 	assert (object->getId() == (*stackit)->getId());
+	deletePositionFromMap(object);
         delete object;
         erase(stackit);
         return true;
     }
+
     return false;
 }
 
@@ -336,7 +382,7 @@ bool Stacklist::enoughMoves() const
 
 bool Stacklist::load(string tag, XML_Helper* helper)
 {
-    static Uint32 active = 0;
+    static guint32 active = 0;
     
     if (tag == Stacklist::d_tag)
     {
@@ -352,7 +398,7 @@ bool Stacklist::load(string tag, XML_Helper* helper)
             d_activestack = s;
         }
 
-        push_back(s);
+        add(s);
         return true;
     }
 
@@ -367,65 +413,25 @@ Stack* Stacklist::getOwnObjectAt(int x, int y)
   return 0;
 }
 
-std::list<Hero*> Stacklist::getTopHeroes(int num)
-{
-  std::list<Hero*> result;
-  std::vector<Uint32> hero_ids;
-
-  if (num == 0)
-    return result;
-
-  //load up a stack with all the heroes we have
-  Stack *stack = Stack::createNonUniqueStack(NULL, Vector<int>(1,1));
-  if (!stack)
-    return result;
-
-  getHeroes(hero_ids);
-  for (std::vector<Uint32>::iterator it = hero_ids.begin(); 
-       it != hero_ids.end(); it++)
-    {
-      Stack *hero_stack = getArmyStackById(*it);
-      Hero *hero = dynamic_cast<Hero*>(hero_stack->getArmyById(*it));
-      stack->push_back(new Hero(*hero));
-    }
-  //now we yank out the top NUM heroes and put them in our list.
-  if (num == -1)
-    num = hero_ids.size();
-  for (int i = 0 ; i < num; i++)
-    {
-      Hero *hero = dynamic_cast<Hero*>(stack->getStrongestHero());
-      if (hero)
-	{
-	  result.push_back(hero);
-	  stack->erase(find (stack->begin(), stack->end(), hero));
-	  if (stack->size() == 0)
-	    break;
-	}
-    }
-  stack->flClear();
-  delete stack;
-  return result;
-}
-
-void Stacklist::getHeroes(std::vector<Uint32>& dst)
+void Stacklist::getHeroes(std::vector<guint32>& dst)
 {
   for (Stacklist::iterator it = begin(); it != end(); it++)
     (*it)->getHeroes(dst);
 }
 
-void Stacklist::collectTaxes(Player *p, Uint32 num_cities)
+void Stacklist::collectTaxes(Player *p, guint32 num_cities)
 {
-  std::vector<Uint32> hero_ids;
+  std::vector<guint32> hero_ids;
   getHeroes(hero_ids);
 
   //now let's see if we have any items that give us gold per city
-  for (std::vector<Uint32>::iterator it = hero_ids.begin(); 
+  for (std::vector<guint32>::iterator it = hero_ids.begin(); 
        it != hero_ids.end(); it++)
     {
       Stack *stack = getArmyStackById(*it);
       Army *army = stack->getArmyById(*it);
       Hero *hero = static_cast<Hero*>(army);
-      Uint32 bonus = hero->getBackpack()->countGoldBonuses();
+      guint32 bonus = hero->getBackpack()->countGoldBonuses();
       p->addGold(bonus * num_cities);
     }
 }
@@ -440,14 +446,14 @@ void Stacklist::collectTaxes(Player *p, Uint32 num_cities)
 bool Stacklist::canJumpOverTooLargeStack(Stack *s)
 {
   bool found = false;
-  Uint32 mp = s->getGroupMoves();
+  guint32 mp = s->getGroupMoves();
   for (Path::iterator it = s->getPath()->begin(); it != s->getPath()->end(); it++)
     {
-      Uint32 moves = s->calculateTileMovementCost(**it);
+      guint32 moves = s->calculateTileMovementCost(*it);
       if (moves > mp)
 	return false;
       mp -= moves;
-      Stack *another_stack = getObjectAt(**it);
+      Stack *another_stack = getObjectAt(*it);
       if (another_stack)
 	{
 	  if (another_stack->getOwner() != s->getOwner())
@@ -467,4 +473,163 @@ bool Stacklist::canJumpOverTooLargeStack(Stack *s)
   return found;
 }
 
+std::list<Hero*> Stacklist::getHeroes()
+{
+  std::list<Hero*> heroes;
+  std::vector<guint32> hero_ids;
+  getHeroes(hero_ids);
+  for (std::vector<guint32>::iterator it = hero_ids.begin(); 
+       it != hero_ids.end(); it++)
+    {
+        Stack *s = getArmyStackById(*it);
+	if (s)
+	  {
+	    Hero *h = dynamic_cast<Hero*>(s->getArmyById(*it));
+	    if (h)
+	      heroes.push_back(h);
+	  }
+    }
+  return heroes;
+}
+	
+Hero *Stacklist::getNearestHero(Vector<int> pos, int dist)
+{
+  std::list<Hero*> heroes = getHeroes();
+  LocationList<Location*> hero_locales;
+  for (std::list<Hero*>::iterator it = heroes.begin(); it != heroes.end(); it++)
+    {
+      hero_locales.push_back(new Location(getPosition((*it)->getId()), 1));
+    }
+  Location *hero_locale = hero_locales.getNearestObjectBefore(pos, dist);
+  if (hero_locale)
+    {
+      for (std::list<Hero*>::iterator it = heroes.begin(); it != heroes.end(); 
+	   it++)
+	{
+	  if (getPosition((*it)->getId()) == hero_locale->getPos())
+	    return (*it);
+	}
+    }
+  return NULL;
+}
+
+bool Stacklist::addPositionToMap(Stack *stack)
+{
+  if (d_object1.find(stack->getPos()) == d_object1.end())
+    {
+      d_object1[stack->getPos()] = stack;
+      return true;
+    }
+
+  if (d_object2.find(stack->getPos()) == d_object2.end())
+    {
+      d_object2[stack->getPos()] = stack;
+      return true;
+    }
+  
+  return false;
+}
+
+bool Stacklist::deletePositionFromMap(Stack *stack)
+{
+  Stack *found = NULL;
+  PositionMap::iterator it = d_object1.find(stack->getPos());
+  if (it != d_object1.end())
+    {
+      found = (*it).second;
+      if (found->getId() == stack->getId())
+	{
+	  d_object1.erase(it);
+	  //d_object1[stack->getPos()] = NULL;
+	  return true;
+	}
+    }
+
+  it = d_object2.find(stack->getPos());
+  if (it != d_object2.end())
+    {
+      found = (*it).second;
+      if (found->getId() == stack->getId())
+	{
+	  //d_object2[stack->getPos()] = NULL;
+	  d_object2.erase(it);
+	  return true;
+	}
+    }
+  
+  return false;
+}
+
+void Stacklist::add(Stack *stack)
+{
+  push_back(stack);
+  if (stack->getPos() != Vector<int>(-1,-1))
+    {
+      bool added = addPositionToMap(stack);
+      if (!added)
+	assert(1 == 0);
+      std::list<sigc::connection> conn;
+      conn.push_back(stack->smoving.connect
+	 (sigc::mem_fun (this, &Stacklist::on_stack_starts_moving)));
+      conn.push_back(stack->smoved.connect
+	 (sigc::mem_fun (this, &Stacklist::on_stack_stops_moving)));
+      conn.push_back(stack->sdying.connect
+	 (sigc::mem_fun (this, &Stacklist::on_stack_died)));
+      conn.push_back(stack->sgrouped.connect
+	 (sigc::mem_fun (this, &Stacklist::on_stack_grouped)));
+      d_connections[stack] = conn;
+    }
+}
+
+void Stacklist::on_stack_grouped (Stack *stack, bool grouped)
+{
+  sgrouped.emit(stack, grouped);
+}
+void Stacklist::on_stack_died (Stack *stack)
+{
+  deletePositionFromMap(stack);
+  ConnectionMap::iterator it = d_connections.find(stack);
+  if (it != d_connections.end())
+    {
+      std::list<sigc::connection> list = (*it).second;
+      for (std::list<sigc::connection>::iterator lit = list.begin(); lit != list.end(); lit++)
+	(*lit).disconnect();
+    }
+  return;
+}
+void Stacklist::on_stack_starts_moving (Stack *stack)
+{
+  deletePositionFromMap(stack);
+  return;
+}
+void Stacklist::on_stack_stops_moving (Stack *stack)
+{
+  addPositionToMap(stack);
+  return;
+}
+void Stacklist::getObjectAt(Vector<int> pos, Stack *& s1, Stack *&s2)
+{
+  PositionMap::iterator it = d_object1.find(pos);
+  if (it == d_object1.end())
+    s1 = NULL;
+  else
+    s1 = (*it).second;
+  it = d_object2.find(pos);
+  if (it == d_object2.end())
+    s2 = NULL;
+  else
+    s2 = (*it).second;
+}
+        
+void Stacklist::setActivestack(Stack* activestack)
+{
+  d_activestack = activestack;
+}
+
+void Stacklist::drainAllMovement()
+{
+  for (iterator it = begin(); it != end(); it++)
+    for (Stack::iterator ait = (*it)->begin(); ait != (*it)->end(); ait++)
+      (*ait)->decrementMoves((*ait)->getMoves());
+}
 // End of file
