@@ -2,12 +2,12 @@
 // Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2004, 2005 Andrea Paternesi
 // Copyright (C) 2004 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2008 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -27,9 +27,10 @@
 #include <vector>
 #include <string>
 #include <sigc++/trackable.h>
-#include <SDL_types.h>
+#include <gtkmm.h>
 #include "vector.h"
 #include <sstream>
+#include <sigc++/signal.h>
 
 class City;
 class Stack;
@@ -74,6 +75,7 @@ class Stacklist : public std::list<Stack*>, public sigc::trackable
 	 */
         //! Return the stack at position (x,y) or 0 if there is none.
         static Stack* getObjectAt(int x, int y);
+        void getObjectAt(Vector<int> pos, Stack *& s1, Stack *& s2);
 
 	/**
 	 * Scan through every player's Stacklist, for a stack that is located 
@@ -100,7 +102,7 @@ class Stacklist : public std::list<Stack*>, public sigc::trackable
 	 *         returned.
 	 */
         //! Return position of an Army.
-        static Vector<int> getPosition(Uint32 id);
+        static Vector<int> getPosition(guint32 id);
 
         /** 
 	 * This method finds stacks which occupy the same tile.
@@ -123,6 +125,7 @@ class Stacklist : public std::list<Stack*>, public sigc::trackable
 
         //! Searches through the all players Stacklists and deletes the stack.
         static bool deleteStack(Stack* stack);
+	static bool deleteStack(guint32 id);
 
         /** 
 	 * Scan each tile occupied by the given city and return a list of
@@ -156,7 +159,7 @@ class Stacklist : public std::list<Stack*>, public sigc::trackable
          *
          * @param activestack      The stack currently selected by the player.
          */
-        void setActivestack(Stack* activestack) {d_activestack = activestack;}
+        void setActivestack(Stack* activestack);
 
 	/**
 	 * Scan through the list of stacks to find one that is not defending, 
@@ -188,6 +191,8 @@ class Stacklist : public std::list<Stack*>, public sigc::trackable
         //! Erase all stacks from the list, and their contents too.
         void flClear();
 
+	//! Add a stack to the list.
+	void add(Stack *stack);
         /** 
 	 * Erase a Stack from the list, and free the contents of the Stack.
 	 *
@@ -208,6 +213,7 @@ class Stacklist : public std::list<Stack*>, public sigc::trackable
          */
         //! Erase a stack from the list.
         bool flRemove(Stack* stack);
+        bool flRemove(guint32 id);
 
 	/**
 	 * Scan through the Stacklist, for a stack that is located at the 
@@ -229,22 +235,48 @@ class Stacklist : public std::list<Stack*>, public sigc::trackable
         Stack* getOwnObjectAt(Vector<int> point)
 	  { return getOwnObjectAt(point.x, point.y);}
 
-        Stack *getStackById(Uint32 id);
-        Stack *getArmyStackById(Uint32 army);
+        Stack *getStackById(guint32 id);
+        Stack *getArmyStackById(guint32 army);
 
-	void collectTaxes(Player *p, Uint32 num_cities);
+	void collectTaxes(Player *p, guint32 num_cities);
 
 	std::list<Hero*> getTopHeroes(int num);
 
 	static bool canJumpOverTooLargeStack(Stack *s);
+
+	std::list<Hero*> getHeroes();
+
+	Hero *getNearestHero(Vector<int> pos, int dist);
+	
+	sigc::signal<void, Stack*, bool> sgrouped;
+
+	//! remove all movement points from every army in every stack.
+	void drainAllMovement();
+
     private:
         //! Callback function for loading.
         bool load(std::string tag, XML_Helper* helper);
 
+	//! Callbacks for when things happen to stack in our list.
+	void on_stack_starts_moving (Stack *s);
+	void on_stack_stops_moving (Stack *s);
+	void on_stack_died (Stack *stack);
+	void on_stack_grouped (Stack *stack, bool grouped);
 
-	void getHeroes(std::vector<Uint32>& dst);
+	void getHeroes(std::vector<guint32>& dst);
 	//! A pointer to the currently selected Stack.
         Stack* d_activestack;
+
+	//! methods for managing the dual hash maps.
+	bool deletePositionFromMap(Stack *stack);
+	bool addPositionToMap(Stack *s);
+	//! a hash map of where the stacks are on the map.
+	typedef std::map<Vector<int>, Stack*> PositionMap;
+	PositionMap d_object1;
+	PositionMap d_object2;
+	typedef std::map<Stack *, std::list<sigc::connection> > ConnectionMap;
+	ConnectionMap d_connections;
+
 };
 
 #endif // STACKLIST_H
