@@ -1,12 +1,12 @@
 // Copyright (C) 2001, 2003 Michael Bartl
 // Copyright (C) 2002, 2003, 2004, 2005, 2006 Ulf Lorenz
 // Copyright (C) 2006 Andrea Paternesi
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -27,7 +27,7 @@
 std::string Temple::d_tag = "temple";
 
 Temple::Temple(Vector<int> pos, std::string name, int type)
-:NamedLocation(pos, TEMPLE_TILE_WIDTH, name,
+:NamedLocation(pos, Temple::getWidth(), name,
 	       name + _(" can bless your armies or give you quests.")), 
     d_type(type)
 {
@@ -41,7 +41,7 @@ Temple::Temple(Vector<int> pos, std::string name, int type)
 }
 
 Temple::Temple(XML_Helper* helper)
-    :NamedLocation(helper, TEMPLE_TILE_WIDTH)
+    :NamedLocation(helper, Temple::getWidth())
 {
     //mark the location on the game map as occupied by a temple
     helper->getData(d_type, "type");
@@ -70,7 +70,7 @@ bool Temple::save(XML_Helper* helper) const
     retval &= helper->saveData("id", d_id);
     retval &= helper->saveData("x", getPos().x);
     retval &= helper->saveData("y", getPos().y);
-    retval &= helper->saveData("name", getName());
+    retval &= helper->saveData("name", getName(false));
     retval &= helper->saveData("description", getDescription());
     retval &= helper->saveData("type", d_type);
     retval &= helper->closeTag();
