@@ -1,11 +1,11 @@
 // Copyright (C) 2000, 2001, 2003 Michael Bartl
 // Copyright (C) 2001, 2003, 2004, 2005 Ulf Lorenz
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 // Copyright (C) 2007 Ole Laursen
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -85,14 +85,14 @@ bool Templelist::load(std::string tag, XML_Helper* helper)
     //what has happened?
         return false;
     
-    push_back(new Temple(helper));
+    add(new Temple(helper));
 
     return true;
 }
 
 static bool isFogged(void *t)
 {
-  return ((Temple*)t)->isFogged(Playerlist::getActiveplayer());
+  return ((Temple*)t)->isVisible(Playerlist::getActiveplayer()) == false;
 }
 
 Temple * Templelist::getNearestVisibleTemple(const Vector<int>& pos)
