@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,8 +18,6 @@
 #include <iostream>
 #include <algorithm>
 #include <expat.h>
-#include <SDL_image.h>
-#include <SDL.h>
 #include "rectangle.h"
 #include "ucompose.hpp"
 #include <sigc++/functors/mem_fun.h>
@@ -27,6 +25,7 @@
 #include "tilesetlist.h"
 #include "File.h"
 #include "defs.h"
+#include "tileset.h"
 
 using namespace std;
 
@@ -54,30 +53,8 @@ void Tilesetlist::deleteInstance()
 Tilesetlist::Tilesetlist()
 {
     // load all tilesets
-    std::list<std::string> tilesets = File::scanTilesets();
-
-    for (std::list<std::string>::const_iterator i = tilesets.begin(); 
-	 i != tilesets.end(); i++)
-      {
-        if (loadTileset(*i) == true)
-	  {
-	    iterator it = end();
-	    it--;
-	    (*it)->setSubDir(*i);
-	    d_dirs[String::ucompose("%1 %2", (*it)->getName(), (*it)->getTileSize())] = *i;
-	    d_tilesets[*i] = *it;
-	  }
-	else
-	  {
-	    //we failed validation
-	    iterator it = end();
-	    it--;
-	    fprintf (stderr, "tileset `%s' fails validation. skipping.\n",
-		     (*it)->getName().c_str());
-	    delete *it;
-	    erase (it);
-	  }
-      }
+    loadTilesets(File::scanTilesets(), false);
+    loadTilesets(File::scanUserTilesets(), true);
 }
 
 Tilesetlist::~Tilesetlist()
@@ -86,7 +63,7 @@ Tilesetlist::~Tilesetlist()
     delete (*it);
 }
 
-void Tilesetlist::getSizes(std::list<Uint32> &sizes)
+void Tilesetlist::getSizes(std::list<guint32> &sizes)
 {
   for (iterator i = begin(); i != end(); i++)
     {
@@ -103,7 +80,7 @@ std::list<std::string> Tilesetlist::getNames()
   return names;
 }
 
-std::list<std::string> Tilesetlist::getNames(Uint32 tilesize)
+std::list<std::string> Tilesetlist::getNames(guint32 tilesize)
 {
   std::list<std::string> names;
   for (iterator it = begin(); it != end(); it++)
@@ -122,30 +99,84 @@ bool Tilesetlist::load(std::string tag, XML_Helper *helper)
   return true;
 }
 
-bool Tilesetlist::loadTileset(std::string name)
+bool Tilesetlist::loadTileset(std::string name, bool from_private_collection)
 {
   debug("Loading tileset " <<name);
-
-  XML_Helper helper(File::getTileset(name), ios::in, false);
-
-  helper.registerTag(Tileset::d_tag, sigc::mem_fun((*this), &Tilesetlist::load));
-
-  if (!helper.parse())
-    {
-      std::cerr << "Error, while loading a tileset. Tileset Name: ";
-      std::cerr <<name <<std::endl <<std::flush;
-      exit(-1);
-    }
-
-  iterator it = end();
-  it--;
-  if ((*it)->validate() == false)
+  Tileset *tileset = Tileset::create(name, from_private_collection);
+  if (tileset == NULL)
     return false;
-
+  if (tileset->validate() == false)
+    {
+      cerr<< "Error!  Tileset: `" << File::getTileset(tileset) <<
+	"' fails validation.  Skipping.\n",
+      delete tileset;
+      return false;
+    }
+  if (d_tilesetids.find(tileset->getId()) != d_tilesetids.end())
+    {
+      Tileset *t = (*d_tilesetids.find(tileset->getId())).second;
+      cerr << "Error!  tileset: `" << tileset->getName() << 
+	"' shares a duplicate tileset id with `" << File::getTileset(t) << 
+	"'.  Skipping." << endl;
+      delete tileset;
+      return false;
+    }
+  push_back(tileset); 
   return true;
 }
 
-std::string Tilesetlist::getTilesetDir(std::string name, Uint32 tilesize)
+std::string Tilesetlist::getTilesetDir(std::string name, guint32 tilesize)
 {
   return d_dirs[String::ucompose("%1 %2", name, tilesize)];
 }
+
+void Tilesetlist::loadTilesets(std::list<std::string> tilesets, bool priv)
+{
+  for (std::list<std::string>::const_iterator i = tilesets.begin(); 
+       i != tilesets.end(); i++)
+    {
+      if (loadTileset(*i, priv) == true)
+	{
+	  iterator it = end();
+	  it--;
+	  (*it)->setSubDir(*i);
+	  d_dirs[String::ucompose("%1 %2", (*it)->getName(), (*it)->getTileSize())] = *i;
+	  d_tilesets[*i] = *it;
+	  d_tilesetids[(*it)->getId()] = *it;
+	}
+    }
+}
+
+int Tilesetlist::getNextAvailableId(int after)
+{
+  std::list<guint32> ids;
+  std::list<std::string> tilesets = File::scanTilesets();
+  //there might be IDs in invalid tilesets.
+  for (std::list<std::string>::const_iterator i = tilesets.begin(); 
+       i != tilesets.end(); i++)
+    {
+      Tileset *tileset = Tileset::create(*i, false);
+      if (tileset != NULL)
+	{
+	  ids.push_back(tileset->getId());
+	  delete tileset;
+	}
+    }
+  tilesets = File::scanUserTilesets();
+  for (std::list<std::string>::const_iterator i = tilesets.begin(); 
+       i != tilesets.end(); i++)
+    {
+      Tileset *tileset = Tileset::create(*i, true);
+      if (tileset != NULL)
+	{
+	  ids.push_back(tileset->getId());
+	  delete tileset;
+	}
+    }
+  for (guint32 i = after + 1; i < 1000000; i++)
+    {
+      if (find(ids.begin(), ids.end(), i) == ids.end())
+	return i;
+    }
+  return -1;
+}
