@@ -1,8 +1,8 @@
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -16,29 +16,32 @@
 //  02110-1301, USA.
 
 #include <iostream>
+#include <iomanip>
+
 
 #include "tilestyle.h"
+#include "ucompose.hpp"
 #include "defs.h"
 
 std::string TileStyle::d_tag = "tilestyle";
 using namespace std;
 
 TileStyle::TileStyle()
+  : d_image(0)
 {
-  d_pixmap = NULL;
 }
 
 TileStyle::TileStyle(XML_Helper* helper)
+  : d_image(0)
 {
   int i;
-  d_pixmap = NULL;
   char *end = NULL;
   std::string idstr;
 
   helper->getData(idstr, "id");
   unsigned long int val = 0;
   val = strtoul (idstr.c_str(), &end, 0);
-  d_id = (Uint32) val;
+  d_id = (guint32) val;
   helper->getData(i, "type");
   d_type = static_cast<TileStyle::Type>(i);
 
@@ -52,15 +55,11 @@ bool TileStyle::save(XML_Helper *helper)
 {
   bool retval = true;
 
-  char *idstr = NULL;
   retval &= helper->openTag(d_tag);
-  if (asprintf (&idstr, "0x%02x", d_id) != -1)
-    {
-      retval &= helper->saveData("id", idstr);
-      free (idstr);
-    }
-  else
-    retval &= false;
+  Glib::ustring idstr;
+  
+  idstr = String::ucompose ("0x%1", Glib::ustring::format(std::hex, std::setfill(L'0'), std::setw(2), d_id));
+  retval &= helper->saveData("id", idstr);
   retval &= helper->saveData("type", d_type);
   retval &= helper->closeTag();
 
