@@ -1,8 +1,8 @@
-// Copyright (C) 2007, 2008 Ben Asselstine
+// Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,9 +18,10 @@
 #ifndef TILESTYLE_H
 #define TILESTYLE_H
 
-#include <SDL.h>
+#include <gtkmm.h>
 
 #include "xmlhelper.h"
+#include "PixMask.h"
 
 //! Describes the look of a Tile.
 /**
@@ -284,16 +285,16 @@ ooooooo
 	void setType(Type type) {d_type = type;}
                 
         //! Get the picture for tile style.
-        SDL_Surface *getPixmap() const {return d_pixmap;}
+	PixMask* getImage() const {return d_image;}
 
         //! Get the id for this tilestyle.
 	/*
 	 * The id is unique among all other tilestyles in the Tileset.
 	 */
-	Uint32 getId() const {return d_id;}
+	guint32 getId() const {return d_id;}
 
 	//! Set the id for this tilestyle.
-	void setId(Uint32 id) {d_id = id;}
+	void setId(guint32 id) {d_id = id;}
  
 	//! Save a TileStyle to an opened tile configuration file.
 	/**
@@ -307,14 +308,14 @@ ooooooo
 	//! Get the name of the another style.
 	static std::string getTypeName(Type type);
 
-	void setPixmap(SDL_Surface *pixmap) {d_pixmap = pixmap;};
+	void setImage(PixMask* image) {d_image = image;};
 
 	//! Return the style type enumeration given the type name.
 	static TileStyle::Type typeNameToType(std::string name);
     private:
         // DATA
 	//! The image of this tilestyle.
-        SDL_Surface* d_pixmap; 
+	PixMask* d_image; 
 
 	//! The type of the tilestyle.
         Type d_type;
@@ -326,7 +327,7 @@ ooooooo
 	 * This id shows up in the saved-game file in the lordsawar.map.styles
 	 * XML entity as a hexidecimal number.
 	 */
-	Uint32 d_id;
+	guint32 d_id;
 };
 
 #endif // TILESTYLE_H
