@@ -2,7 +2,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
 #ifndef VECTOREDUNITLIST_H
 #define VECTOREDUNITLIST_H
 
-#include <SDL.h>
+#include <gtkmm.h>
 #include <list>
 #include <string>
 class VectoredUnit;
@@ -186,7 +186,7 @@ class VectoredUnitlist : public std::list<VectoredUnit*>, public sigc::trackable
 	 * @return The number of VectoredUnit objects that are being vectored
 	 *         to the given position on the game map.
 	 */
-        Uint32 getNumberOfVectoredUnitsGoingTo(Vector<int> pos);
+        guint32 getNumberOfVectoredUnitsGoingTo(Vector<int> pos);
 
 	//! Change the destination of vectored units as they are "in the air".
 	/**
@@ -199,7 +199,7 @@ class VectoredUnitlist : public std::list<VectoredUnit*>, public sigc::trackable
 	 * @param new_dest A position on the game map to change where the
 	 *                 VectoredUnit objects are going to.
 	 */
-	void changeDestination(City *city, Vector<int> new_dest);
+	bool changeDestination(City *city, Vector<int> new_dest);
 
 	void changeOwnership(Player *old_owner, Player *new_owner);
 
