@@ -1,8 +1,8 @@
-//  Copyright (C) 2007, 2008 Ben Asselstine
+//  Copyright (C) 2007, 2008, 2009 Ben Asselstine
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -16,14 +16,15 @@
 //  02110-1301, USA.
 
 #include "vectormap.h"
+#include "gui/image-helpers.h"
 
-#include "sdl-draw.h"
 #include "city.h"
 #include "citylist.h"
 #include "playerlist.h"
 #include "GraphicsCache.h"
 #include "GameMap.h"
 #include "LocationBox.h"
+#include "shieldsetlist.h"
 
 VectorMap::VectorMap(City *c, enum ShowVectoring v, bool see_opponents_production)
 {
@@ -37,52 +38,47 @@ void VectorMap::draw_planted_standard(Vector<int> flag)
 {
   //it can't possibly be fogged
   GraphicsCache *gc = GraphicsCache::getInstance();
-  SDL_Surface *tmp;
-  tmp = gc->getSmallHeroPic();
 
   Vector<int> start;
   
   start = flag;
   start = mapToSurface(start);
-  start += Vector<int>(int(pixels_per_tile/2),int(pixels_per_tile/2));
-  if (tmp)
-    {
-      SDL_Rect r;
-      r.x = start.x - (tmp->w/2);
-      r.y = start.y - (tmp->h/2);
-      r.w = tmp->w;
-      r.h = tmp->h;
-      SDL_BlitSurface(tmp, 0, surface, &r);
-    }
+      
+  PixMask *heropic = gc->getSmallHeroPic(true);
+  heropic->blit_centered(surface, start);
 }
 
-void VectorMap::draw_city (City *c, Uint32 &type, bool &prod)
+void VectorMap::draw_city (City *c, guint32 &type, bool &prod)
 {
-  if (c->isFogged(getViewingPlayer()))
+  if (c->isVisible(getViewingPlayer()) == false)
     return;
   GraphicsCache *gc = GraphicsCache::getInstance();
-  SDL_Surface *tmp;
-  if (c->isBurnt() == true || (type == 3 && prod == false))
+  PixMask *tmp;
+  if (c->isBurnt() == true)
     tmp = gc->getSmallRuinedCityPic ();
+  //else if(type == 4 && prod == false)
+    //tmp = gc->getProdShieldPic (type, prod);
   else
-    tmp = gc->getProdShieldPic (type, prod);
+    {
+      if (Playerlist::getInstance()->getActiveplayer() != c->getOwner())
+	{
+	  guint32 s = GameMap::getInstance()->getShieldset()->getId();
+	  tmp = gc->getShieldPic (s, 0, c->getOwner()->getId());
+	}
+      else
+	tmp = gc->getProdShieldPic (type, prod);
+    }
 
   Vector<int> start;
   
   start  = c->getPos();
   start = mapToSurface(start);
-  start += Vector<int>(int(pixels_per_tile/2),int(pixels_per_tile/2));
   if (tmp)
     {
-      SDL_Rect r;
-      r.x = start.x - (tmp->w/2);
-      r.y = start.y - (tmp->h/2);
-      r.w = tmp->w;
-      r.h = tmp->h;
-      SDL_BlitSurface(tmp, 0, surface, &r);
+      tmp->blit_centered(surface, start);
     }
 }
-void VectorMap::draw_cities (std::list<City*> citylist, Uint32 type)
+void VectorMap::draw_cities (std::list<City*> citylist, guint32 type)
 {
   bool prod;
 
@@ -93,10 +89,10 @@ void VectorMap::draw_cities (std::list<City*> citylist, Uint32 type)
 	{
 	case CLICK_VECTORS:
 	case CLICK_CHANGES_DESTINATION:
-	  if ((*it)->canAcceptVectoredUnit() == false)
+	  if ((*it)->canAcceptMoreVectoring() == false)
 	    {
-	      prod = false; //this is a ruined city
-	      type = 3;
+	      prod = false; //the inn is full
+	      type = 4;
 	    }
 	  else
 	    {
@@ -119,18 +115,17 @@ void VectorMap::draw_cities (std::list<City*> citylist, Uint32 type)
 
 void VectorMap::draw_vectoring_line(Vector<int> src, Vector<int> dest, bool to)
 {
-  Uint32 color;
   Vector<int> start = src;
   Vector <int> end = dest;
   start = mapToSurface(start);
   end = mapToSurface(end);
-  start += Vector<int>(int(pixels_per_tile/2),int(pixels_per_tile/2));
-  end += Vector<int>(int(pixels_per_tile/2), int(pixels_per_tile/2));
+  Gdk::Color line_color = Gdk::Color();
   if (to) //yellow
-    color = SDL_MapRGBA(surface->format, 252, 236, 32, 255);
+    line_color.set_rgb_p(252.0/255.0, 236.0/255.0, 
+			  32.0/255.0);
   else //orange
-    color = SDL_MapRGBA(surface->format, 252, 160, 0, 255);
-  draw_line(surface, start.x, start.y, end.x, end.y, color);
+    line_color.set_rgb_p(252.0/255.0, 160.0/255.0, 0);
+  draw_line(start.x, start.y, end.x, end.y, line_color);
 }
 void VectorMap::draw_vectoring_line_from_here_to (Vector<int> dest)
 {
@@ -153,7 +148,7 @@ void VectorMap::draw_lines (std::list<City*> srcs, std::list<City*> dests)
     {
       if ((*it)->getVectoring() == Vector<int>(-1, -1))
 	continue;
-      if ((*it)->isFogged(getViewingPlayer()) == true)
+      if ((*it)->isVisible(getViewingPlayer()) == false)
         continue;
       City *c = cl->getNearestObjectBefore((*it)->getVectoring(), 2);
       if (c)
@@ -177,7 +172,7 @@ void VectorMap::draw_lines (std::list<City*> srcs, std::list<City*> dests)
 void VectorMap::after_draw()
 {
   Vector<int> start;
-  Uint32 type = 0;
+  guint32 type = 0;
   bool prod = false;
   Vector<int> end;
   Citylist *cl = Citylist::getInstance();
@@ -240,22 +235,22 @@ void VectorMap::after_draw()
               else if ((*it)->getVectoring() != Vector<int>(-1, -1) &&
                        cl->getNearestCity((*it)->getVectoring(), 2)->getId() ==
                        city->getId() && show_vectoring != SHOW_NO_VECTORING)
-                type = 3;
+                type = 3; 
               //otherwise it's just another city, "away" from me
               else
                 type = 1; //away
 	      //show it as a ruined city if we can't vector to it.
-	      if (click_action == CLICK_VECTORS && (*it)->canAcceptVectoredUnit() == false)
+	      if (click_action == CLICK_VECTORS && (*it)->canAcceptMoreVectoring() == false)
 		{
 		  prod = false;
-		  type = 3;
+		  type = 4; //the inn is full
 		}
 	      if (click_action == CLICK_CHANGES_DESTINATION)
 		{
-		  if ((*it)->canAcceptVectoredUnits (sources.size()) == false)
+		  if ((*it)->canAcceptMoreVectoring (sources.size()) == false)
 		    {
-		      prod = false; //this is a ruined city
-		      type = 3;
+		      prod = false; //the inn is full
+		      type = 4;
 		    }
 		}
 	    }
@@ -263,7 +258,7 @@ void VectorMap::after_draw()
 	}
       else
 	{
-	  type = 3;
+	  type = 2;
 	  prod = false;
 	  draw_city ((*it), type, prod); //an impossible combo
 	}
@@ -281,7 +276,7 @@ void VectorMap::after_draw()
       // draw lines from origination to city/planted standard
       for (Citylist::iterator it = cl->begin(); it != cl->end(); it++)
 	{
-	  if ((*it)->isFogged(getViewingPlayer()) == true)
+	  if ((*it)->isVisible(getViewingPlayer()) == false)
 	    continue;
 	  if ((*it)->getOwner() != city->getOwner())
 	    continue;
@@ -304,11 +299,28 @@ void VectorMap::after_draw()
   if (flag.x != -1 && flag.y != -1)
     draw_planted_standard(flag);
 
+  draw_square_around_active_city();  
   map_changed.emit(surface);
 }
 
+void VectorMap::draw_square_around_active_city()
+{
+  Gdk::Color box_color = Gdk::Color();
+  box_color.set_rgb_p(252.0/255.0, 1.0, 1.0);
+  Vector<int> start = city->getPos();
+  start = mapToSurface(start);
+  std::string s = GameMap::getInstance()->getShieldset()->getSubDir();
+  Shieldset *ss = Shieldsetlist::getInstance()->getShieldset(s);
+  guint32 width = ss->getSmallWidth();
+  guint32 height = ss->getSmallHeight();
+  start -= Vector<int>(width,height)/2;
+  Vector<int> end = start + Vector<int>(width,height);
+  draw_rect (start.x-3, start.y-3, end.x-start.x+4, end.y-start.y+4, box_color);
+}
+
 void VectorMap::mouse_button_event(MouseButtonEvent e)
 {
+  Player *active = Playerlist::getActiveplayer();
   if (e.button == MouseButtonEvent::LEFT_BUTTON && 
       e.state == MouseButtonEvent::PRESSED)
     {
@@ -350,17 +362,17 @@ void VectorMap::mouse_button_event(MouseButtonEvent e)
 	    }
 	  if (dest != city->getVectoring() && dest != Vector<int>(-1, -1))
 	    {
-	      destination_chosen.emit(dest);
-	      Playerlist::getActiveplayer()->vectorFromCity(city, dest);
+	      if (active->vectorFromCity(city, dest) == true)
+		destination_chosen.emit(dest);
 	      setClickAction(CLICK_SELECTS);
-	      draw(Playerlist::getActiveplayer());
+	      draw(active);
 	    }
 	  else if (dest == Vector<int>(-1, -1)) //stop vectoring
 	    {
-	      destination_chosen.emit(dest);
-	      Playerlist::getActiveplayer()->vectorFromCity(city, dest);
+	      if (active->vectorFromCity(city, dest) == true)
+		destination_chosen.emit(dest);
 	      setClickAction(CLICK_SELECTS);
-	      draw(Playerlist::getActiveplayer());
+	      draw(active);
 	    }
 	  break;
 	case CLICK_SELECTS:
@@ -371,7 +383,7 @@ void VectorMap::mouse_button_event(MouseButtonEvent e)
 	  if (nearestCity == NULL)
 	    return;
 	  city = nearestCity;
-	  draw(Playerlist::getActiveplayer());
+	  draw(active);
 	  break;
 	case CLICK_CHANGES_DESTINATION:
 	  nearestCity = cl->getNearestVisibleFriendlyCity(dest, 4);
@@ -399,9 +411,13 @@ void VectorMap::mouse_button_event(MouseButtonEvent e)
 
 	  if (dest == Vector<int>(-1, -1)) //stop vectoring
 	    {
+	      //we were doing change destination,
+	      //and we clicked back on our own city
+	      //this is the same thing as a cancel.
 	      destination_chosen.emit(dest);
 	      setClickAction(CLICK_SELECTS);
-	      draw(Playerlist::getActiveplayer());
+	      draw(active);
+	      return;
 	    }
 	  bool is_source_city = false;
 	  std::list<City*> sources = cl->getCitiesVectoringTo(city);
@@ -415,19 +431,25 @@ void VectorMap::mouse_button_event(MouseButtonEvent e)
 		}
 	    }
 	  //if it's not one of our sources, then select it
+	  //why do we care if it's one of our sources anyway?
 	  if (is_source_city == false)
 	    {
-	      destination_chosen.emit(dest);
-	      Playerlist::getActiveplayer()->changeVectorDestination(city, 
-								     dest);
+	      if (active->changeVectorDestination(city->getPos(), dest) == true)
+		destination_chosen.emit(dest);
 	      setClickAction(CLICK_SELECTS);
-	      draw(Playerlist::getActiveplayer());
+	      draw(active);
 	      if (dest != planted_standard)
 		city = nearestCity;
-	      draw(Playerlist::getActiveplayer());
+	      draw(active);
 	    }
 	  break;
 	}
     }
 
 }
+
+void VectorMap::setCity(City *c)
+{
+  city = c;
+  draw(Playerlist::getActiveplayer());
+}
