@@ -4,7 +4,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -249,7 +249,7 @@ bool XML_Helper::saveData(std::string name, int value)
     return true;
 }
 
-bool XML_Helper::saveData(std::string name, Uint32 value)
+bool XML_Helper::saveData(std::string name, guint32 value)
 {
     //prepend a "d_" to show that this is a data tag
     name = "d_" + name;
@@ -318,7 +318,7 @@ bool XML_Helper::saveData(std::string name, double value)
 /* This is a wrapper for the AMD64 platform */
 bool XML_Helper::saveData(std::string name, unsigned long int value)
 {
-    return saveData(name, static_cast<Uint32>(value));
+    return saveData(name, static_cast<guint32>(value));
 }
 /* End wrapper AMD64 */
 
@@ -495,7 +495,7 @@ bool XML_Helper::getData(int& data, std::string name)
     return true;
 }
 
-bool XML_Helper::getData(Uint32& data, std::string name)
+bool XML_Helper::getData(guint32& data, std::string name)
 {
     //the data tags are stored with leading "d_", so prepend it here
     name = "d_" + name;
@@ -505,12 +505,12 @@ bool XML_Helper::getData(Uint32& data, std::string name)
 
     if (it == d_data.end())
     {
-        std::cerr<<"XML_Helper::getData(Uint32, \"" <<name <<"\") failed\n";
+        std::cerr<<"XML_Helper::getData(guint32, \"" <<name <<"\") failed\n";
         d_failed = true;
         return false;
     }
     
-    data = static_cast<Uint32>(atoi((*it).second.c_str()));
+    data = static_cast<guint32>(atoi((*it).second.c_str()));
     return true;
 
     
@@ -596,7 +596,7 @@ bool XML_Helper::parse()
  * which has led tag_open to already call the callback.
  */
 
-bool XML_Helper::tag_open(std::string tag, std::string version)
+bool XML_Helper::tag_open(std::string tag, std::string version, std::string lang)
 {
     if (d_failed)
         return false;
@@ -610,7 +610,10 @@ bool XML_Helper::tag_open(std::string tag, std::string version)
     //look if the tag starts with "d_". If so, it is a data tag without anything
     //important in between
     if ((tag[0] == 'd') && (tag[1] == '_'))
-        return true;
+      {
+	d_lang[tag] = lang;
+	return true;
+      }
     
     //first of all, look if another important tag has already been opened
     //and call the appropriate callback if so
@@ -638,6 +641,7 @@ bool XML_Helper::tag_open(std::string tag, std::string version)
 
         //clear d_data (we are just setting up a new tag)
         d_data.clear();
+        d_lang.clear();
     }
 
     d_last_opened = tag;
@@ -645,6 +649,23 @@ bool XML_Helper::tag_open(std::string tag, std::string version)
     return true;
 }
 
+bool XML_Helper::lang_check(std::string lang)
+{
+  static char *envlang = getenv("LANG");
+  if (lang == "")
+    return true;
+  if (lang == envlang)
+    return true;
+  //try harder
+  char *first_underscore = strchr (envlang, '_');
+  if (first_underscore)
+    {
+      if (strncmp (lang.c_str(), envlang, first_underscore - envlang) == 0)
+	return true;
+    }
+  return false;
+}
+
 bool XML_Helper::tag_close(std::string tag, std::string cdata)
 {
     if (d_failed)
@@ -656,7 +677,8 @@ bool XML_Helper::tag_close(std::string tag, std::string cdata)
     if ((tag[0] == 'd') && (tag[1] == '_'))
     {
         // save the data (we close a data tag)
-        d_data[tag] = cdata;
+	if (lang_check(d_lang[tag]))
+	  d_data[tag] = cdata;
         return true;    //data tags end here with their execution
     }
 
@@ -682,6 +704,7 @@ bool XML_Helper::tag_close(std::string tag, std::string cdata)
 
     //clear d_data (we are just setting up a new tag)
     d_data.clear();
+    d_lang.clear();
     
     return true;
 }
@@ -697,14 +720,18 @@ void start_handler(void* udata, const XML_Char* name, const XML_Char** atts)
     
     XML_Helper* helper = static_cast<XML_Helper*>(udata);
     std::string version = "";
+    std::string lang = "";
 
     //the only attribute we know and handle are version strings
     if ((atts[0] != 0) && (std::string(atts[0]) == "version"))
         version = std::string(atts[1]);
 
+    if ((atts[0] != 0) && (std::string(atts[0]) == "xml:lang"))
+        lang = std::string(atts[1]);
+
     my_cdata = "";
 
-    error = !helper->tag_open(std::string(name), version);
+    error = !helper->tag_open(std::string(name), version, lang);
 }
 
 //the cdata handler, just sums up the string  s
