@@ -4,7 +4,7 @@
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
-//  the Free Software Foundation; either version 2 of the License, or
+//  the Free Software Foundation; either version 3 of the License, or
 //  (at your option) any later version.
 //
 //  This program is distributed in the hope that it will be useful,
@@ -72,6 +72,7 @@
 #ifndef XML_HELPER_H
 #define XML_HELPER_H
 
+#include <gtkmm.h>
 #include <string>
 #include <iostream>
 #include <fstream>
@@ -79,13 +80,13 @@
 #include <map>
 #include <sigc++/slot.h>
 #include <expat.h>
-#include <SDL.h>
     
 class XML_Helper;
 
 typedef sigc::slot<bool, std::string, XML_Helper*> XML_Slot;
 //return type (bool), parameters tag(string), this(XML_Helper)
 
+//! XML handling class.
 class XML_Helper
 {
     public:
@@ -140,7 +141,7 @@ class XML_Helper
           */
         bool saveData(std::string identifier, const std::string value);
         bool saveData(std::string identifier, const int value);
-        bool saveData(std::string identifier, const Uint32 value);
+        bool saveData(std::string identifier, const guint32 value);
         bool saveData(std::string identifier, const bool value);
         bool saveData(std::string identifier, const double value);
         /* amd64 fix, UL: still neccessary?*/
@@ -187,7 +188,7 @@ class XML_Helper
         bool getData(std::string& data, std::string name);
         bool getData(bool& data, std::string name);
         bool getData(int& data, std::string name);
-        bool getData(Uint32& data, std::string name);
+        bool getData(guint32& data, std::string name);
         bool getData(double& data, std::string name);
 
         //! Returns the version number of the save file
@@ -202,7 +203,7 @@ class XML_Helper
 
         
         //! Used internally for the expat callback
-        bool tag_open(std::string tag, std::string version);
+        bool tag_open(std::string tag, std::string version, std::string lang);
 
         //! Used internally for the expat callback
         bool tag_close(std::string tag, std::string cdata = "");
@@ -212,6 +213,8 @@ class XML_Helper
           * to a line. Used for beautification.
           */
         inline void addTabs();
+
+	bool lang_check(std::string lang);
         
         
         //streams, d_fout and d_fin are used when it comes to file
@@ -230,6 +233,7 @@ class XML_Helper
 
         std::map<std::string, XML_Slot> d_callbacks;
         std::map<std::string, std::string> d_data;
+        std::map<std::string, std::string> d_lang;
         
         std::string d_last_opened;
         std::string d_version;
